/*
 * DO NOT EDIT THIS FILE - it is generated by Glade.
 */

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <string.h>

#include <gdk/gdkkeysyms.h>
#include <gtk/gtk.h>

#include "callbacks.h"
#include "interface-glade.h"
#include "support-glade.h"

GtkWidget*
create_main_window (void)
{
  GtkWidget *main_window;
  GtkWidget *vbox12;
  GtkWidget *menubar_main;
  guint tmp_key;
  GtkWidget *menu_file;
  GtkWidget *menu_file_menu;
  GtkAccelGroup *menu_file_menu_accels;
  GtkWidget *menu_prefs;
  GtkWidget *separator23;
  GtkWidget *quit;
  GtkWidget *menu_view;
  GtkWidget *menu_view_menu;
  GtkAccelGroup *menu_view_menu_accels;
  GtkWidget *menu_searchbar_visible;
  GtkWidget *menu_sidebar_visible;
  GtkWidget *menu_menubar_visible;
  GtkWidget *menu_statusbar_visible;
  GtkWidget *separator24;
  GtkWidget *connection_counters1;
  GtkWidget *connection_counters1_menu;
  GtkAccelGroup *connection_counters1_menu_accels;
  GtkWidget *menu_downloads_visible;
  GtkWidget *menu_uploads_visible;
  GtkWidget *menu_connections_visible;
  GtkWidget *menu_http_stats_visible;
  GtkWidget *menu_http_stats_visible_menu;
  GtkAccelGroup *menu_http_stats_visible_menu_accels;
  GtkWidget *menu_bws_in_visible;
  GtkWidget *menu_bws_out_visible;
  GtkWidget *menu_gnet_stats_visible;
  GtkWidget *menu_gnet_stats_visible_menu;
  GtkAccelGroup *menu_gnet_stats_visible_menu_accels;
  GtkWidget *menu_bws_gin_visible;
  GtkWidget *menu_bws_gout_visible;
  GtkWidget *menu_gnet_leaf_stats_visible;
  GtkWidget *menu_gnet_leaf_stats_visible_menu;
  GtkAccelGroup *menu_gnet_leaf_stats_visible_menu_accels;
  GtkWidget *menu_autohide_bws_gleaf;
  GtkWidget *menu_bws_glin_visible;
  GtkWidget *menu_bws_glout_visible;
  GtkWidget *menu_dht_traffic_stats_visible;
  GtkWidget *menu_dht_traffic_stats_visible_menu;
  GtkAccelGroup *menu_dht_traffic_stats_visible_menu_accels;
  GtkWidget *menu_autohide_bws_dht;
  GtkWidget *menu_bws_dht_in_visible;
  GtkWidget *menu_bws_dht_out_visible;
  GtkWidget *separator20;
  GtkWidget *menu_help;
  GtkWidget *menu_help_menu;
  GtkAccelGroup *menu_help_menu_accels;
  GtkWidget *menu_about;
  GtkWidget *menu_faq;
  GtkWidget *viewport_searchbar;
  GtkWidget *vbox147;
  GtkWidget *hbox179;
  GtkWidget *button_search;
  GtkWidget *combo_search;
  GtkWidget *entry_search;
  GtkWidget *button_search_whats_new;
  guint button_search_passive_key;
  GtkWidget *button_search_passive;
  GtkWidget *hbox2112;
  GtkWidget *frame_search_media_type;
  GtkWidget *hbox2111;
  GtkWidget *button_search_media_type_any;
  GtkWidget *checkbutton_config_search_media_type_audio;
  GtkWidget *checkbutton_config_search_media_type_video;
  GtkWidget *checkbutton_config_search_media_type_document;
  GtkWidget *checkbutton_config_search_media_type_image;
  GtkWidget *checkbutton_config_search_media_type_archive;
  GtkWidget *frame157;
  GtkWidget *hbox2113;
  GtkWidget *option_menu_search_lifetime;
  GtkWidget *option_menu_search_lifetime_menu;
  GtkWidget *optionmenu_search_filter;
  GtkWidget *optionmenu_search_filter_menu;
  GtkWidget *hpaned_main;
  GtkWidget *vbox_sidebar;
  GtkWidget *vbox46;
  GtkWidget *notebook_sidebar;
  GtkWidget *viewport49;
  GtkWidget *sw_searches;
  GtkWidget *clist_search;
  GtkWidget *label185;
  GtkWidget *label186;
  GtkWidget *label187;
  GtkWidget *label_nb_sb_1;
  GtkWidget *label189;
  GtkWidget *label188;
  GtkWidget *vbox_sidebar_stats;
  GtkWidget *frame75;
  GtkWidget *vbox108;
  GtkWidget *hbox_stats_connections;
  GtkWidget *eventbox6;
  GtkWidget *pixmap1;
  GtkWidget *progressbar_connections;
  GtkWidget *hbox_stats_uploads;
  GtkWidget *eventbox7;
  GtkWidget *pixmap2;
  GtkWidget *progressbar_uploads;
  GtkWidget *hbox_stats_downloads;
  GtkWidget *eventbox8;
  GtkWidget *pixmap3;
  GtkWidget *progressbar_downloads;
  GtkWidget *frame_bws_inout;
  GtkWidget *vbox42;
  GtkWidget *progressbar_bws_in;
  GtkWidget *progressbar_bws_out;
  GtkWidget *frame_bws_ginout;
  GtkWidget *vbox43;
  GtkWidget *progressbar_bws_gin;
  GtkWidget *progressbar_bws_gout;
  GtkWidget *frame_bws_glinout;
  GtkWidget *vbox107;
  GtkWidget *progressbar_bws_lin;
  GtkWidget *progressbar_bws_lout;
  GtkWidget *frame_bws_dht_inout;
  GtkWidget *vbox145;
  GtkWidget *progressbar_bws_dht_in;
  GtkWidget *progressbar_bws_dht_out;
  GtkWidget *vbox_right;
  GtkWidget *notebook_main;
  GtkWidget *vbox_gnutellanet;
  GtkWidget *vbox17;
  GtkWidget *sw_nodes;
  GtkWidget *clist_nodes;
  GtkWidget *label13;
  GtkWidget *label14b;
  GtkWidget *label14;
  GtkWidget *label_node_vendor;
  GtkWidget *label_node_proto;
  GtkWidget *label_node_connected;
  GtkWidget *label_node_uptime;
  GtkWidget *label_node_info;
  GtkWidget *hbox2;
  GtkWidget *button_nodes_disconnect;
  GtkWidget *button_nodes_add;
  GtkWidget *entry_host;
  GtkWidget *hbox200;
  GtkWidget *hbox_normal_or_ultrapeer;
  GtkWidget *label530;
  GtkWidget *label531;
  GtkObject *spinbutton_up_connections_adj;
  GtkWidget *spinbutton_up_connections;
  GtkObject *spinbutton_max_connections_adj;
  GtkWidget *spinbutton_max_connections;
  GtkWidget *hbox_leaf;
  GtkWidget *label532;
  GtkObject *spinbutton_max_ultrapeers_adj;
  GtkWidget *spinbutton_max_ultrapeers;
  GtkWidget *table91;
  GtkObject *spinbutton_quick_connect_pool_size_adj;
  GtkWidget *spinbutton_quick_connect_pool_size;
  GtkWidget *label680;
  GtkObject *spinbutton_max_g2_hubs_adj;
  GtkWidget *spinbutton_max_g2_hubs;
  GtkWidget *label8035;
  GtkWidget *vbox83;
  GtkWidget *frame_expert_node_info;
  GtkWidget *vbox34;
  GtkWidget *table6;
  GtkWidget *label150;
  GtkWidget *entry_nodes_guid;
  GtkWidget *label151;
  GtkWidget *entry_nodes_ip;
  GtkWidget *label8024;
  GtkWidget *entry_nodes_kuid;
  GtkWidget *label7986;
  GtkWidget *vbox76;
  GtkWidget *hbox146;
  GtkWidget *label651;
  GtkWidget *option_menu_searches;
  GtkWidget *option_menu_searches_menu;
  GtkWidget *viewport51;
  GtkWidget *hbox2107;
  GtkWidget *label_search_expiry;
  guint button_search_close_key;
  GtkWidget *button_search_close;
  GtkWidget *vpaned_results;
  GtkWidget *notebook_search_results;
  GtkWidget *empty_notebook_page;
  GtkWidget *label190;
  GtkWidget *scrolledwindow47;
  GtkWidget *viewport45;
  GtkWidget *notebook4;
  GtkWidget *scrolledwindow495;
  GtkWidget *clist_search_details;
  GtkWidget *label794;
  GtkWidget *label795;
  GtkWidget *label788;
  GtkWidget *scrolledwindow491;
  GtkWidget *text_result_info_xml;
  GtkWidget *label793;
  GtkWidget *table68;
  guint checkbutton_search_hide_downloaded_key;
  GtkWidget *checkbutton_search_hide_downloaded;
  guint checkbutton_search_remove_downloaded_key;
  GtkWidget *checkbutton_search_remove_downloaded;
  GtkWidget *checkbutton_browse_copied_to_passive;
  GtkWidget *checkbutton_search_discard_hashless;
  GtkWidget *checkbutton_search_discard_spam;
  GtkWidget *alignment38;
  GtkObject *spinbutton_browse_host_max_results_adj;
  GtkWidget *spinbutton_browse_host_max_results;
  GtkWidget *label460;
  GtkWidget *label783;
  GtkWidget *label541;
  GtkWidget *option_menu_search_handle_ignored_files;
  GtkWidget *option_menu_search_handle_ignored_files_menu;
  GtkWidget *label8030;
  GtkWidget *alignment39;
  GtkObject *spinbutton_passive_search_max_results_adj;
  GtkWidget *spinbutton_passive_search_max_results;
  GtkWidget *checkbutton_search_sort_casesense;
  GtkWidget *label8031;
  GtkWidget *alignment27;
  GtkObject *spinbutton_search_max_results_adj;
  GtkWidget *spinbutton_search_max_results;
  GtkWidget *alignment40;
  GtkObject *spinbutton_whats_new_search_max_results_adj;
  GtkWidget *spinbutton_whats_new_search_max_results;
  GtkWidget *checkbutton_search_discard_alien_ip;
  GtkWidget *checkbutton_search_discard_banned_guid;
  GtkWidget *checkbutton_search_display_guess_stats;
  GtkWidget *label789;
  GtkWidget *guess_stats_line;
  GtkWidget *viewport_fix_flashing_3;
  GtkWidget *hbox2114;
  GtkWidget *label_guess_stats;
  GtkWidget *checkbutton_guess_stats_show_total;
  GtkWidget *hbox147;
  GtkWidget *viewport_fix_flashing_1;
  GtkWidget *hbox167;
  GtkWidget *label_items_found;
  GtkWidget *hbox_expert_search_timeout;
  guint search_reissue_label_key;
  GtkWidget *search_reissue_label;
  GtkObject *spinbutton_search_reissue_timeout_adj;
  GtkWidget *spinbutton_search_reissue_timeout;
  GtkWidget *label_search_reissue;
  GtkWidget *hbox181;
  guint button_search_download_key;
  GtkWidget *button_search_download;
  guint button_search_filter_key;
  GtkWidget *button_search_filter;
  GtkWidget *label294;
  GtkWidget *label650;
  GtkWidget *button_search_clear;
  GtkWidget *label7985;
  GtkWidget *vbox143;
  GtkWidget *vpaned_fileinfo;
  GtkWidget *viewport52;
  GtkWidget *notebook_downloads;
  GtkWidget *scrolledwindow577;
  GtkWidget *viewport53;
  GtkWidget *vbox140;
  GtkWidget *table59;
  GtkWidget *label658;
  GtkWidget *viewport44;
  GtkWidget *drawingarea_fi_progress;
  GtkWidget *notebook5;
  GtkWidget *vbox110;
  GtkWidget *scrolledwindow496;
  GtkWidget *clist_download_details;
  GtkWidget *label796;
  GtkWidget *label7977;
  GtkWidget *label790;
  GtkWidget *scrolledwindow44;
  GtkWidget *clist_download_aliases;
  GtkWidget *label526;
  GtkWidget *label791;
  GtkWidget *scrolledwindow4971;
  GtkWidget *clist_download_sources;
  GtkWidget *label7998;
  GtkWidget *label7999;
  GtkWidget *label8000;
  GtkWidget *label8001;
  GtkWidget *label8002;
  GtkWidget *label8003;
  GtkWidget *label792;
  GtkWidget *frame152;
  GtkWidget *vbox144;
  GtkWidget *table99;
  GtkWidget *label149;
  GtkWidget *label8006;
  GtkWidget *checkbutton_downloads_filter_regex_case;
  GtkWidget *checkbutton_downloads_select_regex_invert;
  GtkWidget *checkbutton_downloads_filter_regex_invert;
  GtkWidget *checkbutton_downloads_select_regex_case;
  GtkWidget *entry_downloads_select_regex;
  GtkWidget *entry_downloads_filter_regex;
  GtkWidget *hbox86;
  GtkWidget *button_downloads_clear_stopped;
  GtkWidget *label7995;
  GtkWidget *frame151;
  GtkWidget *hbox189;
  GtkWidget *alignment32;
  GtkWidget *table85;
  GtkWidget *checkbutton_downloads_never_push;
  GtkWidget *checkbutton_download_delete_aborted;
  GtkWidget *checkbutton_dl_remove_file_on_mismatch;
  GtkWidget *label639a;
  GtkObject *spinbutton_mismatch_backout_adj;
  GtkWidget *spinbutton_mismatch_backout;
  GtkWidget *label80;
  GtkWidget *label64;
  GtkWidget *label787;
  GtkObject *spinbutton_max_host_downloads_adj;
  GtkWidget *spinbutton_max_host_downloads;
  GtkObject *spinbutton_max_downloads_adj;
  GtkWidget *spinbutton_max_downloads;
  GtkObject *spinbutton_max_file_downloads_adj;
  GtkWidget *spinbutton_max_file_downloads;
  GtkWidget *vbox124;
  GtkWidget *checkbutton_dl_clear_finished;
  GtkWidget *frame_dl_autoclear;
  GtkWidget *vbox118;
  GtkWidget *checkbutton_dl_clear_complete;
  GtkWidget *checkbutton_dl_clear_failed;
  GtkWidget *checkbutton_dl_clear_unavailable;
  GtkWidget *label8009;
  GtkWidget *hbox197a;
  GtkWidget *togglebutton_queue_freeze;
  GtkWidget *hbox159;
  GtkWidget *vbox_queue_freeze;
  GtkWidget *label406;
  GtkWidget *vbox_queue_thaw;
  GtkWidget *label407;
  GtkWidget *frame150;
  GtkWidget *hbox197;
  GtkWidget *hbox175;
  GtkWidget *label_fi_all_count;
  GtkWidget *label542;
  GtkWidget *label_fi_with_source_count;
  GtkWidget *label545;
  GtkWidget *hbox169;
  GtkWidget *label_dl_queue_count;
  GtkWidget *label507;
  GtkWidget *label_dl_qalive_count;
  GtkWidget *label506;
  GtkWidget *label_dl_pqueued_count;
  GtkWidget *label539;
  GtkWidget *hbox166;
  GtkWidget *label_dl_running_count;
  GtkWidget *label533;
  GtkWidget *label_dl_active_count;
  GtkWidget *label537;
  GtkWidget *label_dl_aqueued_count;
  GtkWidget *label536;
  GtkWidget *label8004;
  GtkWidget *label7984;
  GtkWidget *vbox18;
  GtkWidget *scrolledwindow9;
  GtkWidget *clist_uploads;
  GtkWidget *label72;
  GtkWidget *label73;
  GtkWidget *label73b;
  GtkWidget *label_size_range;
  GtkWidget *label_up_range;
  GtkWidget *label_up_user_agent;
  GtkWidget *label_up_progress;
  GtkWidget *label74;
  GtkWidget *hbox72;
  GtkWidget *button_uploads_kill;
  GtkWidget *button_uploads_clear_completed;
  GtkWidget *table61;
  GtkWidget *checkbutton_uploads_auto_clear_complete;
  GtkWidget *checkbutton_uploads_auto_clear_failed;
  GtkWidget *label81;
  GtkWidget *label130;
  GtkObject *spinbutton_max_uploads_adj;
  GtkWidget *spinbutton_max_uploads;
  GtkObject *spinbutton_max_uploads_ip_adj;
  GtkWidget *spinbutton_max_uploads_ip;
  GtkWidget *label7983;
  GtkWidget *vbox93;
  GtkWidget *vbox97;
  GtkWidget *gnet_stats_notebook;
  GtkWidget *hbox2106;
  GtkWidget *scrolledwindow31;
  GtkWidget *clist_gnet_stats_general;
  GtkWidget *label403;
  GtkWidget *label404;
  GtkWidget *scrolledwindow26;
  GtkWidget *clist_gnet_stats_drop_reasons;
  GtkWidget *label375;
  GtkWidget *label376;
  GtkWidget *label436;
  GtkWidget *scrolledwindow38;
  GtkWidget *clist_gnet_stats_fc_ttl;
  GtkWidget *label412;
  GtkWidget *label413;
  GtkWidget *label414;
  GtkWidget *label415;
  GtkWidget *label416;
  GtkWidget *label417;
  GtkWidget *label418;
  GtkWidget *label419;
  GtkWidget *label420;
  GtkWidget *label421;
  GtkWidget *label437;
  GtkWidget *scrolledwindow39;
  GtkWidget *clist_gnet_stats_fc_hops;
  GtkWidget *label423;
  GtkWidget *label424;
  GtkWidget *label425;
  GtkWidget *label426;
  GtkWidget *label427;
  GtkWidget *label428;
  GtkWidget *label429;
  GtkWidget *label430;
  GtkWidget *label431;
  GtkWidget *label432;
  GtkWidget *label438;
  GtkWidget *scrolledwindow29;
  GtkWidget *clist_gnet_stats_msg;
  GtkWidget *label391;
  GtkWidget *label392;
  GtkWidget *label393;
  GtkWidget *label394;
  GtkWidget *label395;
  GtkWidget *label500;
  GtkWidget *label501;
  GtkWidget *label396;
  GtkWidget *label776;
  GtkWidget *vbox141;
  GtkWidget *scrolledwindow45;
  GtkWidget *clist_gnet_stats_horizon;
  GtkWidget *label663;
  GtkWidget *label664;
  GtkWidget *label665;
  GtkWidget *label666;
  GtkWidget *hbox2109;
  GtkWidget *frame129;
  GtkWidget *label_statusbar_horizon_node_count;
  GtkWidget *frame130;
  GtkWidget *label_statusbar_horizon_file_count;
  GtkWidget *frame131;
  GtkWidget *label_statusbar_horizon_kb_count;
  GtkWidget *label777;
  GtkWidget *frame127;
  GtkWidget *table37;
  GtkWidget *label12;
  GtkWidget *label11;
  GtkWidget *entry_count_downloads;
  GtkWidget *entry_count_uploads;
  GtkWidget *label455;
  GtkWidget *label456;
  GtkWidget *entry_ul_byte_count;
  GtkWidget *entry_dl_byte_count;
  GtkWidget *label8008;
  GtkWidget *table93;
  guint checkbutton_gnet_stats_bytes_key;
  GtkWidget *checkbutton_gnet_stats_bytes;
  guint checkbutton_gnet_stats_perc_key;
  GtkWidget *checkbutton_gnet_stats_perc;
  guint checkbutton_gnet_stats_with_headers_key;
  GtkWidget *checkbutton_gnet_stats_with_headers;
  guint label697_key;
  GtkWidget *label697;
  guint label390_key;
  GtkWidget *label390;
  GtkWidget *option_menu_gnet_stats_source;
  GtkWidget *option_menu_gnet_stats_source_menu;
  GtkWidget *option_menu_gnet_stats_type;
  GtkWidget *option_menu_gnet_stats_type_menu;
  GtkWidget *label7982;
  GtkWidget *vbox_monitor;
  GtkWidget *hbox45;
  guint checkbutton_monitor_enable_key;
  GtkWidget *checkbutton_monitor_enable;
  GtkWidget *label75;
  guint label68_key;
  GtkWidget *label68;
  GtkObject *spinbutton_monitor_items_adj;
  GtkWidget *spinbutton_monitor_items;
  GtkWidget *label69;
  GtkWidget *scrolledwindow8;
  GtkWidget *clist_monitor;
  GtkWidget *label70;
  GtkWidget *label7981;
  GtkWidget *vbox19;
  GtkWidget *ul_stats_scrolledwindow;
  GtkWidget *clist_ul_stats;
  GtkWidget *ul_stats_label2;
  GtkWidget *ul_stats_size;
  GtkWidget *ul_stats_label3;
  GtkWidget *ul_stats_label4;
  GtkWidget *ul_stats_label5;
  GtkWidget *ul_stats_label6;
  GtkWidget *ul_stats_label7;
  GtkWidget *ul_stats_hbox2;
  GtkWidget *button_ul_stats_clear_deleted;
  GtkWidget *button_ul_stats_clear_all;
  GtkWidget *viewport50;
  GtkWidget *hbox2101;
  GtkWidget *label745;
  GtkWidget *label8005;
  GtkWidget *label_g2_browse_served;
  GtkWidget *label8037;
  GtkWidget *label_g2_browse_count;
  GtkWidget *label8039;
  GtkWidget *label_html_browse_served;
  GtkWidget *label781;
  GtkWidget *label_html_browse_count;
  GtkWidget *label747;
  GtkWidget *label_qhits_browse_served;
  GtkWidget *label779;
  GtkWidget *label_qhits_browse_count;
  GtkWidget *label749;
  GtkWidget *label7980;
  GtkWidget *vbox127;
  GtkWidget *scrolledwindow46;
  GtkWidget *clist_hcache;
  GtkWidget *label674;
  GtkWidget *label675;
  GtkWidget *label676;
  GtkWidget *label677;
  GtkWidget *frame126;
  GtkWidget *hbox201;
  GtkWidget *vbox128;
  GtkWidget *progressbar_hosts_in_catcher;
  GtkWidget *hbox202;
  GtkWidget *label95;
  GtkObject *spinbutton_max_hosts_cached_adj;
  GtkWidget *spinbutton_max_hosts_cached;
  GtkWidget *button_host_catcher_clear;
  GtkWidget *vbox129;
  GtkWidget *progressbar_hosts_in_ultra_catcher;
  GtkWidget *hbox203;
  GtkWidget *label453;
  GtkObject *spinbutton_max_ultra_hosts_cached_adj;
  GtkWidget *spinbutton_max_ultra_hosts_cached;
  GtkWidget *button_ultra_catcher_clear;
  GtkWidget *vbox130;
  GtkWidget *progressbar_hosts_in_bad_catcher;
  GtkWidget *hbox204;
  GtkWidget *label678;
  GtkObject *spinbutton_max_bad_hosts_cached_adj;
  GtkWidget *spinbutton_max_bad_hosts_cached;
  GtkWidget *button_hostcache_clear_bad;
  GtkWidget *vbox148;
  GtkWidget *progressbar_hosts_in_g2hub_catcher;
  GtkWidget *hbox2115;
  GtkWidget *label_g2_hosts;
  GtkObject *spinbutton_max_g2hub_hosts_cached_adj;
  GtkWidget *spinbutton_max_g2hub_hosts_cached;
  GtkWidget *button_g2hub_catcher_clear;
  GtkWidget *label7987;
  GtkWidget *vbox12a;
  GtkWidget *hbox67;
  GtkWidget *option_menu_search_stats_type;
  GtkWidget *option_menu_search_stats_type_menu;
  guint label101_key;
  GtkWidget *label101;
  GtkObject *spinbutton_search_stats_update_interval_adj;
  GtkWidget *spinbutton_search_stats_update_interval;
  guint label102_key;
  GtkWidget *label102;
  GtkObject *spinbutton_search_stats_delcoef_adj;
  GtkWidget *spinbutton_search_stats_delcoef;
  GtkWidget *scrolledwindow10;
  GtkWidget *clist_search_stats;
  GtkWidget *label105;
  GtkWidget *label106;
  GtkWidget *label107;
  GtkWidget *alignment1;
  GtkWidget *hbox66;
  guint button_search_stats_reset_key;
  GtkWidget *button_search_stats_reset;
  GtkWidget *viewport_fix_flashing_2;
  GtkWidget *hbox168;
  GtkWidget *label_search_stats_count;
  GtkWidget *label7988;
  GtkWidget *hbox_statusbar;
  GtkWidget *togglebutton_online;
  GtkWidget *hbox145;
  GtkWidget *image_online;
  GtkWidget *eventbox5;
  GtkWidget *image_offline;
  GtkWidget *hbox_port_mapping;
  GtkWidget *eventbox_port_mapping_possible;
  GtkWidget *image_port_mapping_possible;
  GtkWidget *eventbox_upnp_port_mapping_successful;
  GtkWidget *image_upnp_successful;
  GtkWidget *eventbox_natpmp_port_mapping_successful;
  GtkWidget *image_natpmp_successful;
  GtkWidget *alignment25;
  GtkWidget *statusbar;
  GtkWidget *frame_status_images;
  GtkWidget *hbox199;
  GtkWidget *eventbox_image_download_queue_frozen;
  GtkWidget *image_download_queue_frozen;
  GtkWidget *eventbox_image_chip;
  GtkWidget *image_chip;
  GtkWidget *eventbox_image_warning;
  GtkWidget *image_warning;
  GtkWidget *hbox2110;
  GtkWidget *eventbox_early_stall_1;
  GtkWidget *image_early_stall_1;
  GtkWidget *eventbox_early_stall_2;
  GtkWidget *image_early_stall_2;
  GtkWidget *eventbox_early_stall_3;
  GtkWidget *image_early_stall_3;
  GtkWidget *eventbox_image_fd_shortage;
  GtkWidget *image_fd_shortage;
  GtkWidget *eventbox_image_fd_runout;
  GtkWidget *image_fd_runout;
  GtkWidget *eventbox_image_ancient;
  GtkWidget *image_ancient;
  GtkWidget *eventbox_image_save;
  GtkWidget *image_save;
  GtkWidget *eventbox_image_sha;
  GtkWidget *image_sha;
  GtkWidget *eventbox_image_shav;
  GtkWidget *image_shav;
  GtkWidget *eventbox_image_tth;
  GtkWidget *image_tth;
  GtkWidget *eventbox_image_tthv;
  GtkWidget *image_tthv;
  GtkWidget *eventbox_image_lib;
  GtkWidget *image_lib;
  GtkWidget *eventbox_image_firewall;
  GtkWidget *image_firewall;
  GtkWidget *eventbox_image_firewall_punchable;
  GtkWidget *image_firewall_punchable;
  GtkWidget *eventbox_image_tcp_firewall;
  GtkWidget *image_tcp_firewall;
  GtkWidget *eventbox_image_udp_firewall;
  GtkWidget *image_udp_firewall;
  GtkWidget *eventbox_image_firewall_udp_punchable;
  GtkWidget *image_firewall_udp_punchable;
  GtkWidget *eventbox_image_no_firewall;
  GtkWidget *image_no_firewall;
  GtkWidget *eventbox_image_leaf;
  GtkWidget *image_leaf;
  GtkWidget *eventbox_image_legacy;
  GtkWidget *image_legacy;
  GtkWidget *eventbox_image_ultra;
  GtkWidget *image_ultra;
  GtkWidget *eventbox_image_dht_none;
  GtkWidget *image_dht_none;
  GtkWidget *eventbox_image_dht_seeded;
  GtkWidget *image_dht_seeded;
  GtkWidget *eventbox_image_dht_own_kuid;
  GtkWidget *image_dht_own_kuid;
  GtkWidget *eventbox_image_dht_completing;
  GtkWidget *image_dht_completing;
  GtkWidget *eventbox_image_dht_active;
  GtkWidget *image_dht_active;
  GtkWidget *eventbox_image_dht_passive;
  GtkWidget *image_dht_passive;
  GtkWidget *frame_statusbar_uptime;
  GtkWidget *label_statusbar_uptime;
  GtkAccelGroup *accel_group;
  GtkTooltips *tooltips;

  tooltips = gtk_tooltips_new ();

  accel_group = gtk_accel_group_new ();

  main_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_widget_set_name (main_window, "main_window");
  gtk_object_set_data (GTK_OBJECT (main_window), "main_window", main_window);
  gtk_window_set_title (GTK_WINDOW (main_window), _("gtk-gnutella"));
  gtk_window_set_policy (GTK_WINDOW (main_window), TRUE, TRUE, FALSE);

  vbox12 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox12, "vbox12");
  gtk_widget_ref (vbox12);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "vbox12", vbox12,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox12);
  gtk_container_add (GTK_CONTAINER (main_window), vbox12);

  menubar_main = gtk_menu_bar_new ();
  gtk_widget_set_name (menubar_main, "menubar_main");
  gtk_widget_ref (menubar_main);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "menubar_main", menubar_main,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (menubar_main);
  gtk_box_pack_start (GTK_BOX (vbox12), menubar_main, FALSE, FALSE, 0);

  menu_file = gtk_menu_item_new_with_label ("");
  tmp_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (menu_file)->child),
                                   _("_File"));
  gtk_widget_add_accelerator (menu_file, "activate_item", accel_group,
                              tmp_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (menu_file, "menu_file");
  gtk_widget_ref (menu_file);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "menu_file", menu_file,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (menu_file);
  gtk_container_add (GTK_CONTAINER (menubar_main), menu_file);
  gtk_widget_add_accelerator (menu_file, "activate_item", accel_group,
                              GDK_f, GDK_CONTROL_MASK,
                              GTK_ACCEL_VISIBLE);

  menu_file_menu = gtk_menu_new ();
  gtk_widget_set_name (menu_file_menu, "menu_file_menu");
  gtk_widget_ref (menu_file_menu);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "menu_file_menu", menu_file_menu,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_file), menu_file_menu);
  menu_file_menu_accels = gtk_menu_ensure_uline_accel_group (GTK_MENU (menu_file_menu));

  menu_prefs = gtk_menu_item_new_with_label ("");
  tmp_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (menu_prefs)->child),
                                   _("_Preferences"));
  gtk_widget_add_accelerator (menu_prefs, "activate_item", menu_file_menu_accels,
                              tmp_key, 0, 0);
  gtk_widget_set_name (menu_prefs, "menu_prefs");
  gtk_widget_ref (menu_prefs);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "menu_prefs", menu_prefs,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (menu_prefs);
  gtk_container_add (GTK_CONTAINER (menu_file_menu), menu_prefs);
  gtk_widget_add_accelerator (menu_prefs, "activate", accel_group,
                              GDK_p, GDK_CONTROL_MASK,
                              GTK_ACCEL_VISIBLE);

  separator23 = gtk_menu_item_new ();
  gtk_widget_set_name (separator23, "separator23");
  gtk_widget_ref (separator23);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "separator23", separator23,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (separator23);
  gtk_container_add (GTK_CONTAINER (menu_file_menu), separator23);
  gtk_widget_set_sensitive (separator23, FALSE);

  quit = gtk_menu_item_new_with_label ("");
  tmp_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (quit)->child),
                                   _("_Quit"));
  gtk_widget_add_accelerator (quit, "activate_item", menu_file_menu_accels,
                              tmp_key, 0, 0);
  gtk_widget_set_name (quit, "quit");
  gtk_widget_ref (quit);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "quit", quit,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (quit);
  gtk_container_add (GTK_CONTAINER (menu_file_menu), quit);
  gtk_widget_add_accelerator (quit, "activate", accel_group,
                              GDK_q, GDK_CONTROL_MASK,
                              GTK_ACCEL_VISIBLE);

  menu_view = gtk_menu_item_new_with_label ("");
  tmp_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (menu_view)->child),
                                   _("_View"));
  gtk_widget_add_accelerator (menu_view, "activate_item", accel_group,
                              tmp_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (menu_view, "menu_view");
  gtk_widget_ref (menu_view);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "menu_view", menu_view,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (menu_view);
  gtk_container_add (GTK_CONTAINER (menubar_main), menu_view);
  gtk_widget_add_accelerator (menu_view, "activate_item", accel_group,
                              GDK_v, GDK_CONTROL_MASK,
                              GTK_ACCEL_VISIBLE);

  menu_view_menu = gtk_menu_new ();
  gtk_widget_set_name (menu_view_menu, "menu_view_menu");
  gtk_widget_ref (menu_view_menu);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "menu_view_menu", menu_view_menu,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_view), menu_view_menu);
  menu_view_menu_accels = gtk_menu_ensure_uline_accel_group (GTK_MENU (menu_view_menu));

  menu_searchbar_visible = gtk_check_menu_item_new_with_label ("");
  tmp_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (menu_searchbar_visible)->child),
                                   _("Show Search_bar"));
  gtk_widget_add_accelerator (menu_searchbar_visible, "activate_item", menu_view_menu_accels,
                              tmp_key, 0, 0);
  gtk_widget_set_name (menu_searchbar_visible, "menu_searchbar_visible");
  gtk_widget_ref (menu_searchbar_visible);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "menu_searchbar_visible", menu_searchbar_visible,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (menu_searchbar_visible);
  gtk_container_add (GTK_CONTAINER (menu_view_menu), menu_searchbar_visible);
  gtk_widget_add_accelerator (menu_searchbar_visible, "activate", accel_group,
                              GDK_F2, 0,
                              GTK_ACCEL_VISIBLE);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu_searchbar_visible), TRUE);
  gtk_check_menu_item_set_show_toggle (GTK_CHECK_MENU_ITEM (menu_searchbar_visible), TRUE);

  menu_sidebar_visible = gtk_check_menu_item_new_with_label ("");
  tmp_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (menu_sidebar_visible)->child),
                                   _("Show _Sidebar"));
  gtk_widget_add_accelerator (menu_sidebar_visible, "activate_item", menu_view_menu_accels,
                              tmp_key, 0, 0);
  gtk_widget_set_name (menu_sidebar_visible, "menu_sidebar_visible");
  gtk_widget_ref (menu_sidebar_visible);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "menu_sidebar_visible", menu_sidebar_visible,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (menu_sidebar_visible);
  gtk_container_add (GTK_CONTAINER (menu_view_menu), menu_sidebar_visible);
  gtk_widget_add_accelerator (menu_sidebar_visible, "activate", accel_group,
                              GDK_F8, 0,
                              GTK_ACCEL_VISIBLE);
  gtk_check_menu_item_set_show_toggle (GTK_CHECK_MENU_ITEM (menu_sidebar_visible), TRUE);

  menu_menubar_visible = gtk_check_menu_item_new_with_label ("");
  tmp_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (menu_menubar_visible)->child),
                                   _("Show _Menubar"));
  gtk_widget_add_accelerator (menu_menubar_visible, "activate_item", menu_view_menu_accels,
                              tmp_key, 0, 0);
  gtk_widget_set_name (menu_menubar_visible, "menu_menubar_visible");
  gtk_widget_ref (menu_menubar_visible);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "menu_menubar_visible", menu_menubar_visible,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (menu_menubar_visible);
  gtk_container_add (GTK_CONTAINER (menu_view_menu), menu_menubar_visible);
  gtk_widget_add_accelerator (menu_menubar_visible, "activate", accel_group,
                              GDK_F9, 0,
                              GTK_ACCEL_VISIBLE);
  gtk_check_menu_item_set_show_toggle (GTK_CHECK_MENU_ITEM (menu_menubar_visible), TRUE);

  menu_statusbar_visible = gtk_check_menu_item_new_with_label ("");
  tmp_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (menu_statusbar_visible)->child),
                                   _("Show Status_bar"));
  gtk_widget_add_accelerator (menu_statusbar_visible, "activate_item", menu_view_menu_accels,
                              tmp_key, 0, 0);
  gtk_widget_set_name (menu_statusbar_visible, "menu_statusbar_visible");
  gtk_widget_ref (menu_statusbar_visible);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "menu_statusbar_visible", menu_statusbar_visible,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (menu_statusbar_visible);
  gtk_container_add (GTK_CONTAINER (menu_view_menu), menu_statusbar_visible);
  gtk_widget_add_accelerator (menu_statusbar_visible, "toggled", accel_group,
                              GDK_s, GDK_CONTROL_MASK,
                              GTK_ACCEL_VISIBLE);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu_statusbar_visible), TRUE);
  gtk_check_menu_item_set_show_toggle (GTK_CHECK_MENU_ITEM (menu_statusbar_visible), TRUE);

  separator24 = gtk_menu_item_new ();
  gtk_widget_set_name (separator24, "separator24");
  gtk_widget_ref (separator24);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "separator24", separator24,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (separator24);
  gtk_container_add (GTK_CONTAINER (menu_view_menu), separator24);
  gtk_widget_set_sensitive (separator24, FALSE);

  connection_counters1 = gtk_menu_item_new_with_label (_("Connection counters"));
  gtk_widget_set_name (connection_counters1, "connection_counters1");
  gtk_widget_ref (connection_counters1);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "connection_counters1", connection_counters1,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (connection_counters1);
  gtk_container_add (GTK_CONTAINER (menu_view_menu), connection_counters1);

  connection_counters1_menu = gtk_menu_new ();
  gtk_widget_set_name (connection_counters1_menu, "connection_counters1_menu");
  gtk_widget_ref (connection_counters1_menu);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "connection_counters1_menu", connection_counters1_menu,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (connection_counters1), connection_counters1_menu);
  connection_counters1_menu_accels = gtk_menu_ensure_uline_accel_group (GTK_MENU (connection_counters1_menu));

  menu_downloads_visible = gtk_check_menu_item_new_with_label ("");
  tmp_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (menu_downloads_visible)->child),
                                   _("Show _Downloads"));
  gtk_widget_add_accelerator (menu_downloads_visible, "activate_item", connection_counters1_menu_accels,
                              tmp_key, 0, 0);
  gtk_widget_set_name (menu_downloads_visible, "menu_downloads_visible");
  gtk_widget_ref (menu_downloads_visible);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "menu_downloads_visible", menu_downloads_visible,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (menu_downloads_visible);
  gtk_container_add (GTK_CONTAINER (connection_counters1_menu), menu_downloads_visible);
  gtk_widget_add_accelerator (menu_downloads_visible, "toggled", accel_group,
                              GDK_d, GDK_CONTROL_MASK,
                              GTK_ACCEL_VISIBLE);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu_downloads_visible), TRUE);
  gtk_check_menu_item_set_show_toggle (GTK_CHECK_MENU_ITEM (menu_downloads_visible), TRUE);

  menu_uploads_visible = gtk_check_menu_item_new_with_label ("");
  tmp_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (menu_uploads_visible)->child),
                                   _("Show _Uploads"));
  gtk_widget_add_accelerator (menu_uploads_visible, "activate_item", connection_counters1_menu_accels,
                              tmp_key, 0, 0);
  gtk_widget_set_name (menu_uploads_visible, "menu_uploads_visible");
  gtk_widget_ref (menu_uploads_visible);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "menu_uploads_visible", menu_uploads_visible,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (menu_uploads_visible);
  gtk_container_add (GTK_CONTAINER (connection_counters1_menu), menu_uploads_visible);
  gtk_widget_add_accelerator (menu_uploads_visible, "toggled", accel_group,
                              GDK_u, GDK_CONTROL_MASK,
                              GTK_ACCEL_VISIBLE);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu_uploads_visible), TRUE);
  gtk_check_menu_item_set_show_toggle (GTK_CHECK_MENU_ITEM (menu_uploads_visible), TRUE);

  menu_connections_visible = gtk_check_menu_item_new_with_label ("");
  tmp_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (menu_connections_visible)->child),
                                   _("Show _Connections"));
  gtk_widget_add_accelerator (menu_connections_visible, "activate_item", connection_counters1_menu_accels,
                              tmp_key, 0, 0);
  gtk_widget_set_name (menu_connections_visible, "menu_connections_visible");
  gtk_widget_ref (menu_connections_visible);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "menu_connections_visible", menu_connections_visible,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (menu_connections_visible);
  gtk_container_add (GTK_CONTAINER (connection_counters1_menu), menu_connections_visible);
  gtk_widget_add_accelerator (menu_connections_visible, "toggled", accel_group,
                              GDK_c, GDK_CONTROL_MASK,
                              GTK_ACCEL_VISIBLE);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu_connections_visible), TRUE);
  gtk_check_menu_item_set_show_toggle (GTK_CHECK_MENU_ITEM (menu_connections_visible), TRUE);

  menu_http_stats_visible = gtk_menu_item_new_with_label ("");
  tmp_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (menu_http_stats_visible)->child),
                                   _("_HTTP traffic stats"));
  gtk_widget_add_accelerator (menu_http_stats_visible, "activate_item", menu_view_menu_accels,
                              tmp_key, 0, 0);
  gtk_widget_set_name (menu_http_stats_visible, "menu_http_stats_visible");
  gtk_widget_ref (menu_http_stats_visible);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "menu_http_stats_visible", menu_http_stats_visible,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (menu_http_stats_visible);
  gtk_container_add (GTK_CONTAINER (menu_view_menu), menu_http_stats_visible);

  menu_http_stats_visible_menu = gtk_menu_new ();
  gtk_widget_set_name (menu_http_stats_visible_menu, "menu_http_stats_visible_menu");
  gtk_widget_ref (menu_http_stats_visible_menu);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "menu_http_stats_visible_menu", menu_http_stats_visible_menu,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_http_stats_visible), menu_http_stats_visible_menu);
  menu_http_stats_visible_menu_accels = gtk_menu_ensure_uline_accel_group (GTK_MENU (menu_http_stats_visible_menu));

  menu_bws_in_visible = gtk_check_menu_item_new_with_label ("");
  tmp_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (menu_bws_in_visible)->child),
                                   _("Show _inbound HTTP traffic"));
  gtk_widget_add_accelerator (menu_bws_in_visible, "activate_item", menu_http_stats_visible_menu_accels,
                              tmp_key, 0, 0);
  gtk_widget_set_name (menu_bws_in_visible, "menu_bws_in_visible");
  gtk_widget_ref (menu_bws_in_visible);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "menu_bws_in_visible", menu_bws_in_visible,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (menu_bws_in_visible);
  gtk_container_add (GTK_CONTAINER (menu_http_stats_visible_menu), menu_bws_in_visible);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu_bws_in_visible), TRUE);
  gtk_check_menu_item_set_show_toggle (GTK_CHECK_MENU_ITEM (menu_bws_in_visible), TRUE);

  menu_bws_out_visible = gtk_check_menu_item_new_with_label ("");
  tmp_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (menu_bws_out_visible)->child),
                                   _("Show _outbound HTTP traffic"));
  gtk_widget_add_accelerator (menu_bws_out_visible, "activate_item", menu_http_stats_visible_menu_accels,
                              tmp_key, 0, 0);
  gtk_widget_set_name (menu_bws_out_visible, "menu_bws_out_visible");
  gtk_widget_ref (menu_bws_out_visible);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "menu_bws_out_visible", menu_bws_out_visible,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (menu_bws_out_visible);
  gtk_container_add (GTK_CONTAINER (menu_http_stats_visible_menu), menu_bws_out_visible);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu_bws_out_visible), TRUE);
  gtk_check_menu_item_set_show_toggle (GTK_CHECK_MENU_ITEM (menu_bws_out_visible), TRUE);

  menu_gnet_stats_visible = gtk_menu_item_new_with_label ("");
  tmp_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (menu_gnet_stats_visible)->child),
                                   _("_Gnutella traffic stats"));
  gtk_widget_add_accelerator (menu_gnet_stats_visible, "activate_item", menu_view_menu_accels,
                              tmp_key, 0, 0);
  gtk_widget_set_name (menu_gnet_stats_visible, "menu_gnet_stats_visible");
  gtk_widget_ref (menu_gnet_stats_visible);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "menu_gnet_stats_visible", menu_gnet_stats_visible,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (menu_gnet_stats_visible);
  gtk_container_add (GTK_CONTAINER (menu_view_menu), menu_gnet_stats_visible);

  menu_gnet_stats_visible_menu = gtk_menu_new ();
  gtk_widget_set_name (menu_gnet_stats_visible_menu, "menu_gnet_stats_visible_menu");
  gtk_widget_ref (menu_gnet_stats_visible_menu);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "menu_gnet_stats_visible_menu", menu_gnet_stats_visible_menu,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_gnet_stats_visible), menu_gnet_stats_visible_menu);
  menu_gnet_stats_visible_menu_accels = gtk_menu_ensure_uline_accel_group (GTK_MENU (menu_gnet_stats_visible_menu));

  menu_bws_gin_visible = gtk_check_menu_item_new_with_label ("");
  tmp_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (menu_bws_gin_visible)->child),
                                   _("Show _inbound Gnutella traffic"));
  gtk_widget_add_accelerator (menu_bws_gin_visible, "activate_item", menu_gnet_stats_visible_menu_accels,
                              tmp_key, 0, 0);
  gtk_widget_set_name (menu_bws_gin_visible, "menu_bws_gin_visible");
  gtk_widget_ref (menu_bws_gin_visible);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "menu_bws_gin_visible", menu_bws_gin_visible,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (menu_bws_gin_visible);
  gtk_container_add (GTK_CONTAINER (menu_gnet_stats_visible_menu), menu_bws_gin_visible);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu_bws_gin_visible), TRUE);
  gtk_check_menu_item_set_show_toggle (GTK_CHECK_MENU_ITEM (menu_bws_gin_visible), TRUE);

  menu_bws_gout_visible = gtk_check_menu_item_new_with_label ("");
  tmp_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (menu_bws_gout_visible)->child),
                                   _("Show _outbound Gnutella traffic"));
  gtk_widget_add_accelerator (menu_bws_gout_visible, "activate_item", menu_gnet_stats_visible_menu_accels,
                              tmp_key, 0, 0);
  gtk_widget_set_name (menu_bws_gout_visible, "menu_bws_gout_visible");
  gtk_widget_ref (menu_bws_gout_visible);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "menu_bws_gout_visible", menu_bws_gout_visible,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (menu_bws_gout_visible);
  gtk_container_add (GTK_CONTAINER (menu_gnet_stats_visible_menu), menu_bws_gout_visible);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu_bws_gout_visible), TRUE);
  gtk_check_menu_item_set_show_toggle (GTK_CHECK_MENU_ITEM (menu_bws_gout_visible), TRUE);

  menu_gnet_leaf_stats_visible = gtk_menu_item_new_with_label ("");
  tmp_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (menu_gnet_leaf_stats_visible)->child),
                                   _("Gnutella _leaf traffic stats"));
  gtk_widget_add_accelerator (menu_gnet_leaf_stats_visible, "activate_item", menu_view_menu_accels,
                              tmp_key, 0, 0);
  gtk_widget_set_name (menu_gnet_leaf_stats_visible, "menu_gnet_leaf_stats_visible");
  gtk_widget_ref (menu_gnet_leaf_stats_visible);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "menu_gnet_leaf_stats_visible", menu_gnet_leaf_stats_visible,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (menu_gnet_leaf_stats_visible);
  gtk_container_add (GTK_CONTAINER (menu_view_menu), menu_gnet_leaf_stats_visible);

  menu_gnet_leaf_stats_visible_menu = gtk_menu_new ();
  gtk_widget_set_name (menu_gnet_leaf_stats_visible_menu, "menu_gnet_leaf_stats_visible_menu");
  gtk_widget_ref (menu_gnet_leaf_stats_visible_menu);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "menu_gnet_leaf_stats_visible_menu", menu_gnet_leaf_stats_visible_menu,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_gnet_leaf_stats_visible), menu_gnet_leaf_stats_visible_menu);
  menu_gnet_leaf_stats_visible_menu_accels = gtk_menu_ensure_uline_accel_group (GTK_MENU (menu_gnet_leaf_stats_visible_menu));

  menu_autohide_bws_gleaf = gtk_check_menu_item_new_with_label ("");
  tmp_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (menu_autohide_bws_gleaf)->child),
                                   _("_auto-hide leaf traffic stats"));
  gtk_widget_add_accelerator (menu_autohide_bws_gleaf, "activate_item", menu_gnet_leaf_stats_visible_menu_accels,
                              tmp_key, 0, 0);
  gtk_widget_set_name (menu_autohide_bws_gleaf, "menu_autohide_bws_gleaf");
  gtk_widget_ref (menu_autohide_bws_gleaf);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "menu_autohide_bws_gleaf", menu_autohide_bws_gleaf,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (menu_autohide_bws_gleaf);
  gtk_container_add (GTK_CONTAINER (menu_gnet_leaf_stats_visible_menu), menu_autohide_bws_gleaf);
  gtk_check_menu_item_set_show_toggle (GTK_CHECK_MENU_ITEM (menu_autohide_bws_gleaf), TRUE);

  menu_bws_glin_visible = gtk_check_menu_item_new_with_label ("");
  tmp_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (menu_bws_glin_visible)->child),
                                   _("Show _inbound leaf traffic"));
  gtk_widget_add_accelerator (menu_bws_glin_visible, "activate_item", menu_gnet_leaf_stats_visible_menu_accels,
                              tmp_key, 0, 0);
  gtk_widget_set_name (menu_bws_glin_visible, "menu_bws_glin_visible");
  gtk_widget_ref (menu_bws_glin_visible);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "menu_bws_glin_visible", menu_bws_glin_visible,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (menu_bws_glin_visible);
  gtk_container_add (GTK_CONTAINER (menu_gnet_leaf_stats_visible_menu), menu_bws_glin_visible);
  gtk_check_menu_item_set_show_toggle (GTK_CHECK_MENU_ITEM (menu_bws_glin_visible), TRUE);

  menu_bws_glout_visible = gtk_check_menu_item_new_with_label ("");
  tmp_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (menu_bws_glout_visible)->child),
                                   _("Show _outbound leaf traffic"));
  gtk_widget_add_accelerator (menu_bws_glout_visible, "activate_item", menu_gnet_leaf_stats_visible_menu_accels,
                              tmp_key, 0, 0);
  gtk_widget_set_name (menu_bws_glout_visible, "menu_bws_glout_visible");
  gtk_widget_ref (menu_bws_glout_visible);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "menu_bws_glout_visible", menu_bws_glout_visible,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (menu_bws_glout_visible);
  gtk_container_add (GTK_CONTAINER (menu_gnet_leaf_stats_visible_menu), menu_bws_glout_visible);
  gtk_check_menu_item_set_show_toggle (GTK_CHECK_MENU_ITEM (menu_bws_glout_visible), TRUE);

  menu_dht_traffic_stats_visible = gtk_menu_item_new_with_label (_("DHT traffic stats"));
  gtk_widget_set_name (menu_dht_traffic_stats_visible, "menu_dht_traffic_stats_visible");
  gtk_widget_ref (menu_dht_traffic_stats_visible);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "menu_dht_traffic_stats_visible", menu_dht_traffic_stats_visible,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (menu_dht_traffic_stats_visible);
  gtk_container_add (GTK_CONTAINER (menu_view_menu), menu_dht_traffic_stats_visible);

  menu_dht_traffic_stats_visible_menu = gtk_menu_new ();
  gtk_widget_set_name (menu_dht_traffic_stats_visible_menu, "menu_dht_traffic_stats_visible_menu");
  gtk_widget_ref (menu_dht_traffic_stats_visible_menu);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "menu_dht_traffic_stats_visible_menu", menu_dht_traffic_stats_visible_menu,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_dht_traffic_stats_visible), menu_dht_traffic_stats_visible_menu);
  menu_dht_traffic_stats_visible_menu_accels = gtk_menu_ensure_uline_accel_group (GTK_MENU (menu_dht_traffic_stats_visible_menu));

  menu_autohide_bws_dht = gtk_check_menu_item_new_with_label (_("auto-hide DHT traffic stats"));
  gtk_widget_set_name (menu_autohide_bws_dht, "menu_autohide_bws_dht");
  gtk_widget_ref (menu_autohide_bws_dht);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "menu_autohide_bws_dht", menu_autohide_bws_dht,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (menu_autohide_bws_dht);
  gtk_container_add (GTK_CONTAINER (menu_dht_traffic_stats_visible_menu), menu_autohide_bws_dht);
  gtk_check_menu_item_set_show_toggle (GTK_CHECK_MENU_ITEM (menu_autohide_bws_dht), TRUE);

  menu_bws_dht_in_visible = gtk_check_menu_item_new_with_label (_("Show inbound DHT traffic"));
  gtk_widget_set_name (menu_bws_dht_in_visible, "menu_bws_dht_in_visible");
  gtk_widget_ref (menu_bws_dht_in_visible);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "menu_bws_dht_in_visible", menu_bws_dht_in_visible,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (menu_bws_dht_in_visible);
  gtk_container_add (GTK_CONTAINER (menu_dht_traffic_stats_visible_menu), menu_bws_dht_in_visible);
  gtk_check_menu_item_set_show_toggle (GTK_CHECK_MENU_ITEM (menu_bws_dht_in_visible), TRUE);

  menu_bws_dht_out_visible = gtk_check_menu_item_new_with_label (_("Show outbound DHT traffic"));
  gtk_widget_set_name (menu_bws_dht_out_visible, "menu_bws_dht_out_visible");
  gtk_widget_ref (menu_bws_dht_out_visible);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "menu_bws_dht_out_visible", menu_bws_dht_out_visible,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (menu_bws_dht_out_visible);
  gtk_container_add (GTK_CONTAINER (menu_dht_traffic_stats_visible_menu), menu_bws_dht_out_visible);
  gtk_check_menu_item_set_show_toggle (GTK_CHECK_MENU_ITEM (menu_bws_dht_out_visible), TRUE);

  separator20 = gtk_menu_item_new ();
  gtk_widget_set_name (separator20, "separator20");
  gtk_widget_ref (separator20);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "separator20", separator20,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (separator20);
  gtk_container_add (GTK_CONTAINER (menu_view_menu), separator20);
  gtk_widget_set_sensitive (separator20, FALSE);

  menu_help = gtk_menu_item_new_with_label ("");
  tmp_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (menu_help)->child),
                                   _("_Help"));
  gtk_widget_add_accelerator (menu_help, "activate_item", accel_group,
                              tmp_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (menu_help, "menu_help");
  gtk_widget_ref (menu_help);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "menu_help", menu_help,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (menu_help);
  gtk_container_add (GTK_CONTAINER (menubar_main), menu_help);

  menu_help_menu = gtk_menu_new ();
  gtk_widget_set_name (menu_help_menu, "menu_help_menu");
  gtk_widget_ref (menu_help_menu);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "menu_help_menu", menu_help_menu,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_help), menu_help_menu);
  menu_help_menu_accels = gtk_menu_ensure_uline_accel_group (GTK_MENU (menu_help_menu));

  menu_about = gtk_menu_item_new_with_label ("");
  tmp_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (menu_about)->child),
                                   _("_About"));
  gtk_widget_add_accelerator (menu_about, "activate_item", menu_help_menu_accels,
                              tmp_key, 0, 0);
  gtk_widget_set_name (menu_about, "menu_about");
  gtk_widget_ref (menu_about);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "menu_about", menu_about,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (menu_about);
  gtk_container_add (GTK_CONTAINER (menu_help_menu), menu_about);

  menu_faq = gtk_menu_item_new_with_label ("");
  tmp_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (menu_faq)->child),
                                   _("_FAQ"));
  gtk_widget_add_accelerator (menu_faq, "activate_item", menu_help_menu_accels,
                              tmp_key, 0, 0);
  gtk_widget_set_name (menu_faq, "menu_faq");
  gtk_widget_ref (menu_faq);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "menu_faq", menu_faq,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (menu_faq);
  gtk_container_add (GTK_CONTAINER (menu_help_menu), menu_faq);
  gtk_tooltips_set_tip (tooltips, menu_faq, _("Frequently Asked Questions"), NULL);

  viewport_searchbar = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport_searchbar, "viewport_searchbar");
  gtk_widget_ref (viewport_searchbar);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "viewport_searchbar", viewport_searchbar,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (viewport_searchbar);
  gtk_box_pack_start (GTK_BOX (vbox12), viewport_searchbar, FALSE, TRUE, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport_searchbar), GTK_SHADOW_OUT);

  vbox147 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox147, "vbox147");
  gtk_widget_ref (vbox147);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "vbox147", vbox147,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox147);
  gtk_container_add (GTK_CONTAINER (viewport_searchbar), vbox147);

  hbox179 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox179, "hbox179");
  gtk_widget_ref (hbox179);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "hbox179", hbox179,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox179);
  gtk_box_pack_start (GTK_BOX (vbox147), hbox179, TRUE, TRUE, 0);

  button_search = gtk_button_new_with_label (_("Search"));
  gtk_widget_set_name (button_search, "button_search");
  gtk_widget_ref (button_search);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "button_search", button_search,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_search);
  gtk_box_pack_start (GTK_BOX (hbox179), button_search, FALSE, FALSE, 0);
  gtk_widget_set_sensitive (button_search, FALSE);
  gtk_button_set_relief (GTK_BUTTON (button_search), GTK_RELIEF_NONE);

  combo_search = gtk_combo_new ();
  gtk_widget_set_name (combo_search, "combo_search");
  gtk_widget_ref (combo_search);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "combo_search", combo_search,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (combo_search);
  gtk_box_pack_start (GTK_BOX (hbox179), combo_search, TRUE, TRUE, 0);
  gtk_combo_set_use_arrows_always (GTK_COMBO (combo_search), TRUE);

  entry_search = GTK_COMBO (combo_search)->entry;
  gtk_widget_set_name (entry_search, "entry_search");
  gtk_widget_ref (entry_search);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "entry_search", entry_search,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_search);

  button_search_whats_new = gtk_button_new_with_label (_("What's New?"));
  gtk_widget_set_name (button_search_whats_new, "button_search_whats_new");
  gtk_widget_ref (button_search_whats_new);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "button_search_whats_new", button_search_whats_new,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_search_whats_new);
  gtk_box_pack_start (GTK_BOX (hbox179), button_search_whats_new, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, button_search_whats_new, _("Look for newest files shared by nodes in the network vicinity"), NULL);

  button_search_passive = gtk_button_new_with_label ("");
  button_search_passive_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (button_search_passive)->child),
                                   _("_Passive"));
  gtk_widget_add_accelerator (button_search_passive, "clicked", accel_group,
                              button_search_passive_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (button_search_passive, "button_search_passive");
  gtk_widget_ref (button_search_passive);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "button_search_passive", button_search_passive,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_search_passive);
  gtk_box_pack_start (GTK_BOX (hbox179), button_search_passive, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, button_search_passive, _("A passive search matches any search results routed through this node"), NULL);

  hbox2112 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox2112, "hbox2112");
  gtk_widget_ref (hbox2112);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "hbox2112", hbox2112,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox2112);
  gtk_box_pack_start (GTK_BOX (vbox147), hbox2112, TRUE, TRUE, 0);

  frame_search_media_type = gtk_frame_new (_("Search Media Type"));
  gtk_widget_set_name (frame_search_media_type, "frame_search_media_type");
  gtk_widget_ref (frame_search_media_type);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "frame_search_media_type", frame_search_media_type,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame_search_media_type);
  gtk_box_pack_start (GTK_BOX (hbox2112), frame_search_media_type, FALSE, TRUE, 0);

  hbox2111 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox2111, "hbox2111");
  gtk_widget_ref (hbox2111);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "hbox2111", hbox2111,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox2111);
  gtk_container_add (GTK_CONTAINER (frame_search_media_type), hbox2111);

  button_search_media_type_any = gtk_button_new_with_label (_("Unspecified"));
  gtk_widget_set_name (button_search_media_type_any, "button_search_media_type_any");
  gtk_widget_ref (button_search_media_type_any);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "button_search_media_type_any", button_search_media_type_any,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_search_media_type_any);
  gtk_box_pack_start (GTK_BOX (hbox2111), button_search_media_type_any, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, button_search_media_type_any, _("Do not specify any media type (will match any kind of files remotely)"), NULL);

  checkbutton_config_search_media_type_audio = gtk_check_button_new_with_label (_("Audio"));
  gtk_widget_set_name (checkbutton_config_search_media_type_audio, "checkbutton_config_search_media_type_audio");
  gtk_widget_ref (checkbutton_config_search_media_type_audio);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "checkbutton_config_search_media_type_audio", checkbutton_config_search_media_type_audio,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_config_search_media_type_audio);
  gtk_box_pack_start (GTK_BOX (hbox2111), checkbutton_config_search_media_type_audio, FALSE, FALSE, 0);

  checkbutton_config_search_media_type_video = gtk_check_button_new_with_label (_("Video"));
  gtk_widget_set_name (checkbutton_config_search_media_type_video, "checkbutton_config_search_media_type_video");
  gtk_widget_ref (checkbutton_config_search_media_type_video);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "checkbutton_config_search_media_type_video", checkbutton_config_search_media_type_video,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_config_search_media_type_video);
  gtk_box_pack_start (GTK_BOX (hbox2111), checkbutton_config_search_media_type_video, FALSE, FALSE, 0);

  checkbutton_config_search_media_type_document = gtk_check_button_new_with_label (_("Document"));
  gtk_widget_set_name (checkbutton_config_search_media_type_document, "checkbutton_config_search_media_type_document");
  gtk_widget_ref (checkbutton_config_search_media_type_document);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "checkbutton_config_search_media_type_document", checkbutton_config_search_media_type_document,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_config_search_media_type_document);
  gtk_box_pack_start (GTK_BOX (hbox2111), checkbutton_config_search_media_type_document, FALSE, FALSE, 0);

  checkbutton_config_search_media_type_image = gtk_check_button_new_with_label (_("Image"));
  gtk_widget_set_name (checkbutton_config_search_media_type_image, "checkbutton_config_search_media_type_image");
  gtk_widget_ref (checkbutton_config_search_media_type_image);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "checkbutton_config_search_media_type_image", checkbutton_config_search_media_type_image,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_config_search_media_type_image);
  gtk_box_pack_start (GTK_BOX (hbox2111), checkbutton_config_search_media_type_image, FALSE, FALSE, 0);

  checkbutton_config_search_media_type_archive = gtk_check_button_new_with_label (_("Archive"));
  gtk_widget_set_name (checkbutton_config_search_media_type_archive, "checkbutton_config_search_media_type_archive");
  gtk_widget_ref (checkbutton_config_search_media_type_archive);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "checkbutton_config_search_media_type_archive", checkbutton_config_search_media_type_archive,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_config_search_media_type_archive);
  gtk_box_pack_start (GTK_BOX (hbox2111), checkbutton_config_search_media_type_archive, FALSE, FALSE, 0);

  frame157 = gtk_frame_new (_("Search Configuration"));
  gtk_widget_set_name (frame157, "frame157");
  gtk_widget_ref (frame157);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "frame157", frame157,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame157);
  gtk_box_pack_start (GTK_BOX (hbox2112), frame157, FALSE, FALSE, 0);

  hbox2113 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox2113, "hbox2113");
  gtk_widget_ref (hbox2113);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "hbox2113", hbox2113,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox2113);
  gtk_container_add (GTK_CONTAINER (frame157), hbox2113);

  option_menu_search_lifetime = gtk_option_menu_new ();
  gtk_widget_set_name (option_menu_search_lifetime, "option_menu_search_lifetime");
  gtk_widget_ref (option_menu_search_lifetime);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "option_menu_search_lifetime", option_menu_search_lifetime,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (option_menu_search_lifetime);
  gtk_box_pack_start (GTK_BOX (hbox2113), option_menu_search_lifetime, FALSE, FALSE, 0);
  option_menu_search_lifetime_menu = gtk_menu_new ();
  gtk_option_menu_set_menu (GTK_OPTION_MENU (option_menu_search_lifetime), option_menu_search_lifetime_menu);

  optionmenu_search_filter = gtk_option_menu_new ();
  gtk_widget_set_name (optionmenu_search_filter, "optionmenu_search_filter");
  gtk_widget_ref (optionmenu_search_filter);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "optionmenu_search_filter", optionmenu_search_filter,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (optionmenu_search_filter);
  gtk_box_pack_start (GTK_BOX (hbox2113), optionmenu_search_filter, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, optionmenu_search_filter, _("Search filters to apply locally on newly created searches."), NULL);
  optionmenu_search_filter_menu = gtk_menu_new ();
  gtk_option_menu_set_menu (GTK_OPTION_MENU (optionmenu_search_filter), optionmenu_search_filter_menu);

  hpaned_main = gtk_hpaned_new ();
  gtk_widget_set_name (hpaned_main, "hpaned_main");
  gtk_widget_ref (hpaned_main);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "hpaned_main", hpaned_main,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hpaned_main);
  gtk_box_pack_start (GTK_BOX (vbox12), hpaned_main, TRUE, TRUE, 0);
  gtk_paned_set_gutter_size (GTK_PANED (hpaned_main), 10);

  vbox_sidebar = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox_sidebar, "vbox_sidebar");
  gtk_widget_ref (vbox_sidebar);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "vbox_sidebar", vbox_sidebar,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox_sidebar);
  gtk_paned_pack1 (GTK_PANED (hpaned_main), vbox_sidebar, FALSE, TRUE);

  vbox46 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox46, "vbox46");
  gtk_widget_ref (vbox46);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "vbox46", vbox46,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox46);
  gtk_box_pack_start (GTK_BOX (vbox_sidebar), vbox46, TRUE, TRUE, 0);

  notebook_sidebar = gtk_notebook_new ();
  gtk_widget_set_name (notebook_sidebar, "notebook_sidebar");
  gtk_widget_ref (notebook_sidebar);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "notebook_sidebar", notebook_sidebar,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (notebook_sidebar);
  gtk_box_pack_start (GTK_BOX (vbox46), notebook_sidebar, TRUE, TRUE, 0);
  GTK_WIDGET_UNSET_FLAGS (notebook_sidebar, GTK_CAN_FOCUS);
  gtk_notebook_set_show_tabs (GTK_NOTEBOOK (notebook_sidebar), FALSE);
  gtk_notebook_set_show_border (GTK_NOTEBOOK (notebook_sidebar), FALSE);

  viewport49 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport49, "viewport49");
  gtk_widget_ref (viewport49);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "viewport49", viewport49,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (viewport49);
  gtk_container_add (GTK_CONTAINER (notebook_sidebar), viewport49);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport49), GTK_SHADOW_NONE);

  sw_searches = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (sw_searches, "sw_searches");
  gtk_widget_ref (sw_searches);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "sw_searches", sw_searches,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (sw_searches);
  gtk_container_add (GTK_CONTAINER (viewport49), sw_searches);
  gtk_widget_set_usize (sw_searches, 150, 200);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw_searches), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);

  clist_search = gtk_clist_new (3);
  gtk_widget_set_name (clist_search, "clist_search");
  gtk_widget_ref (clist_search);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "clist_search", clist_search,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (clist_search);
  gtk_container_add (GTK_CONTAINER (sw_searches), clist_search);
  gtk_clist_set_column_width (GTK_CLIST (clist_search), 0, 109);
  gtk_clist_set_column_width (GTK_CLIST (clist_search), 1, 26);
  gtk_clist_set_column_width (GTK_CLIST (clist_search), 2, 27);
  gtk_clist_set_selection_mode (GTK_CLIST (clist_search), GTK_SELECTION_BROWSE);
  gtk_clist_column_titles_show (GTK_CLIST (clist_search));

  label185 = gtk_label_new (_("Search"));
  gtk_widget_set_name (label185, "label185");
  gtk_widget_ref (label185);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label185", label185,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label185);
  gtk_clist_set_column_widget (GTK_CLIST (clist_search), 0, label185);
  gtk_misc_set_alignment (GTK_MISC (label185), 0, 0.5);

  label186 = gtk_label_new (_("Hits"));
  gtk_widget_set_name (label186, "label186");
  gtk_widget_ref (label186);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label186", label186,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label186);
  gtk_clist_set_column_widget (GTK_CLIST (clist_search), 1, label186);

  label187 = gtk_label_new (_("New"));
  gtk_widget_set_name (label187, "label187");
  gtk_widget_ref (label187);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label187", label187,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label187);
  gtk_clist_set_column_widget (GTK_CLIST (clist_search), 2, label187);

  label_nb_sb_1 = gtk_label_new ("");
  gtk_widget_set_name (label_nb_sb_1, "label_nb_sb_1");
  gtk_widget_ref (label_nb_sb_1);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label_nb_sb_1", label_nb_sb_1,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_nb_sb_1);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_sidebar), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_sidebar), 0), label_nb_sb_1);

  label189 = gtk_label_new ("");
  gtk_widget_set_name (label189, "label189");
  gtk_widget_ref (label189);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label189", label189,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label189);
  gtk_container_add (GTK_CONTAINER (notebook_sidebar), label189);

  label188 = gtk_label_new ("");
  gtk_widget_set_name (label188, "label188");
  gtk_widget_ref (label188);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label188", label188,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label188);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_sidebar), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_sidebar), 1), label188);

  vbox_sidebar_stats = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox_sidebar_stats, "vbox_sidebar_stats");
  gtk_widget_ref (vbox_sidebar_stats);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "vbox_sidebar_stats", vbox_sidebar_stats,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox_sidebar_stats);
  gtk_box_pack_start (GTK_BOX (vbox_sidebar), vbox_sidebar_stats, FALSE, TRUE, 0);

  frame75 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame75, "frame75");
  gtk_widget_ref (frame75);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "frame75", frame75,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame75);
  gtk_box_pack_start (GTK_BOX (vbox_sidebar_stats), frame75, FALSE, FALSE, 0);
  gtk_frame_set_shadow_type (GTK_FRAME (frame75), GTK_SHADOW_OUT);

  vbox108 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox108, "vbox108");
  gtk_widget_ref (vbox108);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "vbox108", vbox108,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox108);
  gtk_container_add (GTK_CONTAINER (frame75), vbox108);

  hbox_stats_connections = gtk_hbox_new (FALSE, 1);
  gtk_widget_set_name (hbox_stats_connections, "hbox_stats_connections");
  gtk_widget_ref (hbox_stats_connections);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "hbox_stats_connections", hbox_stats_connections,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox_stats_connections);
  gtk_box_pack_start (GTK_BOX (vbox108), hbox_stats_connections, FALSE, TRUE, 0);

  eventbox6 = gtk_event_box_new ();
  gtk_widget_set_name (eventbox6, "eventbox6");
  gtk_widget_ref (eventbox6);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "eventbox6", eventbox6,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (eventbox6);
  gtk_box_pack_start (GTK_BOX (hbox_stats_connections), eventbox6, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox6, _("Gnutella peers"), NULL);

  pixmap1 = create_pixmap (main_window, "smallserver.xpm");
  gtk_widget_set_name (pixmap1, "pixmap1");
  gtk_widget_ref (pixmap1);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "pixmap1", pixmap1,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (pixmap1);
  gtk_container_add (GTK_CONTAINER (eventbox6), pixmap1);
  gtk_pixmap_set_build_insensitive (GTK_PIXMAP (pixmap1), FALSE);

  progressbar_connections = gtk_progress_bar_new ();
  gtk_widget_set_name (progressbar_connections, "progressbar_connections");
  gtk_widget_ref (progressbar_connections);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "progressbar_connections", progressbar_connections,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (progressbar_connections);
  gtk_box_pack_start (GTK_BOX (hbox_stats_connections), progressbar_connections, TRUE, TRUE, 0);
  gtk_progress_set_show_text (GTK_PROGRESS (progressbar_connections), TRUE);
  gtk_progress_set_format_string (GTK_PROGRESS (progressbar_connections), _("%v/%u Gnutella peers"));

  hbox_stats_uploads = gtk_hbox_new (FALSE, 1);
  gtk_widget_set_name (hbox_stats_uploads, "hbox_stats_uploads");
  gtk_widget_ref (hbox_stats_uploads);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "hbox_stats_uploads", hbox_stats_uploads,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox_stats_uploads);
  gtk_box_pack_start (GTK_BOX (vbox108), hbox_stats_uploads, FALSE, TRUE, 0);

  eventbox7 = gtk_event_box_new ();
  gtk_widget_set_name (eventbox7, "eventbox7");
  gtk_widget_ref (eventbox7);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "eventbox7", eventbox7,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (eventbox7);
  gtk_box_pack_start (GTK_BOX (hbox_stats_uploads), eventbox7, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox7, _("uploads"), NULL);

  pixmap2 = create_pixmap (main_window, "upload.xpm");
  gtk_widget_set_name (pixmap2, "pixmap2");
  gtk_widget_ref (pixmap2);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "pixmap2", pixmap2,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (pixmap2);
  gtk_container_add (GTK_CONTAINER (eventbox7), pixmap2);
  gtk_pixmap_set_build_insensitive (GTK_PIXMAP (pixmap2), FALSE);

  progressbar_uploads = gtk_progress_bar_new ();
  gtk_widget_set_name (progressbar_uploads, "progressbar_uploads");
  gtk_widget_ref (progressbar_uploads);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "progressbar_uploads", progressbar_uploads,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (progressbar_uploads);
  gtk_box_pack_start (GTK_BOX (hbox_stats_uploads), progressbar_uploads, TRUE, TRUE, 0);
  gtk_progress_set_show_text (GTK_PROGRESS (progressbar_uploads), TRUE);
  gtk_progress_set_format_string (GTK_PROGRESS (progressbar_uploads), _("%v/%u uploads"));

  hbox_stats_downloads = gtk_hbox_new (FALSE, 1);
  gtk_widget_set_name (hbox_stats_downloads, "hbox_stats_downloads");
  gtk_widget_ref (hbox_stats_downloads);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "hbox_stats_downloads", hbox_stats_downloads,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox_stats_downloads);
  gtk_box_pack_start (GTK_BOX (vbox108), hbox_stats_downloads, FALSE, TRUE, 0);

  eventbox8 = gtk_event_box_new ();
  gtk_widget_set_name (eventbox8, "eventbox8");
  gtk_widget_ref (eventbox8);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "eventbox8", eventbox8,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (eventbox8);
  gtk_box_pack_start (GTK_BOX (hbox_stats_downloads), eventbox8, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox8, _("downloads"), NULL);

  pixmap3 = create_pixmap (main_window, "download.xpm");
  gtk_widget_set_name (pixmap3, "pixmap3");
  gtk_widget_ref (pixmap3);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "pixmap3", pixmap3,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (pixmap3);
  gtk_container_add (GTK_CONTAINER (eventbox8), pixmap3);
  gtk_pixmap_set_build_insensitive (GTK_PIXMAP (pixmap3), FALSE);

  progressbar_downloads = gtk_progress_bar_new ();
  gtk_widget_set_name (progressbar_downloads, "progressbar_downloads");
  gtk_widget_ref (progressbar_downloads);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "progressbar_downloads", progressbar_downloads,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (progressbar_downloads);
  gtk_box_pack_start (GTK_BOX (hbox_stats_downloads), progressbar_downloads, TRUE, TRUE, 0);
  gtk_progress_set_show_text (GTK_PROGRESS (progressbar_downloads), TRUE);
  gtk_progress_set_format_string (GTK_PROGRESS (progressbar_downloads), _("%v/%u downloads"));

  frame_bws_inout = gtk_frame_new (_("HTTP traffic"));
  gtk_widget_set_name (frame_bws_inout, "frame_bws_inout");
  gtk_widget_ref (frame_bws_inout);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "frame_bws_inout", frame_bws_inout,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame_bws_inout);
  gtk_box_pack_start (GTK_BOX (vbox_sidebar_stats), frame_bws_inout, FALSE, FALSE, 0);
  gtk_frame_set_label_align (GTK_FRAME (frame_bws_inout), 0.5, 0.5);
  gtk_frame_set_shadow_type (GTK_FRAME (frame_bws_inout), GTK_SHADOW_OUT);

  vbox42 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox42, "vbox42");
  gtk_widget_ref (vbox42);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "vbox42", vbox42,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox42);
  gtk_container_add (GTK_CONTAINER (frame_bws_inout), vbox42);

  progressbar_bws_in = gtk_progress_bar_new ();
  gtk_widget_set_name (progressbar_bws_in, "progressbar_bws_in");
  gtk_widget_ref (progressbar_bws_in);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "progressbar_bws_in", progressbar_bws_in,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (progressbar_bws_in);
  gtk_box_pack_start (GTK_BOX (vbox42), progressbar_bws_in, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, progressbar_bws_in, _("Click to toggle display."), NULL);
  gtk_widget_set_events (progressbar_bws_in, GDK_BUTTON_PRESS_MASK);
  gtk_progress_set_show_text (GTK_PROGRESS (progressbar_bws_in), TRUE);
  gtk_progress_set_format_string (GTK_PROGRESS (progressbar_bws_in), _("in"));

  progressbar_bws_out = gtk_progress_bar_new ();
  gtk_widget_set_name (progressbar_bws_out, "progressbar_bws_out");
  gtk_widget_ref (progressbar_bws_out);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "progressbar_bws_out", progressbar_bws_out,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (progressbar_bws_out);
  gtk_box_pack_start (GTK_BOX (vbox42), progressbar_bws_out, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, progressbar_bws_out, _("Click to toggle display."), NULL);
  gtk_widget_set_events (progressbar_bws_out, GDK_BUTTON_PRESS_MASK);
  gtk_progress_set_show_text (GTK_PROGRESS (progressbar_bws_out), TRUE);
  gtk_progress_set_format_string (GTK_PROGRESS (progressbar_bws_out), _("out"));

  frame_bws_ginout = gtk_frame_new (_("Gnutella traffic"));
  gtk_widget_set_name (frame_bws_ginout, "frame_bws_ginout");
  gtk_widget_ref (frame_bws_ginout);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "frame_bws_ginout", frame_bws_ginout,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame_bws_ginout);
  gtk_box_pack_start (GTK_BOX (vbox_sidebar_stats), frame_bws_ginout, FALSE, FALSE, 0);
  gtk_frame_set_label_align (GTK_FRAME (frame_bws_ginout), 0.5, 0.5);
  gtk_frame_set_shadow_type (GTK_FRAME (frame_bws_ginout), GTK_SHADOW_OUT);

  vbox43 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox43, "vbox43");
  gtk_widget_ref (vbox43);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "vbox43", vbox43,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox43);
  gtk_container_add (GTK_CONTAINER (frame_bws_ginout), vbox43);

  progressbar_bws_gin = gtk_progress_bar_new ();
  gtk_widget_set_name (progressbar_bws_gin, "progressbar_bws_gin");
  gtk_widget_ref (progressbar_bws_gin);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "progressbar_bws_gin", progressbar_bws_gin,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (progressbar_bws_gin);
  gtk_box_pack_start (GTK_BOX (vbox43), progressbar_bws_gin, FALSE, FALSE, 0);
  gtk_widget_set_events (progressbar_bws_gin, GDK_BUTTON_PRESS_MASK);
  gtk_progress_set_show_text (GTK_PROGRESS (progressbar_bws_gin), TRUE);
  gtk_progress_set_format_string (GTK_PROGRESS (progressbar_bws_gin), _("in"));

  progressbar_bws_gout = gtk_progress_bar_new ();
  gtk_widget_set_name (progressbar_bws_gout, "progressbar_bws_gout");
  gtk_widget_ref (progressbar_bws_gout);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "progressbar_bws_gout", progressbar_bws_gout,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (progressbar_bws_gout);
  gtk_box_pack_start (GTK_BOX (vbox43), progressbar_bws_gout, FALSE, FALSE, 0);
  gtk_widget_set_events (progressbar_bws_gout, GDK_BUTTON_PRESS_MASK);
  gtk_progress_set_show_text (GTK_PROGRESS (progressbar_bws_gout), TRUE);
  gtk_progress_set_format_string (GTK_PROGRESS (progressbar_bws_gout), _("out"));

  frame_bws_glinout = gtk_frame_new (_("Leaf traffic"));
  gtk_widget_set_name (frame_bws_glinout, "frame_bws_glinout");
  gtk_widget_ref (frame_bws_glinout);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "frame_bws_glinout", frame_bws_glinout,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame_bws_glinout);
  gtk_box_pack_start (GTK_BOX (vbox_sidebar_stats), frame_bws_glinout, TRUE, TRUE, 0);
  gtk_frame_set_label_align (GTK_FRAME (frame_bws_glinout), 0.5, 0.5);
  gtk_frame_set_shadow_type (GTK_FRAME (frame_bws_glinout), GTK_SHADOW_OUT);

  vbox107 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox107, "vbox107");
  gtk_widget_ref (vbox107);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "vbox107", vbox107,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox107);
  gtk_container_add (GTK_CONTAINER (frame_bws_glinout), vbox107);

  progressbar_bws_lin = gtk_progress_bar_new ();
  gtk_widget_set_name (progressbar_bws_lin, "progressbar_bws_lin");
  gtk_widget_ref (progressbar_bws_lin);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "progressbar_bws_lin", progressbar_bws_lin,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (progressbar_bws_lin);
  gtk_box_pack_start (GTK_BOX (vbox107), progressbar_bws_lin, FALSE, FALSE, 0);
  gtk_widget_set_events (progressbar_bws_lin, GDK_BUTTON_PRESS_MASK);
  gtk_progress_set_show_text (GTK_PROGRESS (progressbar_bws_lin), TRUE);
  gtk_progress_set_format_string (GTK_PROGRESS (progressbar_bws_lin), _("in"));

  progressbar_bws_lout = gtk_progress_bar_new ();
  gtk_widget_set_name (progressbar_bws_lout, "progressbar_bws_lout");
  gtk_widget_ref (progressbar_bws_lout);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "progressbar_bws_lout", progressbar_bws_lout,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (progressbar_bws_lout);
  gtk_box_pack_start (GTK_BOX (vbox107), progressbar_bws_lout, FALSE, FALSE, 0);
  gtk_widget_set_events (progressbar_bws_lout, GDK_BUTTON_PRESS_MASK);
  gtk_progress_set_show_text (GTK_PROGRESS (progressbar_bws_lout), TRUE);
  gtk_progress_set_format_string (GTK_PROGRESS (progressbar_bws_lout), _("out"));

  frame_bws_dht_inout = gtk_frame_new (_("DHT traffic"));
  gtk_widget_set_name (frame_bws_dht_inout, "frame_bws_dht_inout");
  gtk_widget_ref (frame_bws_dht_inout);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "frame_bws_dht_inout", frame_bws_dht_inout,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame_bws_dht_inout);
  gtk_box_pack_start (GTK_BOX (vbox_sidebar_stats), frame_bws_dht_inout, TRUE, TRUE, 0);
  gtk_frame_set_label_align (GTK_FRAME (frame_bws_dht_inout), 0.5, 0.5);
  gtk_frame_set_shadow_type (GTK_FRAME (frame_bws_dht_inout), GTK_SHADOW_OUT);

  vbox145 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox145, "vbox145");
  gtk_widget_ref (vbox145);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "vbox145", vbox145,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox145);
  gtk_container_add (GTK_CONTAINER (frame_bws_dht_inout), vbox145);

  progressbar_bws_dht_in = gtk_progress_bar_new ();
  gtk_widget_set_name (progressbar_bws_dht_in, "progressbar_bws_dht_in");
  gtk_widget_ref (progressbar_bws_dht_in);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "progressbar_bws_dht_in", progressbar_bws_dht_in,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (progressbar_bws_dht_in);
  gtk_box_pack_start (GTK_BOX (vbox145), progressbar_bws_dht_in, FALSE, FALSE, 0);
  gtk_widget_set_events (progressbar_bws_dht_in, GDK_BUTTON_PRESS_MASK);
  gtk_progress_set_show_text (GTK_PROGRESS (progressbar_bws_dht_in), TRUE);
  gtk_progress_set_format_string (GTK_PROGRESS (progressbar_bws_dht_in), _("in"));

  progressbar_bws_dht_out = gtk_progress_bar_new ();
  gtk_widget_set_name (progressbar_bws_dht_out, "progressbar_bws_dht_out");
  gtk_widget_ref (progressbar_bws_dht_out);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "progressbar_bws_dht_out", progressbar_bws_dht_out,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (progressbar_bws_dht_out);
  gtk_box_pack_start (GTK_BOX (vbox145), progressbar_bws_dht_out, FALSE, FALSE, 0);
  gtk_widget_set_events (progressbar_bws_dht_out, GDK_BUTTON_PRESS_MASK);
  gtk_progress_set_show_text (GTK_PROGRESS (progressbar_bws_dht_out), TRUE);
  gtk_progress_set_format_string (GTK_PROGRESS (progressbar_bws_dht_out), _("out"));

  vbox_right = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox_right, "vbox_right");
  gtk_widget_ref (vbox_right);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "vbox_right", vbox_right,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox_right);
  gtk_paned_pack2 (GTK_PANED (hpaned_main), vbox_right, TRUE, TRUE);

  notebook_main = gtk_notebook_new ();
  gtk_widget_set_name (notebook_main, "notebook_main");
  gtk_widget_ref (notebook_main);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "notebook_main", notebook_main,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (notebook_main);
  gtk_box_pack_start (GTK_BOX (vbox_right), notebook_main, TRUE, TRUE, 0);
  gtk_notebook_set_show_border (GTK_NOTEBOOK (notebook_main), FALSE);
  gtk_notebook_set_scrollable (GTK_NOTEBOOK (notebook_main), TRUE);
  gtk_notebook_set_tab_hborder (GTK_NOTEBOOK (notebook_main), 0);
  gtk_notebook_set_tab_vborder (GTK_NOTEBOOK (notebook_main), 0);

  vbox_gnutellanet = gtk_vbox_new (FALSE, 6);
  gtk_widget_set_name (vbox_gnutellanet, "vbox_gnutellanet");
  gtk_widget_ref (vbox_gnutellanet);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "vbox_gnutellanet", vbox_gnutellanet,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox_gnutellanet);
  gtk_container_add (GTK_CONTAINER (notebook_main), vbox_gnutellanet);

  vbox17 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox17, "vbox17");
  gtk_widget_ref (vbox17);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "vbox17", vbox17,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox17);
  gtk_box_pack_start (GTK_BOX (vbox_gnutellanet), vbox17, TRUE, TRUE, 0);

  sw_nodes = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (sw_nodes, "sw_nodes");
  gtk_widget_ref (sw_nodes);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "sw_nodes", sw_nodes,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (sw_nodes);
  gtk_box_pack_start (GTK_BOX (vbox17), sw_nodes, TRUE, TRUE, 0);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw_nodes), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);

  clist_nodes = gtk_clist_new (8);
  gtk_widget_set_name (clist_nodes, "clist_nodes");
  gtk_widget_ref (clist_nodes);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "clist_nodes", clist_nodes,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (clist_nodes);
  gtk_container_add (GTK_CONTAINER (sw_nodes), clist_nodes);
  GTK_WIDGET_UNSET_FLAGS (clist_nodes, GTK_CAN_FOCUS);
  gtk_clist_set_column_width (GTK_CLIST (clist_nodes), 0, 80);
  gtk_clist_set_column_width (GTK_CLIST (clist_nodes), 1, 36);
  gtk_clist_set_column_width (GTK_CLIST (clist_nodes), 2, 80);
  gtk_clist_set_column_width (GTK_CLIST (clist_nodes), 3, 80);
  gtk_clist_set_column_width (GTK_CLIST (clist_nodes), 4, 80);
  gtk_clist_set_column_width (GTK_CLIST (clist_nodes), 5, 80);
  gtk_clist_set_column_width (GTK_CLIST (clist_nodes), 6, 80);
  gtk_clist_set_column_width (GTK_CLIST (clist_nodes), 7, 80);
  gtk_clist_set_selection_mode (GTK_CLIST (clist_nodes), GTK_SELECTION_EXTENDED);
  gtk_clist_column_titles_show (GTK_CLIST (clist_nodes));

  label13 = gtk_label_new (_("Host"));
  gtk_widget_set_name (label13, "label13");
  gtk_widget_ref (label13);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label13", label13,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label13);
  gtk_clist_set_column_widget (GTK_CLIST (clist_nodes), 0, label13);
  gtk_misc_set_alignment (GTK_MISC (label13), 0, 0.5);

  label14b = gtk_label_new (_("Country"));
  gtk_widget_set_name (label14b, "label14b");
  gtk_widget_ref (label14b);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label14b", label14b,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label14b);
  gtk_clist_set_column_widget (GTK_CLIST (clist_nodes), 1, label14b);
  gtk_misc_set_alignment (GTK_MISC (label14b), 0, 0.5);

  label14 = gtk_label_new (_("Flags"));
  gtk_widget_set_name (label14, "label14");
  gtk_widget_ref (label14);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label14", label14,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label14);
  gtk_clist_set_column_widget (GTK_CLIST (clist_nodes), 2, label14);
  gtk_misc_set_alignment (GTK_MISC (label14), 0, 0.5);

  label_node_vendor = gtk_label_new (_("User-Agent"));
  gtk_widget_set_name (label_node_vendor, "label_node_vendor");
  gtk_widget_ref (label_node_vendor);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label_node_vendor", label_node_vendor,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_node_vendor);
  gtk_clist_set_column_widget (GTK_CLIST (clist_nodes), 3, label_node_vendor);
  gtk_misc_set_alignment (GTK_MISC (label_node_vendor), 0, 0.5);

  label_node_proto = gtk_label_new (_("Version"));
  gtk_widget_set_name (label_node_proto, "label_node_proto");
  gtk_widget_ref (label_node_proto);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label_node_proto", label_node_proto,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_node_proto);
  gtk_clist_set_column_widget (GTK_CLIST (clist_nodes), 4, label_node_proto);
  gtk_misc_set_alignment (GTK_MISC (label_node_proto), 0, 0.5);

  label_node_connected = gtk_label_new (_("Connected time"));
  gtk_widget_set_name (label_node_connected, "label_node_connected");
  gtk_widget_ref (label_node_connected);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label_node_connected", label_node_connected,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_node_connected);
  gtk_clist_set_column_widget (GTK_CLIST (clist_nodes), 5, label_node_connected);
  gtk_misc_set_alignment (GTK_MISC (label_node_connected), 0, 0.5);

  label_node_uptime = gtk_label_new (_("Uptime"));
  gtk_widget_set_name (label_node_uptime, "label_node_uptime");
  gtk_widget_ref (label_node_uptime);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label_node_uptime", label_node_uptime,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_node_uptime);
  gtk_clist_set_column_widget (GTK_CLIST (clist_nodes), 6, label_node_uptime);
  gtk_misc_set_alignment (GTK_MISC (label_node_uptime), 0, 0.5);

  label_node_info = gtk_label_new (_("Info"));
  gtk_widget_set_name (label_node_info, "label_node_info");
  gtk_widget_ref (label_node_info);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label_node_info", label_node_info,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_node_info);
  gtk_clist_set_column_widget (GTK_CLIST (clist_nodes), 7, label_node_info);
  gtk_misc_set_alignment (GTK_MISC (label_node_info), 0, 0.5);

  hbox2 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox2, "hbox2");
  gtk_widget_ref (hbox2);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "hbox2", hbox2,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox2);
  gtk_box_pack_start (GTK_BOX (vbox17), hbox2, FALSE, TRUE, 0);

  button_nodes_disconnect = gtk_button_new_with_label (_("Disconnect"));
  gtk_widget_set_name (button_nodes_disconnect, "button_nodes_disconnect");
  gtk_widget_ref (button_nodes_disconnect);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "button_nodes_disconnect", button_nodes_disconnect,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_nodes_disconnect);
  gtk_box_pack_start (GTK_BOX (hbox2), button_nodes_disconnect, FALSE, FALSE, 0);
  gtk_widget_set_sensitive (button_nodes_disconnect, FALSE);
  gtk_tooltips_set_tip (tooltips, button_nodes_disconnect, _("Disconnect from selected nodes"), NULL);

  button_nodes_add = gtk_button_new_with_label (_("Add"));
  gtk_widget_set_name (button_nodes_add, "button_nodes_add");
  gtk_widget_ref (button_nodes_add);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "button_nodes_add", button_nodes_add,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_nodes_add);
  gtk_box_pack_start (GTK_BOX (hbox2), button_nodes_add, FALSE, FALSE, 0);
  gtk_widget_set_sensitive (button_nodes_add, FALSE);
  gtk_tooltips_set_tip (tooltips, button_nodes_add, _("Try to connect to specified address"), NULL);

  entry_host = gtk_entry_new ();
  gtk_widget_set_name (entry_host, "entry_host");
  gtk_widget_ref (entry_host);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "entry_host", entry_host,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_host);
  gtk_box_pack_start (GTK_BOX (hbox2), entry_host, TRUE, TRUE, 0);

  hbox200 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox200, "hbox200");
  gtk_widget_ref (hbox200);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "hbox200", hbox200,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox200);
  gtk_box_pack_start (GTK_BOX (vbox17), hbox200, FALSE, TRUE, 0);

  hbox_normal_or_ultrapeer = gtk_table_new (2, 2, FALSE);
  gtk_widget_set_name (hbox_normal_or_ultrapeer, "hbox_normal_or_ultrapeer");
  gtk_widget_ref (hbox_normal_or_ultrapeer);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "hbox_normal_or_ultrapeer", hbox_normal_or_ultrapeer,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox_normal_or_ultrapeer);
  gtk_box_pack_start (GTK_BOX (hbox200), hbox_normal_or_ultrapeer, TRUE, TRUE, 0);
  gtk_table_set_row_spacings (GTK_TABLE (hbox_normal_or_ultrapeer), 2);
  gtk_table_set_col_spacings (GTK_TABLE (hbox_normal_or_ultrapeer), 4);

  label530 = gtk_label_new (_("Minimum"));
  gtk_widget_set_name (label530, "label530");
  gtk_widget_ref (label530);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label530", label530,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label530);
  gtk_table_attach (GTK_TABLE (hbox_normal_or_ultrapeer), label530, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label530), 0, 0.5);

  label531 = gtk_label_new (_("Maximum"));
  gtk_widget_set_name (label531, "label531");
  gtk_widget_ref (label531);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label531", label531,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label531);
  gtk_table_attach (GTK_TABLE (hbox_normal_or_ultrapeer), label531, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label531), 0, 0.5);

  spinbutton_up_connections_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 10);
  spinbutton_up_connections = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_up_connections_adj), 1, 0);
  gtk_widget_set_name (spinbutton_up_connections, "spinbutton_up_connections");
  gtk_widget_ref (spinbutton_up_connections);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "spinbutton_up_connections", spinbutton_up_connections,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_up_connections);
  gtk_table_attach (GTK_TABLE (hbox_normal_or_ultrapeer), spinbutton_up_connections, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_up_connections), TRUE);

  spinbutton_max_connections_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 10);
  spinbutton_max_connections = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_max_connections_adj), 1, 0);
  gtk_widget_set_name (spinbutton_max_connections, "spinbutton_max_connections");
  gtk_widget_ref (spinbutton_max_connections);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "spinbutton_max_connections", spinbutton_max_connections,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_max_connections);
  gtk_table_attach (GTK_TABLE (hbox_normal_or_ultrapeer), spinbutton_max_connections, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_max_connections), TRUE);

  hbox_leaf = gtk_table_new (1, 2, FALSE);
  gtk_widget_set_name (hbox_leaf, "hbox_leaf");
  gtk_widget_ref (hbox_leaf);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "hbox_leaf", hbox_leaf,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox_leaf);
  gtk_box_pack_start (GTK_BOX (hbox200), hbox_leaf, TRUE, FALSE, 0);
  gtk_table_set_row_spacings (GTK_TABLE (hbox_leaf), 2);
  gtk_table_set_col_spacings (GTK_TABLE (hbox_leaf), 4);

  label532 = gtk_label_new (_("Ultrapeers in leaf mode"));
  gtk_widget_set_name (label532, "label532");
  gtk_widget_ref (label532);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label532", label532,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label532);
  gtk_table_attach (GTK_TABLE (hbox_leaf), label532, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label532), 0, 0.5);

  spinbutton_max_ultrapeers_adj = gtk_adjustment_new (3, 0, 5, 1, 10, 10);
  spinbutton_max_ultrapeers = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_max_ultrapeers_adj), 1, 0);
  gtk_widget_set_name (spinbutton_max_ultrapeers, "spinbutton_max_ultrapeers");
  gtk_widget_ref (spinbutton_max_ultrapeers);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "spinbutton_max_ultrapeers", spinbutton_max_ultrapeers,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_max_ultrapeers);
  gtk_table_attach (GTK_TABLE (hbox_leaf), spinbutton_max_ultrapeers, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  table91 = gtk_table_new (2, 2, FALSE);
  gtk_widget_set_name (table91, "table91");
  gtk_widget_ref (table91);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "table91", table91,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table91);
  gtk_box_pack_start (GTK_BOX (hbox200), table91, TRUE, TRUE, 0);
  gtk_table_set_row_spacings (GTK_TABLE (table91), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table91), 4);

  spinbutton_quick_connect_pool_size_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 10);
  spinbutton_quick_connect_pool_size = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_quick_connect_pool_size_adj), 1, 0);
  gtk_widget_set_name (spinbutton_quick_connect_pool_size, "spinbutton_quick_connect_pool_size");
  gtk_widget_ref (spinbutton_quick_connect_pool_size);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "spinbutton_quick_connect_pool_size", spinbutton_quick_connect_pool_size,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_quick_connect_pool_size);
  gtk_table_attach (GTK_TABLE (table91), spinbutton_quick_connect_pool_size, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label680 = gtk_label_new (_("Quick-connect pool size"));
  gtk_widget_set_name (label680, "label680");
  gtk_widget_ref (label680);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label680", label680,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label680);
  gtk_table_attach (GTK_TABLE (table91), label680, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label680), 1, 0.5);

  spinbutton_max_g2_hubs_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 10);
  spinbutton_max_g2_hubs = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_max_g2_hubs_adj), 1, 0);
  gtk_widget_set_name (spinbutton_max_g2_hubs, "spinbutton_max_g2_hubs");
  gtk_widget_ref (spinbutton_max_g2_hubs);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "spinbutton_max_g2_hubs", spinbutton_max_g2_hubs,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_max_g2_hubs);
  gtk_table_attach (GTK_TABLE (table91), spinbutton_max_g2_hubs, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label8035 = gtk_label_new (_("G2 hubs"));
  gtk_widget_set_name (label8035, "label8035");
  gtk_widget_ref (label8035);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label8035", label8035,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label8035);
  gtk_table_attach (GTK_TABLE (table91), label8035, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label8035), 1, 0.5);

  vbox83 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox83, "vbox83");
  gtk_widget_ref (vbox83);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "vbox83", vbox83,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox83);
  gtk_box_pack_start (GTK_BOX (vbox_gnutellanet), vbox83, FALSE, TRUE, 0);

  frame_expert_node_info = gtk_frame_new (_("Local node"));
  gtk_widget_set_name (frame_expert_node_info, "frame_expert_node_info");
  gtk_widget_ref (frame_expert_node_info);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "frame_expert_node_info", frame_expert_node_info,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame_expert_node_info);
  gtk_box_pack_start (GTK_BOX (vbox83), frame_expert_node_info, TRUE, TRUE, 0);

  vbox34 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox34, "vbox34");
  gtk_widget_ref (vbox34);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "vbox34", vbox34,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox34);
  gtk_container_add (GTK_CONTAINER (frame_expert_node_info), vbox34);

  table6 = gtk_table_new (1, 6, FALSE);
  gtk_widget_set_name (table6, "table6");
  gtk_widget_ref (table6);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "table6", table6,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table6);
  gtk_box_pack_start (GTK_BOX (vbox34), table6, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (table6), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table6), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table6), 4);

  label150 = gtk_label_new (_("GUID:"));
  gtk_widget_set_name (label150, "label150");
  gtk_widget_ref (label150);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label150", label150,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label150);
  gtk_table_attach (GTK_TABLE (table6), label150, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label150), 0, 0.5);

  entry_nodes_guid = gtk_entry_new ();
  gtk_widget_set_name (entry_nodes_guid, "entry_nodes_guid");
  gtk_widget_ref (entry_nodes_guid);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "entry_nodes_guid", entry_nodes_guid,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_nodes_guid);
  gtk_table_attach (GTK_TABLE (table6), entry_nodes_guid, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_usize (entry_nodes_guid, 72, -2);
  gtk_entry_set_editable (GTK_ENTRY (entry_nodes_guid), FALSE);

  label151 = gtk_label_new (_("IP:Port:"));
  gtk_widget_set_name (label151, "label151");
  gtk_widget_ref (label151);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label151", label151,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label151);
  gtk_table_attach (GTK_TABLE (table6), label151, 4, 5, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label151), 0, 0.5);

  entry_nodes_ip = gtk_entry_new ();
  gtk_widget_set_name (entry_nodes_ip, "entry_nodes_ip");
  gtk_widget_ref (entry_nodes_ip);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "entry_nodes_ip", entry_nodes_ip,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_nodes_ip);
  gtk_table_attach (GTK_TABLE (table6), entry_nodes_ip, 5, 6, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_usize (entry_nodes_ip, 72, -2);
  gtk_tooltips_set_tip (tooltips, entry_nodes_ip, _("The current IP address and listening port for this node. To change these go to File->Preferences->Network."), NULL);
  gtk_entry_set_editable (GTK_ENTRY (entry_nodes_ip), FALSE);

  label8024 = gtk_label_new (_("KUID:"));
  gtk_widget_set_name (label8024, "label8024");
  gtk_widget_ref (label8024);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label8024", label8024,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label8024);
  gtk_table_attach (GTK_TABLE (table6), label8024, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label8024), 0, 0.5);

  entry_nodes_kuid = gtk_entry_new ();
  gtk_widget_set_name (entry_nodes_kuid, "entry_nodes_kuid");
  gtk_widget_ref (entry_nodes_kuid);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "entry_nodes_kuid", entry_nodes_kuid,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_nodes_kuid);
  gtk_table_attach (GTK_TABLE (table6), entry_nodes_kuid, 3, 4, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_usize (entry_nodes_kuid, 72, -2);
  gtk_entry_set_editable (GTK_ENTRY (entry_nodes_kuid), FALSE);

  label7986 = gtk_label_new (_("Network"));
  gtk_widget_set_name (label7986, "label7986");
  gtk_widget_ref (label7986);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label7986", label7986,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label7986);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_main), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_main), 0), label7986);

  vbox76 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox76, "vbox76");
  gtk_widget_ref (vbox76);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "vbox76", vbox76,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox76);
  gtk_container_add (GTK_CONTAINER (notebook_main), vbox76);

  hbox146 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox146, "hbox146");
  gtk_widget_ref (hbox146);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "hbox146", hbox146,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox146);
  gtk_box_pack_start (GTK_BOX (vbox76), hbox146, FALSE, TRUE, 0);

  label651 = gtk_label_new (_("Current search:"));
  gtk_widget_set_name (label651, "label651");
  gtk_widget_ref (label651);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label651", label651,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label651);
  gtk_box_pack_start (GTK_BOX (hbox146), label651, FALSE, FALSE, 0);

  option_menu_searches = gtk_option_menu_new ();
  gtk_widget_set_name (option_menu_searches, "option_menu_searches");
  gtk_widget_ref (option_menu_searches);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "option_menu_searches", option_menu_searches,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (option_menu_searches);
  gtk_box_pack_start (GTK_BOX (hbox146), option_menu_searches, TRUE, TRUE, 0);
  option_menu_searches_menu = gtk_menu_new ();
  gtk_option_menu_set_menu (GTK_OPTION_MENU (option_menu_searches), option_menu_searches_menu);

  viewport51 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport51, "viewport51");
  gtk_widget_ref (viewport51);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "viewport51", viewport51,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (viewport51);
  gtk_box_pack_start (GTK_BOX (hbox146), viewport51, TRUE, TRUE, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport51), GTK_SHADOW_ETCHED_IN);

  hbox2107 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox2107, "hbox2107");
  gtk_widget_ref (hbox2107);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "hbox2107", hbox2107,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox2107);
  gtk_container_add (GTK_CONTAINER (viewport51), hbox2107);

  label_search_expiry = gtk_label_new ("");
  gtk_widget_set_name (label_search_expiry, "label_search_expiry");
  gtk_widget_ref (label_search_expiry);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label_search_expiry", label_search_expiry,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_search_expiry);
  gtk_box_pack_start (GTK_BOX (hbox2107), label_search_expiry, FALSE, TRUE, 0);
  gtk_misc_set_alignment (GTK_MISC (label_search_expiry), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_search_expiry), 5, 0);

  button_search_close = gtk_button_new_with_label ("");
  button_search_close_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (button_search_close)->child),
                                   _("Cl_ose search"));
  gtk_widget_add_accelerator (button_search_close, "clicked", accel_group,
                              button_search_close_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (button_search_close, "button_search_close");
  gtk_widget_ref (button_search_close);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "button_search_close", button_search_close,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_search_close);
  gtk_box_pack_start (GTK_BOX (hbox146), button_search_close, FALSE, FALSE, 0);
  gtk_widget_set_sensitive (button_search_close, FALSE);

  vpaned_results = gtk_vpaned_new ();
  gtk_widget_set_name (vpaned_results, "vpaned_results");
  gtk_widget_ref (vpaned_results);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "vpaned_results", vpaned_results,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vpaned_results);
  gtk_box_pack_start (GTK_BOX (vbox76), vpaned_results, TRUE, TRUE, 0);
  gtk_paned_set_gutter_size (GTK_PANED (vpaned_results), 10);
  gtk_paned_set_position (GTK_PANED (vpaned_results), 354);

  notebook_search_results = gtk_notebook_new ();
  gtk_widget_set_name (notebook_search_results, "notebook_search_results");
  gtk_widget_ref (notebook_search_results);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "notebook_search_results", notebook_search_results,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (notebook_search_results);
  gtk_paned_pack1 (GTK_PANED (vpaned_results), notebook_search_results, FALSE, TRUE);
  gtk_notebook_set_show_border (GTK_NOTEBOOK (notebook_search_results), FALSE);
  gtk_notebook_popup_enable (GTK_NOTEBOOK (notebook_search_results));

  empty_notebook_page = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (empty_notebook_page);
  gtk_container_add (GTK_CONTAINER (notebook_search_results), empty_notebook_page);

  label190 = gtk_label_new (_("(no search)"));
  gtk_widget_set_name (label190, "label190");
  gtk_widget_ref (label190);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label190", label190,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label190);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_search_results), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_search_results), 0), label190);

  scrolledwindow47 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow47, "scrolledwindow47");
  gtk_widget_ref (scrolledwindow47);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "scrolledwindow47", scrolledwindow47,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (scrolledwindow47);
  gtk_paned_pack2 (GTK_PANED (vpaned_results), scrolledwindow47, TRUE, TRUE);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow47), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);

  viewport45 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport45, "viewport45");
  gtk_widget_ref (viewport45);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "viewport45", viewport45,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (viewport45);
  gtk_container_add (GTK_CONTAINER (scrolledwindow47), viewport45);

  notebook4 = gtk_notebook_new ();
  gtk_widget_set_name (notebook4, "notebook4");
  gtk_widget_ref (notebook4);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "notebook4", notebook4,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (notebook4);
  gtk_container_add (GTK_CONTAINER (viewport45), notebook4);

  scrolledwindow495 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow495, "scrolledwindow495");
  gtk_widget_ref (scrolledwindow495);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "scrolledwindow495", scrolledwindow495,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (scrolledwindow495);
  gtk_container_add (GTK_CONTAINER (notebook4), scrolledwindow495);

  clist_search_details = gtk_clist_new (2);
  gtk_widget_set_name (clist_search_details, "clist_search_details");
  gtk_widget_ref (clist_search_details);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "clist_search_details", clist_search_details,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (clist_search_details);
  gtk_container_add (GTK_CONTAINER (scrolledwindow495), clist_search_details);
  gtk_clist_set_column_width (GTK_CLIST (clist_search_details), 0, 80);
  gtk_clist_set_column_width (GTK_CLIST (clist_search_details), 1, 80);
  gtk_clist_column_titles_hide (GTK_CLIST (clist_search_details));

  label794 = gtk_label_new (_("label794"));
  gtk_widget_set_name (label794, "label794");
  gtk_widget_ref (label794);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label794", label794,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label794);
  gtk_clist_set_column_widget (GTK_CLIST (clist_search_details), 0, label794);

  label795 = gtk_label_new (_("label795"));
  gtk_widget_set_name (label795, "label795");
  gtk_widget_ref (label795);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label795", label795,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label795);
  gtk_clist_set_column_widget (GTK_CLIST (clist_search_details), 1, label795);

  label788 = gtk_label_new (_("Details"));
  gtk_widget_set_name (label788, "label788");
  gtk_widget_ref (label788);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label788", label788,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label788);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook4), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook4), 0), label788);

  scrolledwindow491 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow491, "scrolledwindow491");
  gtk_widget_ref (scrolledwindow491);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "scrolledwindow491", scrolledwindow491,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (scrolledwindow491);
  gtk_container_add (GTK_CONTAINER (notebook4), scrolledwindow491);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow491), GTK_POLICY_NEVER, GTK_POLICY_ALWAYS);

  text_result_info_xml = gtk_text_new (NULL, NULL);
  gtk_widget_set_name (text_result_info_xml, "text_result_info_xml");
  gtk_widget_ref (text_result_info_xml);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "text_result_info_xml", text_result_info_xml,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (text_result_info_xml);
  gtk_container_add (GTK_CONTAINER (scrolledwindow491), text_result_info_xml);

  label793 = gtk_label_new (_("XML Metadata"));
  gtk_widget_set_name (label793, "label793");
  gtk_widget_ref (label793);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label793", label793,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label793);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook4), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook4), 1), label793);

  table68 = gtk_table_new (7, 4, FALSE);
  gtk_widget_set_name (table68, "table68");
  gtk_widget_ref (table68);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "table68", table68,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table68);
  gtk_container_add (GTK_CONTAINER (notebook4), table68);
  gtk_container_set_border_width (GTK_CONTAINER (table68), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table68), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table68), 4);

  checkbutton_search_hide_downloaded = gtk_check_button_new_with_label ("");
  checkbutton_search_hide_downloaded_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (checkbutton_search_hide_downloaded)->child),
                                   _("_Hide downloaded files"));
  gtk_widget_add_accelerator (checkbutton_search_hide_downloaded, "clicked", accel_group,
                              checkbutton_search_hide_downloaded_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (checkbutton_search_hide_downloaded, "checkbutton_search_hide_downloaded");
  gtk_widget_ref (checkbutton_search_hide_downloaded);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "checkbutton_search_hide_downloaded", checkbutton_search_hide_downloaded,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_search_hide_downloaded);
  gtk_table_attach (GTK_TABLE (table68), checkbutton_search_hide_downloaded, 2, 4, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_search_remove_downloaded = gtk_check_button_new_with_label ("");
  checkbutton_search_remove_downloaded_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (checkbutton_search_remove_downloaded)->child),
                                   _("_Remove manually downloaded files"));
  gtk_widget_add_accelerator (checkbutton_search_remove_downloaded, "clicked", accel_group,
                              checkbutton_search_remove_downloaded_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (checkbutton_search_remove_downloaded, "checkbutton_search_remove_downloaded");
  gtk_widget_ref (checkbutton_search_remove_downloaded);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "checkbutton_search_remove_downloaded", checkbutton_search_remove_downloaded,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_search_remove_downloaded);
  gtk_table_attach (GTK_TABLE (table68), checkbutton_search_remove_downloaded, 2, 4, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_browse_copied_to_passive = gtk_check_button_new_with_label (_("Copy browse-host results to passive searches"));
  gtk_widget_set_name (checkbutton_browse_copied_to_passive, "checkbutton_browse_copied_to_passive");
  gtk_widget_ref (checkbutton_browse_copied_to_passive);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "checkbutton_browse_copied_to_passive", checkbutton_browse_copied_to_passive,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_browse_copied_to_passive);
  gtk_table_attach (GTK_TABLE (table68), checkbutton_browse_copied_to_passive, 2, 4, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_search_discard_hashless = gtk_check_button_new_with_label (_("Discard results without SHA-1 hashes"));
  gtk_widget_set_name (checkbutton_search_discard_hashless, "checkbutton_search_discard_hashless");
  gtk_widget_ref (checkbutton_search_discard_hashless);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "checkbutton_search_discard_hashless", checkbutton_search_discard_hashless,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_search_discard_hashless);
  gtk_table_attach (GTK_TABLE (table68), checkbutton_search_discard_hashless, 2, 4, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_search_discard_spam = gtk_check_button_new_with_label (_("Discard spam"));
  gtk_widget_set_name (checkbutton_search_discard_spam, "checkbutton_search_discard_spam");
  gtk_widget_ref (checkbutton_search_discard_spam);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "checkbutton_search_discard_spam", checkbutton_search_discard_spam,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_search_discard_spam);
  gtk_table_attach (GTK_TABLE (table68), checkbutton_search_discard_spam, 2, 4, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  alignment38 = gtk_alignment_new (0, 0.5, 0.15, 1);
  gtk_widget_set_name (alignment38, "alignment38");
  gtk_widget_ref (alignment38);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "alignment38", alignment38,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (alignment38);
  gtk_table_attach (GTK_TABLE (table68), alignment38, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  spinbutton_browse_host_max_results_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 10);
  spinbutton_browse_host_max_results = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_browse_host_max_results_adj), 1, 0);
  gtk_widget_set_name (spinbutton_browse_host_max_results, "spinbutton_browse_host_max_results");
  gtk_widget_ref (spinbutton_browse_host_max_results);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "spinbutton_browse_host_max_results", spinbutton_browse_host_max_results,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_browse_host_max_results);
  gtk_container_add (GTK_CONTAINER (alignment38), spinbutton_browse_host_max_results);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_browse_host_max_results), TRUE);

  label460 = gtk_label_new (_("Max. number of What's New? results"));
  gtk_widget_set_name (label460, "label460");
  gtk_widget_ref (label460);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label460", label460,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label460);
  gtk_table_attach (GTK_TABLE (table68), label460, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label460), 0, 0.5);

  label783 = gtk_label_new (_("Max. number of browse host results"));
  gtk_widget_set_name (label783, "label783");
  gtk_widget_ref (label783);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label783", label783,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label783);
  gtk_table_attach (GTK_TABLE (table68), label783, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label783), 0, 0.5);

  label541 = gtk_label_new (_("Ignored files are"));
  gtk_widget_set_name (label541, "label541");
  gtk_widget_ref (label541);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label541", label541,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label541);
  gtk_table_attach (GTK_TABLE (table68), label541, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label541), GTK_JUSTIFY_RIGHT);
  gtk_misc_set_alignment (GTK_MISC (label541), 0, 0.5);

  option_menu_search_handle_ignored_files = gtk_option_menu_new ();
  gtk_widget_set_name (option_menu_search_handle_ignored_files, "option_menu_search_handle_ignored_files");
  gtk_widget_ref (option_menu_search_handle_ignored_files);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "option_menu_search_handle_ignored_files", option_menu_search_handle_ignored_files,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (option_menu_search_handle_ignored_files);
  gtk_table_attach (GTK_TABLE (table68), option_menu_search_handle_ignored_files, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  option_menu_search_handle_ignored_files_menu = gtk_menu_new ();
  gtk_option_menu_set_menu (GTK_OPTION_MENU (option_menu_search_handle_ignored_files), option_menu_search_handle_ignored_files_menu);

  label8030 = gtk_label_new (_("Max. number of passive results"));
  gtk_widget_set_name (label8030, "label8030");
  gtk_widget_ref (label8030);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label8030", label8030,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label8030);
  gtk_table_attach (GTK_TABLE (table68), label8030, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label8030), GTK_JUSTIFY_RIGHT);
  gtk_misc_set_alignment (GTK_MISC (label8030), 0, 0.5);

  alignment39 = gtk_alignment_new (0, 0.5, 0.15, 1);
  gtk_widget_set_name (alignment39, "alignment39");
  gtk_widget_ref (alignment39);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "alignment39", alignment39,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (alignment39);
  gtk_table_attach (GTK_TABLE (table68), alignment39, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  spinbutton_passive_search_max_results_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 10);
  spinbutton_passive_search_max_results = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_passive_search_max_results_adj), 1, 0);
  gtk_widget_set_name (spinbutton_passive_search_max_results, "spinbutton_passive_search_max_results");
  gtk_widget_ref (spinbutton_passive_search_max_results);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "spinbutton_passive_search_max_results", spinbutton_passive_search_max_results,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_passive_search_max_results);
  gtk_container_add (GTK_CONTAINER (alignment39), spinbutton_passive_search_max_results);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_passive_search_max_results), TRUE);

  checkbutton_search_sort_casesense = gtk_check_button_new_with_label (_("Case-sensitive sorting"));
  gtk_widget_set_name (checkbutton_search_sort_casesense, "checkbutton_search_sort_casesense");
  gtk_widget_ref (checkbutton_search_sort_casesense);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "checkbutton_search_sort_casesense", checkbutton_search_sort_casesense,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_search_sort_casesense);
  gtk_table_attach (GTK_TABLE (table68), checkbutton_search_sort_casesense, 0, 1, 5, 6,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label8031 = gtk_label_new ("");
  gtk_label_parse_uline (GTK_LABEL (label8031),
                         _("Max. _number of results"));
  gtk_widget_set_name (label8031, "label8031");
  gtk_widget_ref (label8031);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label8031", label8031,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label8031);
  gtk_table_attach (GTK_TABLE (table68), label8031, 0, 1, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label8031), 0, 0.5);

  alignment27 = gtk_alignment_new (0, 0.5, 0.15, 1);
  gtk_widget_set_name (alignment27, "alignment27");
  gtk_widget_ref (alignment27);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "alignment27", alignment27,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (alignment27);
  gtk_table_attach (GTK_TABLE (table68), alignment27, 1, 2, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  spinbutton_search_max_results_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 10);
  spinbutton_search_max_results = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_search_max_results_adj), 1, 0);
  gtk_widget_set_name (spinbutton_search_max_results, "spinbutton_search_max_results");
  gtk_widget_ref (spinbutton_search_max_results);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "spinbutton_search_max_results", spinbutton_search_max_results,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_search_max_results);
  gtk_container_add (GTK_CONTAINER (alignment27), spinbutton_search_max_results);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_search_max_results), TRUE);

  alignment40 = gtk_alignment_new (0, 0.5, 0.15, 1);
  gtk_widget_set_name (alignment40, "alignment40");
  gtk_widget_ref (alignment40);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "alignment40", alignment40,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (alignment40);
  gtk_table_attach (GTK_TABLE (table68), alignment40, 1, 2, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  spinbutton_whats_new_search_max_results_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 10);
  spinbutton_whats_new_search_max_results = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_whats_new_search_max_results_adj), 1, 0);
  gtk_widget_set_name (spinbutton_whats_new_search_max_results, "spinbutton_whats_new_search_max_results");
  gtk_widget_ref (spinbutton_whats_new_search_max_results);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "spinbutton_whats_new_search_max_results", spinbutton_whats_new_search_max_results,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_whats_new_search_max_results);
  gtk_container_add (GTK_CONTAINER (alignment40), spinbutton_whats_new_search_max_results);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_whats_new_search_max_results), TRUE);

  checkbutton_search_discard_alien_ip = gtk_check_button_new_with_label (_("Discard results bearing an alien IP address"));
  gtk_widget_set_name (checkbutton_search_discard_alien_ip, "checkbutton_search_discard_alien_ip");
  gtk_widget_ref (checkbutton_search_discard_alien_ip);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "checkbutton_search_discard_alien_ip", checkbutton_search_discard_alien_ip,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_search_discard_alien_ip);
  gtk_table_attach (GTK_TABLE (table68), checkbutton_search_discard_alien_ip, 2, 3, 5, 6,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_search_discard_banned_guid = gtk_check_button_new_with_label (_("Discard results bearing a banned GUID"));
  gtk_widget_set_name (checkbutton_search_discard_banned_guid, "checkbutton_search_discard_banned_guid");
  gtk_widget_ref (checkbutton_search_discard_banned_guid);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "checkbutton_search_discard_banned_guid", checkbutton_search_discard_banned_guid,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_search_discard_banned_guid);
  gtk_table_attach (GTK_TABLE (table68), checkbutton_search_discard_banned_guid, 2, 3, 6, 7,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_search_display_guess_stats = gtk_check_button_new_with_label (_("Display GUESS statistics"));
  gtk_widget_set_name (checkbutton_search_display_guess_stats, "checkbutton_search_display_guess_stats");
  gtk_widget_ref (checkbutton_search_display_guess_stats);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "checkbutton_search_display_guess_stats", checkbutton_search_display_guess_stats,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_search_display_guess_stats);
  gtk_table_attach (GTK_TABLE (table68), checkbutton_search_display_guess_stats, 0, 1, 6, 7,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label789 = gtk_label_new (_("General search settings (affect all searches)"));
  gtk_widget_set_name (label789, "label789");
  gtk_widget_ref (label789);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label789", label789,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label789);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook4), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook4), 2), label789);

  guess_stats_line = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (guess_stats_line, "guess_stats_line");
  gtk_widget_ref (guess_stats_line);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "guess_stats_line", guess_stats_line,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (guess_stats_line);
  gtk_box_pack_start (GTK_BOX (vbox76), guess_stats_line, FALSE, TRUE, 0);

  viewport_fix_flashing_3 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport_fix_flashing_3, "viewport_fix_flashing_3");
  gtk_widget_ref (viewport_fix_flashing_3);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "viewport_fix_flashing_3", viewport_fix_flashing_3,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (viewport_fix_flashing_3);
  gtk_box_pack_start (GTK_BOX (guess_stats_line), viewport_fix_flashing_3, TRUE, TRUE, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport_fix_flashing_3), GTK_SHADOW_ETCHED_IN);

  hbox2114 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox2114, "hbox2114");
  gtk_widget_ref (hbox2114);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "hbox2114", hbox2114,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox2114);
  gtk_container_add (GTK_CONTAINER (viewport_fix_flashing_3), hbox2114);

  label_guess_stats = gtk_label_new ("");
  gtk_widget_set_name (label_guess_stats, "label_guess_stats");
  gtk_widget_ref (label_guess_stats);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label_guess_stats", label_guess_stats,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_guess_stats);
  gtk_box_pack_start (GTK_BOX (hbox2114), label_guess_stats, TRUE, TRUE, 0);
  gtk_misc_set_alignment (GTK_MISC (label_guess_stats), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_guess_stats), 5, 0);

  checkbutton_guess_stats_show_total = gtk_check_button_new_with_label (_("Total"));
  gtk_widget_set_name (checkbutton_guess_stats_show_total, "checkbutton_guess_stats_show_total");
  gtk_widget_ref (checkbutton_guess_stats_show_total);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "checkbutton_guess_stats_show_total", checkbutton_guess_stats_show_total,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_guess_stats_show_total);
  gtk_box_pack_start (GTK_BOX (guess_stats_line), checkbutton_guess_stats_show_total, FALSE, FALSE, 0);

  hbox147 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox147, "hbox147");
  gtk_widget_ref (hbox147);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "hbox147", hbox147,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox147);
  gtk_box_pack_start (GTK_BOX (vbox76), hbox147, FALSE, TRUE, 0);

  viewport_fix_flashing_1 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport_fix_flashing_1, "viewport_fix_flashing_1");
  gtk_widget_ref (viewport_fix_flashing_1);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "viewport_fix_flashing_1", viewport_fix_flashing_1,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (viewport_fix_flashing_1);
  gtk_box_pack_start (GTK_BOX (hbox147), viewport_fix_flashing_1, TRUE, TRUE, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport_fix_flashing_1), GTK_SHADOW_ETCHED_IN);

  hbox167 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox167, "hbox167");
  gtk_widget_ref (hbox167);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "hbox167", hbox167,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox167);
  gtk_container_add (GTK_CONTAINER (viewport_fix_flashing_1), hbox167);

  label_items_found = gtk_label_new ("");
  gtk_widget_set_name (label_items_found, "label_items_found");
  gtk_widget_ref (label_items_found);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label_items_found", label_items_found,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_items_found);
  gtk_box_pack_start (GTK_BOX (hbox167), label_items_found, TRUE, TRUE, 0);
  gtk_misc_set_alignment (GTK_MISC (label_items_found), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_items_found), 5, 0);

  hbox_expert_search_timeout = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox_expert_search_timeout, "hbox_expert_search_timeout");
  gtk_widget_ref (hbox_expert_search_timeout);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "hbox_expert_search_timeout", hbox_expert_search_timeout,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox_expert_search_timeout);
  gtk_box_pack_start (GTK_BOX (hbox147), hbox_expert_search_timeout, FALSE, FALSE, 0);

  search_reissue_label = gtk_label_new ("");
  search_reissue_label_key = gtk_label_parse_uline (GTK_LABEL (search_reissue_label),
                                   _("Re_try search every"));
  gtk_widget_set_name (search_reissue_label, "search_reissue_label");
  gtk_widget_ref (search_reissue_label);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "search_reissue_label", search_reissue_label,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (search_reissue_label);
  gtk_box_pack_start (GTK_BOX (hbox_expert_search_timeout), search_reissue_label, FALSE, FALSE, 0);
  gtk_misc_set_alignment (GTK_MISC (search_reissue_label), 1, 0.5);

  spinbutton_search_reissue_timeout_adj = gtk_adjustment_new (600, 0, 100000, 60, 600, 600);
  spinbutton_search_reissue_timeout = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_search_reissue_timeout_adj), 1, 0);
  gtk_widget_set_name (spinbutton_search_reissue_timeout, "spinbutton_search_reissue_timeout");
  gtk_widget_ref (spinbutton_search_reissue_timeout);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "spinbutton_search_reissue_timeout", spinbutton_search_reissue_timeout,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_search_reissue_timeout);
  gtk_box_pack_start (GTK_BOX (hbox_expert_search_timeout), spinbutton_search_reissue_timeout, TRUE, TRUE, 0);
  gtk_widget_set_usize (spinbutton_search_reissue_timeout, 70, -2);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_search_reissue_timeout), TRUE);

  label_search_reissue = gtk_label_new (_("secs   "));
  gtk_widget_set_name (label_search_reissue, "label_search_reissue");
  gtk_widget_ref (label_search_reissue);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label_search_reissue", label_search_reissue,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_search_reissue);
  gtk_box_pack_start (GTK_BOX (hbox_expert_search_timeout), label_search_reissue, FALSE, FALSE, 0);

  hbox181 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox181, "hbox181");
  gtk_widget_ref (hbox181);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "hbox181", hbox181,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox181);
  gtk_box_pack_start (GTK_BOX (vbox76), hbox181, FALSE, TRUE, 0);

  button_search_download = gtk_button_new_with_label ("");
  button_search_download_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (button_search_download)->child),
                                   _("_Download selected"));
  gtk_widget_add_accelerator (button_search_download, "clicked", accel_group,
                              button_search_download_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (button_search_download, "button_search_download");
  gtk_widget_ref (button_search_download);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "button_search_download", button_search_download,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_search_download);
  gtk_box_pack_start (GTK_BOX (hbox181), button_search_download, FALSE, FALSE, 0);
  gtk_widget_set_sensitive (button_search_download, FALSE);
  gtk_widget_add_accelerator (button_search_download, "clicked", accel_group,
                              GDK_d, GDK_CONTROL_MASK,
                              GTK_ACCEL_VISIBLE);

  button_search_filter = gtk_button_new_with_label ("");
  button_search_filter_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (button_search_filter)->child),
                                   _("_Edit filters"));
  gtk_widget_add_accelerator (button_search_filter, "clicked", accel_group,
                              button_search_filter_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (button_search_filter, "button_search_filter");
  gtk_widget_ref (button_search_filter);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "button_search_filter", button_search_filter,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_search_filter);
  gtk_box_pack_start (GTK_BOX (hbox181), button_search_filter, FALSE, FALSE, 0);
  GTK_WIDGET_UNSET_FLAGS (button_search_filter, GTK_CAN_FOCUS);

  label294 = gtk_label_new ("");
  gtk_widget_set_name (label294, "label294");
  gtk_widget_ref (label294);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label294", label294,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label294);
  gtk_box_pack_start (GTK_BOX (hbox181), label294, TRUE, TRUE, 0);

  label650 = gtk_label_new ("");
  gtk_widget_set_name (label650, "label650");
  gtk_widget_ref (label650);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label650", label650,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label650);
  gtk_box_pack_start (GTK_BOX (hbox181), label650, TRUE, TRUE, 0);

  button_search_clear = gtk_button_new_with_label (_("Clear results"));
  gtk_widget_set_name (button_search_clear, "button_search_clear");
  gtk_widget_ref (button_search_clear);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "button_search_clear", button_search_clear,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_search_clear);
  gtk_box_pack_start (GTK_BOX (hbox181), button_search_clear, FALSE, FALSE, 0);
  gtk_widget_set_sensitive (button_search_clear, FALSE);

  label7985 = gtk_label_new (_("Searches"));
  gtk_widget_set_name (label7985, "label7985");
  gtk_widget_ref (label7985);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label7985", label7985,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label7985);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_main), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_main), 1), label7985);

  vbox143 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox143, "vbox143");
  gtk_widget_ref (vbox143);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "vbox143", vbox143,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox143);
  gtk_container_add (GTK_CONTAINER (notebook_main), vbox143);

  vpaned_fileinfo = gtk_vpaned_new ();
  gtk_widget_set_name (vpaned_fileinfo, "vpaned_fileinfo");
  gtk_widget_ref (vpaned_fileinfo);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "vpaned_fileinfo", vpaned_fileinfo,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vpaned_fileinfo);
  gtk_box_pack_start (GTK_BOX (vbox143), vpaned_fileinfo, TRUE, TRUE, 0);
  gtk_paned_set_gutter_size (GTK_PANED (vpaned_fileinfo), 10);
  gtk_paned_set_position (GTK_PANED (vpaned_fileinfo), 305);

  viewport52 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport52, "viewport52");
  gtk_widget_ref (viewport52);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "viewport52", viewport52,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (viewport52);
  gtk_paned_pack1 (GTK_PANED (vpaned_fileinfo), viewport52, FALSE, TRUE);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport52), GTK_SHADOW_NONE);

  notebook_downloads = gtk_notebook_new ();
  gtk_widget_set_name (notebook_downloads, "notebook_downloads");
  gtk_widget_ref (notebook_downloads);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "notebook_downloads", notebook_downloads,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (notebook_downloads);
  gtk_container_add (GTK_CONTAINER (viewport52), notebook_downloads);
  gtk_notebook_set_show_border (GTK_NOTEBOOK (notebook_downloads), FALSE);
  gtk_notebook_set_tab_pos (GTK_NOTEBOOK (notebook_downloads), GTK_POS_BOTTOM);
  gtk_notebook_set_scrollable (GTK_NOTEBOOK (notebook_downloads), TRUE);
  gtk_notebook_set_tab_hborder (GTK_NOTEBOOK (notebook_downloads), 0);
  gtk_notebook_set_tab_vborder (GTK_NOTEBOOK (notebook_downloads), 0);

  empty_notebook_page = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (empty_notebook_page);
  gtk_container_add (GTK_CONTAINER (notebook_downloads), empty_notebook_page);

  scrolledwindow577 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow577, "scrolledwindow577");
  gtk_widget_ref (scrolledwindow577);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "scrolledwindow577", scrolledwindow577,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (scrolledwindow577);
  gtk_paned_pack2 (GTK_PANED (vpaned_fileinfo), scrolledwindow577, TRUE, TRUE);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow577), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);

  viewport53 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport53, "viewport53");
  gtk_widget_ref (viewport53);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "viewport53", viewport53,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (viewport53);
  gtk_container_add (GTK_CONTAINER (scrolledwindow577), viewport53);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport53), GTK_SHADOW_NONE);

  vbox140 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox140, "vbox140");
  gtk_widget_ref (vbox140);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "vbox140", vbox140,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox140);
  gtk_container_add (GTK_CONTAINER (viewport53), vbox140);

  table59 = gtk_table_new (1, 2, FALSE);
  gtk_widget_set_name (table59, "table59");
  gtk_widget_ref (table59);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "table59", table59,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table59);
  gtk_box_pack_start (GTK_BOX (vbox140), table59, FALSE, TRUE, 0);

  label658 = gtk_label_new (_("Progress:"));
  gtk_widget_set_name (label658, "label658");
  gtk_widget_ref (label658);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label658", label658,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label658);
  gtk_table_attach (GTK_TABLE (table59), label658, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 3, 0);
  gtk_misc_set_alignment (GTK_MISC (label658), 0, 0.5);

  viewport44 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport44, "viewport44");
  gtk_widget_ref (viewport44);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "viewport44", viewport44,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (viewport44);
  gtk_table_attach (GTK_TABLE (table59), viewport44, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport44), GTK_SHADOW_ETCHED_IN);

  drawingarea_fi_progress = gtk_drawing_area_new ();
  gtk_widget_set_name (drawingarea_fi_progress, "drawingarea_fi_progress");
  gtk_widget_ref (drawingarea_fi_progress);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "drawingarea_fi_progress", drawingarea_fi_progress,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (drawingarea_fi_progress);
  gtk_container_add (GTK_CONTAINER (viewport44), drawingarea_fi_progress);
  gtk_widget_set_usize (drawingarea_fi_progress, -2, 16);
  gtk_tooltips_set_tip (tooltips, drawingarea_fi_progress, _("Shows visual information on the download progress. Green chunks have been downloaded, with the brighter green chunks touched during this session. Yellow chunks are active right now; these active chunks are also marked with a triangle. Red chunks have not been downloaded yet. The blue line indicates which parts of the file have been seen on the network in this session."), NULL);
  gtk_widget_set_events (drawingarea_fi_progress, GDK_ENTER_NOTIFY_MASK | GDK_LEAVE_NOTIFY_MASK);

  notebook5 = gtk_notebook_new ();
  gtk_widget_set_name (notebook5, "notebook5");
  gtk_widget_ref (notebook5);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "notebook5", notebook5,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (notebook5);
  gtk_box_pack_start (GTK_BOX (vbox140), notebook5, TRUE, TRUE, 0);
  gtk_notebook_set_show_border (GTK_NOTEBOOK (notebook5), FALSE);
  gtk_notebook_set_tab_pos (GTK_NOTEBOOK (notebook5), GTK_POS_BOTTOM);
  gtk_notebook_set_scrollable (GTK_NOTEBOOK (notebook5), TRUE);
  gtk_notebook_set_tab_hborder (GTK_NOTEBOOK (notebook5), 0);
  gtk_notebook_set_tab_vborder (GTK_NOTEBOOK (notebook5), 0);

  vbox110 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox110, "vbox110");
  gtk_widget_ref (vbox110);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "vbox110", vbox110,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox110);
  gtk_container_add (GTK_CONTAINER (notebook5), vbox110);

  scrolledwindow496 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow496, "scrolledwindow496");
  gtk_widget_ref (scrolledwindow496);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "scrolledwindow496", scrolledwindow496,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (scrolledwindow496);
  gtk_box_pack_start (GTK_BOX (vbox110), scrolledwindow496, TRUE, TRUE, 0);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow496), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);

  clist_download_details = gtk_clist_new (2);
  gtk_widget_set_name (clist_download_details, "clist_download_details");
  gtk_widget_ref (clist_download_details);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "clist_download_details", clist_download_details,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (clist_download_details);
  gtk_container_add (GTK_CONTAINER (scrolledwindow496), clist_download_details);
  gtk_clist_set_column_width (GTK_CLIST (clist_download_details), 0, 80);
  gtk_clist_set_column_width (GTK_CLIST (clist_download_details), 1, 80);
  gtk_clist_column_titles_hide (GTK_CLIST (clist_download_details));
  gtk_clist_set_shadow_type (GTK_CLIST (clist_download_details), GTK_SHADOW_ETCHED_IN);

  label796 = gtk_label_new ("");
  gtk_widget_set_name (label796, "label796");
  gtk_widget_ref (label796);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label796", label796,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label796);
  gtk_clist_set_column_widget (GTK_CLIST (clist_download_details), 0, label796);

  label7977 = gtk_label_new ("");
  gtk_widget_set_name (label7977, "label7977");
  gtk_widget_ref (label7977);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label7977", label7977,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label7977);
  gtk_clist_set_column_widget (GTK_CLIST (clist_download_details), 1, label7977);

  label790 = gtk_label_new (_("Details"));
  gtk_widget_set_name (label790, "label790");
  gtk_widget_ref (label790);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label790", label790,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label790);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook5), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook5), 0), label790);

  scrolledwindow44 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow44, "scrolledwindow44");
  gtk_widget_ref (scrolledwindow44);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "scrolledwindow44", scrolledwindow44,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (scrolledwindow44);
  gtk_container_add (GTK_CONTAINER (notebook5), scrolledwindow44);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow44), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);

  clist_download_aliases = gtk_clist_new (1);
  gtk_widget_set_name (clist_download_aliases, "clist_download_aliases");
  gtk_widget_ref (clist_download_aliases);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "clist_download_aliases", clist_download_aliases,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (clist_download_aliases);
  gtk_container_add (GTK_CONTAINER (scrolledwindow44), clist_download_aliases);
  gtk_clist_set_column_width (GTK_CLIST (clist_download_aliases), 0, 80);
  gtk_clist_column_titles_hide (GTK_CLIST (clist_download_aliases));
  gtk_clist_set_shadow_type (GTK_CLIST (clist_download_aliases), GTK_SHADOW_ETCHED_IN);

  label526 = gtk_label_new ("");
  gtk_widget_set_name (label526, "label526");
  gtk_widget_ref (label526);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label526", label526,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label526);
  gtk_clist_set_column_widget (GTK_CLIST (clist_download_aliases), 0, label526);

  label791 = gtk_label_new (_("Aliases"));
  gtk_widget_set_name (label791, "label791");
  gtk_widget_ref (label791);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label791", label791,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label791);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook5), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook5), 1), label791);

  scrolledwindow4971 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow4971, "scrolledwindow4971");
  gtk_widget_ref (scrolledwindow4971);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "scrolledwindow4971", scrolledwindow4971,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (scrolledwindow4971);
  gtk_container_add (GTK_CONTAINER (notebook5), scrolledwindow4971);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow4971), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);

  clist_download_sources = gtk_clist_new (6);
  gtk_widget_set_name (clist_download_sources, "clist_download_sources");
  gtk_widget_ref (clist_download_sources);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "clist_download_sources", clist_download_sources,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (clist_download_sources);
  gtk_container_add (GTK_CONTAINER (scrolledwindow4971), clist_download_sources);
  gtk_clist_set_column_width (GTK_CLIST (clist_download_sources), 0, 80);
  gtk_clist_set_column_width (GTK_CLIST (clist_download_sources), 1, 80);
  gtk_clist_set_column_width (GTK_CLIST (clist_download_sources), 2, 80);
  gtk_clist_set_column_width (GTK_CLIST (clist_download_sources), 3, 80);
  gtk_clist_set_column_width (GTK_CLIST (clist_download_sources), 4, 80);
  gtk_clist_set_column_width (GTK_CLIST (clist_download_sources), 5, 80);
  gtk_clist_set_selection_mode (GTK_CLIST (clist_download_sources), GTK_SELECTION_EXTENDED);
  gtk_clist_column_titles_show (GTK_CLIST (clist_download_sources));

  label7998 = gtk_label_new (_("Host"));
  gtk_widget_set_name (label7998, "label7998");
  gtk_widget_ref (label7998);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label7998", label7998,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label7998);
  gtk_clist_set_column_widget (GTK_CLIST (clist_download_sources), 0, label7998);

  label7999 = gtk_label_new (_("Country"));
  gtk_widget_set_name (label7999, "label7999");
  gtk_widget_ref (label7999);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label7999", label7999,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label7999);
  gtk_clist_set_column_widget (GTK_CLIST (clist_download_sources), 1, label7999);

  label8000 = gtk_label_new (_("Server"));
  gtk_widget_set_name (label8000, "label8000");
  gtk_widget_ref (label8000);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label8000", label8000,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label8000);
  gtk_clist_set_column_widget (GTK_CLIST (clist_download_sources), 2, label8000);

  label8001 = gtk_label_new (_("Range"));
  gtk_widget_set_name (label8001, "label8001");
  gtk_widget_ref (label8001);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label8001", label8001,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label8001);
  gtk_clist_set_column_widget (GTK_CLIST (clist_download_sources), 3, label8001);

  label8002 = gtk_label_new (_("Progress"));
  gtk_widget_set_name (label8002, "label8002");
  gtk_widget_ref (label8002);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label8002", label8002,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label8002);
  gtk_clist_set_column_widget (GTK_CLIST (clist_download_sources), 4, label8002);

  label8003 = gtk_label_new (_("Status"));
  gtk_widget_set_name (label8003, "label8003");
  gtk_widget_ref (label8003);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label8003", label8003,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label8003);
  gtk_clist_set_column_widget (GTK_CLIST (clist_download_sources), 5, label8003);

  label792 = gtk_label_new (_("Sources"));
  gtk_widget_set_name (label792, "label792");
  gtk_widget_ref (label792);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label792", label792,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label792);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook5), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook5), 2), label792);

  frame152 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame152, "frame152");
  gtk_widget_ref (frame152);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "frame152", frame152,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame152);
  gtk_container_add (GTK_CONTAINER (notebook5), frame152);

  vbox144 = gtk_vbox_new (FALSE, 4);
  gtk_widget_set_name (vbox144, "vbox144");
  gtk_widget_ref (vbox144);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "vbox144", vbox144,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox144);
  gtk_container_add (GTK_CONTAINER (frame152), vbox144);
  gtk_container_set_border_width (GTK_CONTAINER (vbox144), 2);

  table99 = gtk_table_new (2, 4, FALSE);
  gtk_widget_set_name (table99, "table99");
  gtk_widget_ref (table99);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "table99", table99,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table99);
  gtk_box_pack_start (GTK_BOX (vbox144), table99, FALSE, TRUE, 0);
  gtk_table_set_col_spacings (GTK_TABLE (table99), 2);

  label149 = gtk_label_new (_("Select files by regex"));
  gtk_widget_set_name (label149, "label149");
  gtk_widget_ref (label149);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label149", label149,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label149);
  gtk_table_attach (GTK_TABLE (table99), label149, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label149), 0, 0.5);

  label8006 = gtk_label_new (_("Filter files by regex"));
  gtk_widget_set_name (label8006, "label8006");
  gtk_widget_ref (label8006);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label8006", label8006,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label8006);
  gtk_table_attach (GTK_TABLE (table99), label8006, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label8006), 0, 0.5);

  checkbutton_downloads_filter_regex_case = gtk_check_button_new_with_label (_("case-sensitive"));
  gtk_widget_set_name (checkbutton_downloads_filter_regex_case, "checkbutton_downloads_filter_regex_case");
  gtk_widget_ref (checkbutton_downloads_filter_regex_case);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "checkbutton_downloads_filter_regex_case", checkbutton_downloads_filter_regex_case,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_downloads_filter_regex_case);
  gtk_table_attach (GTK_TABLE (table99), checkbutton_downloads_filter_regex_case, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_downloads_select_regex_invert = gtk_check_button_new_with_label (_("invert"));
  gtk_widget_set_name (checkbutton_downloads_select_regex_invert, "checkbutton_downloads_select_regex_invert");
  gtk_widget_ref (checkbutton_downloads_select_regex_invert);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "checkbutton_downloads_select_regex_invert", checkbutton_downloads_select_regex_invert,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_downloads_select_regex_invert);
  gtk_table_attach (GTK_TABLE (table99), checkbutton_downloads_select_regex_invert, 3, 4, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_downloads_filter_regex_invert = gtk_check_button_new_with_label (_("invert"));
  gtk_widget_set_name (checkbutton_downloads_filter_regex_invert, "checkbutton_downloads_filter_regex_invert");
  gtk_widget_ref (checkbutton_downloads_filter_regex_invert);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "checkbutton_downloads_filter_regex_invert", checkbutton_downloads_filter_regex_invert,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_downloads_filter_regex_invert);
  gtk_table_attach (GTK_TABLE (table99), checkbutton_downloads_filter_regex_invert, 3, 4, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_downloads_select_regex_case = gtk_check_button_new_with_label (_("case-sensitive"));
  gtk_widget_set_name (checkbutton_downloads_select_regex_case, "checkbutton_downloads_select_regex_case");
  gtk_widget_ref (checkbutton_downloads_select_regex_case);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "checkbutton_downloads_select_regex_case", checkbutton_downloads_select_regex_case,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_downloads_select_regex_case);
  gtk_table_attach (GTK_TABLE (table99), checkbutton_downloads_select_regex_case, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_downloads_select_regex = gtk_entry_new ();
  gtk_widget_set_name (entry_downloads_select_regex, "entry_downloads_select_regex");
  gtk_widget_ref (entry_downloads_select_regex);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "entry_downloads_select_regex", entry_downloads_select_regex,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_downloads_select_regex);
  gtk_table_attach (GTK_TABLE (table99), entry_downloads_select_regex, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_downloads_filter_regex = gtk_entry_new ();
  gtk_widget_set_name (entry_downloads_filter_regex, "entry_downloads_filter_regex");
  gtk_widget_ref (entry_downloads_filter_regex);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "entry_downloads_filter_regex", entry_downloads_filter_regex,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_downloads_filter_regex);
  gtk_table_attach (GTK_TABLE (table99), entry_downloads_filter_regex, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  hbox86 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox86, "hbox86");
  gtk_widget_ref (hbox86);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "hbox86", hbox86,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox86);
  gtk_box_pack_start (GTK_BOX (vbox144), hbox86, FALSE, TRUE, 0);

  button_downloads_clear_stopped = gtk_button_new_with_label (_("Clear stopped"));
  gtk_widget_set_name (button_downloads_clear_stopped, "button_downloads_clear_stopped");
  gtk_widget_ref (button_downloads_clear_stopped);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "button_downloads_clear_stopped", button_downloads_clear_stopped,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_downloads_clear_stopped);
  gtk_box_pack_start (GTK_BOX (hbox86), button_downloads_clear_stopped, FALSE, TRUE, 0);
  gtk_widget_set_sensitive (button_downloads_clear_stopped, FALSE);
  gtk_tooltips_set_tip (tooltips, button_downloads_clear_stopped, _("Clear completed, failed and unavailable downloads from list"), NULL);

  label7995 = gtk_label_new (_("Tools"));
  gtk_widget_set_name (label7995, "label7995");
  gtk_widget_ref (label7995);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label7995", label7995,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label7995);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook5), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook5), 3), label7995);

  frame151 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame151, "frame151");
  gtk_widget_ref (frame151);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "frame151", frame151,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame151);
  gtk_container_add (GTK_CONTAINER (notebook5), frame151);

  hbox189 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox189, "hbox189");
  gtk_widget_ref (hbox189);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "hbox189", hbox189,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox189);
  gtk_container_add (GTK_CONTAINER (frame151), hbox189);
  gtk_container_set_border_width (GTK_CONTAINER (hbox189), 2);

  alignment32 = gtk_alignment_new (0, 0.5, 0, 1);
  gtk_widget_set_name (alignment32, "alignment32");
  gtk_widget_ref (alignment32);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "alignment32", alignment32,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (alignment32);
  gtk_box_pack_start (GTK_BOX (hbox189), alignment32, FALSE, TRUE, 0);

  table85 = gtk_table_new (4, 3, FALSE);
  gtk_widget_set_name (table85, "table85");
  gtk_widget_ref (table85);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "table85", table85,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table85);
  gtk_container_add (GTK_CONTAINER (alignment32), table85);
  gtk_table_set_row_spacings (GTK_TABLE (table85), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table85), 4);

  checkbutton_downloads_never_push = gtk_check_button_new_with_label (_("Never send a push request"));
  gtk_widget_set_name (checkbutton_downloads_never_push, "checkbutton_downloads_never_push");
  gtk_widget_ref (checkbutton_downloads_never_push);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "checkbutton_downloads_never_push", checkbutton_downloads_never_push,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_downloads_never_push);
  gtk_table_attach (GTK_TABLE (table85), checkbutton_downloads_never_push, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_download_delete_aborted = gtk_check_button_new_with_label (_("Delete file on abort"));
  gtk_widget_set_name (checkbutton_download_delete_aborted, "checkbutton_download_delete_aborted");
  gtk_widget_ref (checkbutton_download_delete_aborted);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "checkbutton_download_delete_aborted", checkbutton_download_delete_aborted,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_download_delete_aborted);
  gtk_table_attach (GTK_TABLE (table85), checkbutton_download_delete_aborted, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_dl_remove_file_on_mismatch = gtk_check_button_new_with_label (_("Delete file on mismatch"));
  gtk_widget_set_name (checkbutton_dl_remove_file_on_mismatch, "checkbutton_dl_remove_file_on_mismatch");
  gtk_widget_ref (checkbutton_dl_remove_file_on_mismatch);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "checkbutton_dl_remove_file_on_mismatch", checkbutton_dl_remove_file_on_mismatch,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_dl_remove_file_on_mismatch);
  gtk_table_attach (GTK_TABLE (table85), checkbutton_dl_remove_file_on_mismatch, 2, 3, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label639a = gtk_label_new (_("Bytes to back off on mismatch"));
  gtk_widget_set_name (label639a, "label639a");
  gtk_widget_ref (label639a);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label639a", label639a,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label639a);
  gtk_table_attach (GTK_TABLE (table85), label639a, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label639a), GTK_JUSTIFY_RIGHT);
  gtk_misc_set_alignment (GTK_MISC (label639a), 0, 0.5);

  spinbutton_mismatch_backout_adj = gtk_adjustment_new (50000, 0, 250000, 1000, 10000, 10);
  spinbutton_mismatch_backout = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_mismatch_backout_adj), 100, 0);
  gtk_widget_set_name (spinbutton_mismatch_backout, "spinbutton_mismatch_backout");
  gtk_widget_ref (spinbutton_mismatch_backout);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "spinbutton_mismatch_backout", spinbutton_mismatch_backout,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_mismatch_backout);
  gtk_table_attach (GTK_TABLE (table85), spinbutton_mismatch_backout, 1, 2, 3, 4,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_usize (spinbutton_mismatch_backout, 68, -2);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_mismatch_backout), TRUE);

  label80 = gtk_label_new (_("Max. downloads from single host"));
  gtk_widget_set_name (label80, "label80");
  gtk_widget_ref (label80);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label80", label80,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label80);
  gtk_table_attach (GTK_TABLE (table85), label80, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label80), 0, 0.5);

  label64 = gtk_label_new (_("Max. simultaneous downloads"));
  gtk_widget_set_name (label64, "label64");
  gtk_widget_ref (label64);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label64", label64,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label64);
  gtk_table_attach (GTK_TABLE (table85), label64, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label64), 0, 0.5);

  label787 = gtk_label_new (_("Max. simultaneous downloads per file"));
  gtk_widget_set_name (label787, "label787");
  gtk_widget_ref (label787);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label787", label787,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label787);
  gtk_table_attach (GTK_TABLE (table85), label787, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label787), 0, 0.5);

  spinbutton_max_host_downloads_adj = gtk_adjustment_new (1, 1, 100, 1, 10, 10);
  spinbutton_max_host_downloads = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_max_host_downloads_adj), 1, 0);
  gtk_widget_set_name (spinbutton_max_host_downloads, "spinbutton_max_host_downloads");
  gtk_widget_ref (spinbutton_max_host_downloads);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "spinbutton_max_host_downloads", spinbutton_max_host_downloads,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_max_host_downloads);
  gtk_table_attach (GTK_TABLE (table85), spinbutton_max_host_downloads, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_max_host_downloads), TRUE);

  spinbutton_max_downloads_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 10);
  spinbutton_max_downloads = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_max_downloads_adj), 1, 0);
  gtk_widget_set_name (spinbutton_max_downloads, "spinbutton_max_downloads");
  gtk_widget_ref (spinbutton_max_downloads);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "spinbutton_max_downloads", spinbutton_max_downloads,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_max_downloads);
  gtk_table_attach (GTK_TABLE (table85), spinbutton_max_downloads, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_max_downloads), TRUE);

  spinbutton_max_file_downloads_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 10);
  spinbutton_max_file_downloads = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_max_file_downloads_adj), 1, 0);
  gtk_widget_set_name (spinbutton_max_file_downloads, "spinbutton_max_file_downloads");
  gtk_widget_ref (spinbutton_max_file_downloads);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "spinbutton_max_file_downloads", spinbutton_max_file_downloads,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_max_file_downloads);
  gtk_table_attach (GTK_TABLE (table85), spinbutton_max_file_downloads, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_max_file_downloads), TRUE);

  vbox124 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox124, "vbox124");
  gtk_widget_ref (vbox124);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "vbox124", vbox124,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox124);
  gtk_box_pack_start (GTK_BOX (hbox189), vbox124, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (vbox124), 4);

  checkbutton_dl_clear_finished = gtk_check_button_new_with_label (_("Automatically clear finished files"));
  gtk_widget_set_name (checkbutton_dl_clear_finished, "checkbutton_dl_clear_finished");
  gtk_widget_ref (checkbutton_dl_clear_finished);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "checkbutton_dl_clear_finished", checkbutton_dl_clear_finished,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_dl_clear_finished);
  gtk_box_pack_start (GTK_BOX (vbox124), checkbutton_dl_clear_finished, FALSE, TRUE, 0);

  frame_dl_autoclear = gtk_frame_new (_("Automatically clear sources when..."));
  gtk_widget_set_name (frame_dl_autoclear, "frame_dl_autoclear");
  gtk_widget_ref (frame_dl_autoclear);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "frame_dl_autoclear", frame_dl_autoclear,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame_dl_autoclear);
  gtk_box_pack_start (GTK_BOX (vbox124), frame_dl_autoclear, FALSE, TRUE, 0);

  vbox118 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox118, "vbox118");
  gtk_widget_ref (vbox118);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "vbox118", vbox118,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox118);
  gtk_container_add (GTK_CONTAINER (frame_dl_autoclear), vbox118);
  gtk_container_set_border_width (GTK_CONTAINER (vbox118), 2);

  checkbutton_dl_clear_complete = gtk_check_button_new_with_label (_("completed"));
  gtk_widget_set_name (checkbutton_dl_clear_complete, "checkbutton_dl_clear_complete");
  gtk_widget_ref (checkbutton_dl_clear_complete);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "checkbutton_dl_clear_complete", checkbutton_dl_clear_complete,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_dl_clear_complete);
  gtk_box_pack_start (GTK_BOX (vbox118), checkbutton_dl_clear_complete, FALSE, TRUE, 0);

  checkbutton_dl_clear_failed = gtk_check_button_new_with_label (_("failed"));
  gtk_widget_set_name (checkbutton_dl_clear_failed, "checkbutton_dl_clear_failed");
  gtk_widget_ref (checkbutton_dl_clear_failed);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "checkbutton_dl_clear_failed", checkbutton_dl_clear_failed,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_dl_clear_failed);
  gtk_box_pack_start (GTK_BOX (vbox118), checkbutton_dl_clear_failed, FALSE, TRUE, 0);

  checkbutton_dl_clear_unavailable = gtk_check_button_new_with_label (_("unavailable"));
  gtk_widget_set_name (checkbutton_dl_clear_unavailable, "checkbutton_dl_clear_unavailable");
  gtk_widget_ref (checkbutton_dl_clear_unavailable);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "checkbutton_dl_clear_unavailable", checkbutton_dl_clear_unavailable,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_dl_clear_unavailable);
  gtk_box_pack_start (GTK_BOX (vbox118), checkbutton_dl_clear_unavailable, FALSE, TRUE, 0);

  label8009 = gtk_label_new (_("Settings"));
  gtk_widget_set_name (label8009, "label8009");
  gtk_widget_ref (label8009);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label8009", label8009,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label8009);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook5), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook5), 4), label8009);

  hbox197a = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox197a, "hbox197a");
  gtk_widget_ref (hbox197a);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "hbox197a", hbox197a,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox197a);
  gtk_box_pack_start (GTK_BOX (vbox143), hbox197a, FALSE, FALSE, 0);

  togglebutton_queue_freeze = gtk_toggle_button_new ();
  gtk_widget_set_name (togglebutton_queue_freeze, "togglebutton_queue_freeze");
  gtk_widget_ref (togglebutton_queue_freeze);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "togglebutton_queue_freeze", togglebutton_queue_freeze,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (togglebutton_queue_freeze);
  gtk_box_pack_start (GTK_BOX (hbox197a), togglebutton_queue_freeze, FALSE, FALSE, 0);

  hbox159 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox159, "hbox159");
  gtk_widget_ref (hbox159);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "hbox159", hbox159,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox159);
  gtk_container_add (GTK_CONTAINER (togglebutton_queue_freeze), hbox159);

  vbox_queue_freeze = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox_queue_freeze, "vbox_queue_freeze");
  gtk_widget_ref (vbox_queue_freeze);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "vbox_queue_freeze", vbox_queue_freeze,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox_queue_freeze);
  gtk_box_pack_start (GTK_BOX (hbox159), vbox_queue_freeze, TRUE, TRUE, 0);

  label406 = gtk_label_new (_("Freeze queue"));
  gtk_widget_set_name (label406, "label406");
  gtk_widget_ref (label406);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label406", label406,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label406);
  gtk_box_pack_start (GTK_BOX (vbox_queue_freeze), label406, TRUE, TRUE, 0);

  vbox_queue_thaw = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox_queue_thaw, "vbox_queue_thaw");
  gtk_widget_ref (vbox_queue_thaw);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "vbox_queue_thaw", vbox_queue_thaw,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_box_pack_start (GTK_BOX (hbox159), vbox_queue_thaw, TRUE, TRUE, 0);

  label407 = gtk_label_new (_("Thaw queue"));
  gtk_widget_set_name (label407, "label407");
  gtk_widget_ref (label407);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label407", label407,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label407);
  gtk_box_pack_start (GTK_BOX (vbox_queue_thaw), label407, TRUE, TRUE, 0);

  frame150 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame150, "frame150");
  gtk_widget_ref (frame150);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "frame150", frame150,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame150);
  gtk_box_pack_start (GTK_BOX (hbox197a), frame150, TRUE, TRUE, 0);

  hbox197 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox197, "hbox197");
  gtk_widget_ref (hbox197);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "hbox197", hbox197,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox197);
  gtk_container_add (GTK_CONTAINER (frame150), hbox197);

  hbox175 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox175, "hbox175");
  gtk_widget_ref (hbox175);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "hbox175", hbox175,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox175);
  gtk_box_pack_start (GTK_BOX (hbox197), hbox175, TRUE, TRUE, 3);

  label_fi_all_count = gtk_label_new (_("[all count]"));
  gtk_widget_set_name (label_fi_all_count, "label_fi_all_count");
  gtk_widget_ref (label_fi_all_count);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label_fi_all_count", label_fi_all_count,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_fi_all_count);
  gtk_box_pack_start (GTK_BOX (hbox175), label_fi_all_count, TRUE, TRUE, 0);
  gtk_misc_set_alignment (GTK_MISC (label_fi_all_count), 1, 0.5);

  label542 = gtk_label_new (_(" registered, "));
  gtk_widget_set_name (label542, "label542");
  gtk_widget_ref (label542);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label542", label542,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label542);
  gtk_box_pack_start (GTK_BOX (hbox175), label542, FALSE, FALSE, 0);
  gtk_widget_set_usize (label542, -2, 21);

  label_fi_with_source_count = gtk_label_new (_("[with source count]"));
  gtk_widget_set_name (label_fi_with_source_count, "label_fi_with_source_count");
  gtk_widget_ref (label_fi_with_source_count);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label_fi_with_source_count", label_fi_with_source_count,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_fi_with_source_count);
  gtk_box_pack_start (GTK_BOX (hbox175), label_fi_with_source_count, FALSE, FALSE, 0);

  label545 = gtk_label_new (_(" with sources"));
  gtk_widget_set_name (label545, "label545");
  gtk_widget_ref (label545);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label545", label545,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label545);
  gtk_box_pack_start (GTK_BOX (hbox175), label545, FALSE, FALSE, 0);

  hbox169 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox169, "hbox169");
  gtk_widget_ref (hbox169);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "hbox169", hbox169,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox169);
  gtk_box_pack_start (GTK_BOX (hbox197), hbox169, TRUE, TRUE, 0);

  label_dl_queue_count = gtk_label_new (_("[queued downloads]"));
  gtk_widget_set_name (label_dl_queue_count, "label_dl_queue_count");
  gtk_widget_ref (label_dl_queue_count);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label_dl_queue_count", label_dl_queue_count,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_dl_queue_count);
  gtk_box_pack_start (GTK_BOX (hbox169), label_dl_queue_count, TRUE, TRUE, 0);
  gtk_misc_set_alignment (GTK_MISC (label_dl_queue_count), 1, 0.5);

  label507 = gtk_label_new (_(" queued ("));
  gtk_widget_set_name (label507, "label507");
  gtk_widget_ref (label507);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label507", label507,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label507);
  gtk_box_pack_start (GTK_BOX (hbox169), label507, FALSE, FALSE, 0);

  label_dl_qalive_count = gtk_label_new (_("[hosts alive]"));
  gtk_widget_set_name (label_dl_qalive_count, "label_dl_qalive_count");
  gtk_widget_ref (label_dl_qalive_count);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label_dl_qalive_count", label_dl_qalive_count,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_dl_qalive_count);
  gtk_box_pack_start (GTK_BOX (hbox169), label_dl_qalive_count, FALSE, FALSE, 0);

  label506 = gtk_label_new (_(" alive with "));
  gtk_widget_set_name (label506, "label506");
  gtk_widget_ref (label506);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label506", label506,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label506);
  gtk_box_pack_start (GTK_BOX (hbox169), label506, FALSE, FALSE, 0);

  label_dl_pqueued_count = gtk_label_new (_("queued"));
  gtk_widget_set_name (label_dl_pqueued_count, "label_dl_pqueued_count");
  gtk_widget_ref (label_dl_pqueued_count);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label_dl_pqueued_count", label_dl_pqueued_count,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_dl_pqueued_count);
  gtk_box_pack_start (GTK_BOX (hbox169), label_dl_pqueued_count, FALSE, FALSE, 0);

  label539 = gtk_label_new (_(" passive)"));
  gtk_widget_set_name (label539, "label539");
  gtk_widget_ref (label539);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label539", label539,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label539);
  gtk_box_pack_start (GTK_BOX (hbox169), label539, FALSE, FALSE, 0);

  hbox166 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox166, "hbox166");
  gtk_widget_ref (hbox166);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "hbox166", hbox166,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox166);
  gtk_box_pack_start (GTK_BOX (hbox197), hbox166, TRUE, TRUE, 0);

  label_dl_running_count = gtk_label_new (_("[running]"));
  gtk_widget_set_name (label_dl_running_count, "label_dl_running_count");
  gtk_widget_ref (label_dl_running_count);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label_dl_running_count", label_dl_running_count,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_dl_running_count);
  gtk_box_pack_start (GTK_BOX (hbox166), label_dl_running_count, TRUE, TRUE, 0);
  gtk_misc_set_alignment (GTK_MISC (label_dl_running_count), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_dl_running_count), 5, 0);

  label533 = gtk_label_new (_("("));
  gtk_widget_set_name (label533, "label533");
  gtk_widget_ref (label533);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label533", label533,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label533);
  gtk_box_pack_start (GTK_BOX (hbox166), label533, FALSE, FALSE, 0);

  label_dl_active_count = gtk_label_new (_("active"));
  gtk_widget_set_name (label_dl_active_count, "label_dl_active_count");
  gtk_widget_ref (label_dl_active_count);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label_dl_active_count", label_dl_active_count,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_dl_active_count);
  gtk_box_pack_start (GTK_BOX (hbox166), label_dl_active_count, FALSE, FALSE, 0);

  label537 = gtk_label_new (_(", "));
  gtk_widget_set_name (label537, "label537");
  gtk_widget_ref (label537);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label537", label537,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label537);
  gtk_box_pack_start (GTK_BOX (hbox166), label537, FALSE, FALSE, 0);

  label_dl_aqueued_count = gtk_label_new (_("queued"));
  gtk_widget_set_name (label_dl_aqueued_count, "label_dl_aqueued_count");
  gtk_widget_ref (label_dl_aqueued_count);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label_dl_aqueued_count", label_dl_aqueued_count,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_dl_aqueued_count);
  gtk_box_pack_start (GTK_BOX (hbox166), label_dl_aqueued_count, FALSE, FALSE, 0);

  label536 = gtk_label_new (_(")"));
  gtk_widget_set_name (label536, "label536");
  gtk_widget_ref (label536);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label536", label536,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label536);
  gtk_box_pack_start (GTK_BOX (hbox166), label536, FALSE, FALSE, 0);

  label8004 = gtk_label_new ("");
  gtk_widget_set_name (label8004, "label8004");
  gtk_widget_ref (label8004);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label8004", label8004,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label8004);
  gtk_box_pack_start (GTK_BOX (hbox166), label8004, FALSE, TRUE, 0);
  gtk_misc_set_padding (GTK_MISC (label8004), 4, 0);

  label7984 = gtk_label_new (_("Downloads"));
  gtk_widget_set_name (label7984, "label7984");
  gtk_widget_ref (label7984);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label7984", label7984,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label7984);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_main), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_main), 2), label7984);

  vbox18 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox18, "vbox18");
  gtk_widget_ref (vbox18);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "vbox18", vbox18,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox18);
  gtk_container_add (GTK_CONTAINER (notebook_main), vbox18);

  scrolledwindow9 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow9, "scrolledwindow9");
  gtk_widget_ref (scrolledwindow9);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "scrolledwindow9", scrolledwindow9,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (scrolledwindow9);
  gtk_box_pack_start (GTK_BOX (vbox18), scrolledwindow9, TRUE, TRUE, 0);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow9), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);

  clist_uploads = gtk_clist_new (8);
  gtk_widget_set_name (clist_uploads, "clist_uploads");
  gtk_widget_ref (clist_uploads);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "clist_uploads", clist_uploads,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (clist_uploads);
  gtk_container_add (GTK_CONTAINER (scrolledwindow9), clist_uploads);
  gtk_clist_set_column_width (GTK_CLIST (clist_uploads), 0, 80);
  gtk_clist_set_column_width (GTK_CLIST (clist_uploads), 1, 60);
  gtk_clist_set_column_width (GTK_CLIST (clist_uploads), 2, 36);
  gtk_clist_set_column_width (GTK_CLIST (clist_uploads), 3, 40);
  gtk_clist_set_column_width (GTK_CLIST (clist_uploads), 4, 40);
  gtk_clist_set_column_width (GTK_CLIST (clist_uploads), 5, 60);
  gtk_clist_set_column_width (GTK_CLIST (clist_uploads), 6, 80);
  gtk_clist_set_column_width (GTK_CLIST (clist_uploads), 7, 80);
  gtk_clist_set_selection_mode (GTK_CLIST (clist_uploads), GTK_SELECTION_EXTENDED);
  gtk_clist_column_titles_show (GTK_CLIST (clist_uploads));

  label72 = gtk_label_new (_("Filename"));
  gtk_widget_set_name (label72, "label72");
  gtk_widget_ref (label72);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label72", label72,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label72);
  gtk_clist_set_column_widget (GTK_CLIST (clist_uploads), 0, label72);
  gtk_misc_set_alignment (GTK_MISC (label72), 0, 0.5);

  label73 = gtk_label_new (_("Host"));
  gtk_widget_set_name (label73, "label73");
  gtk_widget_ref (label73);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label73", label73,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label73);
  gtk_clist_set_column_widget (GTK_CLIST (clist_uploads), 1, label73);
  gtk_misc_set_alignment (GTK_MISC (label73), 0, 0.5);

  label73b = gtk_label_new (_("Country"));
  gtk_widget_set_name (label73b, "label73b");
  gtk_widget_ref (label73b);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label73b", label73b,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label73b);
  gtk_clist_set_column_widget (GTK_CLIST (clist_uploads), 2, label73b);
  gtk_misc_set_alignment (GTK_MISC (label73b), 0, 0.5);

  label_size_range = gtk_label_new (_("Size"));
  gtk_widget_set_name (label_size_range, "label_size_range");
  gtk_widget_ref (label_size_range);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label_size_range", label_size_range,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_size_range);
  gtk_clist_set_column_widget (GTK_CLIST (clist_uploads), 3, label_size_range);
  gtk_misc_set_alignment (GTK_MISC (label_size_range), 0, 0.5);

  label_up_range = gtk_label_new (_("Range"));
  gtk_widget_set_name (label_up_range, "label_up_range");
  gtk_widget_ref (label_up_range);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label_up_range", label_up_range,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_up_range);
  gtk_clist_set_column_widget (GTK_CLIST (clist_uploads), 4, label_up_range);
  gtk_misc_set_alignment (GTK_MISC (label_up_range), 0, 0.5);

  label_up_user_agent = gtk_label_new (_("User-Agent"));
  gtk_widget_set_name (label_up_user_agent, "label_up_user_agent");
  gtk_widget_ref (label_up_user_agent);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label_up_user_agent", label_up_user_agent,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_up_user_agent);
  gtk_clist_set_column_widget (GTK_CLIST (clist_uploads), 5, label_up_user_agent);
  gtk_misc_set_alignment (GTK_MISC (label_up_user_agent), 0, 0.5);

  label_up_progress = gtk_label_new (_("Progress"));
  gtk_widget_set_name (label_up_progress, "label_up_progress");
  gtk_widget_ref (label_up_progress);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label_up_progress", label_up_progress,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_up_progress);
  gtk_clist_set_column_widget (GTK_CLIST (clist_uploads), 6, label_up_progress);
  gtk_misc_set_alignment (GTK_MISC (label_up_progress), 0, 0.5);

  label74 = gtk_label_new (_("Status"));
  gtk_widget_set_name (label74, "label74");
  gtk_widget_ref (label74);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label74", label74,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label74);
  gtk_clist_set_column_widget (GTK_CLIST (clist_uploads), 7, label74);
  gtk_misc_set_alignment (GTK_MISC (label74), 0, 0.5);

  hbox72 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox72, "hbox72");
  gtk_widget_ref (hbox72);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "hbox72", hbox72,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox72);
  gtk_box_pack_start (GTK_BOX (vbox18), hbox72, FALSE, TRUE, 0);

  button_uploads_kill = gtk_button_new_with_label (_(" Kill selected "));
  gtk_widget_set_name (button_uploads_kill, "button_uploads_kill");
  gtk_widget_ref (button_uploads_kill);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "button_uploads_kill", button_uploads_kill,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_uploads_kill);
  gtk_box_pack_start (GTK_BOX (hbox72), button_uploads_kill, FALSE, FALSE, 0);
  gtk_widget_set_sensitive (button_uploads_kill, FALSE);
  gtk_tooltips_set_tip (tooltips, button_uploads_kill, _("Abort and remove all selected uploads"), NULL);

  button_uploads_clear_completed = gtk_button_new_with_label (_(" Clear completed "));
  gtk_widget_set_name (button_uploads_clear_completed, "button_uploads_clear_completed");
  gtk_widget_ref (button_uploads_clear_completed);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "button_uploads_clear_completed", button_uploads_clear_completed,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_uploads_clear_completed);
  gtk_box_pack_start (GTK_BOX (hbox72), button_uploads_clear_completed, FALSE, FALSE, 0);
  gtk_widget_set_sensitive (button_uploads_clear_completed, FALSE);
  gtk_tooltips_set_tip (tooltips, button_uploads_clear_completed, _("Clear already completed uploads from list"), NULL);

  table61 = gtk_table_new (2, 4, FALSE);
  gtk_widget_set_name (table61, "table61");
  gtk_widget_ref (table61);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "table61", table61,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table61);
  gtk_box_pack_start (GTK_BOX (vbox18), table61, FALSE, FALSE, 0);
  gtk_table_set_row_spacings (GTK_TABLE (table61), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table61), 4);

  checkbutton_uploads_auto_clear_complete = gtk_check_button_new_with_label (_("Auto clear completed uploads"));
  gtk_widget_set_name (checkbutton_uploads_auto_clear_complete, "checkbutton_uploads_auto_clear_complete");
  gtk_widget_ref (checkbutton_uploads_auto_clear_complete);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "checkbutton_uploads_auto_clear_complete", checkbutton_uploads_auto_clear_complete,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_uploads_auto_clear_complete);
  gtk_table_attach (GTK_TABLE (table61), checkbutton_uploads_auto_clear_complete, 0, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_uploads_auto_clear_failed = gtk_check_button_new_with_label (_("Auto clear failed uploads"));
  gtk_widget_set_name (checkbutton_uploads_auto_clear_failed, "checkbutton_uploads_auto_clear_failed");
  gtk_widget_ref (checkbutton_uploads_auto_clear_failed);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "checkbutton_uploads_auto_clear_failed", checkbutton_uploads_auto_clear_failed,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_uploads_auto_clear_failed);
  gtk_table_attach (GTK_TABLE (table61), checkbutton_uploads_auto_clear_failed, 2, 4, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label81 = gtk_label_new (_("Max. simultaneous uploads"));
  gtk_widget_set_name (label81, "label81");
  gtk_widget_ref (label81);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label81", label81,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label81);
  gtk_table_attach (GTK_TABLE (table61), label81, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label130 = gtk_label_new (_("Max. uploads to a single host"));
  gtk_widget_set_name (label130, "label130");
  gtk_widget_ref (label130);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label130", label130,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label130);
  gtk_table_attach (GTK_TABLE (table61), label130, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label130), 1, 0.5);

  spinbutton_max_uploads_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 10);
  spinbutton_max_uploads = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_max_uploads_adj), 1, 0);
  gtk_widget_set_name (spinbutton_max_uploads, "spinbutton_max_uploads");
  gtk_widget_ref (spinbutton_max_uploads);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "spinbutton_max_uploads", spinbutton_max_uploads,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_max_uploads);
  gtk_table_attach (GTK_TABLE (table61), spinbutton_max_uploads, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_max_uploads), TRUE);

  spinbutton_max_uploads_ip_adj = gtk_adjustment_new (1, 1, 100, 1, 10, 10);
  spinbutton_max_uploads_ip = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_max_uploads_ip_adj), 1, 0);
  gtk_widget_set_name (spinbutton_max_uploads_ip, "spinbutton_max_uploads_ip");
  gtk_widget_ref (spinbutton_max_uploads_ip);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "spinbutton_max_uploads_ip", spinbutton_max_uploads_ip,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_max_uploads_ip);
  gtk_table_attach (GTK_TABLE (table61), spinbutton_max_uploads_ip, 3, 4, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_max_uploads_ip), TRUE);

  label7983 = gtk_label_new (_("Uploads"));
  gtk_widget_set_name (label7983, "label7983");
  gtk_widget_ref (label7983);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label7983", label7983,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label7983);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_main), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_main), 3), label7983);

  vbox93 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox93, "vbox93");
  gtk_widget_ref (vbox93);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "vbox93", vbox93,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox93);
  gtk_container_add (GTK_CONTAINER (notebook_main), vbox93);

  vbox97 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox97, "vbox97");
  gtk_widget_ref (vbox97);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "vbox97", vbox97,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox97);
  gtk_box_pack_start (GTK_BOX (vbox93), vbox97, TRUE, TRUE, 0);

  gnet_stats_notebook = gtk_notebook_new ();
  gtk_widget_set_name (gnet_stats_notebook, "gnet_stats_notebook");
  gtk_widget_ref (gnet_stats_notebook);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "gnet_stats_notebook", gnet_stats_notebook,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (gnet_stats_notebook);
  gtk_box_pack_start (GTK_BOX (vbox97), gnet_stats_notebook, TRUE, TRUE, 0);
  gtk_widget_set_usize (gnet_stats_notebook, -2, 157);
  gtk_notebook_set_tab_pos (GTK_NOTEBOOK (gnet_stats_notebook), GTK_POS_BOTTOM);

  hbox2106 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox2106, "hbox2106");
  gtk_widget_ref (hbox2106);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "hbox2106", hbox2106,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox2106);
  gtk_container_add (GTK_CONTAINER (gnet_stats_notebook), hbox2106);

  scrolledwindow31 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow31, "scrolledwindow31");
  gtk_widget_ref (scrolledwindow31);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "scrolledwindow31", scrolledwindow31,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (scrolledwindow31);
  gtk_box_pack_start (GTK_BOX (hbox2106), scrolledwindow31, TRUE, TRUE, 0);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow31), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);

  clist_gnet_stats_general = gtk_clist_new (2);
  gtk_widget_set_name (clist_gnet_stats_general, "clist_gnet_stats_general");
  gtk_widget_ref (clist_gnet_stats_general);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "clist_gnet_stats_general", clist_gnet_stats_general,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (clist_gnet_stats_general);
  gtk_container_add (GTK_CONTAINER (scrolledwindow31), clist_gnet_stats_general);
  gtk_clist_set_column_width (GTK_CLIST (clist_gnet_stats_general), 0, 80);
  gtk_clist_set_column_width (GTK_CLIST (clist_gnet_stats_general), 1, 80);
  gtk_clist_column_titles_show (GTK_CLIST (clist_gnet_stats_general));

  label403 = gtk_label_new (_("Type"));
  gtk_widget_set_name (label403, "label403");
  gtk_widget_ref (label403);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label403", label403,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label403);
  gtk_clist_set_column_widget (GTK_CLIST (clist_gnet_stats_general), 0, label403);
  gtk_misc_set_alignment (GTK_MISC (label403), 0, 0.5);

  label404 = gtk_label_new (_("Count"));
  gtk_widget_set_name (label404, "label404");
  gtk_widget_ref (label404);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label404", label404,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label404);
  gtk_clist_set_column_widget (GTK_CLIST (clist_gnet_stats_general), 1, label404);

  scrolledwindow26 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow26, "scrolledwindow26");
  gtk_widget_ref (scrolledwindow26);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "scrolledwindow26", scrolledwindow26,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (scrolledwindow26);
  gtk_box_pack_start (GTK_BOX (hbox2106), scrolledwindow26, TRUE, TRUE, 0);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow26), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);

  clist_gnet_stats_drop_reasons = gtk_clist_new (2);
  gtk_widget_set_name (clist_gnet_stats_drop_reasons, "clist_gnet_stats_drop_reasons");
  gtk_widget_ref (clist_gnet_stats_drop_reasons);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "clist_gnet_stats_drop_reasons", clist_gnet_stats_drop_reasons,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (clist_gnet_stats_drop_reasons);
  gtk_container_add (GTK_CONTAINER (scrolledwindow26), clist_gnet_stats_drop_reasons);
  gtk_clist_set_column_width (GTK_CLIST (clist_gnet_stats_drop_reasons), 0, 125);
  gtk_clist_set_column_width (GTK_CLIST (clist_gnet_stats_drop_reasons), 1, 57);
  gtk_clist_column_titles_show (GTK_CLIST (clist_gnet_stats_drop_reasons));

  label375 = gtk_label_new (_("Reason"));
  gtk_widget_set_name (label375, "label375");
  gtk_widget_ref (label375);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label375", label375,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label375);
  gtk_clist_set_column_widget (GTK_CLIST (clist_gnet_stats_drop_reasons), 0, label375);
  gtk_misc_set_alignment (GTK_MISC (label375), 0, 0.5);

  label376 = gtk_label_new (_("Count"));
  gtk_widget_set_name (label376, "label376");
  gtk_widget_ref (label376);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label376", label376,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label376);
  gtk_clist_set_column_widget (GTK_CLIST (clist_gnet_stats_drop_reasons), 1, label376);

  label436 = gtk_label_new ("");
  gtk_label_parse_uline (GTK_LABEL (label436),
                         _("_General"));
  gtk_widget_set_name (label436, "label436");
  gtk_widget_ref (label436);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label436", label436,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label436);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (gnet_stats_notebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK (gnet_stats_notebook), 0), label436);

  scrolledwindow38 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow38, "scrolledwindow38");
  gtk_widget_ref (scrolledwindow38);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "scrolledwindow38", scrolledwindow38,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (scrolledwindow38);
  gtk_container_add (GTK_CONTAINER (gnet_stats_notebook), scrolledwindow38);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow38), GTK_POLICY_ALWAYS, GTK_POLICY_AUTOMATIC);

  clist_gnet_stats_fc_ttl = gtk_clist_new (10);
  gtk_widget_set_name (clist_gnet_stats_fc_ttl, "clist_gnet_stats_fc_ttl");
  gtk_widget_ref (clist_gnet_stats_fc_ttl);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "clist_gnet_stats_fc_ttl", clist_gnet_stats_fc_ttl,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (clist_gnet_stats_fc_ttl);
  gtk_container_add (GTK_CONTAINER (scrolledwindow38), clist_gnet_stats_fc_ttl);
  gtk_clist_set_column_width (GTK_CLIST (clist_gnet_stats_fc_ttl), 0, 80);
  gtk_clist_set_column_width (GTK_CLIST (clist_gnet_stats_fc_ttl), 1, 28);
  gtk_clist_set_column_width (GTK_CLIST (clist_gnet_stats_fc_ttl), 2, 29);
  gtk_clist_set_column_width (GTK_CLIST (clist_gnet_stats_fc_ttl), 3, 38);
  gtk_clist_set_column_width (GTK_CLIST (clist_gnet_stats_fc_ttl), 4, 39);
  gtk_clist_set_column_width (GTK_CLIST (clist_gnet_stats_fc_ttl), 5, 25);
  gtk_clist_set_column_width (GTK_CLIST (clist_gnet_stats_fc_ttl), 6, 37);
  gtk_clist_set_column_width (GTK_CLIST (clist_gnet_stats_fc_ttl), 7, 29);
  gtk_clist_set_column_width (GTK_CLIST (clist_gnet_stats_fc_ttl), 8, 37);
  gtk_clist_set_column_width (GTK_CLIST (clist_gnet_stats_fc_ttl), 9, 80);
  gtk_clist_column_titles_show (GTK_CLIST (clist_gnet_stats_fc_ttl));

  label412 = gtk_label_new (_("Type"));
  gtk_widget_set_name (label412, "label412");
  gtk_widget_ref (label412);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label412", label412,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label412);
  gtk_clist_set_column_widget (GTK_CLIST (clist_gnet_stats_fc_ttl), 0, label412);

  label413 = gtk_label_new (_("0"));
  gtk_widget_set_name (label413, "label413");
  gtk_widget_ref (label413);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label413", label413,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label413);
  gtk_clist_set_column_widget (GTK_CLIST (clist_gnet_stats_fc_ttl), 1, label413);

  label414 = gtk_label_new (_("1"));
  gtk_widget_set_name (label414, "label414");
  gtk_widget_ref (label414);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label414", label414,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label414);
  gtk_clist_set_column_widget (GTK_CLIST (clist_gnet_stats_fc_ttl), 2, label414);

  label415 = gtk_label_new (_("2"));
  gtk_widget_set_name (label415, "label415");
  gtk_widget_ref (label415);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label415", label415,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label415);
  gtk_clist_set_column_widget (GTK_CLIST (clist_gnet_stats_fc_ttl), 3, label415);

  label416 = gtk_label_new (_("3"));
  gtk_widget_set_name (label416, "label416");
  gtk_widget_ref (label416);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label416", label416,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label416);
  gtk_clist_set_column_widget (GTK_CLIST (clist_gnet_stats_fc_ttl), 4, label416);

  label417 = gtk_label_new (_("4"));
  gtk_widget_set_name (label417, "label417");
  gtk_widget_ref (label417);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label417", label417,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label417);
  gtk_clist_set_column_widget (GTK_CLIST (clist_gnet_stats_fc_ttl), 5, label417);

  label418 = gtk_label_new (_("5"));
  gtk_widget_set_name (label418, "label418");
  gtk_widget_ref (label418);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label418", label418,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label418);
  gtk_clist_set_column_widget (GTK_CLIST (clist_gnet_stats_fc_ttl), 6, label418);

  label419 = gtk_label_new (_("6"));
  gtk_widget_set_name (label419, "label419");
  gtk_widget_ref (label419);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label419", label419,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label419);
  gtk_clist_set_column_widget (GTK_CLIST (clist_gnet_stats_fc_ttl), 7, label419);

  label420 = gtk_label_new (_("7"));
  gtk_widget_set_name (label420, "label420");
  gtk_widget_ref (label420);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label420", label420,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label420);
  gtk_clist_set_column_widget (GTK_CLIST (clist_gnet_stats_fc_ttl), 8, label420);

  label421 = gtk_label_new (_("8+"));
  gtk_widget_set_name (label421, "label421");
  gtk_widget_ref (label421);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label421", label421,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label421);
  gtk_clist_set_column_widget (GTK_CLIST (clist_gnet_stats_fc_ttl), 9, label421);

  label437 = gtk_label_new ("");
  gtk_label_parse_uline (GTK_LABEL (label437),
                         _("FC/_TTL"));
  gtk_widget_set_name (label437, "label437");
  gtk_widget_ref (label437);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label437", label437,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label437);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (gnet_stats_notebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK (gnet_stats_notebook), 1), label437);

  scrolledwindow39 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow39, "scrolledwindow39");
  gtk_widget_ref (scrolledwindow39);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "scrolledwindow39", scrolledwindow39,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (scrolledwindow39);
  gtk_container_add (GTK_CONTAINER (gnet_stats_notebook), scrolledwindow39);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow39), GTK_POLICY_ALWAYS, GTK_POLICY_AUTOMATIC);

  clist_gnet_stats_fc_hops = gtk_clist_new (10);
  gtk_widget_set_name (clist_gnet_stats_fc_hops, "clist_gnet_stats_fc_hops");
  gtk_widget_ref (clist_gnet_stats_fc_hops);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "clist_gnet_stats_fc_hops", clist_gnet_stats_fc_hops,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (clist_gnet_stats_fc_hops);
  gtk_container_add (GTK_CONTAINER (scrolledwindow39), clist_gnet_stats_fc_hops);
  gtk_clist_set_column_width (GTK_CLIST (clist_gnet_stats_fc_hops), 0, 80);
  gtk_clist_set_column_width (GTK_CLIST (clist_gnet_stats_fc_hops), 1, 28);
  gtk_clist_set_column_width (GTK_CLIST (clist_gnet_stats_fc_hops), 2, 29);
  gtk_clist_set_column_width (GTK_CLIST (clist_gnet_stats_fc_hops), 3, 38);
  gtk_clist_set_column_width (GTK_CLIST (clist_gnet_stats_fc_hops), 4, 39);
  gtk_clist_set_column_width (GTK_CLIST (clist_gnet_stats_fc_hops), 5, 25);
  gtk_clist_set_column_width (GTK_CLIST (clist_gnet_stats_fc_hops), 6, 37);
  gtk_clist_set_column_width (GTK_CLIST (clist_gnet_stats_fc_hops), 7, 29);
  gtk_clist_set_column_width (GTK_CLIST (clist_gnet_stats_fc_hops), 8, 37);
  gtk_clist_set_column_width (GTK_CLIST (clist_gnet_stats_fc_hops), 9, 80);
  gtk_clist_column_titles_show (GTK_CLIST (clist_gnet_stats_fc_hops));

  label423 = gtk_label_new (_("Type"));
  gtk_widget_set_name (label423, "label423");
  gtk_widget_ref (label423);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label423", label423,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label423);
  gtk_clist_set_column_widget (GTK_CLIST (clist_gnet_stats_fc_hops), 0, label423);

  label424 = gtk_label_new (_("0"));
  gtk_widget_set_name (label424, "label424");
  gtk_widget_ref (label424);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label424", label424,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label424);
  gtk_clist_set_column_widget (GTK_CLIST (clist_gnet_stats_fc_hops), 1, label424);

  label425 = gtk_label_new (_("1"));
  gtk_widget_set_name (label425, "label425");
  gtk_widget_ref (label425);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label425", label425,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label425);
  gtk_clist_set_column_widget (GTK_CLIST (clist_gnet_stats_fc_hops), 2, label425);

  label426 = gtk_label_new (_("2"));
  gtk_widget_set_name (label426, "label426");
  gtk_widget_ref (label426);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label426", label426,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label426);
  gtk_clist_set_column_widget (GTK_CLIST (clist_gnet_stats_fc_hops), 3, label426);

  label427 = gtk_label_new (_("3"));
  gtk_widget_set_name (label427, "label427");
  gtk_widget_ref (label427);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label427", label427,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label427);
  gtk_clist_set_column_widget (GTK_CLIST (clist_gnet_stats_fc_hops), 4, label427);

  label428 = gtk_label_new (_("4"));
  gtk_widget_set_name (label428, "label428");
  gtk_widget_ref (label428);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label428", label428,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label428);
  gtk_clist_set_column_widget (GTK_CLIST (clist_gnet_stats_fc_hops), 5, label428);

  label429 = gtk_label_new (_("5"));
  gtk_widget_set_name (label429, "label429");
  gtk_widget_ref (label429);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label429", label429,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label429);
  gtk_clist_set_column_widget (GTK_CLIST (clist_gnet_stats_fc_hops), 6, label429);

  label430 = gtk_label_new (_("6"));
  gtk_widget_set_name (label430, "label430");
  gtk_widget_ref (label430);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label430", label430,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label430);
  gtk_clist_set_column_widget (GTK_CLIST (clist_gnet_stats_fc_hops), 7, label430);

  label431 = gtk_label_new (_("7"));
  gtk_widget_set_name (label431, "label431");
  gtk_widget_ref (label431);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label431", label431,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label431);
  gtk_clist_set_column_widget (GTK_CLIST (clist_gnet_stats_fc_hops), 8, label431);

  label432 = gtk_label_new (_("8+"));
  gtk_widget_set_name (label432, "label432");
  gtk_widget_ref (label432);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label432", label432,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label432);
  gtk_clist_set_column_widget (GTK_CLIST (clist_gnet_stats_fc_hops), 9, label432);

  label438 = gtk_label_new ("");
  gtk_label_parse_uline (GTK_LABEL (label438),
                         _("FC/_hops"));
  gtk_widget_set_name (label438, "label438");
  gtk_widget_ref (label438);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label438", label438,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label438);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (gnet_stats_notebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK (gnet_stats_notebook), 2), label438);

  scrolledwindow29 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow29, "scrolledwindow29");
  gtk_widget_ref (scrolledwindow29);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "scrolledwindow29", scrolledwindow29,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (scrolledwindow29);
  gtk_container_add (GTK_CONTAINER (gnet_stats_notebook), scrolledwindow29);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow29), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);

  clist_gnet_stats_msg = gtk_clist_new (8);
  gtk_widget_set_name (clist_gnet_stats_msg, "clist_gnet_stats_msg");
  gtk_widget_ref (clist_gnet_stats_msg);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "clist_gnet_stats_msg", clist_gnet_stats_msg,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (clist_gnet_stats_msg);
  gtk_container_add (GTK_CONTAINER (scrolledwindow29), clist_gnet_stats_msg);
  gtk_clist_set_column_width (GTK_CLIST (clist_gnet_stats_msg), 0, 80);
  gtk_clist_set_column_width (GTK_CLIST (clist_gnet_stats_msg), 1, 80);
  gtk_clist_set_column_width (GTK_CLIST (clist_gnet_stats_msg), 2, 80);
  gtk_clist_set_column_width (GTK_CLIST (clist_gnet_stats_msg), 3, 79);
  gtk_clist_set_column_width (GTK_CLIST (clist_gnet_stats_msg), 4, 80);
  gtk_clist_set_column_width (GTK_CLIST (clist_gnet_stats_msg), 5, 80);
  gtk_clist_set_column_width (GTK_CLIST (clist_gnet_stats_msg), 6, 80);
  gtk_clist_set_column_width (GTK_CLIST (clist_gnet_stats_msg), 7, 80);
  gtk_clist_column_titles_show (GTK_CLIST (clist_gnet_stats_msg));

  label391 = gtk_label_new (_("Type"));
  gtk_widget_set_name (label391, "label391");
  gtk_widget_ref (label391);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label391", label391,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label391);
  gtk_clist_set_column_widget (GTK_CLIST (clist_gnet_stats_msg), 0, label391);
  gtk_misc_set_alignment (GTK_MISC (label391), 0, 0.5);

  label392 = gtk_label_new (_("Received"));
  gtk_widget_set_name (label392, "label392");
  gtk_widget_ref (label392);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label392", label392,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label392);
  gtk_clist_set_column_widget (GTK_CLIST (clist_gnet_stats_msg), 1, label392);

  label393 = gtk_label_new (_("Expired"));
  gtk_widget_set_name (label393, "label393");
  gtk_widget_ref (label393);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label393", label393,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label393);
  gtk_clist_set_column_widget (GTK_CLIST (clist_gnet_stats_msg), 2, label393);

  label394 = gtk_label_new (_("Dropped"));
  gtk_widget_set_name (label394, "label394");
  gtk_widget_ref (label394);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label394", label394,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label394);
  gtk_clist_set_column_widget (GTK_CLIST (clist_gnet_stats_msg), 3, label394);

  label395 = gtk_label_new (_("Queued"));
  gtk_widget_set_name (label395, "label395");
  gtk_widget_ref (label395);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label395", label395,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label395);
  gtk_clist_set_column_widget (GTK_CLIST (clist_gnet_stats_msg), 4, label395);

  label500 = gtk_label_new (_("Relayed"));
  gtk_widget_set_name (label500, "label500");
  gtk_widget_ref (label500);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label500", label500,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label500);
  gtk_clist_set_column_widget (GTK_CLIST (clist_gnet_stats_msg), 5, label500);

  label501 = gtk_label_new (_("Gen. queued"));
  gtk_widget_set_name (label501, "label501");
  gtk_widget_ref (label501);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label501", label501,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label501);
  gtk_clist_set_column_widget (GTK_CLIST (clist_gnet_stats_msg), 6, label501);

  label396 = gtk_label_new (_("Gen. sent"));
  gtk_widget_set_name (label396, "label396");
  gtk_widget_ref (label396);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label396", label396,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label396);
  gtk_clist_set_column_widget (GTK_CLIST (clist_gnet_stats_msg), 7, label396);

  label776 = gtk_label_new ("");
  gtk_label_parse_uline (GTK_LABEL (label776),
                         _("_Messages"));
  gtk_widget_set_name (label776, "label776");
  gtk_widget_ref (label776);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label776", label776,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label776);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (gnet_stats_notebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK (gnet_stats_notebook), 3), label776);

  vbox141 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox141, "vbox141");
  gtk_widget_ref (vbox141);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "vbox141", vbox141,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox141);
  gtk_container_add (GTK_CONTAINER (gnet_stats_notebook), vbox141);

  scrolledwindow45 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow45, "scrolledwindow45");
  gtk_widget_ref (scrolledwindow45);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "scrolledwindow45", scrolledwindow45,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (scrolledwindow45);
  gtk_box_pack_start (GTK_BOX (vbox141), scrolledwindow45, TRUE, TRUE, 0);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow45), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);

  clist_gnet_stats_horizon = gtk_clist_new (4);
  gtk_widget_set_name (clist_gnet_stats_horizon, "clist_gnet_stats_horizon");
  gtk_widget_ref (clist_gnet_stats_horizon);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "clist_gnet_stats_horizon", clist_gnet_stats_horizon,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (clist_gnet_stats_horizon);
  gtk_container_add (GTK_CONTAINER (scrolledwindow45), clist_gnet_stats_horizon);
  gtk_clist_set_column_width (GTK_CLIST (clist_gnet_stats_horizon), 0, 56);
  gtk_clist_set_column_width (GTK_CLIST (clist_gnet_stats_horizon), 1, 50);
  gtk_clist_set_column_width (GTK_CLIST (clist_gnet_stats_horizon), 2, 78);
  gtk_clist_set_column_width (GTK_CLIST (clist_gnet_stats_horizon), 3, 80);
  gtk_clist_column_titles_show (GTK_CLIST (clist_gnet_stats_horizon));

  label663 = gtk_label_new (_("Hops"));
  gtk_widget_set_name (label663, "label663");
  gtk_widget_ref (label663);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label663", label663,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label663);
  gtk_clist_set_column_widget (GTK_CLIST (clist_gnet_stats_horizon), 0, label663);
  gtk_widget_set_usize (label663, 30, -2);

  label664 = gtk_label_new (_("Nodes"));
  gtk_widget_set_name (label664, "label664");
  gtk_widget_ref (label664);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label664", label664,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label664);
  gtk_clist_set_column_widget (GTK_CLIST (clist_gnet_stats_horizon), 1, label664);
  gtk_widget_set_usize (label664, 36, -2);

  label665 = gtk_label_new (_("Files"));
  gtk_widget_set_name (label665, "label665");
  gtk_widget_ref (label665);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label665", label665,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label665);
  gtk_clist_set_column_widget (GTK_CLIST (clist_gnet_stats_horizon), 2, label665);
  gtk_widget_set_usize (label665, 36, -2);

  label666 = gtk_label_new (_("Size"));
  gtk_widget_set_name (label666, "label666");
  gtk_widget_ref (label666);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label666", label666,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label666);
  gtk_clist_set_column_widget (GTK_CLIST (clist_gnet_stats_horizon), 3, label666);
  gtk_widget_set_usize (label666, 36, -2);

  hbox2109 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox2109, "hbox2109");
  gtk_widget_ref (hbox2109);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "hbox2109", hbox2109,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox2109);
  gtk_box_pack_start (GTK_BOX (vbox141), hbox2109, FALSE, TRUE, 0);

  frame129 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame129, "frame129");
  gtk_widget_ref (frame129);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "frame129", frame129,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame129);
  gtk_box_pack_start (GTK_BOX (hbox2109), frame129, TRUE, TRUE, 0);

  label_statusbar_horizon_node_count = gtk_label_new (_("Nodes"));
  gtk_widget_set_name (label_statusbar_horizon_node_count, "label_statusbar_horizon_node_count");
  gtk_widget_ref (label_statusbar_horizon_node_count);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label_statusbar_horizon_node_count", label_statusbar_horizon_node_count,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_statusbar_horizon_node_count);
  gtk_container_add (GTK_CONTAINER (frame129), label_statusbar_horizon_node_count);
  gtk_misc_set_padding (GTK_MISC (label_statusbar_horizon_node_count), 5, 0);

  frame130 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame130, "frame130");
  gtk_widget_ref (frame130);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "frame130", frame130,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame130);
  gtk_box_pack_start (GTK_BOX (hbox2109), frame130, TRUE, TRUE, 0);

  label_statusbar_horizon_file_count = gtk_label_new (_("Files"));
  gtk_widget_set_name (label_statusbar_horizon_file_count, "label_statusbar_horizon_file_count");
  gtk_widget_ref (label_statusbar_horizon_file_count);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label_statusbar_horizon_file_count", label_statusbar_horizon_file_count,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_statusbar_horizon_file_count);
  gtk_container_add (GTK_CONTAINER (frame130), label_statusbar_horizon_file_count);
  gtk_misc_set_padding (GTK_MISC (label_statusbar_horizon_file_count), 5, 0);

  frame131 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame131, "frame131");
  gtk_widget_ref (frame131);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "frame131", frame131,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame131);
  gtk_box_pack_start (GTK_BOX (hbox2109), frame131, TRUE, TRUE, 0);

  label_statusbar_horizon_kb_count = gtk_label_new (_("Size"));
  gtk_widget_set_name (label_statusbar_horizon_kb_count, "label_statusbar_horizon_kb_count");
  gtk_widget_ref (label_statusbar_horizon_kb_count);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label_statusbar_horizon_kb_count", label_statusbar_horizon_kb_count,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_statusbar_horizon_kb_count);
  gtk_container_add (GTK_CONTAINER (frame131), label_statusbar_horizon_kb_count);
  gtk_misc_set_padding (GTK_MISC (label_statusbar_horizon_kb_count), 5, 0);

  label777 = gtk_label_new ("");
  gtk_label_parse_uline (GTK_LABEL (label777),
                         _("_Horizon"));
  gtk_widget_set_name (label777, "label777");
  gtk_widget_ref (label777);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label777", label777,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label777);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (gnet_stats_notebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK (gnet_stats_notebook), 4), label777);

  frame127 = gtk_frame_new (_("Transferred data"));
  gtk_widget_set_name (frame127, "frame127");
  gtk_widget_ref (frame127);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "frame127", frame127,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame127);
  gtk_container_add (GTK_CONTAINER (gnet_stats_notebook), frame127);

  table37 = gtk_table_new (3, 3, FALSE);
  gtk_widget_set_name (table37, "table37");
  gtk_widget_ref (table37);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "table37", table37,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table37);
  gtk_container_add (GTK_CONTAINER (frame127), table37);
  gtk_container_set_border_width (GTK_CONTAINER (table37), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table37), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table37), 4);

  label12 = gtk_label_new (_("Uploaded:"));
  gtk_widget_set_name (label12, "label12");
  gtk_widget_ref (label12);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label12", label12,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label12);
  gtk_table_attach (GTK_TABLE (table37), label12, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label12), GTK_JUSTIFY_LEFT);
  gtk_misc_set_alignment (GTK_MISC (label12), 0, 0.5);

  label11 = gtk_label_new (_("Downloaded:"));
  gtk_widget_set_name (label11, "label11");
  gtk_widget_ref (label11);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label11", label11,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label11);
  gtk_table_attach (GTK_TABLE (table37), label11, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label11), GTK_JUSTIFY_LEFT);
  gtk_misc_set_alignment (GTK_MISC (label11), 0, 0.5);

  entry_count_downloads = gtk_entry_new ();
  gtk_widget_set_name (entry_count_downloads, "entry_count_downloads");
  gtk_widget_ref (entry_count_downloads);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "entry_count_downloads", entry_count_downloads,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_count_downloads);
  gtk_table_attach (GTK_TABLE (table37), entry_count_downloads, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_tooltips_set_tip (tooltips, entry_count_downloads, _("Somebody tell me a sensible tooltip for this."), NULL);
  gtk_entry_set_editable (GTK_ENTRY (entry_count_downloads), FALSE);

  entry_count_uploads = gtk_entry_new ();
  gtk_widget_set_name (entry_count_uploads, "entry_count_uploads");
  gtk_widget_ref (entry_count_uploads);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "entry_count_uploads", entry_count_uploads,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_count_uploads);
  gtk_table_attach (GTK_TABLE (table37), entry_count_uploads, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_tooltips_set_tip (tooltips, entry_count_uploads, _("Somebody tell me a sensible tooltip for this."), NULL);
  gtk_entry_set_editable (GTK_ENTRY (entry_count_uploads), FALSE);

  label455 = gtk_label_new (_("Chunks/Files:"));
  gtk_widget_set_name (label455, "label455");
  gtk_widget_ref (label455);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label455", label455,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label455);
  gtk_table_attach (GTK_TABLE (table37), label455, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label456 = gtk_label_new (_("Volume:"));
  gtk_widget_set_name (label456, "label456");
  gtk_widget_ref (label456);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label456", label456,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label456);
  gtk_table_attach (GTK_TABLE (table37), label456, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_ul_byte_count = gtk_entry_new ();
  gtk_widget_set_name (entry_ul_byte_count, "entry_ul_byte_count");
  gtk_widget_ref (entry_ul_byte_count);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "entry_ul_byte_count", entry_ul_byte_count,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_ul_byte_count);
  gtk_table_attach (GTK_TABLE (table37), entry_ul_byte_count, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_entry_set_editable (GTK_ENTRY (entry_ul_byte_count), FALSE);

  entry_dl_byte_count = gtk_entry_new ();
  gtk_widget_set_name (entry_dl_byte_count, "entry_dl_byte_count");
  gtk_widget_ref (entry_dl_byte_count);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "entry_dl_byte_count", entry_dl_byte_count,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_dl_byte_count);
  gtk_table_attach (GTK_TABLE (table37), entry_dl_byte_count, 2, 3, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_entry_set_editable (GTK_ENTRY (entry_dl_byte_count), FALSE);

  label8008 = gtk_label_new (_("File transfers"));
  gtk_widget_set_name (label8008, "label8008");
  gtk_widget_ref (label8008);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label8008", label8008,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label8008);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (gnet_stats_notebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK (gnet_stats_notebook), 5), label8008);

  table93 = gtk_table_new (2, 4, FALSE);
  gtk_widget_set_name (table93, "table93");
  gtk_widget_ref (table93);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "table93", table93,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table93);
  gtk_box_pack_start (GTK_BOX (vbox97), table93, FALSE, FALSE, 0);

  checkbutton_gnet_stats_bytes = gtk_check_button_new_with_label ("");
  checkbutton_gnet_stats_bytes_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (checkbutton_gnet_stats_bytes)->child),
                                   _("Show _bytes"));
  gtk_widget_add_accelerator (checkbutton_gnet_stats_bytes, "clicked", accel_group,
                              checkbutton_gnet_stats_bytes_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (checkbutton_gnet_stats_bytes, "checkbutton_gnet_stats_bytes");
  gtk_widget_ref (checkbutton_gnet_stats_bytes);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "checkbutton_gnet_stats_bytes", checkbutton_gnet_stats_bytes,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_gnet_stats_bytes);
  gtk_table_attach (GTK_TABLE (table93), checkbutton_gnet_stats_bytes, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_gnet_stats_perc = gtk_check_button_new_with_label ("");
  checkbutton_gnet_stats_perc_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (checkbutton_gnet_stats_perc)->child),
                                   _("Show _percentages"));
  gtk_widget_add_accelerator (checkbutton_gnet_stats_perc, "clicked", accel_group,
                              checkbutton_gnet_stats_perc_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (checkbutton_gnet_stats_perc, "checkbutton_gnet_stats_perc");
  gtk_widget_ref (checkbutton_gnet_stats_perc);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "checkbutton_gnet_stats_perc", checkbutton_gnet_stats_perc,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_gnet_stats_perc);
  gtk_table_attach (GTK_TABLE (table93), checkbutton_gnet_stats_perc, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_gnet_stats_with_headers = gtk_check_button_new_with_label ("");
  checkbutton_gnet_stats_with_headers_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (checkbutton_gnet_stats_with_headers)->child),
                                   _("_Include headers"));
  gtk_widget_add_accelerator (checkbutton_gnet_stats_with_headers, "clicked", accel_group,
                              checkbutton_gnet_stats_with_headers_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (checkbutton_gnet_stats_with_headers, "checkbutton_gnet_stats_with_headers");
  gtk_widget_ref (checkbutton_gnet_stats_with_headers);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "checkbutton_gnet_stats_with_headers", checkbutton_gnet_stats_with_headers,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_gnet_stats_with_headers);
  gtk_table_attach (GTK_TABLE (table93), checkbutton_gnet_stats_with_headers, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label697 = gtk_label_new ("");
  label697_key = gtk_label_parse_uline (GTK_LABEL (label697),
                                   _("Show pr_otocol:"));
  gtk_widget_set_name (label697, "label697");
  gtk_widget_ref (label697);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label697", label697,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label697);
  gtk_table_attach (GTK_TABLE (table93), label697, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label697), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label697), 4, 0);

  label390 = gtk_label_new ("");
  label390_key = gtk_label_parse_uline (GTK_LABEL (label390),
                                   _("Show r_easons for"));
  gtk_widget_set_name (label390, "label390");
  gtk_widget_ref (label390);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label390", label390,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label390);
  gtk_table_attach (GTK_TABLE (table93), label390, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label390), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label390), 2, 0);

  option_menu_gnet_stats_source = gtk_option_menu_new ();
  gtk_widget_set_name (option_menu_gnet_stats_source, "option_menu_gnet_stats_source");
  gtk_widget_ref (option_menu_gnet_stats_source);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "option_menu_gnet_stats_source", option_menu_gnet_stats_source,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (option_menu_gnet_stats_source);
  gtk_table_attach (GTK_TABLE (table93), option_menu_gnet_stats_source, 3, 4, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  option_menu_gnet_stats_source_menu = gtk_menu_new ();
  gtk_option_menu_set_menu (GTK_OPTION_MENU (option_menu_gnet_stats_source), option_menu_gnet_stats_source_menu);

  option_menu_gnet_stats_type = gtk_option_menu_new ();
  gtk_widget_set_name (option_menu_gnet_stats_type, "option_menu_gnet_stats_type");
  gtk_widget_ref (option_menu_gnet_stats_type);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "option_menu_gnet_stats_type", option_menu_gnet_stats_type,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (option_menu_gnet_stats_type);
  gtk_table_attach (GTK_TABLE (table93), option_menu_gnet_stats_type, 3, 4, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  option_menu_gnet_stats_type_menu = gtk_menu_new ();
  gtk_option_menu_set_menu (GTK_OPTION_MENU (option_menu_gnet_stats_type), option_menu_gnet_stats_type_menu);

  label7982 = gtk_label_new (_("Statistics"));
  gtk_widget_set_name (label7982, "label7982");
  gtk_widget_ref (label7982);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label7982", label7982,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label7982);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_main), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_main), 4), label7982);

  vbox_monitor = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox_monitor, "vbox_monitor");
  gtk_widget_ref (vbox_monitor);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "vbox_monitor", vbox_monitor,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox_monitor);
  gtk_container_add (GTK_CONTAINER (notebook_main), vbox_monitor);

  hbox45 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox45, "hbox45");
  gtk_widget_ref (hbox45);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "hbox45", hbox45,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox45);
  gtk_box_pack_start (GTK_BOX (vbox_monitor), hbox45, FALSE, TRUE, 0);

  checkbutton_monitor_enable = gtk_check_button_new_with_label ("");
  checkbutton_monitor_enable_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (checkbutton_monitor_enable)->child),
                                   _("Search _monitor enabled"));
  gtk_widget_add_accelerator (checkbutton_monitor_enable, "clicked", accel_group,
                              checkbutton_monitor_enable_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (checkbutton_monitor_enable, "checkbutton_monitor_enable");
  gtk_widget_ref (checkbutton_monitor_enable);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "checkbutton_monitor_enable", checkbutton_monitor_enable,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_monitor_enable);
  gtk_box_pack_start (GTK_BOX (hbox45), checkbutton_monitor_enable, FALSE, FALSE, 0);

  label75 = gtk_label_new ("");
  gtk_widget_set_name (label75, "label75");
  gtk_widget_ref (label75);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label75", label75,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label75);
  gtk_box_pack_start (GTK_BOX (hbox45), label75, TRUE, FALSE, 0);

  label68 = gtk_label_new ("");
  label68_key = gtk_label_parse_uline (GTK_LABEL (label68),
                                   _("Show _last"));
  gtk_widget_set_name (label68, "label68");
  gtk_widget_ref (label68);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label68", label68,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label68);
  gtk_box_pack_start (GTK_BOX (hbox45), label68, FALSE, FALSE, 0);

  spinbutton_monitor_items_adj = gtk_adjustment_new (1, 0, 1000, 1, 10, 10);
  spinbutton_monitor_items = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_monitor_items_adj), 1, 0);
  gtk_widget_set_name (spinbutton_monitor_items, "spinbutton_monitor_items");
  gtk_widget_ref (spinbutton_monitor_items);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "spinbutton_monitor_items", spinbutton_monitor_items,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_monitor_items);
  gtk_box_pack_start (GTK_BOX (hbox45), spinbutton_monitor_items, FALSE, TRUE, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_monitor_items), TRUE);

  label69 = gtk_label_new (_("searches"));
  gtk_widget_set_name (label69, "label69");
  gtk_widget_ref (label69);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label69", label69,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label69);
  gtk_box_pack_start (GTK_BOX (hbox45), label69, FALSE, FALSE, 0);

  scrolledwindow8 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow8, "scrolledwindow8");
  gtk_widget_ref (scrolledwindow8);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "scrolledwindow8", scrolledwindow8,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (scrolledwindow8);
  gtk_box_pack_start (GTK_BOX (vbox_monitor), scrolledwindow8, TRUE, TRUE, 0);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow8), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);

  clist_monitor = gtk_clist_new (1);
  gtk_widget_set_name (clist_monitor, "clist_monitor");
  gtk_widget_ref (clist_monitor);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "clist_monitor", clist_monitor,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (clist_monitor);
  gtk_container_add (GTK_CONTAINER (scrolledwindow8), clist_monitor);
  GTK_WIDGET_UNSET_FLAGS (clist_monitor, GTK_CAN_FOCUS);
  gtk_clist_set_column_width (GTK_CLIST (clist_monitor), 0, 80);
  gtk_clist_column_titles_show (GTK_CLIST (clist_monitor));

  label70 = gtk_label_new (_("Search"));
  gtk_widget_set_name (label70, "label70");
  gtk_widget_ref (label70);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label70", label70,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label70);
  gtk_clist_set_column_widget (GTK_CLIST (clist_monitor), 0, label70);
  gtk_label_set_justify (GTK_LABEL (label70), GTK_JUSTIFY_LEFT);
  gtk_misc_set_alignment (GTK_MISC (label70), 0, 0.5);

  label7981 = gtk_label_new (_("Search Monitor"));
  gtk_widget_set_name (label7981, "label7981");
  gtk_widget_ref (label7981);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label7981", label7981,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label7981);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_main), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_main), 5), label7981);

  vbox19 = gtk_vbox_new (FALSE, 4);
  gtk_widget_set_name (vbox19, "vbox19");
  gtk_widget_ref (vbox19);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "vbox19", vbox19,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox19);
  gtk_container_add (GTK_CONTAINER (notebook_main), vbox19);

  ul_stats_scrolledwindow = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (ul_stats_scrolledwindow, "ul_stats_scrolledwindow");
  gtk_widget_ref (ul_stats_scrolledwindow);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "ul_stats_scrolledwindow", ul_stats_scrolledwindow,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ul_stats_scrolledwindow);
  gtk_box_pack_start (GTK_BOX (vbox19), ul_stats_scrolledwindow, TRUE, TRUE, 0);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (ul_stats_scrolledwindow), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);

  clist_ul_stats = gtk_clist_new (7);
  gtk_widget_set_name (clist_ul_stats, "clist_ul_stats");
  gtk_widget_ref (clist_ul_stats);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "clist_ul_stats", clist_ul_stats,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (clist_ul_stats);
  gtk_container_add (GTK_CONTAINER (ul_stats_scrolledwindow), clist_ul_stats);
  gtk_clist_set_column_width (GTK_CLIST (clist_ul_stats), 0, 304);
  gtk_clist_set_column_width (GTK_CLIST (clist_ul_stats), 1, 41);
  gtk_clist_set_column_width (GTK_CLIST (clist_ul_stats), 2, 60);
  gtk_clist_set_column_width (GTK_CLIST (clist_ul_stats), 3, 67);
  gtk_clist_set_column_width (GTK_CLIST (clist_ul_stats), 4, 80);
  gtk_clist_set_column_width (GTK_CLIST (clist_ul_stats), 5, 80);
  gtk_clist_set_column_width (GTK_CLIST (clist_ul_stats), 6, 80);
  gtk_clist_column_titles_show (GTK_CLIST (clist_ul_stats));

  ul_stats_label2 = gtk_label_new (_("Filename"));
  gtk_widget_set_name (ul_stats_label2, "ul_stats_label2");
  gtk_widget_ref (ul_stats_label2);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "ul_stats_label2", ul_stats_label2,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ul_stats_label2);
  gtk_clist_set_column_widget (GTK_CLIST (clist_ul_stats), 0, ul_stats_label2);
  gtk_label_set_justify (GTK_LABEL (ul_stats_label2), GTK_JUSTIFY_LEFT);
  gtk_misc_set_alignment (GTK_MISC (ul_stats_label2), 0, 0.5);

  ul_stats_size = gtk_label_new (_("Size"));
  gtk_widget_set_name (ul_stats_size, "ul_stats_size");
  gtk_widget_ref (ul_stats_size);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "ul_stats_size", ul_stats_size,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ul_stats_size);
  gtk_clist_set_column_widget (GTK_CLIST (clist_ul_stats), 1, ul_stats_size);
  gtk_label_set_justify (GTK_LABEL (ul_stats_size), GTK_JUSTIFY_LEFT);
  gtk_misc_set_alignment (GTK_MISC (ul_stats_size), 0, 0.5);

  ul_stats_label3 = gtk_label_new (_("Attempts"));
  gtk_widget_set_name (ul_stats_label3, "ul_stats_label3");
  gtk_widget_ref (ul_stats_label3);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "ul_stats_label3", ul_stats_label3,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ul_stats_label3);
  gtk_clist_set_column_widget (GTK_CLIST (clist_ul_stats), 2, ul_stats_label3);
  gtk_label_set_justify (GTK_LABEL (ul_stats_label3), GTK_JUSTIFY_LEFT);
  gtk_misc_set_alignment (GTK_MISC (ul_stats_label3), 0, 0.5);

  ul_stats_label4 = gtk_label_new (_("Complete"));
  gtk_widget_set_name (ul_stats_label4, "ul_stats_label4");
  gtk_widget_ref (ul_stats_label4);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "ul_stats_label4", ul_stats_label4,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ul_stats_label4);
  gtk_clist_set_column_widget (GTK_CLIST (clist_ul_stats), 3, ul_stats_label4);
  gtk_label_set_justify (GTK_LABEL (ul_stats_label4), GTK_JUSTIFY_LEFT);
  gtk_misc_set_alignment (GTK_MISC (ul_stats_label4), 0, 0.5);

  ul_stats_label5 = gtk_label_new (_("Normalized"));
  gtk_widget_set_name (ul_stats_label5, "ul_stats_label5");
  gtk_widget_ref (ul_stats_label5);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "ul_stats_label5", ul_stats_label5,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ul_stats_label5);
  gtk_clist_set_column_widget (GTK_CLIST (clist_ul_stats), 4, ul_stats_label5);
  gtk_label_set_justify (GTK_LABEL (ul_stats_label5), GTK_JUSTIFY_LEFT);
  gtk_misc_set_alignment (GTK_MISC (ul_stats_label5), 0, 0.5);

  ul_stats_label6 = gtk_label_new (_("Last Request"));
  gtk_widget_set_name (ul_stats_label6, "ul_stats_label6");
  gtk_widget_ref (ul_stats_label6);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "ul_stats_label6", ul_stats_label6,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ul_stats_label6);
  gtk_clist_set_column_widget (GTK_CLIST (clist_ul_stats), 5, ul_stats_label6);
  gtk_label_set_justify (GTK_LABEL (ul_stats_label6), GTK_JUSTIFY_LEFT);
  gtk_misc_set_alignment (GTK_MISC (ul_stats_label6), 0, 0.5);

  ul_stats_label7 = gtk_label_new (_("Last Upload"));
  gtk_widget_set_name (ul_stats_label7, "ul_stats_label7");
  gtk_widget_ref (ul_stats_label7);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "ul_stats_label7", ul_stats_label7,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ul_stats_label7);
  gtk_clist_set_column_widget (GTK_CLIST (clist_ul_stats), 6, ul_stats_label7);
  gtk_label_set_justify (GTK_LABEL (ul_stats_label7), GTK_JUSTIFY_LEFT);
  gtk_misc_set_alignment (GTK_MISC (ul_stats_label7), 0, 0.5);

  ul_stats_hbox2 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (ul_stats_hbox2, "ul_stats_hbox2");
  gtk_widget_ref (ul_stats_hbox2);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "ul_stats_hbox2", ul_stats_hbox2,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ul_stats_hbox2);
  gtk_box_pack_start (GTK_BOX (vbox19), ul_stats_hbox2, FALSE, TRUE, 0);

  button_ul_stats_clear_deleted = gtk_button_new_with_label (_("Clear non-existent files"));
  gtk_widget_set_name (button_ul_stats_clear_deleted, "button_ul_stats_clear_deleted");
  gtk_widget_ref (button_ul_stats_clear_deleted);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "button_ul_stats_clear_deleted", button_ul_stats_clear_deleted,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_ul_stats_clear_deleted);
  gtk_box_pack_start (GTK_BOX (ul_stats_hbox2), button_ul_stats_clear_deleted, FALSE, FALSE, 0);
  gtk_widget_set_sensitive (button_ul_stats_clear_deleted, FALSE);
  gtk_tooltips_set_tip (tooltips, button_ul_stats_clear_deleted, _("Somebody tell me a sensible tooltip for this."), NULL);

  button_ul_stats_clear_all = gtk_button_new_with_label (_("Clear all"));
  gtk_widget_set_name (button_ul_stats_clear_all, "button_ul_stats_clear_all");
  gtk_widget_ref (button_ul_stats_clear_all);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "button_ul_stats_clear_all", button_ul_stats_clear_all,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_ul_stats_clear_all);
  gtk_box_pack_start (GTK_BOX (ul_stats_hbox2), button_ul_stats_clear_all, FALSE, FALSE, 0);

  viewport50 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport50, "viewport50");
  gtk_widget_ref (viewport50);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "viewport50", viewport50,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (viewport50);
  gtk_box_pack_start (GTK_BOX (ul_stats_hbox2), viewport50, TRUE, TRUE, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport50), GTK_SHADOW_ETCHED_IN);

  hbox2101 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox2101, "hbox2101");
  gtk_widget_ref (hbox2101);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "hbox2101", hbox2101,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox2101);
  gtk_container_add (GTK_CONTAINER (viewport50), hbox2101);

  label745 = gtk_label_new (_("Fully served "));
  gtk_widget_set_name (label745, "label745");
  gtk_widget_ref (label745);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label745", label745,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label745);
  gtk_box_pack_start (GTK_BOX (hbox2101), label745, TRUE, TRUE, 0);
  gtk_misc_set_alignment (GTK_MISC (label745), 1, 0.5);

  label8005 = gtk_label_new ("");
  gtk_widget_set_name (label8005, "label8005");
  gtk_widget_ref (label8005);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label8005", label8005,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label8005);
  gtk_box_pack_start (GTK_BOX (hbox2101), label8005, FALSE, FALSE, 0);
  gtk_misc_set_padding (GTK_MISC (label8005), 4, 0);

  label_g2_browse_served = gtk_label_new (_("[G2 served]"));
  gtk_widget_set_name (label_g2_browse_served, "label_g2_browse_served");
  gtk_widget_ref (label_g2_browse_served);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label_g2_browse_served", label_g2_browse_served,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_g2_browse_served);
  gtk_box_pack_start (GTK_BOX (hbox2101), label_g2_browse_served, FALSE, FALSE, 0);

  label8037 = gtk_label_new (_(" / "));
  gtk_widget_set_name (label8037, "label8037");
  gtk_widget_ref (label8037);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label8037", label8037,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label8037);
  gtk_box_pack_start (GTK_BOX (hbox2101), label8037, FALSE, FALSE, 0);

  label_g2_browse_count = gtk_label_new (_("[G2]"));
  gtk_widget_set_name (label_g2_browse_count, "label_g2_browse_count");
  gtk_widget_ref (label_g2_browse_count);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label_g2_browse_count", label_g2_browse_count,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_g2_browse_count);
  gtk_box_pack_start (GTK_BOX (hbox2101), label_g2_browse_count, FALSE, FALSE, 0);

  label8039 = gtk_label_new (_(" G2, "));
  gtk_widget_set_name (label8039, "label8039");
  gtk_widget_ref (label8039);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label8039", label8039,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label8039);
  gtk_box_pack_start (GTK_BOX (hbox2101), label8039, FALSE, FALSE, 0);

  label_html_browse_served = gtk_label_new (_("[BH HTML served]"));
  gtk_widget_set_name (label_html_browse_served, "label_html_browse_served");
  gtk_widget_ref (label_html_browse_served);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label_html_browse_served", label_html_browse_served,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_html_browse_served);
  gtk_box_pack_start (GTK_BOX (hbox2101), label_html_browse_served, FALSE, FALSE, 0);

  label781 = gtk_label_new (_(" / "));
  gtk_widget_set_name (label781, "label781");
  gtk_widget_ref (label781);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label781", label781,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label781);
  gtk_box_pack_start (GTK_BOX (hbox2101), label781, FALSE, FALSE, 0);

  label_html_browse_count = gtk_label_new (_("[BH HTML]"));
  gtk_widget_set_name (label_html_browse_count, "label_html_browse_count");
  gtk_widget_ref (label_html_browse_count);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label_html_browse_count", label_html_browse_count,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_html_browse_count);
  gtk_box_pack_start (GTK_BOX (hbox2101), label_html_browse_count, FALSE, FALSE, 0);

  label747 = gtk_label_new (_(" HTML and "));
  gtk_widget_set_name (label747, "label747");
  gtk_widget_ref (label747);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label747", label747,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label747);
  gtk_box_pack_start (GTK_BOX (hbox2101), label747, FALSE, FALSE, 0);

  label_qhits_browse_served = gtk_label_new (_("[BH qhits served]"));
  gtk_widget_set_name (label_qhits_browse_served, "label_qhits_browse_served");
  gtk_widget_ref (label_qhits_browse_served);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label_qhits_browse_served", label_qhits_browse_served,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_qhits_browse_served);
  gtk_box_pack_start (GTK_BOX (hbox2101), label_qhits_browse_served, FALSE, FALSE, 0);

  label779 = gtk_label_new (_(" / "));
  gtk_widget_set_name (label779, "label779");
  gtk_widget_ref (label779);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label779", label779,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label779);
  gtk_box_pack_start (GTK_BOX (hbox2101), label779, FALSE, FALSE, 0);

  label_qhits_browse_count = gtk_label_new (_("[BH qhits]"));
  gtk_widget_set_name (label_qhits_browse_count, "label_qhits_browse_count");
  gtk_widget_ref (label_qhits_browse_count);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label_qhits_browse_count", label_qhits_browse_count,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_qhits_browse_count);
  gtk_box_pack_start (GTK_BOX (hbox2101), label_qhits_browse_count, FALSE, FALSE, 0);

  label749 = gtk_label_new (_(" Gnutella browse requests"));
  gtk_widget_set_name (label749, "label749");
  gtk_widget_ref (label749);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label749", label749,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label749);
  gtk_box_pack_start (GTK_BOX (hbox2101), label749, FALSE, FALSE, 0);

  label7980 = gtk_label_new (_("Upload History"));
  gtk_widget_set_name (label7980, "label7980");
  gtk_widget_ref (label7980);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label7980", label7980,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label7980);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_main), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_main), 6), label7980);

  vbox127 = gtk_vbox_new (FALSE, 4);
  gtk_widget_set_name (vbox127, "vbox127");
  gtk_widget_ref (vbox127);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "vbox127", vbox127,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox127);
  gtk_container_add (GTK_CONTAINER (notebook_main), vbox127);

  scrolledwindow46 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow46, "scrolledwindow46");
  gtk_widget_ref (scrolledwindow46);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "scrolledwindow46", scrolledwindow46,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (scrolledwindow46);
  gtk_box_pack_start (GTK_BOX (vbox127), scrolledwindow46, TRUE, TRUE, 0);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow46), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);

  clist_hcache = gtk_clist_new (4);
  gtk_widget_set_name (clist_hcache, "clist_hcache");
  gtk_widget_ref (clist_hcache);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "clist_hcache", clist_hcache,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (clist_hcache);
  gtk_container_add (GTK_CONTAINER (scrolledwindow46), clist_hcache);
  gtk_clist_set_column_width (GTK_CLIST (clist_hcache), 0, 80);
  gtk_clist_set_column_width (GTK_CLIST (clist_hcache), 1, 80);
  gtk_clist_set_column_width (GTK_CLIST (clist_hcache), 2, 80);
  gtk_clist_set_column_width (GTK_CLIST (clist_hcache), 3, 80);
  gtk_clist_column_titles_show (GTK_CLIST (clist_hcache));

  label674 = gtk_label_new (_("Cache"));
  gtk_widget_set_name (label674, "label674");
  gtk_widget_ref (label674);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label674", label674,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label674);
  gtk_clist_set_column_widget (GTK_CLIST (clist_hcache), 0, label674);

  label675 = gtk_label_new (_("Hosts"));
  gtk_widget_set_name (label675, "label675");
  gtk_widget_ref (label675);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label675", label675,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label675);
  gtk_clist_set_column_widget (GTK_CLIST (clist_hcache), 1, label675);

  label676 = gtk_label_new (_("Hits"));
  gtk_widget_set_name (label676, "label676");
  gtk_widget_ref (label676);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label676", label676,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label676);
  gtk_clist_set_column_widget (GTK_CLIST (clist_hcache), 2, label676);

  label677 = gtk_label_new (_("Misses"));
  gtk_widget_set_name (label677, "label677");
  gtk_widget_ref (label677);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label677", label677,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label677);
  gtk_clist_set_column_widget (GTK_CLIST (clist_hcache), 3, label677);

  frame126 = gtk_frame_new (_("Hostcache capacity"));
  gtk_widget_set_name (frame126, "frame126");
  gtk_widget_ref (frame126);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "frame126", frame126,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame126);
  gtk_box_pack_start (GTK_BOX (vbox127), frame126, FALSE, TRUE, 0);

  hbox201 = gtk_hbox_new (TRUE, 4);
  gtk_widget_set_name (hbox201, "hbox201");
  gtk_widget_ref (hbox201);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "hbox201", hbox201,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox201);
  gtk_container_add (GTK_CONTAINER (frame126), hbox201);
  gtk_container_set_border_width (GTK_CONTAINER (hbox201), 2);

  vbox128 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox128, "vbox128");
  gtk_widget_ref (vbox128);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "vbox128", vbox128,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox128);
  gtk_box_pack_start (GTK_BOX (hbox201), vbox128, TRUE, TRUE, 0);

  progressbar_hosts_in_catcher = gtk_progress_bar_new ();
  gtk_widget_set_name (progressbar_hosts_in_catcher, "progressbar_hosts_in_catcher");
  gtk_widget_ref (progressbar_hosts_in_catcher);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "progressbar_hosts_in_catcher", progressbar_hosts_in_catcher,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (progressbar_hosts_in_catcher);
  gtk_box_pack_start (GTK_BOX (vbox128), progressbar_hosts_in_catcher, FALSE, FALSE, 0);
  gtk_progress_set_show_text (GTK_PROGRESS (progressbar_hosts_in_catcher), TRUE);
  gtk_progress_set_format_string (GTK_PROGRESS (progressbar_hosts_in_catcher), _("%v/%u (%P%%)"));

  hbox202 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox202, "hbox202");
  gtk_widget_ref (hbox202);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "hbox202", hbox202,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox202);
  gtk_box_pack_start (GTK_BOX (vbox128), hbox202, TRUE, TRUE, 0);

  label95 = gtk_label_new (_("Regular hosts"));
  gtk_widget_set_name (label95, "label95");
  gtk_widget_ref (label95);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label95", label95,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label95);
  gtk_box_pack_start (GTK_BOX (hbox202), label95, FALSE, FALSE, 0);
  gtk_misc_set_alignment (GTK_MISC (label95), 0, 0.5);

  spinbutton_max_hosts_cached_adj = gtk_adjustment_new (100, 100, 500000, 1, 100, 100);
  spinbutton_max_hosts_cached = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_max_hosts_cached_adj), 1, 0);
  gtk_widget_set_name (spinbutton_max_hosts_cached, "spinbutton_max_hosts_cached");
  gtk_widget_ref (spinbutton_max_hosts_cached);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "spinbutton_max_hosts_cached", spinbutton_max_hosts_cached,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_max_hosts_cached);
  gtk_box_pack_start (GTK_BOX (hbox202), spinbutton_max_hosts_cached, TRUE, TRUE, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_max_hosts_cached), TRUE);

  button_host_catcher_clear = gtk_button_new_with_label (_("Clear"));
  gtk_widget_set_name (button_host_catcher_clear, "button_host_catcher_clear");
  gtk_widget_ref (button_host_catcher_clear);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "button_host_catcher_clear", button_host_catcher_clear,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_host_catcher_clear);
  gtk_box_pack_start (GTK_BOX (hbox202), button_host_catcher_clear, FALSE, FALSE, 0);

  vbox129 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox129, "vbox129");
  gtk_widget_ref (vbox129);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "vbox129", vbox129,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox129);
  gtk_box_pack_start (GTK_BOX (hbox201), vbox129, TRUE, TRUE, 0);

  progressbar_hosts_in_ultra_catcher = gtk_progress_bar_new ();
  gtk_widget_set_name (progressbar_hosts_in_ultra_catcher, "progressbar_hosts_in_ultra_catcher");
  gtk_widget_ref (progressbar_hosts_in_ultra_catcher);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "progressbar_hosts_in_ultra_catcher", progressbar_hosts_in_ultra_catcher,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (progressbar_hosts_in_ultra_catcher);
  gtk_box_pack_start (GTK_BOX (vbox129), progressbar_hosts_in_ultra_catcher, FALSE, FALSE, 0);
  gtk_progress_set_show_text (GTK_PROGRESS (progressbar_hosts_in_ultra_catcher), TRUE);
  gtk_progress_set_format_string (GTK_PROGRESS (progressbar_hosts_in_ultra_catcher), _("%v/%u (%P%%)"));

  hbox203 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox203, "hbox203");
  gtk_widget_ref (hbox203);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "hbox203", hbox203,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox203);
  gtk_box_pack_start (GTK_BOX (vbox129), hbox203, TRUE, TRUE, 0);

  label453 = gtk_label_new (_("Ultrapeers"));
  gtk_widget_set_name (label453, "label453");
  gtk_widget_ref (label453);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label453", label453,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label453);
  gtk_box_pack_start (GTK_BOX (hbox203), label453, FALSE, FALSE, 0);

  spinbutton_max_ultra_hosts_cached_adj = gtk_adjustment_new (100, 100, 500000, 1, 100, 100);
  spinbutton_max_ultra_hosts_cached = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_max_ultra_hosts_cached_adj), 1, 0);
  gtk_widget_set_name (spinbutton_max_ultra_hosts_cached, "spinbutton_max_ultra_hosts_cached");
  gtk_widget_ref (spinbutton_max_ultra_hosts_cached);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "spinbutton_max_ultra_hosts_cached", spinbutton_max_ultra_hosts_cached,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_max_ultra_hosts_cached);
  gtk_box_pack_start (GTK_BOX (hbox203), spinbutton_max_ultra_hosts_cached, TRUE, TRUE, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_max_ultra_hosts_cached), TRUE);

  button_ultra_catcher_clear = gtk_button_new_with_label (_("Clear"));
  gtk_widget_set_name (button_ultra_catcher_clear, "button_ultra_catcher_clear");
  gtk_widget_ref (button_ultra_catcher_clear);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "button_ultra_catcher_clear", button_ultra_catcher_clear,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_ultra_catcher_clear);
  gtk_box_pack_start (GTK_BOX (hbox203), button_ultra_catcher_clear, FALSE, FALSE, 0);

  vbox130 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox130, "vbox130");
  gtk_widget_ref (vbox130);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "vbox130", vbox130,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox130);
  gtk_box_pack_start (GTK_BOX (hbox201), vbox130, TRUE, TRUE, 0);

  progressbar_hosts_in_bad_catcher = gtk_progress_bar_new ();
  gtk_widget_set_name (progressbar_hosts_in_bad_catcher, "progressbar_hosts_in_bad_catcher");
  gtk_widget_ref (progressbar_hosts_in_bad_catcher);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "progressbar_hosts_in_bad_catcher", progressbar_hosts_in_bad_catcher,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (progressbar_hosts_in_bad_catcher);
  gtk_box_pack_start (GTK_BOX (vbox130), progressbar_hosts_in_bad_catcher, FALSE, FALSE, 0);
  gtk_progress_set_show_text (GTK_PROGRESS (progressbar_hosts_in_bad_catcher), TRUE);
  gtk_progress_set_format_string (GTK_PROGRESS (progressbar_hosts_in_bad_catcher), _("%v/%u (%P%%)"));

  hbox204 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox204, "hbox204");
  gtk_widget_ref (hbox204);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "hbox204", hbox204,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox204);
  gtk_box_pack_start (GTK_BOX (vbox130), hbox204, TRUE, TRUE, 0);

  label678 = gtk_label_new (_("Bad hosts"));
  gtk_widget_set_name (label678, "label678");
  gtk_widget_ref (label678);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label678", label678,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label678);
  gtk_box_pack_start (GTK_BOX (hbox204), label678, FALSE, FALSE, 0);
  gtk_misc_set_alignment (GTK_MISC (label678), 0, 0.5);

  spinbutton_max_bad_hosts_cached_adj = gtk_adjustment_new (100, 100, 500000, 1, 100, 100);
  spinbutton_max_bad_hosts_cached = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_max_bad_hosts_cached_adj), 1, 0);
  gtk_widget_set_name (spinbutton_max_bad_hosts_cached, "spinbutton_max_bad_hosts_cached");
  gtk_widget_ref (spinbutton_max_bad_hosts_cached);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "spinbutton_max_bad_hosts_cached", spinbutton_max_bad_hosts_cached,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_max_bad_hosts_cached);
  gtk_box_pack_start (GTK_BOX (hbox204), spinbutton_max_bad_hosts_cached, TRUE, TRUE, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_max_bad_hosts_cached), TRUE);

  button_hostcache_clear_bad = gtk_button_new_with_label (_("Clear"));
  gtk_widget_set_name (button_hostcache_clear_bad, "button_hostcache_clear_bad");
  gtk_widget_ref (button_hostcache_clear_bad);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "button_hostcache_clear_bad", button_hostcache_clear_bad,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_hostcache_clear_bad);
  gtk_box_pack_start (GTK_BOX (hbox204), button_hostcache_clear_bad, FALSE, FALSE, 0);

  vbox148 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox148, "vbox148");
  gtk_widget_ref (vbox148);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "vbox148", vbox148,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox148);
  gtk_box_pack_start (GTK_BOX (hbox201), vbox148, TRUE, TRUE, 0);

  progressbar_hosts_in_g2hub_catcher = gtk_progress_bar_new ();
  gtk_widget_set_name (progressbar_hosts_in_g2hub_catcher, "progressbar_hosts_in_g2hub_catcher");
  gtk_widget_ref (progressbar_hosts_in_g2hub_catcher);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "progressbar_hosts_in_g2hub_catcher", progressbar_hosts_in_g2hub_catcher,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (progressbar_hosts_in_g2hub_catcher);
  gtk_box_pack_start (GTK_BOX (vbox148), progressbar_hosts_in_g2hub_catcher, FALSE, FALSE, 0);
  gtk_progress_set_show_text (GTK_PROGRESS (progressbar_hosts_in_g2hub_catcher), TRUE);
  gtk_progress_set_format_string (GTK_PROGRESS (progressbar_hosts_in_g2hub_catcher), _("%v/%u (%P%%)"));

  hbox2115 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox2115, "hbox2115");
  gtk_widget_ref (hbox2115);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "hbox2115", hbox2115,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox2115);
  gtk_box_pack_start (GTK_BOX (vbox148), hbox2115, TRUE, TRUE, 0);

  label_g2_hosts = gtk_label_new (_("G2 hubs"));
  gtk_widget_set_name (label_g2_hosts, "label_g2_hosts");
  gtk_widget_ref (label_g2_hosts);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label_g2_hosts", label_g2_hosts,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_g2_hosts);
  gtk_box_pack_start (GTK_BOX (hbox2115), label_g2_hosts, FALSE, FALSE, 0);
  gtk_misc_set_alignment (GTK_MISC (label_g2_hosts), 0, 0.5);

  spinbutton_max_g2hub_hosts_cached_adj = gtk_adjustment_new (100, 100, 500000, 1, 100, 100);
  spinbutton_max_g2hub_hosts_cached = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_max_g2hub_hosts_cached_adj), 1, 0);
  gtk_widget_set_name (spinbutton_max_g2hub_hosts_cached, "spinbutton_max_g2hub_hosts_cached");
  gtk_widget_ref (spinbutton_max_g2hub_hosts_cached);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "spinbutton_max_g2hub_hosts_cached", spinbutton_max_g2hub_hosts_cached,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_max_g2hub_hosts_cached);
  gtk_box_pack_start (GTK_BOX (hbox2115), spinbutton_max_g2hub_hosts_cached, TRUE, TRUE, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_max_g2hub_hosts_cached), TRUE);

  button_g2hub_catcher_clear = gtk_button_new_with_label (_("Clear"));
  gtk_widget_set_name (button_g2hub_catcher_clear, "button_g2hub_catcher_clear");
  gtk_widget_ref (button_g2hub_catcher_clear);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "button_g2hub_catcher_clear", button_g2hub_catcher_clear,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_g2hub_catcher_clear);
  gtk_box_pack_start (GTK_BOX (hbox2115), button_g2hub_catcher_clear, FALSE, FALSE, 0);

  label7987 = gtk_label_new (_("Hostcache"));
  gtk_widget_set_name (label7987, "label7987");
  gtk_widget_ref (label7987);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label7987", label7987,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label7987);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_main), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_main), 7), label7987);

  vbox12a = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox12a, "vbox12a");
  gtk_widget_ref (vbox12a);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "vbox12a", vbox12a,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox12a);
  gtk_container_add (GTK_CONTAINER (notebook_main), vbox12a);

  hbox67 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox67, "hbox67");
  gtk_widget_ref (hbox67);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "hbox67", hbox67,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox67);
  gtk_box_pack_start (GTK_BOX (vbox12a), hbox67, FALSE, TRUE, 0);

  option_menu_search_stats_type = gtk_option_menu_new ();
  gtk_widget_set_name (option_menu_search_stats_type, "option_menu_search_stats_type");
  gtk_widget_ref (option_menu_search_stats_type);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "option_menu_search_stats_type", option_menu_search_stats_type,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (option_menu_search_stats_type);
  gtk_box_pack_start (GTK_BOX (hbox67), option_menu_search_stats_type, FALSE, FALSE, 0);
  option_menu_search_stats_type_menu = gtk_menu_new ();
  gtk_option_menu_set_menu (GTK_OPTION_MENU (option_menu_search_stats_type), option_menu_search_stats_type_menu);

  label101 = gtk_label_new ("");
  label101_key = gtk_label_parse_uline (GTK_LABEL (label101),
                                   _("_Update interval (sec)"));
  gtk_widget_set_name (label101, "label101");
  gtk_widget_ref (label101);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label101", label101,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label101);
  gtk_box_pack_start (GTK_BOX (hbox67), label101, FALSE, TRUE, 0);
  gtk_label_set_justify (GTK_LABEL (label101), GTK_JUSTIFY_RIGHT);

  spinbutton_search_stats_update_interval_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 10);
  spinbutton_search_stats_update_interval = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_search_stats_update_interval_adj), 1, 0);
  gtk_widget_set_name (spinbutton_search_stats_update_interval, "spinbutton_search_stats_update_interval");
  gtk_widget_ref (spinbutton_search_stats_update_interval);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "spinbutton_search_stats_update_interval", spinbutton_search_stats_update_interval,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_search_stats_update_interval);
  gtk_box_pack_start (GTK_BOX (hbox67), spinbutton_search_stats_update_interval, FALSE, FALSE, 0);

  label102 = gtk_label_new ("");
  label102_key = gtk_label_parse_uline (GTK_LABEL (label102),
                                   _("_Deletion coeff. (0-100)"));
  gtk_widget_set_name (label102, "label102");
  gtk_widget_ref (label102);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label102", label102,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label102);
  gtk_box_pack_start (GTK_BOX (hbox67), label102, FALSE, TRUE, 0);
  gtk_label_set_justify (GTK_LABEL (label102), GTK_JUSTIFY_RIGHT);

  spinbutton_search_stats_delcoef_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 10);
  spinbutton_search_stats_delcoef = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_search_stats_delcoef_adj), 1, 0);
  gtk_widget_set_name (spinbutton_search_stats_delcoef, "spinbutton_search_stats_delcoef");
  gtk_widget_ref (spinbutton_search_stats_delcoef);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "spinbutton_search_stats_delcoef", spinbutton_search_stats_delcoef,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_search_stats_delcoef);
  gtk_box_pack_start (GTK_BOX (hbox67), spinbutton_search_stats_delcoef, FALSE, TRUE, 0);

  scrolledwindow10 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow10, "scrolledwindow10");
  gtk_widget_ref (scrolledwindow10);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "scrolledwindow10", scrolledwindow10,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (scrolledwindow10);
  gtk_box_pack_start (GTK_BOX (vbox12a), scrolledwindow10, TRUE, TRUE, 0);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow10), GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS);

  clist_search_stats = gtk_clist_new (3);
  gtk_widget_set_name (clist_search_stats, "clist_search_stats");
  gtk_widget_ref (clist_search_stats);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "clist_search_stats", clist_search_stats,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (clist_search_stats);
  gtk_container_add (GTK_CONTAINER (scrolledwindow10), clist_search_stats);
  gtk_clist_set_column_width (GTK_CLIST (clist_search_stats), 0, 239);
  gtk_clist_set_column_width (GTK_CLIST (clist_search_stats), 1, 93);
  gtk_clist_set_column_width (GTK_CLIST (clist_search_stats), 2, 80);
  gtk_clist_column_titles_show (GTK_CLIST (clist_search_stats));

  label105 = gtk_label_new (_("Search Term"));
  gtk_widget_set_name (label105, "label105");
  gtk_widget_ref (label105);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label105", label105,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label105);
  gtk_clist_set_column_widget (GTK_CLIST (clist_search_stats), 0, label105);
  gtk_misc_set_alignment (GTK_MISC (label105), 0, 0.5);

  label106 = gtk_label_new (_("This Interval"));
  gtk_widget_set_name (label106, "label106");
  gtk_widget_ref (label106);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label106", label106,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label106);
  gtk_clist_set_column_widget (GTK_CLIST (clist_search_stats), 1, label106);

  label107 = gtk_label_new (_("Total"));
  gtk_widget_set_name (label107, "label107");
  gtk_widget_ref (label107);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label107", label107,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label107);
  gtk_clist_set_column_widget (GTK_CLIST (clist_search_stats), 2, label107);

  alignment1 = gtk_alignment_new (0.5, 0.5, 1, 1);
  gtk_widget_set_name (alignment1, "alignment1");
  gtk_widget_ref (alignment1);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "alignment1", alignment1,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (alignment1);
  gtk_box_pack_start (GTK_BOX (vbox12a), alignment1, FALSE, FALSE, 0);

  hbox66 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox66, "hbox66");
  gtk_widget_ref (hbox66);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "hbox66", hbox66,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox66);
  gtk_container_add (GTK_CONTAINER (alignment1), hbox66);

  button_search_stats_reset = gtk_button_new_with_label ("");
  button_search_stats_reset_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (button_search_stats_reset)->child),
                                   _("_Reset stats"));
  gtk_widget_add_accelerator (button_search_stats_reset, "clicked", accel_group,
                              button_search_stats_reset_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (button_search_stats_reset, "button_search_stats_reset");
  gtk_widget_ref (button_search_stats_reset);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "button_search_stats_reset", button_search_stats_reset,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_search_stats_reset);
  gtk_box_pack_start (GTK_BOX (hbox66), button_search_stats_reset, FALSE, FALSE, 0);

  viewport_fix_flashing_2 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport_fix_flashing_2, "viewport_fix_flashing_2");
  gtk_widget_ref (viewport_fix_flashing_2);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "viewport_fix_flashing_2", viewport_fix_flashing_2,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (viewport_fix_flashing_2);
  gtk_box_pack_start (GTK_BOX (hbox66), viewport_fix_flashing_2, TRUE, TRUE, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport_fix_flashing_2), GTK_SHADOW_ETCHED_IN);

  hbox168 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox168, "hbox168");
  gtk_widget_ref (hbox168);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "hbox168", hbox168,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox168);
  gtk_container_add (GTK_CONTAINER (viewport_fix_flashing_2), hbox168);

  label_search_stats_count = gtk_label_new (_("0 terms counted"));
  gtk_widget_set_name (label_search_stats_count, "label_search_stats_count");
  gtk_widget_ref (label_search_stats_count);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label_search_stats_count", label_search_stats_count,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_search_stats_count);
  gtk_box_pack_start (GTK_BOX (hbox168), label_search_stats_count, TRUE, TRUE, 0);
  gtk_label_set_justify (GTK_LABEL (label_search_stats_count), GTK_JUSTIFY_RIGHT);
  gtk_misc_set_alignment (GTK_MISC (label_search_stats_count), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_search_stats_count), 5, 0);

  label7988 = gtk_label_new (_("Search Stats"));
  gtk_widget_set_name (label7988, "label7988");
  gtk_widget_ref (label7988);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label7988", label7988,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label7988);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_main), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_main), 8), label7988);

  hbox_statusbar = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox_statusbar, "hbox_statusbar");
  gtk_widget_ref (hbox_statusbar);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "hbox_statusbar", hbox_statusbar,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox_statusbar);
  gtk_box_pack_start (GTK_BOX (vbox12), hbox_statusbar, FALSE, TRUE, 0);

  togglebutton_online = gtk_toggle_button_new ();
  gtk_widget_set_name (togglebutton_online, "togglebutton_online");
  gtk_widget_ref (togglebutton_online);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "togglebutton_online", togglebutton_online,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (togglebutton_online);
  gtk_box_pack_start (GTK_BOX (hbox_statusbar), togglebutton_online, FALSE, FALSE, 0);

  hbox145 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox145, "hbox145");
  gtk_widget_ref (hbox145);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "hbox145", hbox145,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox145);
  gtk_container_add (GTK_CONTAINER (togglebutton_online), hbox145);

  image_online = create_pixmap (main_window, "online.xpm");
  gtk_widget_set_name (image_online, "image_online");
  gtk_widget_ref (image_online);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "image_online", image_online,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (image_online);
  gtk_box_pack_start (GTK_BOX (hbox145), image_online, TRUE, TRUE, 0);
  gtk_pixmap_set_build_insensitive (GTK_PIXMAP (image_online), FALSE);

  eventbox5 = gtk_event_box_new ();
  gtk_widget_set_name (eventbox5, "eventbox5");
  gtk_widget_ref (eventbox5);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "eventbox5", eventbox5,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (eventbox5);
  gtk_box_pack_start (GTK_BOX (hbox145), eventbox5, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox5, _("You seem to be offline."), NULL);

  image_offline = create_pixmap (main_window, "offline.xpm");
  gtk_widget_set_name (image_offline, "image_offline");
  gtk_widget_ref (image_offline);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "image_offline", image_offline,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (image_offline);
  gtk_container_add (GTK_CONTAINER (eventbox5), image_offline);
  gtk_pixmap_set_build_insensitive (GTK_PIXMAP (image_offline), FALSE);

  hbox_port_mapping = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox_port_mapping, "hbox_port_mapping");
  gtk_widget_ref (hbox_port_mapping);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "hbox_port_mapping", hbox_port_mapping,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox_port_mapping);
  gtk_box_pack_start (GTK_BOX (hbox_statusbar), hbox_port_mapping, FALSE, TRUE, 0);

  eventbox_port_mapping_possible = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_port_mapping_possible, "eventbox_port_mapping_possible");
  gtk_widget_ref (eventbox_port_mapping_possible);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "eventbox_port_mapping_possible", eventbox_port_mapping_possible,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (eventbox_port_mapping_possible);
  gtk_box_pack_start (GTK_BOX (hbox_port_mapping), eventbox_port_mapping_possible, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox_port_mapping_possible, _("Port mapping possible through UPnP or NAT-PMP."), NULL);

  image_port_mapping_possible = create_pixmap (main_window, "upnp-unusable.xpm");
  gtk_widget_set_name (image_port_mapping_possible, "image_port_mapping_possible");
  gtk_widget_ref (image_port_mapping_possible);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "image_port_mapping_possible", image_port_mapping_possible,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (image_port_mapping_possible);
  gtk_container_add (GTK_CONTAINER (eventbox_port_mapping_possible), image_port_mapping_possible);
  gtk_pixmap_set_build_insensitive (GTK_PIXMAP (image_port_mapping_possible), FALSE);

  eventbox_upnp_port_mapping_successful = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_upnp_port_mapping_successful, "eventbox_upnp_port_mapping_successful");
  gtk_widget_ref (eventbox_upnp_port_mapping_successful);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "eventbox_upnp_port_mapping_successful", eventbox_upnp_port_mapping_successful,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (eventbox_upnp_port_mapping_successful);
  gtk_box_pack_start (GTK_BOX (hbox_port_mapping), eventbox_upnp_port_mapping_successful, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox_upnp_port_mapping_successful, _("Port mapping configured through UPnP."), NULL);

  image_upnp_successful = create_pixmap (main_window, "upnp.xpm");
  gtk_widget_set_name (image_upnp_successful, "image_upnp_successful");
  gtk_widget_ref (image_upnp_successful);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "image_upnp_successful", image_upnp_successful,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (image_upnp_successful);
  gtk_container_add (GTK_CONTAINER (eventbox_upnp_port_mapping_successful), image_upnp_successful);
  gtk_pixmap_set_build_insensitive (GTK_PIXMAP (image_upnp_successful), FALSE);

  eventbox_natpmp_port_mapping_successful = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_natpmp_port_mapping_successful, "eventbox_natpmp_port_mapping_successful");
  gtk_widget_ref (eventbox_natpmp_port_mapping_successful);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "eventbox_natpmp_port_mapping_successful", eventbox_natpmp_port_mapping_successful,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (eventbox_natpmp_port_mapping_successful);
  gtk_box_pack_start (GTK_BOX (hbox_port_mapping), eventbox_natpmp_port_mapping_successful, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox_natpmp_port_mapping_successful, _("Port mapping configured through NAT-PMP."), NULL);

  image_natpmp_successful = create_pixmap (main_window, "natpmp.xpm");
  gtk_widget_set_name (image_natpmp_successful, "image_natpmp_successful");
  gtk_widget_ref (image_natpmp_successful);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "image_natpmp_successful", image_natpmp_successful,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (image_natpmp_successful);
  gtk_container_add (GTK_CONTAINER (eventbox_natpmp_port_mapping_successful), image_natpmp_successful);
  gtk_pixmap_set_build_insensitive (GTK_PIXMAP (image_natpmp_successful), FALSE);

  alignment25 = gtk_alignment_new (0.5, 0.5, 1, 1);
  gtk_widget_set_name (alignment25, "alignment25");
  gtk_widget_ref (alignment25);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "alignment25", alignment25,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (alignment25);
  gtk_box_pack_start (GTK_BOX (hbox_statusbar), alignment25, TRUE, TRUE, 0);

  statusbar = gtk_statusbar_new ();
  gtk_widget_set_name (statusbar, "statusbar");
  gtk_widget_ref (statusbar);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "statusbar", statusbar,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (statusbar);
  gtk_container_add (GTK_CONTAINER (alignment25), statusbar);

  frame_status_images = gtk_frame_new (NULL);
  gtk_widget_set_name (frame_status_images, "frame_status_images");
  gtk_widget_ref (frame_status_images);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "frame_status_images", frame_status_images,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame_status_images);
  gtk_box_pack_start (GTK_BOX (hbox_statusbar), frame_status_images, FALSE, FALSE, 0);

  hbox199 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox199, "hbox199");
  gtk_widget_ref (hbox199);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "hbox199", hbox199,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox199);
  gtk_container_add (GTK_CONTAINER (frame_status_images), hbox199);

  eventbox_image_download_queue_frozen = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_download_queue_frozen, "eventbox_image_download_queue_frozen");
  gtk_widget_ref (eventbox_image_download_queue_frozen);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "eventbox_image_download_queue_frozen", eventbox_image_download_queue_frozen,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (eventbox_image_download_queue_frozen);
  gtk_box_pack_start (GTK_BOX (hbox199), eventbox_image_download_queue_frozen, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox_image_download_queue_frozen, _("Download queue is frozen."), NULL);

  image_download_queue_frozen = create_pixmap (main_window, "pause.xpm");
  gtk_widget_set_name (image_download_queue_frozen, "image_download_queue_frozen");
  gtk_widget_ref (image_download_queue_frozen);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "image_download_queue_frozen", image_download_queue_frozen,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (image_download_queue_frozen);
  gtk_container_add (GTK_CONTAINER (eventbox_image_download_queue_frozen), image_download_queue_frozen);
  gtk_misc_set_padding (GTK_MISC (image_download_queue_frozen), 1, 0);
  gtk_pixmap_set_build_insensitive (GTK_PIXMAP (image_download_queue_frozen), FALSE);

  eventbox_image_chip = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_chip, "eventbox_image_chip");
  gtk_widget_ref (eventbox_image_chip);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "eventbox_image_chip", eventbox_image_chip,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (eventbox_image_chip);
  gtk_box_pack_start (GTK_BOX (hbox199), eventbox_image_chip, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox_image_chip, _("CPU overloaded."), NULL);

  image_chip = create_pixmap (main_window, "chip.xpm");
  gtk_widget_set_name (image_chip, "image_chip");
  gtk_widget_ref (image_chip);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "image_chip", image_chip,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (image_chip);
  gtk_container_add (GTK_CONTAINER (eventbox_image_chip), image_chip);
  gtk_misc_set_padding (GTK_MISC (image_chip), 1, 0);
  gtk_pixmap_set_build_insensitive (GTK_PIXMAP (image_chip), FALSE);

  eventbox_image_warning = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_warning, "eventbox_image_warning");
  gtk_widget_ref (eventbox_image_warning);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "eventbox_image_warning", eventbox_image_warning,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (eventbox_image_warning);
  gtk_box_pack_start (GTK_BOX (hbox199), eventbox_image_warning, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox_image_warning, _("Your uploads are stalling at an abnormal rate, indicating that your bandwidth is probably saturated. You should not run as an ultra node, and try to reduce the allocated bandwidth to gtk-gnutella to avoid saturating both your incoming and outgoing paths."), NULL);

  image_warning = create_pixmap (main_window, "warning.xpm");
  gtk_widget_set_name (image_warning, "image_warning");
  gtk_widget_ref (image_warning);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "image_warning", image_warning,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (image_warning);
  gtk_container_add (GTK_CONTAINER (eventbox_image_warning), image_warning);
  gtk_pixmap_set_build_insensitive (GTK_PIXMAP (image_warning), FALSE);

  hbox2110 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox2110, "hbox2110");
  gtk_widget_ref (hbox2110);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "hbox2110", hbox2110,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox2110);
  gtk_box_pack_start (GTK_BOX (hbox199), hbox2110, TRUE, TRUE, 0);

  eventbox_early_stall_1 = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_early_stall_1, "eventbox_early_stall_1");
  gtk_widget_ref (eventbox_early_stall_1);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "eventbox_early_stall_1", eventbox_early_stall_1,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (eventbox_early_stall_1);
  gtk_box_pack_start (GTK_BOX (hbox2110), eventbox_early_stall_1, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox_early_stall_1, _("Capping HTTP outgoing bandwidth."), NULL);

  image_early_stall_1 = create_pixmap (main_window, "upload.xpm");
  gtk_widget_set_name (image_early_stall_1, "image_early_stall_1");
  gtk_widget_ref (image_early_stall_1);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "image_early_stall_1", image_early_stall_1,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (image_early_stall_1);
  gtk_container_add (GTK_CONTAINER (eventbox_early_stall_1), image_early_stall_1);
  gtk_pixmap_set_build_insensitive (GTK_PIXMAP (image_early_stall_1), FALSE);

  eventbox_early_stall_2 = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_early_stall_2, "eventbox_early_stall_2");
  gtk_widget_ref (eventbox_early_stall_2);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "eventbox_early_stall_2", eventbox_early_stall_2,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (eventbox_early_stall_2);
  gtk_box_pack_start (GTK_BOX (hbox2110), eventbox_early_stall_2, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox_early_stall_2, _("Splitting outgoing HTTP bandwidth evenly."), NULL);

  image_early_stall_2 = create_pixmap (main_window, "upload-yellow.xpm");
  gtk_widget_set_name (image_early_stall_2, "image_early_stall_2");
  gtk_widget_ref (image_early_stall_2);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "image_early_stall_2", image_early_stall_2,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (image_early_stall_2);
  gtk_container_add (GTK_CONTAINER (eventbox_early_stall_2), image_early_stall_2);
  gtk_pixmap_set_build_insensitive (GTK_PIXMAP (image_early_stall_2), FALSE);

  eventbox_early_stall_3 = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_early_stall_3, "eventbox_early_stall_3");
  gtk_widget_ref (eventbox_early_stall_3);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "eventbox_early_stall_3", eventbox_early_stall_3,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (eventbox_early_stall_3);
  gtk_box_pack_start (GTK_BOX (hbox2110), eventbox_early_stall_3, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox_early_stall_3, _("Disabled stealing of outgoing HTTP bandwidth."), NULL);

  image_early_stall_3 = create_pixmap (main_window, "upload-red.xpm");
  gtk_widget_set_name (image_early_stall_3, "image_early_stall_3");
  gtk_widget_ref (image_early_stall_3);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "image_early_stall_3", image_early_stall_3,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (image_early_stall_3);
  gtk_container_add (GTK_CONTAINER (eventbox_early_stall_3), image_early_stall_3);
  gtk_pixmap_set_build_insensitive (GTK_PIXMAP (image_early_stall_3), FALSE);

  eventbox_image_fd_shortage = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_fd_shortage, "eventbox_image_fd_shortage");
  gtk_widget_ref (eventbox_image_fd_shortage);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "eventbox_image_fd_shortage", eventbox_image_fd_shortage,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (eventbox_image_fd_shortage);
  gtk_box_pack_start (GTK_BOX (hbox199), eventbox_image_fd_shortage, TRUE, TRUE, 0);

  image_fd_shortage = create_pixmap (main_window, "clanbomber_yellow.xpm");
  gtk_widget_set_name (image_fd_shortage, "image_fd_shortage");
  gtk_widget_ref (image_fd_shortage);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "image_fd_shortage", image_fd_shortage,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (image_fd_shortage);
  gtk_container_add (GTK_CONTAINER (eventbox_image_fd_shortage), image_fd_shortage);
  gtk_pixmap_set_build_insensitive (GTK_PIXMAP (image_fd_shortage), FALSE);

  eventbox_image_fd_runout = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_fd_runout, "eventbox_image_fd_runout");
  gtk_widget_ref (eventbox_image_fd_runout);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "eventbox_image_fd_runout", eventbox_image_fd_runout,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (eventbox_image_fd_runout);
  gtk_box_pack_start (GTK_BOX (hbox199), eventbox_image_fd_runout, TRUE, TRUE, 0);

  image_fd_runout = create_pixmap (main_window, "clanbomber_red.xpm");
  gtk_widget_set_name (image_fd_runout, "image_fd_runout");
  gtk_widget_ref (image_fd_runout);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "image_fd_runout", image_fd_runout,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (image_fd_runout);
  gtk_container_add (GTK_CONTAINER (eventbox_image_fd_runout), image_fd_runout);
  gtk_pixmap_set_build_insensitive (GTK_PIXMAP (image_fd_runout), FALSE);

  eventbox_image_ancient = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_ancient, "eventbox_image_ancient");
  gtk_widget_ref (eventbox_image_ancient);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "eventbox_image_ancient", eventbox_image_ancient,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (eventbox_image_ancient);
  gtk_box_pack_start (GTK_BOX (hbox199), eventbox_image_ancient, TRUE, TRUE, 0);

  image_ancient = create_pixmap (main_window, "stock_form-time-field-16.xpm");
  gtk_widget_set_name (image_ancient, "image_ancient");
  gtk_widget_ref (image_ancient);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "image_ancient", image_ancient,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (image_ancient);
  gtk_container_add (GTK_CONTAINER (eventbox_image_ancient), image_ancient);

  eventbox_image_save = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_save, "eventbox_image_save");
  gtk_widget_ref (eventbox_image_save);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "eventbox_image_save", eventbox_image_save,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (eventbox_image_save);
  gtk_box_pack_start (GTK_BOX (hbox199), eventbox_image_save, TRUE, TRUE, 0);

  image_save = create_pixmap (main_window, "save.xpm");
  gtk_widget_set_name (image_save, "image_save");
  gtk_widget_ref (image_save);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "image_save", image_save,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (image_save);
  gtk_container_add (GTK_CONTAINER (eventbox_image_save), image_save);
  gtk_misc_set_padding (GTK_MISC (image_save), 1, 0);

  eventbox_image_sha = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_sha, "eventbox_image_sha");
  gtk_widget_ref (eventbox_image_sha);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "eventbox_image_sha", eventbox_image_sha,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (eventbox_image_sha);
  gtk_box_pack_start (GTK_BOX (hbox199), eventbox_image_sha, TRUE, TRUE, 0);

  image_sha = create_pixmap (main_window, "booksha.xpm");
  gtk_widget_set_name (image_sha, "image_sha");
  gtk_widget_ref (image_sha);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "image_sha", image_sha,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (image_sha);
  gtk_container_add (GTK_CONTAINER (eventbox_image_sha), image_sha);

  eventbox_image_shav = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_shav, "eventbox_image_shav");
  gtk_widget_ref (eventbox_image_shav);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "eventbox_image_shav", eventbox_image_shav,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (eventbox_image_shav);
  gtk_box_pack_start (GTK_BOX (hbox199), eventbox_image_shav, TRUE, TRUE, 0);

  image_shav = create_pixmap (main_window, "bookshav.xpm");
  gtk_widget_set_name (image_shav, "image_shav");
  gtk_widget_ref (image_shav);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "image_shav", image_shav,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (image_shav);
  gtk_container_add (GTK_CONTAINER (eventbox_image_shav), image_shav);
  gtk_misc_set_padding (GTK_MISC (image_shav), 1, 0);

  eventbox_image_tth = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_tth, "eventbox_image_tth");
  gtk_widget_ref (eventbox_image_tth);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "eventbox_image_tth", eventbox_image_tth,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (eventbox_image_tth);
  gtk_box_pack_start (GTK_BOX (hbox199), eventbox_image_tth, TRUE, TRUE, 0);

  image_tth = create_pixmap (main_window, "booktth.xpm");
  gtk_widget_set_name (image_tth, "image_tth");
  gtk_widget_ref (image_tth);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "image_tth", image_tth,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (image_tth);
  gtk_container_add (GTK_CONTAINER (eventbox_image_tth), image_tth);

  eventbox_image_tthv = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_tthv, "eventbox_image_tthv");
  gtk_widget_ref (eventbox_image_tthv);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "eventbox_image_tthv", eventbox_image_tthv,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (eventbox_image_tthv);
  gtk_box_pack_start (GTK_BOX (hbox199), eventbox_image_tthv, TRUE, TRUE, 0);

  image_tthv = create_pixmap (main_window, "booktthv.xpm");
  gtk_widget_set_name (image_tthv, "image_tthv");
  gtk_widget_ref (image_tthv);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "image_tthv", image_tthv,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (image_tthv);
  gtk_container_add (GTK_CONTAINER (eventbox_image_tthv), image_tthv);
  gtk_misc_set_padding (GTK_MISC (image_tthv), 1, 0);

  eventbox_image_lib = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_lib, "eventbox_image_lib");
  gtk_widget_ref (eventbox_image_lib);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "eventbox_image_lib", eventbox_image_lib,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (eventbox_image_lib);
  gtk_box_pack_start (GTK_BOX (hbox199), eventbox_image_lib, TRUE, TRUE, 0);

  image_lib = create_pixmap (main_window, "booklib.xpm");
  gtk_widget_set_name (image_lib, "image_lib");
  gtk_widget_ref (image_lib);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "image_lib", image_lib,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (image_lib);
  gtk_container_add (GTK_CONTAINER (eventbox_image_lib), image_lib);

  eventbox_image_firewall = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_firewall, "eventbox_image_firewall");
  gtk_widget_ref (eventbox_image_firewall);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "eventbox_image_firewall", eventbox_image_firewall,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (eventbox_image_firewall);
  gtk_box_pack_start (GTK_BOX (hbox199), eventbox_image_firewall, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox_image_firewall, _("You appear to be firewalled, both TCP-wise and UDP-wise. You will not see any push results, which may prevent you from seeing a large amount of results. You will not be able to send queries requesting out-of-band delivery of query hits."), NULL);

  image_firewall = create_pixmap (main_window, "firewall.xpm");
  gtk_widget_set_name (image_firewall, "image_firewall");
  gtk_widget_ref (image_firewall);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "image_firewall", image_firewall,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (image_firewall);
  gtk_container_add (GTK_CONTAINER (eventbox_image_firewall), image_firewall);
  gtk_misc_set_padding (GTK_MISC (image_firewall), 1, 0);
  gtk_pixmap_set_build_insensitive (GTK_PIXMAP (image_firewall), FALSE);

  eventbox_image_firewall_punchable = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_firewall_punchable, "eventbox_image_firewall_punchable");
  gtk_widget_ref (eventbox_image_firewall_punchable);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "eventbox_image_firewall_punchable", eventbox_image_firewall_punchable,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (eventbox_image_firewall_punchable);
  gtk_box_pack_start (GTK_BOX (hbox199), eventbox_image_firewall_punchable, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox_image_firewall_punchable, _("You appear to be firewalled, both TCP-wise and UDP-wise. You will not see any push results, which may prevent you from seeing a large amount of results. You will not be able to send queries requesting out-of-band delivery of query hits. However, it is possible to punch a hole into the UDP firewall, so you will be able to send out-of-band query hits."), NULL);

  image_firewall_punchable = create_pixmap (main_window, "firewall_punchable.xpm");
  gtk_widget_set_name (image_firewall_punchable, "image_firewall_punchable");
  gtk_widget_ref (image_firewall_punchable);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "image_firewall_punchable", image_firewall_punchable,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (image_firewall_punchable);
  gtk_container_add (GTK_CONTAINER (eventbox_image_firewall_punchable), image_firewall_punchable);
  gtk_misc_set_padding (GTK_MISC (image_firewall_punchable), 1, 0);
  gtk_pixmap_set_build_insensitive (GTK_PIXMAP (image_firewall_punchable), FALSE);

  eventbox_image_tcp_firewall = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_tcp_firewall, "eventbox_image_tcp_firewall");
  gtk_widget_ref (eventbox_image_tcp_firewall);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "eventbox_image_tcp_firewall", eventbox_image_tcp_firewall,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (eventbox_image_tcp_firewall);
  gtk_box_pack_start (GTK_BOX (hbox199), eventbox_image_tcp_firewall, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox_image_tcp_firewall, _("You appear to be TCP-firewalled, i.e. others cannot connect to you to download files. You will not see push results, which may prevent you from seeing a large amount of results."), NULL);

  image_tcp_firewall = create_pixmap (main_window, "firewall_tcp.xpm");
  gtk_widget_set_name (image_tcp_firewall, "image_tcp_firewall");
  gtk_widget_ref (image_tcp_firewall);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "image_tcp_firewall", image_tcp_firewall,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (image_tcp_firewall);
  gtk_container_add (GTK_CONTAINER (eventbox_image_tcp_firewall), image_tcp_firewall);
  gtk_misc_set_padding (GTK_MISC (image_tcp_firewall), 1, 0);
  gtk_pixmap_set_build_insensitive (GTK_PIXMAP (image_tcp_firewall), FALSE);

  eventbox_image_udp_firewall = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_udp_firewall, "eventbox_image_udp_firewall");
  gtk_widget_ref (eventbox_image_udp_firewall);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "eventbox_image_udp_firewall", eventbox_image_udp_firewall,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (eventbox_image_udp_firewall);
  gtk_box_pack_start (GTK_BOX (hbox199), eventbox_image_udp_firewall, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox_image_udp_firewall, _("You appear to be UDP-firewalled, i.e. you cannot receive unsolicited traffic via UDP. You will not be able to send queries requesting out-of-band delivery of query hits."), NULL);

  image_udp_firewall = create_pixmap (main_window, "firewall_udp.xpm");
  gtk_widget_set_name (image_udp_firewall, "image_udp_firewall");
  gtk_widget_ref (image_udp_firewall);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "image_udp_firewall", image_udp_firewall,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (image_udp_firewall);
  gtk_container_add (GTK_CONTAINER (eventbox_image_udp_firewall), image_udp_firewall);
  gtk_misc_set_padding (GTK_MISC (image_udp_firewall), 1, 0);
  gtk_pixmap_set_build_insensitive (GTK_PIXMAP (image_udp_firewall), FALSE);

  eventbox_image_firewall_udp_punchable = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_firewall_udp_punchable, "eventbox_image_firewall_udp_punchable");
  gtk_widget_ref (eventbox_image_firewall_udp_punchable);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "eventbox_image_firewall_udp_punchable", eventbox_image_firewall_udp_punchable,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (eventbox_image_firewall_udp_punchable);
  gtk_box_pack_start (GTK_BOX (hbox199), eventbox_image_firewall_udp_punchable, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox_image_firewall_udp_punchable, _("People can connect to you via TCP, but you are UDP-firewalled.  However, you can punch a hole into that firewall, allowing reception of replies to your UDP packets.  You will be able to send out-of-band query hits, but you won't be able to receive any."), NULL);

  image_firewall_udp_punchable = create_pixmap (main_window, "firewall_udp_punchable.xpm");
  gtk_widget_set_name (image_firewall_udp_punchable, "image_firewall_udp_punchable");
  gtk_widget_ref (image_firewall_udp_punchable);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "image_firewall_udp_punchable", image_firewall_udp_punchable,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (image_firewall_udp_punchable);
  gtk_container_add (GTK_CONTAINER (eventbox_image_firewall_udp_punchable), image_firewall_udp_punchable);
  gtk_misc_set_padding (GTK_MISC (image_firewall_udp_punchable), 1, 0);
  gtk_pixmap_set_build_insensitive (GTK_PIXMAP (image_firewall_udp_punchable), FALSE);

  eventbox_image_no_firewall = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_no_firewall, "eventbox_image_no_firewall");
  gtk_widget_ref (eventbox_image_no_firewall);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "eventbox_image_no_firewall", eventbox_image_no_firewall,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (eventbox_image_no_firewall);
  gtk_box_pack_start (GTK_BOX (hbox199), eventbox_image_no_firewall, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox_image_no_firewall, _("People can connect to you, using both TCP and UDP. Push should work and you will be able to receive out-of-band results for your queries."), NULL);

  image_no_firewall = create_pixmap (main_window, "no_firewall.xpm");
  gtk_widget_set_name (image_no_firewall, "image_no_firewall");
  gtk_widget_ref (image_no_firewall);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "image_no_firewall", image_no_firewall,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (image_no_firewall);
  gtk_container_add (GTK_CONTAINER (eventbox_image_no_firewall), image_no_firewall);
  gtk_misc_set_padding (GTK_MISC (image_no_firewall), 1, 0);
  gtk_pixmap_set_build_insensitive (GTK_PIXMAP (image_no_firewall), FALSE);

  eventbox_image_leaf = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_leaf, "eventbox_image_leaf");
  gtk_widget_ref (eventbox_image_leaf);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "eventbox_image_leaf", eventbox_image_leaf,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (eventbox_image_leaf);
  gtk_box_pack_start (GTK_BOX (hbox199), eventbox_image_leaf, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox_image_leaf, _("Running in leaf mode."), NULL);

  image_leaf = create_pixmap (main_window, "leaf.xpm");
  gtk_widget_set_name (image_leaf, "image_leaf");
  gtk_widget_ref (image_leaf);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "image_leaf", image_leaf,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (image_leaf);
  gtk_container_add (GTK_CONTAINER (eventbox_image_leaf), image_leaf);
  gtk_pixmap_set_build_insensitive (GTK_PIXMAP (image_leaf), FALSE);

  eventbox_image_legacy = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_legacy, "eventbox_image_legacy");
  gtk_widget_ref (eventbox_image_legacy);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "eventbox_image_legacy", eventbox_image_legacy,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (eventbox_image_legacy);
  gtk_box_pack_start (GTK_BOX (hbox199), eventbox_image_legacy, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox_image_legacy, _("Running in legacy mode. Consider switching to auto mode."), NULL);

  image_legacy = create_pixmap (main_window, "legacy.xpm");
  gtk_widget_set_name (image_legacy, "image_legacy");
  gtk_widget_ref (image_legacy);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "image_legacy", image_legacy,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (image_legacy);
  gtk_container_add (GTK_CONTAINER (eventbox_image_legacy), image_legacy);
  gtk_pixmap_set_build_insensitive (GTK_PIXMAP (image_legacy), FALSE);

  eventbox_image_ultra = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_ultra, "eventbox_image_ultra");
  gtk_widget_ref (eventbox_image_ultra);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "eventbox_image_ultra", eventbox_image_ultra,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (eventbox_image_ultra);
  gtk_box_pack_start (GTK_BOX (hbox199), eventbox_image_ultra, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox_image_ultra, _("Running in ultrapeer mode."), NULL);

  image_ultra = create_pixmap (main_window, "ultra.xpm");
  gtk_widget_set_name (image_ultra, "image_ultra");
  gtk_widget_ref (image_ultra);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "image_ultra", image_ultra,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (image_ultra);
  gtk_container_add (GTK_CONTAINER (eventbox_image_ultra), image_ultra);
  gtk_pixmap_set_build_insensitive (GTK_PIXMAP (image_ultra), FALSE);

  eventbox_image_dht_none = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_dht_none, "eventbox_image_dht_none");
  gtk_widget_ref (eventbox_image_dht_none);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "eventbox_image_dht_none", eventbox_image_dht_none,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (eventbox_image_dht_none);
  gtk_box_pack_start (GTK_BOX (hbox199), eventbox_image_dht_none, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox_image_dht_none, _("DHT inactive."), NULL);

  image_dht_none = create_pixmap (main_window, "star-black.xpm");
  gtk_widget_set_name (image_dht_none, "image_dht_none");
  gtk_widget_ref (image_dht_none);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "image_dht_none", image_dht_none,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (image_dht_none);
  gtk_container_add (GTK_CONTAINER (eventbox_image_dht_none), image_dht_none);
  gtk_pixmap_set_build_insensitive (GTK_PIXMAP (image_dht_none), FALSE);

  eventbox_image_dht_seeded = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_dht_seeded, "eventbox_image_dht_seeded");
  gtk_widget_ref (eventbox_image_dht_seeded);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "eventbox_image_dht_seeded", eventbox_image_dht_seeded,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (eventbox_image_dht_seeded);
  gtk_box_pack_start (GTK_BOX (hbox199), eventbox_image_dht_seeded, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox_image_dht_seeded, _("DHT seeded."), NULL);

  image_dht_seeded = create_pixmap (main_window, "star-violet.xpm");
  gtk_widget_set_name (image_dht_seeded, "image_dht_seeded");
  gtk_widget_ref (image_dht_seeded);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "image_dht_seeded", image_dht_seeded,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (image_dht_seeded);
  gtk_container_add (GTK_CONTAINER (eventbox_image_dht_seeded), image_dht_seeded);
  gtk_pixmap_set_build_insensitive (GTK_PIXMAP (image_dht_seeded), FALSE);

  eventbox_image_dht_own_kuid = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_dht_own_kuid, "eventbox_image_dht_own_kuid");
  gtk_widget_ref (eventbox_image_dht_own_kuid);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "eventbox_image_dht_own_kuid", eventbox_image_dht_own_kuid,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (eventbox_image_dht_own_kuid);
  gtk_box_pack_start (GTK_BOX (hbox199), eventbox_image_dht_own_kuid, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox_image_dht_own_kuid, _("DHT looking up own KUID."), NULL);

  image_dht_own_kuid = create_pixmap (main_window, "star-blue.xpm");
  gtk_widget_set_name (image_dht_own_kuid, "image_dht_own_kuid");
  gtk_widget_ref (image_dht_own_kuid);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "image_dht_own_kuid", image_dht_own_kuid,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (image_dht_own_kuid);
  gtk_container_add (GTK_CONTAINER (eventbox_image_dht_own_kuid), image_dht_own_kuid);
  gtk_pixmap_set_build_insensitive (GTK_PIXMAP (image_dht_own_kuid), FALSE);

  eventbox_image_dht_completing = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_dht_completing, "eventbox_image_dht_completing");
  gtk_widget_ref (eventbox_image_dht_completing);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "eventbox_image_dht_completing", eventbox_image_dht_completing,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (eventbox_image_dht_completing);
  gtk_box_pack_start (GTK_BOX (hbox199), eventbox_image_dht_completing, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox_image_dht_completing, _("DHT bootstrapping."), NULL);

  image_dht_completing = create_pixmap (main_window, "star-green.xpm");
  gtk_widget_set_name (image_dht_completing, "image_dht_completing");
  gtk_widget_ref (image_dht_completing);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "image_dht_completing", image_dht_completing,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (image_dht_completing);
  gtk_container_add (GTK_CONTAINER (eventbox_image_dht_completing), image_dht_completing);
  gtk_pixmap_set_build_insensitive (GTK_PIXMAP (image_dht_completing), FALSE);

  eventbox_image_dht_active = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_dht_active, "eventbox_image_dht_active");
  gtk_widget_ref (eventbox_image_dht_active);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "eventbox_image_dht_active", eventbox_image_dht_active,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (eventbox_image_dht_active);
  gtk_box_pack_start (GTK_BOX (hbox199), eventbox_image_dht_active, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox_image_dht_active, _("DHT up, active mode."), NULL);

  image_dht_active = create_pixmap (main_window, "star-yellow.xpm");
  gtk_widget_set_name (image_dht_active, "image_dht_active");
  gtk_widget_ref (image_dht_active);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "image_dht_active", image_dht_active,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (image_dht_active);
  gtk_container_add (GTK_CONTAINER (eventbox_image_dht_active), image_dht_active);
  gtk_pixmap_set_build_insensitive (GTK_PIXMAP (image_dht_active), FALSE);

  eventbox_image_dht_passive = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_dht_passive, "eventbox_image_dht_passive");
  gtk_widget_ref (eventbox_image_dht_passive);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "eventbox_image_dht_passive", eventbox_image_dht_passive,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (eventbox_image_dht_passive);
  gtk_box_pack_start (GTK_BOX (hbox199), eventbox_image_dht_passive, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox_image_dht_passive, _("DHT up, passive mode."), NULL);

  image_dht_passive = create_pixmap (main_window, "star-red.xpm");
  gtk_widget_set_name (image_dht_passive, "image_dht_passive");
  gtk_widget_ref (image_dht_passive);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "image_dht_passive", image_dht_passive,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (image_dht_passive);
  gtk_container_add (GTK_CONTAINER (eventbox_image_dht_passive), image_dht_passive);
  gtk_pixmap_set_build_insensitive (GTK_PIXMAP (image_dht_passive), FALSE);

  frame_statusbar_uptime = gtk_frame_new (NULL);
  gtk_widget_set_name (frame_statusbar_uptime, "frame_statusbar_uptime");
  gtk_widget_ref (frame_statusbar_uptime);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "frame_statusbar_uptime", frame_statusbar_uptime,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame_statusbar_uptime);
  gtk_box_pack_start (GTK_BOX (hbox_statusbar), frame_statusbar_uptime, FALSE, FALSE, 0);

  label_statusbar_uptime = gtk_label_new (_("Uptime"));
  gtk_widget_set_name (label_statusbar_uptime, "label_statusbar_uptime");
  gtk_widget_ref (label_statusbar_uptime);
  gtk_object_set_data_full (GTK_OBJECT (main_window), "label_statusbar_uptime", label_statusbar_uptime,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_statusbar_uptime);
  gtk_container_add (GTK_CONTAINER (frame_statusbar_uptime), label_statusbar_uptime);

  gtk_signal_connect (GTK_OBJECT (main_window), "delete_event",
                      GTK_SIGNAL_FUNC (on_main_window_delete_event),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (menu_prefs), "activate",
                      GTK_SIGNAL_FUNC (on_menu_prefs_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (quit), "activate",
                      GTK_SIGNAL_FUNC (on_button_quit_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (menu_searchbar_visible), "activate",
                      GTK_SIGNAL_FUNC (on_menu_searchbar_visible_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (menu_sidebar_visible), "activate",
                      GTK_SIGNAL_FUNC (on_menu_sidebar_visible_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (menu_menubar_visible), "activate",
                      GTK_SIGNAL_FUNC (on_menu_menubar_visible_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (menu_statusbar_visible), "activate",
                      GTK_SIGNAL_FUNC (on_menu_statusbar_visible_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (menu_downloads_visible), "activate",
                      GTK_SIGNAL_FUNC (on_menu_downloads_visible_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (menu_uploads_visible), "activate",
                      GTK_SIGNAL_FUNC (on_menu_uploads_visible_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (menu_connections_visible), "activate",
                      GTK_SIGNAL_FUNC (on_menu_connections_visible_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (menu_bws_in_visible), "activate",
                      GTK_SIGNAL_FUNC (on_menu_bws_in_visible_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (menu_bws_out_visible), "activate",
                      GTK_SIGNAL_FUNC (on_menu_bws_out_visible_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (menu_bws_gin_visible), "activate",
                      GTK_SIGNAL_FUNC (on_menu_bws_gin_visible_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (menu_bws_gout_visible), "activate",
                      GTK_SIGNAL_FUNC (on_menu_bws_gout_visible_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (menu_autohide_bws_gleaf), "activate",
                      GTK_SIGNAL_FUNC (on_menu_autohide_bws_gleaf_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (menu_bws_glin_visible), "activate",
                      GTK_SIGNAL_FUNC (on_menu_bws_glin_visible_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (menu_bws_glout_visible), "activate",
                      GTK_SIGNAL_FUNC (on_menu_bws_glout_visible_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (menu_autohide_bws_dht), "activate",
                      GTK_SIGNAL_FUNC (on_menu_autohide_bws_dht_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (menu_bws_dht_in_visible), "activate",
                      GTK_SIGNAL_FUNC (on_menu_bws_dht_in_visible_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (menu_bws_dht_out_visible), "activate",
                      GTK_SIGNAL_FUNC (on_menu_bws_dht_out_visible_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (menu_about), "activate",
                      GTK_SIGNAL_FUNC (on_menu_about_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (menu_faq), "activate",
                      GTK_SIGNAL_FUNC (on_menu_faq_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (progressbar_bws_in), "button_press_event",
                      GTK_SIGNAL_FUNC (on_progressbar_bws_in_button_press_event),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (progressbar_bws_out), "button_press_event",
                      GTK_SIGNAL_FUNC (on_progressbar_bws_out_button_press_event),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (progressbar_bws_gin), "button_press_event",
                      GTK_SIGNAL_FUNC (on_progressbar_bws_gin_button_press_event),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (progressbar_bws_gout), "button_press_event",
                      GTK_SIGNAL_FUNC (on_progressbar_bws_gout_button_press_event),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (progressbar_bws_lin), "button_press_event",
                      GTK_SIGNAL_FUNC (on_progressbar_bws_lin_button_press_event),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (progressbar_bws_lout), "button_press_event",
                      GTK_SIGNAL_FUNC (on_progressbar_bws_lout_button_press_event),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (progressbar_bws_dht_in), "button_press_event",
                      GTK_SIGNAL_FUNC (on_progressbar_bws_dht_in_button_press_event),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (progressbar_bws_dht_out), "button_press_event",
                      GTK_SIGNAL_FUNC (on_progressbar_bws_dht_out_button_press_event),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (clist_nodes), "select_row",
                      GTK_SIGNAL_FUNC (on_clist_nodes_select_row),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (clist_nodes), "unselect_row",
                      GTK_SIGNAL_FUNC (on_clist_nodes_unselect_row),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (clist_nodes), "button_press_event",
                      GTK_SIGNAL_FUNC (on_clist_nodes_button_press_event),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button_nodes_disconnect), "clicked",
                      GTK_SIGNAL_FUNC (on_button_nodes_disconnect_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button_nodes_add), "clicked",
                      GTK_SIGNAL_FUNC (on_button_nodes_add_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (entry_host), "changed",
                      GTK_SIGNAL_FUNC (on_entry_host_changed),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (entry_host), "activate",
                      GTK_SIGNAL_FUNC (on_entry_host_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (drawingarea_fi_progress), "realize",
                      GTK_SIGNAL_FUNC (on_drawingarea_fi_progress_realize),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (drawingarea_fi_progress), "expose_event",
                      GTK_SIGNAL_FUNC (on_drawingarea_fi_progress_expose_event),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (checkbutton_downloads_filter_regex_case), "toggled",
                      GTK_SIGNAL_FUNC (on_checkbutton_downloads_filter_regex_case_toggled),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (checkbutton_downloads_select_regex_invert), "toggled",
                      GTK_SIGNAL_FUNC (on_checkbutton_downloads_select_regex_invert_toggled),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (checkbutton_downloads_filter_regex_invert), "toggled",
                      GTK_SIGNAL_FUNC (on_checkbutton_downloads_filter_regex_invert_toggled),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (checkbutton_downloads_select_regex_case), "toggled",
                      GTK_SIGNAL_FUNC (on_checkbutton_downloads_select_regex_case_toggled),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (entry_downloads_select_regex), "activate",
                      GTK_SIGNAL_FUNC (on_entry_downloads_select_regex_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (entry_downloads_filter_regex), "activate",
                      GTK_SIGNAL_FUNC (on_entry_downloads_filter_regex_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button_downloads_clear_stopped), "clicked",
                      GTK_SIGNAL_FUNC (on_button_downloads_clear_stopped_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (togglebutton_queue_freeze), "toggled",
                      GTK_SIGNAL_FUNC (on_togglebutton_queue_freeze_toggled),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (clist_uploads), "select_row",
                      GTK_SIGNAL_FUNC (on_clist_uploads_select_row),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (clist_uploads), "unselect_row",
                      GTK_SIGNAL_FUNC (on_clist_uploads_unselect_row),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (clist_uploads), "button_press_event",
                      GTK_SIGNAL_FUNC (on_clist_uploads_button_press_event),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button_uploads_kill), "clicked",
                      GTK_SIGNAL_FUNC (on_button_uploads_kill_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button_uploads_clear_completed), "clicked",
                      GTK_SIGNAL_FUNC (on_button_uploads_clear_completed_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (clist_monitor), "button_press_event",
                      GTK_SIGNAL_FUNC (on_clist_monitor_button_press_event),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (clist_ul_stats), "click_column",
                      GTK_SIGNAL_FUNC (on_clist_ul_stats_click_column),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button_ul_stats_clear_deleted), "clicked",
                      GTK_SIGNAL_FUNC (on_button_ul_stats_clear_deleted_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button_ul_stats_clear_all), "clicked",
                      GTK_SIGNAL_FUNC (on_button_ul_stats_clear_all_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button_host_catcher_clear), "clicked",
                      GTK_SIGNAL_FUNC (on_button_host_catcher_clear_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button_ultra_catcher_clear), "clicked",
                      GTK_SIGNAL_FUNC (on_button_ultra_catcher_clear_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button_hostcache_clear_bad), "clicked",
                      GTK_SIGNAL_FUNC (on_button_hostcache_clear_bad_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button_g2hub_catcher_clear), "clicked",
                      GTK_SIGNAL_FUNC (on_button_hostcache_clear_bad_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button_search_stats_reset), "clicked",
                      GTK_SIGNAL_FUNC (on_button_search_stats_reset_clicked),
                      NULL);

  gtk_widget_add_accelerator (spinbutton_search_reissue_timeout, "grab_focus", accel_group,
                              search_reissue_label_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_add_accelerator (option_menu_gnet_stats_source, "grab_focus", accel_group,
                              label697_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_add_accelerator (option_menu_gnet_stats_type, "grab_focus", accel_group,
                              label390_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_add_accelerator (spinbutton_monitor_items, "grab_focus", accel_group,
                              label68_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_add_accelerator (spinbutton_search_stats_update_interval, "grab_focus", accel_group,
                              label101_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_add_accelerator (spinbutton_search_stats_delcoef, "grab_focus", accel_group,
                              label102_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);

  gtk_object_set_data (GTK_OBJECT (main_window), "tooltips", tooltips);

  gtk_window_add_accel_group (GTK_WINDOW (main_window), accel_group);

  return main_window;
}

GtkWidget*
create_popup_downloads (void)
{
  GtkWidget *popup_downloads;
  GtkAccelGroup *popup_downloads_accels;
  GtkWidget *popup_downloads_copy_magnet;
  GtkWidget *popup_downloads_start_now;
  GtkWidget *popup_downloads_pause;
  GtkWidget *popup_downloads_resume;
  GtkWidget *popup_downloads_queue;
  GtkWidget *separator9;
  GtkWidget *popup_downloads_abort;
  GtkWidget *separator27;
  GtkWidget *popup_downloads_config_cols;

  popup_downloads = gtk_menu_new ();
  gtk_widget_set_name (popup_downloads, "popup_downloads");
  gtk_object_set_data (GTK_OBJECT (popup_downloads), "popup_downloads", popup_downloads);
  popup_downloads_accels = gtk_menu_ensure_uline_accel_group (GTK_MENU (popup_downloads));

  popup_downloads_copy_magnet = gtk_menu_item_new_with_label (_("Copy Magnet to clipboard"));
  gtk_widget_set_name (popup_downloads_copy_magnet, "popup_downloads_copy_magnet");
  gtk_widget_ref (popup_downloads_copy_magnet);
  gtk_object_set_data_full (GTK_OBJECT (popup_downloads), "popup_downloads_copy_magnet", popup_downloads_copy_magnet,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (popup_downloads_copy_magnet);
  gtk_container_add (GTK_CONTAINER (popup_downloads), popup_downloads_copy_magnet);

  popup_downloads_start_now = gtk_menu_item_new_with_label (_("Start now"));
  gtk_widget_set_name (popup_downloads_start_now, "popup_downloads_start_now");
  gtk_widget_ref (popup_downloads_start_now);
  gtk_object_set_data_full (GTK_OBJECT (popup_downloads), "popup_downloads_start_now", popup_downloads_start_now,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (popup_downloads_start_now);
  gtk_container_add (GTK_CONTAINER (popup_downloads), popup_downloads_start_now);

  popup_downloads_pause = gtk_menu_item_new_with_label (_("Pause"));
  gtk_widget_set_name (popup_downloads_pause, "popup_downloads_pause");
  gtk_widget_ref (popup_downloads_pause);
  gtk_object_set_data_full (GTK_OBJECT (popup_downloads), "popup_downloads_pause", popup_downloads_pause,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (popup_downloads_pause);
  gtk_container_add (GTK_CONTAINER (popup_downloads), popup_downloads_pause);

  popup_downloads_resume = gtk_menu_item_new_with_label (_("Resume"));
  gtk_widget_set_name (popup_downloads_resume, "popup_downloads_resume");
  gtk_widget_ref (popup_downloads_resume);
  gtk_object_set_data_full (GTK_OBJECT (popup_downloads), "popup_downloads_resume", popup_downloads_resume,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (popup_downloads_resume);
  gtk_container_add (GTK_CONTAINER (popup_downloads), popup_downloads_resume);

  popup_downloads_queue = gtk_menu_item_new_with_label (_("Move back to queue"));
  gtk_widget_set_name (popup_downloads_queue, "popup_downloads_queue");
  gtk_widget_ref (popup_downloads_queue);
  gtk_object_set_data_full (GTK_OBJECT (popup_downloads), "popup_downloads_queue", popup_downloads_queue,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (popup_downloads_queue);
  gtk_container_add (GTK_CONTAINER (popup_downloads), popup_downloads_queue);

  separator9 = gtk_menu_item_new ();
  gtk_widget_set_name (separator9, "separator9");
  gtk_widget_ref (separator9);
  gtk_object_set_data_full (GTK_OBJECT (popup_downloads), "separator9", separator9,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (separator9);
  gtk_container_add (GTK_CONTAINER (popup_downloads), separator9);
  gtk_widget_set_sensitive (separator9, FALSE);

  popup_downloads_abort = gtk_menu_item_new_with_label (_("Abort"));
  gtk_widget_set_name (popup_downloads_abort, "popup_downloads_abort");
  gtk_widget_ref (popup_downloads_abort);
  gtk_object_set_data_full (GTK_OBJECT (popup_downloads), "popup_downloads_abort", popup_downloads_abort,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (popup_downloads_abort);
  gtk_container_add (GTK_CONTAINER (popup_downloads), popup_downloads_abort);

  separator27 = gtk_menu_item_new ();
  gtk_widget_set_name (separator27, "separator27");
  gtk_widget_ref (separator27);
  gtk_object_set_data_full (GTK_OBJECT (popup_downloads), "separator27", separator27,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (separator27);
  gtk_container_add (GTK_CONTAINER (popup_downloads), separator27);
  gtk_widget_set_sensitive (separator27, FALSE);

  popup_downloads_config_cols = gtk_menu_item_new_with_label (_("Configure columns"));
  gtk_widget_set_name (popup_downloads_config_cols, "popup_downloads_config_cols");
  gtk_widget_ref (popup_downloads_config_cols);
  gtk_object_set_data_full (GTK_OBJECT (popup_downloads), "popup_downloads_config_cols", popup_downloads_config_cols,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (popup_downloads_config_cols);
  gtk_container_add (GTK_CONTAINER (popup_downloads), popup_downloads_config_cols);

  gtk_signal_connect (GTK_OBJECT (popup_downloads_copy_magnet), "activate",
                      GTK_SIGNAL_FUNC (on_popup_downloads_copy_magnet_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (popup_downloads_start_now), "activate",
                      GTK_SIGNAL_FUNC (on_popup_downloads_start_now_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (popup_downloads_pause), "activate",
                      GTK_SIGNAL_FUNC (on_popup_downloads_pause_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (popup_downloads_resume), "activate",
                      GTK_SIGNAL_FUNC (on_popup_downloads_resume_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (popup_downloads_queue), "activate",
                      GTK_SIGNAL_FUNC (on_popup_downloads_queue_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (popup_downloads_abort), "activate",
                      GTK_SIGNAL_FUNC (on_popup_downloads_abort_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (popup_downloads_config_cols), "activate",
                      GTK_SIGNAL_FUNC (on_popup_downloads_config_cols_activate),
                      NULL);

  return popup_downloads;
}

GtkWidget*
create_popup_search (void)
{
  GtkWidget *popup_search;
  GtkAccelGroup *popup_search_accels;
  GtkWidget *popup_search_download;
  GtkWidget *popup_search_browse_host;
  GtkWidget *popup_search_copy_magnet;
  GtkWidget *separator14;
  GtkWidget *popup_search_stop;
  GtkWidget *popup_search_resume;
  GtkWidget *popup_search_restart;
  GtkWidget *separator29;
  GtkWidget *popup_search_collapse_all;
  GtkWidget *popup_search_expand_all;
  GtkWidget *separator2;
  GtkWidget *item2;
  GtkWidget *item2_menu;
  GtkAccelGroup *item2_menu_accels;
  GtkWidget *popup_search_toggle_tabs;
  GtkWidget *popup_search_config_cols;
  GtkWidget *popup_search_sort_defaults;

  popup_search = gtk_menu_new ();
  gtk_widget_set_name (popup_search, "popup_search");
  gtk_object_set_data (GTK_OBJECT (popup_search), "popup_search", popup_search);
  popup_search_accels = gtk_menu_ensure_uline_accel_group (GTK_MENU (popup_search));

  popup_search_download = gtk_menu_item_new_with_label (_("Download"));
  gtk_widget_set_name (popup_search_download, "popup_search_download");
  gtk_widget_ref (popup_search_download);
  gtk_object_set_data_full (GTK_OBJECT (popup_search), "popup_search_download", popup_search_download,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (popup_search_download);
  gtk_container_add (GTK_CONTAINER (popup_search), popup_search_download);

  popup_search_browse_host = gtk_menu_item_new_with_label (_("Browse host"));
  gtk_widget_set_name (popup_search_browse_host, "popup_search_browse_host");
  gtk_widget_ref (popup_search_browse_host);
  gtk_object_set_data_full (GTK_OBJECT (popup_search), "popup_search_browse_host", popup_search_browse_host,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (popup_search_browse_host);
  gtk_container_add (GTK_CONTAINER (popup_search), popup_search_browse_host);

  popup_search_copy_magnet = gtk_menu_item_new_with_label (_("Copy magnet to clipboard"));
  gtk_widget_set_name (popup_search_copy_magnet, "popup_search_copy_magnet");
  gtk_widget_ref (popup_search_copy_magnet);
  gtk_object_set_data_full (GTK_OBJECT (popup_search), "popup_search_copy_magnet", popup_search_copy_magnet,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (popup_search_copy_magnet);
  gtk_container_add (GTK_CONTAINER (popup_search), popup_search_copy_magnet);

  separator14 = gtk_menu_item_new ();
  gtk_widget_set_name (separator14, "separator14");
  gtk_widget_ref (separator14);
  gtk_object_set_data_full (GTK_OBJECT (popup_search), "separator14", separator14,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (separator14);
  gtk_container_add (GTK_CONTAINER (popup_search), separator14);
  gtk_widget_set_sensitive (separator14, FALSE);

  popup_search_stop = gtk_menu_item_new_with_label (_("Stop"));
  gtk_widget_set_name (popup_search_stop, "popup_search_stop");
  gtk_widget_ref (popup_search_stop);
  gtk_object_set_data_full (GTK_OBJECT (popup_search), "popup_search_stop", popup_search_stop,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (popup_search_stop);
  gtk_container_add (GTK_CONTAINER (popup_search), popup_search_stop);

  popup_search_resume = gtk_menu_item_new_with_label (_("Resume"));
  gtk_widget_set_name (popup_search_resume, "popup_search_resume");
  gtk_widget_ref (popup_search_resume);
  gtk_object_set_data_full (GTK_OBJECT (popup_search), "popup_search_resume", popup_search_resume,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (popup_search_resume);
  gtk_container_add (GTK_CONTAINER (popup_search), popup_search_resume);

  popup_search_restart = gtk_menu_item_new_with_label (_("Restart"));
  gtk_widget_set_name (popup_search_restart, "popup_search_restart");
  gtk_widget_ref (popup_search_restart);
  gtk_object_set_data_full (GTK_OBJECT (popup_search), "popup_search_restart", popup_search_restart,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (popup_search_restart);
  gtk_container_add (GTK_CONTAINER (popup_search), popup_search_restart);

  separator29 = gtk_menu_item_new ();
  gtk_widget_set_name (separator29, "separator29");
  gtk_widget_ref (separator29);
  gtk_object_set_data_full (GTK_OBJECT (popup_search), "separator29", separator29,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (separator29);
  gtk_container_add (GTK_CONTAINER (popup_search), separator29);
  gtk_widget_set_sensitive (separator29, FALSE);

  popup_search_collapse_all = gtk_menu_item_new_with_label (_("Collapse all"));
  gtk_widget_set_name (popup_search_collapse_all, "popup_search_collapse_all");
  gtk_widget_ref (popup_search_collapse_all);
  gtk_object_set_data_full (GTK_OBJECT (popup_search), "popup_search_collapse_all", popup_search_collapse_all,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (popup_search_collapse_all);
  gtk_container_add (GTK_CONTAINER (popup_search), popup_search_collapse_all);

  popup_search_expand_all = gtk_menu_item_new_with_label (_("Expand all"));
  gtk_widget_set_name (popup_search_expand_all, "popup_search_expand_all");
  gtk_widget_ref (popup_search_expand_all);
  gtk_object_set_data_full (GTK_OBJECT (popup_search), "popup_search_expand_all", popup_search_expand_all,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (popup_search_expand_all);
  gtk_container_add (GTK_CONTAINER (popup_search), popup_search_expand_all);

  separator2 = gtk_menu_item_new ();
  gtk_widget_set_name (separator2, "separator2");
  gtk_widget_ref (separator2);
  gtk_object_set_data_full (GTK_OBJECT (popup_search), "separator2", separator2,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (separator2);
  gtk_container_add (GTK_CONTAINER (popup_search), separator2);
  gtk_widget_set_sensitive (separator2, FALSE);

  item2 = gtk_menu_item_new_with_label (_("Preferences"));
  gtk_widget_set_name (item2, "item2");
  gtk_widget_ref (item2);
  gtk_object_set_data_full (GTK_OBJECT (popup_search), "item2", item2,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (item2);
  gtk_container_add (GTK_CONTAINER (popup_search), item2);

  item2_menu = gtk_menu_new ();
  gtk_widget_set_name (item2_menu, "item2_menu");
  gtk_widget_ref (item2_menu);
  gtk_object_set_data_full (GTK_OBJECT (popup_search), "item2_menu", item2_menu,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (item2), item2_menu);
  item2_menu_accels = gtk_menu_ensure_uline_accel_group (GTK_MENU (item2_menu));

  popup_search_toggle_tabs = gtk_menu_item_new_with_label (_("Show tabs"));
  gtk_widget_set_name (popup_search_toggle_tabs, "popup_search_toggle_tabs");
  gtk_widget_ref (popup_search_toggle_tabs);
  gtk_object_set_data_full (GTK_OBJECT (popup_search), "popup_search_toggle_tabs", popup_search_toggle_tabs,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (popup_search_toggle_tabs);
  gtk_container_add (GTK_CONTAINER (item2_menu), popup_search_toggle_tabs);

  popup_search_config_cols = gtk_menu_item_new_with_label (_("Configure columns"));
  gtk_widget_set_name (popup_search_config_cols, "popup_search_config_cols");
  gtk_widget_ref (popup_search_config_cols);
  gtk_object_set_data_full (GTK_OBJECT (popup_search), "popup_search_config_cols", popup_search_config_cols,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (popup_search_config_cols);
  gtk_container_add (GTK_CONTAINER (item2_menu), popup_search_config_cols);

  popup_search_sort_defaults = gtk_menu_item_new_with_label (_("Make current sorting default"));
  gtk_widget_set_name (popup_search_sort_defaults, "popup_search_sort_defaults");
  gtk_widget_ref (popup_search_sort_defaults);
  gtk_object_set_data_full (GTK_OBJECT (popup_search), "popup_search_sort_defaults", popup_search_sort_defaults,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (popup_search_sort_defaults);
  gtk_container_add (GTK_CONTAINER (item2_menu), popup_search_sort_defaults);

  return popup_search;
}

GtkWidget*
create_popup_monitor (void)
{
  GtkWidget *popup_monitor;
  GtkAccelGroup *popup_monitor_accels;
  GtkWidget *popup_monitor_add_search;

  popup_monitor = gtk_menu_new ();
  gtk_widget_set_name (popup_monitor, "popup_monitor");
  gtk_object_set_data (GTK_OBJECT (popup_monitor), "popup_monitor", popup_monitor);
  popup_monitor_accels = gtk_menu_ensure_uline_accel_group (GTK_MENU (popup_monitor));

  popup_monitor_add_search = gtk_menu_item_new_with_label (_("Add as search"));
  gtk_widget_set_name (popup_monitor_add_search, "popup_monitor_add_search");
  gtk_widget_ref (popup_monitor_add_search);
  gtk_object_set_data_full (GTK_OBJECT (popup_monitor), "popup_monitor_add_search", popup_monitor_add_search,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (popup_monitor_add_search);
  gtk_container_add (GTK_CONTAINER (popup_monitor), popup_monitor_add_search);

  gtk_signal_connect (GTK_OBJECT (popup_monitor_add_search), "activate",
                      GTK_SIGNAL_FUNC (on_popup_monitor_add_search_activate),
                      NULL);

  return popup_monitor;
}

GtkWidget*
create_popup_nodes (void)
{
  GtkWidget *popup_nodes;
  GtkAccelGroup *popup_nodes_accels;
  GtkWidget *popup_nodes_disconnect;
  GtkWidget *popup_nodes_browse_host;
  GtkWidget *trennlinie1;
  GtkWidget *popup_nodes_config_cols;

  popup_nodes = gtk_menu_new ();
  gtk_widget_set_name (popup_nodes, "popup_nodes");
  gtk_object_set_data (GTK_OBJECT (popup_nodes), "popup_nodes", popup_nodes);
  popup_nodes_accels = gtk_menu_ensure_uline_accel_group (GTK_MENU (popup_nodes));

  popup_nodes_disconnect = gtk_menu_item_new_with_label (_("Disconnect"));
  gtk_widget_set_name (popup_nodes_disconnect, "popup_nodes_disconnect");
  gtk_widget_ref (popup_nodes_disconnect);
  gtk_object_set_data_full (GTK_OBJECT (popup_nodes), "popup_nodes_disconnect", popup_nodes_disconnect,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (popup_nodes_disconnect);
  gtk_container_add (GTK_CONTAINER (popup_nodes), popup_nodes_disconnect);

  popup_nodes_browse_host = gtk_menu_item_new_with_label (_("Browse Host"));
  gtk_widget_set_name (popup_nodes_browse_host, "popup_nodes_browse_host");
  gtk_widget_ref (popup_nodes_browse_host);
  gtk_object_set_data_full (GTK_OBJECT (popup_nodes), "popup_nodes_browse_host", popup_nodes_browse_host,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (popup_nodes_browse_host);
  gtk_container_add (GTK_CONTAINER (popup_nodes), popup_nodes_browse_host);

  trennlinie1 = gtk_menu_item_new ();
  gtk_widget_set_name (trennlinie1, "trennlinie1");
  gtk_widget_ref (trennlinie1);
  gtk_object_set_data_full (GTK_OBJECT (popup_nodes), "trennlinie1", trennlinie1,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (trennlinie1);
  gtk_container_add (GTK_CONTAINER (popup_nodes), trennlinie1);
  gtk_widget_set_sensitive (trennlinie1, FALSE);

  popup_nodes_config_cols = gtk_menu_item_new_with_label (_("Configure columns"));
  gtk_widget_set_name (popup_nodes_config_cols, "popup_nodes_config_cols");
  gtk_widget_ref (popup_nodes_config_cols);
  gtk_object_set_data_full (GTK_OBJECT (popup_nodes), "popup_nodes_config_cols", popup_nodes_config_cols,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (popup_nodes_config_cols);
  gtk_container_add (GTK_CONTAINER (popup_nodes), popup_nodes_config_cols);

  gtk_signal_connect (GTK_OBJECT (popup_nodes_disconnect), "activate",
                      GTK_SIGNAL_FUNC (on_popup_nodes_disconnect_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (popup_nodes_browse_host), "activate",
                      GTK_SIGNAL_FUNC (on_popup_nodes_browse_host_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (popup_nodes_config_cols), "activate",
                      GTK_SIGNAL_FUNC (on_popup_nodes_config_cols_activate),
                      NULL);

  return popup_nodes;
}

GtkWidget*
create_popup_uploads (void)
{
  GtkWidget *popup_uploads;
  GtkAccelGroup *popup_uploads_accels;
  GtkWidget *popup_uploads_browse_host;
  GtkWidget *separator30;
  GtkWidget *popup_uploads_config_cols;

  popup_uploads = gtk_menu_new ();
  gtk_widget_set_name (popup_uploads, "popup_uploads");
  gtk_object_set_data (GTK_OBJECT (popup_uploads), "popup_uploads", popup_uploads);
  popup_uploads_accels = gtk_menu_ensure_uline_accel_group (GTK_MENU (popup_uploads));

  popup_uploads_browse_host = gtk_menu_item_new_with_label (_("Browse Host"));
  gtk_widget_set_name (popup_uploads_browse_host, "popup_uploads_browse_host");
  gtk_widget_ref (popup_uploads_browse_host);
  gtk_object_set_data_full (GTK_OBJECT (popup_uploads), "popup_uploads_browse_host", popup_uploads_browse_host,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (popup_uploads_browse_host);
  gtk_container_add (GTK_CONTAINER (popup_uploads), popup_uploads_browse_host);

  separator30 = gtk_menu_item_new ();
  gtk_widget_set_name (separator30, "separator30");
  gtk_widget_ref (separator30);
  gtk_object_set_data_full (GTK_OBJECT (popup_uploads), "separator30", separator30,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (separator30);
  gtk_container_add (GTK_CONTAINER (popup_uploads), separator30);
  gtk_widget_set_sensitive (separator30, FALSE);

  popup_uploads_config_cols = gtk_menu_item_new_with_label (_("Configure columns"));
  gtk_widget_set_name (popup_uploads_config_cols, "popup_uploads_config_cols");
  gtk_widget_ref (popup_uploads_config_cols);
  gtk_object_set_data_full (GTK_OBJECT (popup_uploads), "popup_uploads_config_cols", popup_uploads_config_cols,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (popup_uploads_config_cols);
  gtk_container_add (GTK_CONTAINER (popup_uploads), popup_uploads_config_cols);

  gtk_signal_connect (GTK_OBJECT (popup_uploads_browse_host), "activate",
                      GTK_SIGNAL_FUNC (on_popup_uploads_browse_host_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (popup_uploads_config_cols), "activate",
                      GTK_SIGNAL_FUNC (on_popup_uploads_config_cols_activate),
                      NULL);

  return popup_uploads;
}

GtkWidget*
create_dlg_filters (void)
{
  GtkWidget *dlg_filters;
  GtkWidget *vbox_filter_main;
  GtkWidget *hpaned_filter_main;
  GtkWidget *vbox59;
  GtkWidget *hbox111;
  GtkWidget *entry_filter_new;
  guint button_filter_create_key;
  GtkWidget *button_filter_create;
  GtkWidget *scrolledwindow17;
  GtkWidget *ctree_filter_filters;
  GtkWidget *label222;
  GtkWidget *label223;
  GtkWidget *label224;
  GtkWidget *scrolledwindow48;
  GtkWidget *viewport46;
  GtkWidget *vbox32;
  GtkWidget *hbox97;
  GtkWidget *label221;
  GtkWidget *entry_filter_name;
  GtkWidget *checkbutton_filter_enabled;
  GtkWidget *button_filter_remove;
  GtkWidget *scrolledwindow490;
  GtkWidget *viewport47;
  GtkWidget *clist_filter_rules;
  GtkWidget *label212;
  GtkWidget *label213;
  GtkWidget *label214;
  GtkWidget *label215;
  GtkWidget *hbox125;
  GtkWidget *button_filter_clear;
  GtkWidget *button_filter_reset_all_rules;
  GtkWidget *button_filter_reset;
  GtkWidget *button_filter_reset_all;
  GtkWidget *hseparator6;
  GtkWidget *hbox210;
  GtkWidget *notebook_filter_detail;
  GtkWidget *alignment37;
  GtkWidget *hbox2100;
  GtkWidget *vbox137;
  GtkWidget *button_filter_add_rule_text;
  GtkWidget *button_filter_add_rule_size;
  GtkWidget *button_filter_add_rule_flag;
  GtkWidget *vbox138;
  GtkWidget *button_filter_add_rule_jump;
  GtkWidget *button_filter_add_rule_ip;
  GtkWidget *button_filter_add_rule_state;
  GtkWidget *label724;
  GtkWidget *vbox52;
  GtkWidget *alignment12;
  GtkWidget *hbox120;
  GtkWidget *frame31;
  GtkWidget *vbox55;
  GtkWidget *checkbutton_filter_text_invert_cond;
  GtkWidget *checkbutton_filter_text_active;
  GtkWidget *checkbutton_filter_text_soft;
  GtkWidget *frame25;
  GtkWidget *hbox117;
  GtkWidget *table22;
  GtkWidget *optionmenu_filter_text_type;
  GtkWidget *optionmenu_filter_text_type_menu;
  GtkWidget *glade_menuitem;
  GtkWidget *entry_filter_text_pattern;
  GtkWidget *checkbutton_filter_text_case;
  GtkWidget *hbox110;
  GtkWidget *frame26;
  GtkWidget *optionmenu_filter_text_target;
  GtkWidget *optionmenu_filter_text_target_menu;
  GtkWidget *vbox60;
  GtkWidget *hbox138;
  GtkWidget *button_filter_text_add;
  GtkWidget *button_filter_text_remove;
  GtkWidget *button16;
  GtkWidget *vseparator10;
  guint button_filter_text_reset_key;
  GtkWidget *button_filter_text_reset;
  GtkWidget *label725;
  GtkWidget *vbox51;
  GtkWidget *alignment11;
  GtkWidget *hbox121;
  GtkWidget *frame32;
  GtkWidget *vbox56;
  GtkWidget *checkbutton_filter_ip_invert_cond;
  GtkWidget *checkbutton_filter_ip_active;
  GtkWidget *checkbutton_filter_ip_soft;
  GtkWidget *frame23;
  GtkWidget *hbox118;
  GtkWidget *table23;
  GtkWidget *label191;
  GtkWidget *entry_filter_ip_address;
  GtkWidget *hbox109;
  GtkWidget *frame24;
  GtkWidget *optionmenu_filter_ip_target;
  GtkWidget *optionmenu_filter_ip_target_menu;
  GtkWidget *vbox61;
  GtkWidget *hbox139;
  GtkWidget *button4;
  GtkWidget *button5;
  GtkWidget *button17;
  GtkWidget *vseparator11;
  guint button_filter_ip_reset_key;
  GtkWidget *button_filter_ip_reset;
  GtkWidget *label726;
  GtkWidget *vbox49;
  GtkWidget *alignment10;
  GtkWidget *hbox122;
  GtkWidget *frame33;
  GtkWidget *vbox57;
  GtkWidget *checkbutton_filter_size_invert_cond;
  GtkWidget *checkbutton_filter_size_active;
  GtkWidget *checkbutton_filter_size_soft;
  GtkWidget *frame22;
  GtkWidget *hbox119;
  GtkWidget *table24;
  GtkWidget *label192;
  GtkWidget *label193;
  GtkWidget *label194;
  GtkWidget *label195;
  GtkWidget *entry_filter_size_min;
  GtkWidget *entry_filter_size_max;
  GtkWidget *hbox108;
  GtkWidget *frame21;
  GtkWidget *optionmenu_filter_size_target;
  GtkWidget *optionmenu_filter_size_target_menu;
  GtkWidget *vbox62;
  GtkWidget *hbox140;
  GtkWidget *button6;
  GtkWidget *button7;
  GtkWidget *button18;
  GtkWidget *vseparator12;
  guint button_filter_size_reset_key;
  GtkWidget *button_filter_size_reset;
  GtkWidget *label727;
  GtkWidget *vbox54;
  GtkWidget *alignment24;
  GtkWidget *hbox123;
  GtkWidget *frame34;
  GtkWidget *vbox58;
  GtkWidget *checkbutton_filter_jump_active;
  GtkWidget *frame29;
  GtkWidget *hbox115;
  GtkWidget *label209;
  GtkWidget *alignment17;
  GtkWidget *hbox114;
  GtkWidget *frame28;
  GtkWidget *optionmenu_filter_jump_target;
  GtkWidget *optionmenu_filter_jump_target_menu;
  GtkWidget *vbox63;
  GtkWidget *hbox141;
  GtkWidget *button8;
  GtkWidget *button9;
  GtkWidget *button19;
  GtkWidget *vseparator13;
  guint button_filter_jump_reset_key;
  GtkWidget *button_filter_jump_reset;
  GtkWidget *label728;
  GtkWidget *vbox64;
  GtkWidget *alignment20;
  GtkWidget *hbox126;
  GtkWidget *frame35;
  GtkWidget *vbox65;
  GtkWidget *checkbutton_filter_sha1_invert_cond;
  GtkWidget *checkbutton_filter_sha1_active;
  GtkWidget *checkbutton_filter_sha1_soft;
  GtkWidget *frame36;
  GtkWidget *hbox127;
  GtkWidget *table25;
  GtkWidget *label226;
  GtkWidget *entry_filter_sha1_hash;
  GtkWidget *hbox132;
  GtkWidget *label245;
  GtkWidget *entry_filter_sha1_origfile;
  GtkWidget *hbox128;
  GtkWidget *frame37;
  GtkWidget *optionmenu_filter_sha1_target;
  GtkWidget *optionmenu_filter_sha1_target_menu;
  GtkWidget *vbox66;
  GtkWidget *hbox142;
  GtkWidget *button10;
  GtkWidget *button11;
  GtkWidget *button20;
  GtkWidget *vseparator14;
  guint button_filter_sha1_reset_key;
  GtkWidget *button_filter_sha1_reset;
  GtkWidget *label729;
  GtkWidget *vbox68;
  GtkWidget *alignment21;
  GtkWidget *hbox129;
  GtkWidget *frame38;
  GtkWidget *vbox69;
  GtkWidget *checkbutton_filter_flag_active;
  GtkWidget *checkbutton_filter_flag_soft;
  GtkWidget *frame39;
  GtkWidget *hbox130;
  GtkWidget *table26;
  GtkWidget *label230;
  GtkWidget *label231;
  GSList *filter_busy_group_group = NULL;
  GtkWidget *radiobutton_filter_flag_busy_unset;
  GtkWidget *label241;
  GtkWidget *radiobutton_filter_flag_busy_ignore;
  GtkWidget *label242;
  GSList *filter_push_group_group = NULL;
  GtkWidget *radiobutton_filter_flag_push_ignore;
  GtkWidget *label243;
  GtkWidget *radiobutton_filter_flag_push_unset;
  GtkWidget *label240;
  GtkWidget *radiobutton_filter_flag_push_set;
  GtkWidget *label237;
  GtkWidget *radiobutton_filter_flag_busy_set;
  GtkWidget *label236;
  GtkWidget *label232;
  GSList *filter_stable_group_group = NULL;
  GtkWidget *radiobutton_filter_flag_stable_set;
  GtkWidget *label238;
  GtkWidget *radiobutton_filter_flag_stable_unset;
  GtkWidget *label239;
  GtkWidget *radiobutton_filter_flag_stable_ignore;
  GtkWidget *label244;
  GtkWidget *hbox131;
  GtkWidget *frame40;
  GtkWidget *optionmenu_filter_flag_target;
  GtkWidget *optionmenu_filter_flag_target_menu;
  GtkWidget *vbox70;
  GtkWidget *hbox143;
  GtkWidget *button12;
  GtkWidget *button13;
  GtkWidget *button21;
  GtkWidget *vseparator8;
  guint button_filter_flag_reset_key;
  GtkWidget *button_filter_flag_reset;
  GtkWidget *label730;
  GtkWidget *vbox71;
  GtkWidget *alignment22;
  GtkWidget *hbox133;
  GtkWidget *frame41;
  GtkWidget *vbox74;
  GtkWidget *checkbutton_filter_state_invert_cond;
  GtkWidget *checkbutton_filter_state_active;
  GtkWidget *checkbutton_filter_state_soft;
  GtkWidget *frame42;
  GtkWidget *alignment23;
  GtkWidget *table27;
  GtkWidget *label249;
  GSList *filter_download_group_group = NULL;
  GtkWidget *radiobutton_filter_state_download_dont;
  GtkWidget *label251;
  GtkWidget *radiobutton_filter_state_download_undef;
  GtkWidget *label252;
  GtkWidget *label257;
  GtkWidget *radiobutton_filter_state_download_do;
  GtkWidget *label256;
  GSList *filter_display_group_group = NULL;
  GtkWidget *radiobutton_filter_state_display_do;
  GtkWidget *label258;
  GtkWidget *radiobutton_filter_state_display_dont;
  GtkWidget *label259;
  GtkWidget *radiobutton_filter_state_display_undef;
  GtkWidget *label260;
  GtkWidget *radiobutton_filter_state_display_ignore;
  GtkWidget *label261;
  GtkWidget *radiobutton_filter_state_download_ignore;
  GtkWidget *label262;
  GtkWidget *hbox136;
  GtkWidget *frame43;
  GtkWidget *optionmenu_filter_state_target;
  GtkWidget *optionmenu_filter_state_target_menu;
  GtkWidget *vbox73;
  GtkWidget *hbox144;
  GtkWidget *button14;
  GtkWidget *button15;
  GtkWidget *button22;
  GtkWidget *vseparator9;
  guint button_filter_state_reset_key;
  GtkWidget *button_filter_state_reset;
  GtkWidget *label731;
  GtkWidget *hseparator5;
  GtkWidget *hbox103;
  GtkWidget *button_filter_apply;
  GtkWidget *button_filter_revert;
  GtkWidget *button_filter_ok;
  GtkWidget *button_filter_cancel;
  GtkAccelGroup *accel_group;
  GtkTooltips *tooltips;

  tooltips = gtk_tooltips_new ();

  accel_group = gtk_accel_group_new ();

  dlg_filters = gtk_window_new (GTK_WINDOW_DIALOG);
  gtk_widget_set_name (dlg_filters, "dlg_filters");
  gtk_object_set_data (GTK_OBJECT (dlg_filters), "dlg_filters", dlg_filters);
  gtk_window_set_title (GTK_WINDOW (dlg_filters), _("Ruleset editor"));
  gtk_window_set_position (GTK_WINDOW (dlg_filters), GTK_WIN_POS_CENTER);
  gtk_window_set_default_size (GTK_WINDOW (dlg_filters), 450, 300);
  gtk_window_set_policy (GTK_WINDOW (dlg_filters), TRUE, TRUE, FALSE);

  vbox_filter_main = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox_filter_main, "vbox_filter_main");
  gtk_widget_ref (vbox_filter_main);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "vbox_filter_main", vbox_filter_main,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox_filter_main);
  gtk_container_add (GTK_CONTAINER (dlg_filters), vbox_filter_main);

  hpaned_filter_main = gtk_hpaned_new ();
  gtk_widget_set_name (hpaned_filter_main, "hpaned_filter_main");
  gtk_widget_ref (hpaned_filter_main);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "hpaned_filter_main", hpaned_filter_main,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hpaned_filter_main);
  gtk_box_pack_start (GTK_BOX (vbox_filter_main), hpaned_filter_main, TRUE, TRUE, 0);
  gtk_paned_set_handle_size (GTK_PANED (hpaned_filter_main), 8);
  gtk_paned_set_gutter_size (GTK_PANED (hpaned_filter_main), 8);
  gtk_paned_set_position (GTK_PANED (hpaned_filter_main), 0);

  vbox59 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox59, "vbox59");
  gtk_widget_ref (vbox59);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "vbox59", vbox59,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox59);
  gtk_paned_pack1 (GTK_PANED (hpaned_filter_main), vbox59, FALSE, TRUE);

  hbox111 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox111, "hbox111");
  gtk_widget_ref (hbox111);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "hbox111", hbox111,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox111);
  gtk_box_pack_start (GTK_BOX (vbox59), hbox111, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (hbox111), 2);

  entry_filter_new = gtk_entry_new ();
  gtk_widget_set_name (entry_filter_new, "entry_filter_new");
  gtk_widget_ref (entry_filter_new);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "entry_filter_new", entry_filter_new,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_filter_new);
  gtk_box_pack_start (GTK_BOX (hbox111), entry_filter_new, TRUE, TRUE, 0);

  button_filter_create = gtk_button_new_with_label ("");
  button_filter_create_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (button_filter_create)->child),
                                   _("_Create filter"));
  gtk_widget_add_accelerator (button_filter_create, "clicked", accel_group,
                              button_filter_create_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (button_filter_create, "button_filter_create");
  gtk_widget_ref (button_filter_create);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "button_filter_create", button_filter_create,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_filter_create);
  gtk_box_pack_start (GTK_BOX (hbox111), button_filter_create, FALSE, FALSE, 0);

  scrolledwindow17 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow17, "scrolledwindow17");
  gtk_widget_ref (scrolledwindow17);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "scrolledwindow17", scrolledwindow17,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (scrolledwindow17);
  gtk_box_pack_start (GTK_BOX (vbox59), scrolledwindow17, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (scrolledwindow17), 2);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow17), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);

  ctree_filter_filters = gtk_ctree_new (3, 0);
  gtk_widget_set_name (ctree_filter_filters, "ctree_filter_filters");
  gtk_widget_ref (ctree_filter_filters);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "ctree_filter_filters", ctree_filter_filters,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (ctree_filter_filters);
  gtk_container_add (GTK_CONTAINER (scrolledwindow17), ctree_filter_filters);
  gtk_clist_set_column_width (GTK_CLIST (ctree_filter_filters), 0, 80);
  gtk_clist_set_column_width (GTK_CLIST (ctree_filter_filters), 1, 80);
  gtk_clist_set_column_width (GTK_CLIST (ctree_filter_filters), 2, 80);
  gtk_clist_column_titles_show (GTK_CLIST (ctree_filter_filters));

  label222 = gtk_label_new (_("Filter"));
  gtk_widget_set_name (label222, "label222");
  gtk_widget_ref (label222);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "label222", label222,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label222);
  gtk_clist_set_column_widget (GTK_CLIST (ctree_filter_filters), 0, label222);

  label223 = gtk_label_new (_("Rules"));
  gtk_widget_set_name (label223, "label223");
  gtk_widget_ref (label223);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "label223", label223,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label223);
  gtk_clist_set_column_widget (GTK_CLIST (ctree_filter_filters), 1, label223);

  label224 = gtk_label_new (_("Match"));
  gtk_widget_set_name (label224, "label224");
  gtk_widget_ref (label224);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "label224", label224,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label224);
  gtk_clist_set_column_widget (GTK_CLIST (ctree_filter_filters), 2, label224);

  scrolledwindow48 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow48, "scrolledwindow48");
  gtk_widget_ref (scrolledwindow48);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "scrolledwindow48", scrolledwindow48,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (scrolledwindow48);
  gtk_paned_pack2 (GTK_PANED (hpaned_filter_main), scrolledwindow48, FALSE, TRUE);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow48), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);

  viewport46 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport46, "viewport46");
  gtk_widget_ref (viewport46);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "viewport46", viewport46,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (viewport46);
  gtk_container_add (GTK_CONTAINER (scrolledwindow48), viewport46);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport46), GTK_SHADOW_NONE);

  vbox32 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox32, "vbox32");
  gtk_widget_ref (vbox32);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "vbox32", vbox32,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox32);
  gtk_container_add (GTK_CONTAINER (viewport46), vbox32);

  hbox97 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox97, "hbox97");
  gtk_widget_ref (hbox97);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "hbox97", hbox97,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox97);
  gtk_box_pack_start (GTK_BOX (vbox32), hbox97, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (hbox97), 2);

  label221 = gtk_label_new (_("Filter"));
  gtk_widget_set_name (label221, "label221");
  gtk_widget_ref (label221);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "label221", label221,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label221);
  gtk_box_pack_start (GTK_BOX (hbox97), label221, FALSE, FALSE, 0);

  entry_filter_name = gtk_entry_new ();
  gtk_widget_set_name (entry_filter_name, "entry_filter_name");
  gtk_widget_ref (entry_filter_name);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "entry_filter_name", entry_filter_name,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_filter_name);
  gtk_box_pack_start (GTK_BOX (hbox97), entry_filter_name, TRUE, TRUE, 0);
  gtk_entry_set_editable (GTK_ENTRY (entry_filter_name), FALSE);

  checkbutton_filter_enabled = gtk_check_button_new_with_label (_("enabled"));
  gtk_widget_set_name (checkbutton_filter_enabled, "checkbutton_filter_enabled");
  gtk_widget_ref (checkbutton_filter_enabled);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "checkbutton_filter_enabled", checkbutton_filter_enabled,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_filter_enabled);
  gtk_box_pack_start (GTK_BOX (hbox97), checkbutton_filter_enabled, FALSE, FALSE, 0);

  button_filter_remove = gtk_button_new_with_label (_("Remove filter"));
  gtk_widget_set_name (button_filter_remove, "button_filter_remove");
  gtk_widget_ref (button_filter_remove);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "button_filter_remove", button_filter_remove,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_filter_remove);
  gtk_box_pack_start (GTK_BOX (hbox97), button_filter_remove, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, button_filter_remove, _("A filter cannot be removed if it is bound to a search or if it is in use (used as a target in a rule)."), NULL);

  scrolledwindow490 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow490, "scrolledwindow490");
  gtk_widget_ref (scrolledwindow490);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "scrolledwindow490", scrolledwindow490,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (scrolledwindow490);
  gtk_box_pack_start (GTK_BOX (vbox32), scrolledwindow490, TRUE, TRUE, 0);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow490), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);

  viewport47 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport47, "viewport47");
  gtk_widget_ref (viewport47);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "viewport47", viewport47,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (viewport47);
  gtk_container_add (GTK_CONTAINER (scrolledwindow490), viewport47);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport47), GTK_SHADOW_NONE);

  clist_filter_rules = gtk_clist_new (4);
  gtk_widget_set_name (clist_filter_rules, "clist_filter_rules");
  gtk_widget_ref (clist_filter_rules);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "clist_filter_rules", clist_filter_rules,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (clist_filter_rules);
  gtk_container_add (GTK_CONTAINER (viewport47), clist_filter_rules);
  gtk_clist_set_column_width (GTK_CLIST (clist_filter_rules), 0, 15);
  gtk_clist_set_column_width (GTK_CLIST (clist_filter_rules), 1, 211);
  gtk_clist_set_column_width (GTK_CLIST (clist_filter_rules), 2, 80);
  gtk_clist_set_column_width (GTK_CLIST (clist_filter_rules), 3, 80);
  gtk_clist_column_titles_show (GTK_CLIST (clist_filter_rules));

  label212 = gtk_label_new (_("!"));
  gtk_widget_set_name (label212, "label212");
  gtk_widget_ref (label212);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "label212", label212,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label212);
  gtk_clist_set_column_widget (GTK_CLIST (clist_filter_rules), 0, label212);

  label213 = gtk_label_new (_("Condition"));
  gtk_widget_set_name (label213, "label213");
  gtk_widget_ref (label213);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "label213", label213,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label213);
  gtk_clist_set_column_widget (GTK_CLIST (clist_filter_rules), 1, label213);

  label214 = gtk_label_new (_("Target"));
  gtk_widget_set_name (label214, "label214");
  gtk_widget_ref (label214);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "label214", label214,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label214);
  gtk_clist_set_column_widget (GTK_CLIST (clist_filter_rules), 2, label214);

  label215 = gtk_label_new (_("Match"));
  gtk_widget_set_name (label215, "label215");
  gtk_widget_ref (label215);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "label215", label215,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label215);
  gtk_clist_set_column_widget (GTK_CLIST (clist_filter_rules), 3, label215);

  hbox125 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox125, "hbox125");
  gtk_widget_ref (hbox125);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "hbox125", hbox125,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox125);
  gtk_box_pack_start (GTK_BOX (vbox32), hbox125, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (hbox125), 2);

  button_filter_clear = gtk_button_new_with_label (_("Remove all rules\nfrom this filter"));
  gtk_widget_set_name (button_filter_clear, "button_filter_clear");
  gtk_widget_ref (button_filter_clear);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "button_filter_clear", button_filter_clear,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_filter_clear);
  gtk_box_pack_start (GTK_BOX (hbox125), button_filter_clear, FALSE, TRUE, 0);

  button_filter_reset_all_rules = gtk_button_new_with_label (_("Reset all rule stats\nin this filter"));
  gtk_widget_set_name (button_filter_reset_all_rules, "button_filter_reset_all_rules");
  gtk_widget_ref (button_filter_reset_all_rules);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "button_filter_reset_all_rules", button_filter_reset_all_rules,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_filter_reset_all_rules);
  gtk_box_pack_start (GTK_BOX (hbox125), button_filter_reset_all_rules, FALSE, TRUE, 0);

  button_filter_reset = gtk_button_new_with_label (_("Reset filter stats\nfor this filter"));
  gtk_widget_set_name (button_filter_reset, "button_filter_reset");
  gtk_widget_ref (button_filter_reset);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "button_filter_reset", button_filter_reset,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_filter_reset);
  gtk_box_pack_start (GTK_BOX (hbox125), button_filter_reset, FALSE, TRUE, 0);

  button_filter_reset_all = gtk_button_new_with_label (_("Reset filter stats\nfor all filters"));
  gtk_widget_set_name (button_filter_reset_all, "button_filter_reset_all");
  gtk_widget_ref (button_filter_reset_all);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "button_filter_reset_all", button_filter_reset_all,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_filter_reset_all);
  gtk_box_pack_start (GTK_BOX (hbox125), button_filter_reset_all, FALSE, FALSE, 0);

  hseparator6 = gtk_hseparator_new ();
  gtk_widget_set_name (hseparator6, "hseparator6");
  gtk_widget_ref (hseparator6);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "hseparator6", hseparator6,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_box_pack_start (GTK_BOX (vbox32), hseparator6, FALSE, FALSE, 0);

  hbox210 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox210, "hbox210");
  gtk_widget_ref (hbox210);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "hbox210", hbox210,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox210);
  gtk_box_pack_start (GTK_BOX (vbox32), hbox210, FALSE, TRUE, 0);

  notebook_filter_detail = gtk_notebook_new ();
  gtk_widget_set_name (notebook_filter_detail, "notebook_filter_detail");
  gtk_widget_ref (notebook_filter_detail);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "notebook_filter_detail", notebook_filter_detail,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (notebook_filter_detail);
  gtk_box_pack_start (GTK_BOX (hbox210), notebook_filter_detail, TRUE, TRUE, 0);
  gtk_widget_set_usize (notebook_filter_detail, 429, -2);
  gtk_container_set_border_width (GTK_CONTAINER (notebook_filter_detail), 2);
  gtk_notebook_set_show_border (GTK_NOTEBOOK (notebook_filter_detail), FALSE);

  alignment37 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment37, "alignment37");
  gtk_widget_ref (alignment37);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "alignment37", alignment37,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (alignment37);
  gtk_container_add (GTK_CONTAINER (notebook_filter_detail), alignment37);

  hbox2100 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox2100, "hbox2100");
  gtk_widget_ref (hbox2100);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "hbox2100", hbox2100,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox2100);
  gtk_container_add (GTK_CONTAINER (alignment37), hbox2100);
  gtk_container_set_border_width (GTK_CONTAINER (hbox2100), 2);

  vbox137 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox137, "vbox137");
  gtk_widget_ref (vbox137);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "vbox137", vbox137,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox137);
  gtk_box_pack_start (GTK_BOX (hbox2100), vbox137, FALSE, FALSE, 0);

  button_filter_add_rule_text = gtk_button_new_with_label (_("Add name rule"));
  gtk_widget_set_name (button_filter_add_rule_text, "button_filter_add_rule_text");
  gtk_widget_ref (button_filter_add_rule_text);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "button_filter_add_rule_text", button_filter_add_rule_text,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_filter_add_rule_text);
  gtk_box_pack_start (GTK_BOX (vbox137), button_filter_add_rule_text, FALSE, TRUE, 0);

  button_filter_add_rule_size = gtk_button_new_with_label (_("Add size rule"));
  gtk_widget_set_name (button_filter_add_rule_size, "button_filter_add_rule_size");
  gtk_widget_ref (button_filter_add_rule_size);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "button_filter_add_rule_size", button_filter_add_rule_size,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_filter_add_rule_size);
  gtk_box_pack_start (GTK_BOX (vbox137), button_filter_add_rule_size, FALSE, TRUE, 0);

  button_filter_add_rule_flag = gtk_button_new_with_label (_("Add flag rule"));
  gtk_widget_set_name (button_filter_add_rule_flag, "button_filter_add_rule_flag");
  gtk_widget_ref (button_filter_add_rule_flag);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "button_filter_add_rule_flag", button_filter_add_rule_flag,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_filter_add_rule_flag);
  gtk_box_pack_start (GTK_BOX (vbox137), button_filter_add_rule_flag, FALSE, TRUE, 0);

  vbox138 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox138, "vbox138");
  gtk_widget_ref (vbox138);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "vbox138", vbox138,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox138);
  gtk_box_pack_start (GTK_BOX (hbox2100), vbox138, FALSE, FALSE, 0);

  button_filter_add_rule_jump = gtk_button_new_with_label (_("Add jump rule"));
  gtk_widget_set_name (button_filter_add_rule_jump, "button_filter_add_rule_jump");
  gtk_widget_ref (button_filter_add_rule_jump);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "button_filter_add_rule_jump", button_filter_add_rule_jump,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_filter_add_rule_jump);
  gtk_box_pack_start (GTK_BOX (vbox138), button_filter_add_rule_jump, FALSE, TRUE, 0);

  button_filter_add_rule_ip = gtk_button_new_with_label (_("Add IP rule"));
  gtk_widget_set_name (button_filter_add_rule_ip, "button_filter_add_rule_ip");
  gtk_widget_ref (button_filter_add_rule_ip);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "button_filter_add_rule_ip", button_filter_add_rule_ip,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_filter_add_rule_ip);
  gtk_box_pack_start (GTK_BOX (vbox138), button_filter_add_rule_ip, FALSE, TRUE, 0);

  button_filter_add_rule_state = gtk_button_new_with_label (_("Add state rule"));
  gtk_widget_set_name (button_filter_add_rule_state, "button_filter_add_rule_state");
  gtk_widget_ref (button_filter_add_rule_state);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "button_filter_add_rule_state", button_filter_add_rule_state,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_filter_add_rule_state);
  gtk_box_pack_start (GTK_BOX (vbox138), button_filter_add_rule_state, FALSE, TRUE, 0);

  label724 = gtk_label_new (_("[Add/Remove]"));
  gtk_widget_set_name (label724, "label724");
  gtk_widget_ref (label724);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "label724", label724,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label724);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_filter_detail), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_filter_detail), 0), label724);

  vbox52 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox52, "vbox52");
  gtk_widget_ref (vbox52);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "vbox52", vbox52,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox52);
  gtk_container_add (GTK_CONTAINER (notebook_filter_detail), vbox52);

  alignment12 = gtk_alignment_new (0.5, 0, 1, 1);
  gtk_widget_set_name (alignment12, "alignment12");
  gtk_widget_ref (alignment12);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "alignment12", alignment12,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (alignment12);
  gtk_box_pack_start (GTK_BOX (vbox52), alignment12, TRUE, TRUE, 0);

  hbox120 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox120, "hbox120");
  gtk_widget_ref (hbox120);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "hbox120", hbox120,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox120);
  gtk_container_add (GTK_CONTAINER (alignment12), hbox120);

  frame31 = gtk_frame_new (_("Flags"));
  gtk_widget_set_name (frame31, "frame31");
  gtk_widget_ref (frame31);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "frame31", frame31,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame31);
  gtk_box_pack_start (GTK_BOX (hbox120), frame31, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame31), 2);

  vbox55 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox55, "vbox55");
  gtk_widget_ref (vbox55);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "vbox55", vbox55,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox55);
  gtk_container_add (GTK_CONTAINER (frame31), vbox55);

  checkbutton_filter_text_invert_cond = gtk_check_button_new_with_label (_("invert condition"));
  gtk_widget_set_name (checkbutton_filter_text_invert_cond, "checkbutton_filter_text_invert_cond");
  gtk_widget_ref (checkbutton_filter_text_invert_cond);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "checkbutton_filter_text_invert_cond", checkbutton_filter_text_invert_cond,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_filter_text_invert_cond);
  gtk_box_pack_start (GTK_BOX (vbox55), checkbutton_filter_text_invert_cond, FALSE, FALSE, 0);

  checkbutton_filter_text_active = gtk_check_button_new_with_label (_("active"));
  gtk_widget_set_name (checkbutton_filter_text_active, "checkbutton_filter_text_active");
  gtk_widget_ref (checkbutton_filter_text_active);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "checkbutton_filter_text_active", checkbutton_filter_text_active,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_filter_text_active);
  gtk_box_pack_start (GTK_BOX (vbox55), checkbutton_filter_text_active, FALSE, FALSE, 0);

  checkbutton_filter_text_soft = gtk_check_button_new_with_label (_("mark only"));
  gtk_widget_set_name (checkbutton_filter_text_soft, "checkbutton_filter_text_soft");
  gtk_widget_ref (checkbutton_filter_text_soft);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "checkbutton_filter_text_soft", checkbutton_filter_text_soft,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_filter_text_soft);
  gtk_box_pack_start (GTK_BOX (vbox55), checkbutton_filter_text_soft, FALSE, FALSE, 0);

  frame25 = gtk_frame_new (_("Condition: If filename matches"));
  gtk_widget_set_name (frame25, "frame25");
  gtk_widget_ref (frame25);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "frame25", frame25,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame25);
  gtk_box_pack_start (GTK_BOX (hbox120), frame25, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame25), 2);

  hbox117 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox117, "hbox117");
  gtk_widget_ref (hbox117);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "hbox117", hbox117,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox117);
  gtk_container_add (GTK_CONTAINER (frame25), hbox117);

  table22 = gtk_table_new (2, 2, FALSE);
  gtk_widget_set_name (table22, "table22");
  gtk_widget_ref (table22);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "table22", table22,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table22);
  gtk_box_pack_start (GTK_BOX (hbox117), table22, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (table22), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table22), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table22), 4);

  optionmenu_filter_text_type = gtk_option_menu_new ();
  gtk_widget_set_name (optionmenu_filter_text_type, "optionmenu_filter_text_type");
  gtk_widget_ref (optionmenu_filter_text_type);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "optionmenu_filter_text_type", optionmenu_filter_text_type,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (optionmenu_filter_text_type);
  gtk_table_attach (GTK_TABLE (table22), optionmenu_filter_text_type, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  optionmenu_filter_text_type_menu = gtk_menu_new ();
  glade_menuitem = gtk_menu_item_new_with_label ("");
  gtk_widget_show (glade_menuitem);
  gtk_menu_append (GTK_MENU (optionmenu_filter_text_type_menu), glade_menuitem);
  gtk_option_menu_set_menu (GTK_OPTION_MENU (optionmenu_filter_text_type), optionmenu_filter_text_type_menu);

  entry_filter_text_pattern = gtk_entry_new ();
  gtk_widget_set_name (entry_filter_text_pattern, "entry_filter_text_pattern");
  gtk_widget_ref (entry_filter_text_pattern);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "entry_filter_text_pattern", entry_filter_text_pattern,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_filter_text_pattern);
  gtk_table_attach (GTK_TABLE (table22), entry_filter_text_pattern, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_filter_text_case = gtk_check_button_new_with_label (_("case sensitive"));
  gtk_widget_set_name (checkbutton_filter_text_case, "checkbutton_filter_text_case");
  gtk_widget_ref (checkbutton_filter_text_case);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "checkbutton_filter_text_case", checkbutton_filter_text_case,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_filter_text_case);
  gtk_table_attach (GTK_TABLE (table22), checkbutton_filter_text_case, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  hbox110 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox110, "hbox110");
  gtk_widget_ref (hbox110);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "hbox110", hbox110,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox110);
  gtk_box_pack_start (GTK_BOX (vbox52), hbox110, FALSE, FALSE, 0);

  frame26 = gtk_frame_new (_("Target"));
  gtk_widget_set_name (frame26, "frame26");
  gtk_widget_ref (frame26);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "frame26", frame26,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame26);
  gtk_box_pack_start (GTK_BOX (hbox110), frame26, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame26), 2);

  optionmenu_filter_text_target = gtk_option_menu_new ();
  gtk_widget_set_name (optionmenu_filter_text_target, "optionmenu_filter_text_target");
  gtk_widget_ref (optionmenu_filter_text_target);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "optionmenu_filter_text_target", optionmenu_filter_text_target,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (optionmenu_filter_text_target);
  gtk_container_add (GTK_CONTAINER (frame26), optionmenu_filter_text_target);
  optionmenu_filter_text_target_menu = gtk_menu_new ();
  gtk_option_menu_set_menu (GTK_OPTION_MENU (optionmenu_filter_text_target), optionmenu_filter_text_target_menu);

  vbox60 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox60, "vbox60");
  gtk_widget_ref (vbox60);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "vbox60", vbox60,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox60);
  gtk_box_pack_start (GTK_BOX (hbox110), vbox60, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (vbox60), 2);

  hbox138 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox138, "hbox138");
  gtk_widget_ref (hbox138);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "hbox138", hbox138,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox138);
  gtk_box_pack_start (GTK_BOX (vbox60), hbox138, FALSE, TRUE, 4);
  gtk_container_set_border_width (GTK_CONTAINER (hbox138), 4);

  button_filter_text_add = gtk_button_new_with_label (_("Save"));
  gtk_widget_set_name (button_filter_text_add, "button_filter_text_add");
  gtk_widget_ref (button_filter_text_add);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "button_filter_text_add", button_filter_text_add,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_filter_text_add);
  gtk_box_pack_start (GTK_BOX (hbox138), button_filter_text_add, TRUE, TRUE, 0);

  button_filter_text_remove = gtk_button_new_with_label (_("Remove"));
  gtk_widget_set_name (button_filter_text_remove, "button_filter_text_remove");
  gtk_widget_ref (button_filter_text_remove);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "button_filter_text_remove", button_filter_text_remove,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_filter_text_remove);
  gtk_box_pack_start (GTK_BOX (hbox138), button_filter_text_remove, TRUE, TRUE, 0);

  button16 = gtk_button_new_with_label (_("Abort"));
  gtk_widget_set_name (button16, "button16");
  gtk_widget_ref (button16);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "button16", button16,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button16);
  gtk_box_pack_start (GTK_BOX (hbox138), button16, TRUE, TRUE, 0);

  vseparator10 = gtk_vseparator_new ();
  gtk_widget_set_name (vseparator10, "vseparator10");
  gtk_widget_ref (vseparator10);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "vseparator10", vseparator10,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vseparator10);
  gtk_box_pack_start (GTK_BOX (hbox138), vseparator10, TRUE, TRUE, 0);

  button_filter_text_reset = gtk_button_new_with_label ("");
  button_filter_text_reset_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (button_filter_text_reset)->child),
                                   _("_Reset stats"));
  gtk_widget_add_accelerator (button_filter_text_reset, "clicked", accel_group,
                              button_filter_text_reset_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (button_filter_text_reset, "button_filter_text_reset");
  gtk_widget_ref (button_filter_text_reset);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "button_filter_text_reset", button_filter_text_reset,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_filter_text_reset);
  gtk_box_pack_start (GTK_BOX (hbox138), button_filter_text_reset, TRUE, TRUE, 0);

  label725 = gtk_label_new (_("[Filename]"));
  gtk_widget_set_name (label725, "label725");
  gtk_widget_ref (label725);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "label725", label725,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label725);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_filter_detail), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_filter_detail), 1), label725);

  vbox51 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox51, "vbox51");
  gtk_widget_ref (vbox51);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "vbox51", vbox51,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox51);
  gtk_container_add (GTK_CONTAINER (notebook_filter_detail), vbox51);

  alignment11 = gtk_alignment_new (0.5, 0, 1, 1);
  gtk_widget_set_name (alignment11, "alignment11");
  gtk_widget_ref (alignment11);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "alignment11", alignment11,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (alignment11);
  gtk_box_pack_start (GTK_BOX (vbox51), alignment11, TRUE, TRUE, 0);

  hbox121 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox121, "hbox121");
  gtk_widget_ref (hbox121);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "hbox121", hbox121,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox121);
  gtk_container_add (GTK_CONTAINER (alignment11), hbox121);

  frame32 = gtk_frame_new (_("Flags"));
  gtk_widget_set_name (frame32, "frame32");
  gtk_widget_ref (frame32);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "frame32", frame32,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame32);
  gtk_box_pack_start (GTK_BOX (hbox121), frame32, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame32), 2);

  vbox56 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox56, "vbox56");
  gtk_widget_ref (vbox56);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "vbox56", vbox56,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox56);
  gtk_container_add (GTK_CONTAINER (frame32), vbox56);

  checkbutton_filter_ip_invert_cond = gtk_check_button_new_with_label (_("invert condition"));
  gtk_widget_set_name (checkbutton_filter_ip_invert_cond, "checkbutton_filter_ip_invert_cond");
  gtk_widget_ref (checkbutton_filter_ip_invert_cond);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "checkbutton_filter_ip_invert_cond", checkbutton_filter_ip_invert_cond,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_filter_ip_invert_cond);
  gtk_box_pack_start (GTK_BOX (vbox56), checkbutton_filter_ip_invert_cond, FALSE, FALSE, 0);

  checkbutton_filter_ip_active = gtk_check_button_new_with_label (_("active"));
  gtk_widget_set_name (checkbutton_filter_ip_active, "checkbutton_filter_ip_active");
  gtk_widget_ref (checkbutton_filter_ip_active);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "checkbutton_filter_ip_active", checkbutton_filter_ip_active,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_filter_ip_active);
  gtk_box_pack_start (GTK_BOX (vbox56), checkbutton_filter_ip_active, FALSE, FALSE, 0);

  checkbutton_filter_ip_soft = gtk_check_button_new_with_label (_("mark only"));
  gtk_widget_set_name (checkbutton_filter_ip_soft, "checkbutton_filter_ip_soft");
  gtk_widget_ref (checkbutton_filter_ip_soft);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "checkbutton_filter_ip_soft", checkbutton_filter_ip_soft,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_filter_ip_soft);
  gtk_box_pack_start (GTK_BOX (vbox56), checkbutton_filter_ip_soft, FALSE, FALSE, 0);

  frame23 = gtk_frame_new (_("Condition: If IP address matches"));
  gtk_widget_set_name (frame23, "frame23");
  gtk_widget_ref (frame23);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "frame23", frame23,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame23);
  gtk_box_pack_start (GTK_BOX (hbox121), frame23, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame23), 2);

  hbox118 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox118, "hbox118");
  gtk_widget_ref (hbox118);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "hbox118", hbox118,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox118);
  gtk_container_add (GTK_CONTAINER (frame23), hbox118);

  table23 = gtk_table_new (1, 2, FALSE);
  gtk_widget_set_name (table23, "table23");
  gtk_widget_ref (table23);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "table23", table23,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table23);
  gtk_box_pack_start (GTK_BOX (hbox118), table23, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (table23), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table23), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table23), 4);

  label191 = gtk_label_new (_("IP address/mask"));
  gtk_widget_set_name (label191, "label191");
  gtk_widget_ref (label191);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "label191", label191,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label191);
  gtk_table_attach (GTK_TABLE (table23), label191, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label191), 0, 0.5);

  entry_filter_ip_address = gtk_entry_new ();
  gtk_widget_set_name (entry_filter_ip_address, "entry_filter_ip_address");
  gtk_widget_ref (entry_filter_ip_address);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "entry_filter_ip_address", entry_filter_ip_address,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_filter_ip_address);
  gtk_table_attach (GTK_TABLE (table23), entry_filter_ip_address, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  hbox109 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox109, "hbox109");
  gtk_widget_ref (hbox109);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "hbox109", hbox109,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox109);
  gtk_box_pack_start (GTK_BOX (vbox51), hbox109, FALSE, FALSE, 0);

  frame24 = gtk_frame_new (_("Target"));
  gtk_widget_set_name (frame24, "frame24");
  gtk_widget_ref (frame24);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "frame24", frame24,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame24);
  gtk_box_pack_start (GTK_BOX (hbox109), frame24, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame24), 2);

  optionmenu_filter_ip_target = gtk_option_menu_new ();
  gtk_widget_set_name (optionmenu_filter_ip_target, "optionmenu_filter_ip_target");
  gtk_widget_ref (optionmenu_filter_ip_target);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "optionmenu_filter_ip_target", optionmenu_filter_ip_target,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (optionmenu_filter_ip_target);
  gtk_container_add (GTK_CONTAINER (frame24), optionmenu_filter_ip_target);
  optionmenu_filter_ip_target_menu = gtk_menu_new ();
  glade_menuitem = gtk_menu_item_new_with_label ("");
  gtk_widget_show (glade_menuitem);
  gtk_menu_append (GTK_MENU (optionmenu_filter_ip_target_menu), glade_menuitem);
  gtk_option_menu_set_menu (GTK_OPTION_MENU (optionmenu_filter_ip_target), optionmenu_filter_ip_target_menu);

  vbox61 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox61, "vbox61");
  gtk_widget_ref (vbox61);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "vbox61", vbox61,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox61);
  gtk_box_pack_start (GTK_BOX (hbox109), vbox61, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (vbox61), 2);

  hbox139 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox139, "hbox139");
  gtk_widget_ref (hbox139);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "hbox139", hbox139,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox139);
  gtk_box_pack_start (GTK_BOX (vbox61), hbox139, FALSE, FALSE, 4);
  gtk_container_set_border_width (GTK_CONTAINER (hbox139), 4);

  button4 = gtk_button_new_with_label (_("Save"));
  gtk_widget_set_name (button4, "button4");
  gtk_widget_ref (button4);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "button4", button4,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button4);
  gtk_box_pack_start (GTK_BOX (hbox139), button4, TRUE, TRUE, 2);

  button5 = gtk_button_new_with_label (_("Remove"));
  gtk_widget_set_name (button5, "button5");
  gtk_widget_ref (button5);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "button5", button5,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button5);
  gtk_box_pack_start (GTK_BOX (hbox139), button5, TRUE, TRUE, 0);

  button17 = gtk_button_new_with_label (_("Abort"));
  gtk_widget_set_name (button17, "button17");
  gtk_widget_ref (button17);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "button17", button17,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button17);
  gtk_box_pack_start (GTK_BOX (hbox139), button17, TRUE, TRUE, 0);

  vseparator11 = gtk_vseparator_new ();
  gtk_widget_set_name (vseparator11, "vseparator11");
  gtk_widget_ref (vseparator11);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "vseparator11", vseparator11,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vseparator11);
  gtk_box_pack_start (GTK_BOX (hbox139), vseparator11, TRUE, TRUE, 0);

  button_filter_ip_reset = gtk_button_new_with_label ("");
  button_filter_ip_reset_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (button_filter_ip_reset)->child),
                                   _("_Reset stats"));
  gtk_widget_add_accelerator (button_filter_ip_reset, "clicked", accel_group,
                              button_filter_ip_reset_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (button_filter_ip_reset, "button_filter_ip_reset");
  gtk_widget_ref (button_filter_ip_reset);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "button_filter_ip_reset", button_filter_ip_reset,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_filter_ip_reset);
  gtk_box_pack_start (GTK_BOX (hbox139), button_filter_ip_reset, TRUE, TRUE, 0);

  label726 = gtk_label_new (_("[IP address]"));
  gtk_widget_set_name (label726, "label726");
  gtk_widget_ref (label726);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "label726", label726,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label726);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_filter_detail), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_filter_detail), 2), label726);

  vbox49 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox49, "vbox49");
  gtk_widget_ref (vbox49);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "vbox49", vbox49,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox49);
  gtk_container_add (GTK_CONTAINER (notebook_filter_detail), vbox49);

  alignment10 = gtk_alignment_new (0.5, 0, 1, 1);
  gtk_widget_set_name (alignment10, "alignment10");
  gtk_widget_ref (alignment10);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "alignment10", alignment10,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (alignment10);
  gtk_box_pack_start (GTK_BOX (vbox49), alignment10, TRUE, TRUE, 0);

  hbox122 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox122, "hbox122");
  gtk_widget_ref (hbox122);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "hbox122", hbox122,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox122);
  gtk_container_add (GTK_CONTAINER (alignment10), hbox122);

  frame33 = gtk_frame_new (_("Flags"));
  gtk_widget_set_name (frame33, "frame33");
  gtk_widget_ref (frame33);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "frame33", frame33,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame33);
  gtk_box_pack_start (GTK_BOX (hbox122), frame33, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame33), 2);

  vbox57 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox57, "vbox57");
  gtk_widget_ref (vbox57);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "vbox57", vbox57,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox57);
  gtk_container_add (GTK_CONTAINER (frame33), vbox57);

  checkbutton_filter_size_invert_cond = gtk_check_button_new_with_label (_("invert condition"));
  gtk_widget_set_name (checkbutton_filter_size_invert_cond, "checkbutton_filter_size_invert_cond");
  gtk_widget_ref (checkbutton_filter_size_invert_cond);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "checkbutton_filter_size_invert_cond", checkbutton_filter_size_invert_cond,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_filter_size_invert_cond);
  gtk_box_pack_start (GTK_BOX (vbox57), checkbutton_filter_size_invert_cond, FALSE, FALSE, 0);

  checkbutton_filter_size_active = gtk_check_button_new_with_label (_("active"));
  gtk_widget_set_name (checkbutton_filter_size_active, "checkbutton_filter_size_active");
  gtk_widget_ref (checkbutton_filter_size_active);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "checkbutton_filter_size_active", checkbutton_filter_size_active,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_filter_size_active);
  gtk_box_pack_start (GTK_BOX (vbox57), checkbutton_filter_size_active, FALSE, FALSE, 0);

  checkbutton_filter_size_soft = gtk_check_button_new_with_label (_("mark only"));
  gtk_widget_set_name (checkbutton_filter_size_soft, "checkbutton_filter_size_soft");
  gtk_widget_ref (checkbutton_filter_size_soft);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "checkbutton_filter_size_soft", checkbutton_filter_size_soft,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_filter_size_soft);
  gtk_box_pack_start (GTK_BOX (vbox57), checkbutton_filter_size_soft, FALSE, FALSE, 0);

  frame22 = gtk_frame_new (_("Condition: If file size matches"));
  gtk_widget_set_name (frame22, "frame22");
  gtk_widget_ref (frame22);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "frame22", frame22,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame22);
  gtk_box_pack_start (GTK_BOX (hbox122), frame22, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame22), 2);

  hbox119 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox119, "hbox119");
  gtk_widget_ref (hbox119);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "hbox119", hbox119,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox119);
  gtk_container_add (GTK_CONTAINER (frame22), hbox119);

  table24 = gtk_table_new (2, 3, FALSE);
  gtk_widget_set_name (table24, "table24");
  gtk_widget_ref (table24);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "table24", table24,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table24);
  gtk_box_pack_start (GTK_BOX (hbox119), table24, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (table24), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table24), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table24), 4);

  label192 = gtk_label_new (_("Minimum size:"));
  gtk_widget_set_name (label192, "label192");
  gtk_widget_ref (label192);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "label192", label192,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label192);
  gtk_table_attach (GTK_TABLE (table24), label192, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label192), 0, 0.5);

  label193 = gtk_label_new (_("Maximum size:"));
  gtk_widget_set_name (label193, "label193");
  gtk_widget_ref (label193);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "label193", label193,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label193);
  gtk_table_attach (GTK_TABLE (table24), label193, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label193), 0, 0.5);

  label194 = gtk_label_new (_("bytes"));
  gtk_widget_set_name (label194, "label194");
  gtk_widget_ref (label194);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "label194", label194,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label194);
  gtk_table_attach (GTK_TABLE (table24), label194, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label194), 0, 0.5);

  label195 = gtk_label_new (_("bytes"));
  gtk_widget_set_name (label195, "label195");
  gtk_widget_ref (label195);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "label195", label195,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label195);
  gtk_table_attach (GTK_TABLE (table24), label195, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label195), 0, 0.5);

  entry_filter_size_min = gtk_entry_new ();
  gtk_widget_set_name (entry_filter_size_min, "entry_filter_size_min");
  gtk_widget_ref (entry_filter_size_min);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "entry_filter_size_min", entry_filter_size_min,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_filter_size_min);
  gtk_table_attach (GTK_TABLE (table24), entry_filter_size_min, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_filter_size_max = gtk_entry_new ();
  gtk_widget_set_name (entry_filter_size_max, "entry_filter_size_max");
  gtk_widget_ref (entry_filter_size_max);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "entry_filter_size_max", entry_filter_size_max,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_filter_size_max);
  gtk_table_attach (GTK_TABLE (table24), entry_filter_size_max, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  hbox108 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox108, "hbox108");
  gtk_widget_ref (hbox108);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "hbox108", hbox108,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox108);
  gtk_box_pack_start (GTK_BOX (vbox49), hbox108, FALSE, FALSE, 0);

  frame21 = gtk_frame_new (_("Target"));
  gtk_widget_set_name (frame21, "frame21");
  gtk_widget_ref (frame21);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "frame21", frame21,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame21);
  gtk_box_pack_start (GTK_BOX (hbox108), frame21, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame21), 2);

  optionmenu_filter_size_target = gtk_option_menu_new ();
  gtk_widget_set_name (optionmenu_filter_size_target, "optionmenu_filter_size_target");
  gtk_widget_ref (optionmenu_filter_size_target);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "optionmenu_filter_size_target", optionmenu_filter_size_target,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (optionmenu_filter_size_target);
  gtk_container_add (GTK_CONTAINER (frame21), optionmenu_filter_size_target);
  optionmenu_filter_size_target_menu = gtk_menu_new ();
  glade_menuitem = gtk_menu_item_new_with_label ("");
  gtk_widget_show (glade_menuitem);
  gtk_menu_append (GTK_MENU (optionmenu_filter_size_target_menu), glade_menuitem);
  gtk_option_menu_set_menu (GTK_OPTION_MENU (optionmenu_filter_size_target), optionmenu_filter_size_target_menu);

  vbox62 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox62, "vbox62");
  gtk_widget_ref (vbox62);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "vbox62", vbox62,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox62);
  gtk_box_pack_start (GTK_BOX (hbox108), vbox62, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (vbox62), 2);

  hbox140 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox140, "hbox140");
  gtk_widget_ref (hbox140);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "hbox140", hbox140,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox140);
  gtk_box_pack_start (GTK_BOX (vbox62), hbox140, FALSE, FALSE, 4);
  gtk_container_set_border_width (GTK_CONTAINER (hbox140), 4);

  button6 = gtk_button_new_with_label (_("Save"));
  gtk_widget_set_name (button6, "button6");
  gtk_widget_ref (button6);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "button6", button6,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button6);
  gtk_box_pack_start (GTK_BOX (hbox140), button6, TRUE, TRUE, 0);

  button7 = gtk_button_new_with_label (_("Remove"));
  gtk_widget_set_name (button7, "button7");
  gtk_widget_ref (button7);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "button7", button7,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button7);
  gtk_box_pack_start (GTK_BOX (hbox140), button7, TRUE, TRUE, 0);

  button18 = gtk_button_new_with_label (_("Abort"));
  gtk_widget_set_name (button18, "button18");
  gtk_widget_ref (button18);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "button18", button18,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button18);
  gtk_box_pack_start (GTK_BOX (hbox140), button18, TRUE, TRUE, 0);

  vseparator12 = gtk_vseparator_new ();
  gtk_widget_set_name (vseparator12, "vseparator12");
  gtk_widget_ref (vseparator12);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "vseparator12", vseparator12,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vseparator12);
  gtk_box_pack_start (GTK_BOX (hbox140), vseparator12, TRUE, TRUE, 0);

  button_filter_size_reset = gtk_button_new_with_label ("");
  button_filter_size_reset_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (button_filter_size_reset)->child),
                                   _("_Reset stats"));
  gtk_widget_add_accelerator (button_filter_size_reset, "clicked", accel_group,
                              button_filter_size_reset_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (button_filter_size_reset, "button_filter_size_reset");
  gtk_widget_ref (button_filter_size_reset);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "button_filter_size_reset", button_filter_size_reset,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_filter_size_reset);
  gtk_box_pack_start (GTK_BOX (hbox140), button_filter_size_reset, TRUE, TRUE, 0);

  label727 = gtk_label_new (_("[Filesize]"));
  gtk_widget_set_name (label727, "label727");
  gtk_widget_ref (label727);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "label727", label727,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label727);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_filter_detail), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_filter_detail), 3), label727);

  vbox54 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox54, "vbox54");
  gtk_widget_ref (vbox54);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "vbox54", vbox54,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox54);
  gtk_container_add (GTK_CONTAINER (notebook_filter_detail), vbox54);

  alignment24 = gtk_alignment_new (0.5, 0, 1, 1);
  gtk_widget_set_name (alignment24, "alignment24");
  gtk_widget_ref (alignment24);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "alignment24", alignment24,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (alignment24);
  gtk_box_pack_start (GTK_BOX (vbox54), alignment24, TRUE, TRUE, 0);

  hbox123 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox123, "hbox123");
  gtk_widget_ref (hbox123);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "hbox123", hbox123,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox123);
  gtk_container_add (GTK_CONTAINER (alignment24), hbox123);

  frame34 = gtk_frame_new (_("Flags"));
  gtk_widget_set_name (frame34, "frame34");
  gtk_widget_ref (frame34);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "frame34", frame34,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame34);
  gtk_box_pack_start (GTK_BOX (hbox123), frame34, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame34), 2);

  vbox58 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox58, "vbox58");
  gtk_widget_ref (vbox58);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "vbox58", vbox58,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox58);
  gtk_container_add (GTK_CONTAINER (frame34), vbox58);

  checkbutton_filter_jump_active = gtk_check_button_new_with_label (_("active"));
  gtk_widget_set_name (checkbutton_filter_jump_active, "checkbutton_filter_jump_active");
  gtk_widget_ref (checkbutton_filter_jump_active);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "checkbutton_filter_jump_active", checkbutton_filter_jump_active,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_filter_jump_active);
  gtk_box_pack_start (GTK_BOX (vbox58), checkbutton_filter_jump_active, FALSE, FALSE, 0);

  frame29 = gtk_frame_new (_("Condition: always"));
  gtk_widget_set_name (frame29, "frame29");
  gtk_widget_ref (frame29);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "frame29", frame29,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame29);
  gtk_box_pack_start (GTK_BOX (hbox123), frame29, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame29), 2);

  hbox115 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox115, "hbox115");
  gtk_widget_ref (hbox115);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "hbox115", hbox115,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox115);
  gtk_container_add (GTK_CONTAINER (frame29), hbox115);
  gtk_container_set_border_width (GTK_CONTAINER (hbox115), 2);

  label209 = gtk_label_new (_("There is no condition. When this rule is reached, the matching will continue in the specified target filter. That's also why you can't invert this condition. If you could, this rule would just be ignored."));
  gtk_widget_set_name (label209, "label209");
  gtk_widget_ref (label209);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "label209", label209,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label209);
  gtk_box_pack_start (GTK_BOX (hbox115), label209, FALSE, TRUE, 0);
  gtk_label_set_justify (GTK_LABEL (label209), GTK_JUSTIFY_LEFT);
  gtk_label_set_line_wrap (GTK_LABEL (label209), TRUE);

  alignment17 = gtk_alignment_new (0.5, 1, 1, 0);
  gtk_widget_set_name (alignment17, "alignment17");
  gtk_widget_ref (alignment17);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "alignment17", alignment17,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (alignment17);
  gtk_box_pack_start (GTK_BOX (vbox54), alignment17, TRUE, TRUE, 0);

  hbox114 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox114, "hbox114");
  gtk_widget_ref (hbox114);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "hbox114", hbox114,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox114);
  gtk_container_add (GTK_CONTAINER (alignment17), hbox114);

  frame28 = gtk_frame_new (_("Target"));
  gtk_widget_set_name (frame28, "frame28");
  gtk_widget_ref (frame28);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "frame28", frame28,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame28);
  gtk_box_pack_start (GTK_BOX (hbox114), frame28, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame28), 2);

  optionmenu_filter_jump_target = gtk_option_menu_new ();
  gtk_widget_set_name (optionmenu_filter_jump_target, "optionmenu_filter_jump_target");
  gtk_widget_ref (optionmenu_filter_jump_target);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "optionmenu_filter_jump_target", optionmenu_filter_jump_target,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (optionmenu_filter_jump_target);
  gtk_container_add (GTK_CONTAINER (frame28), optionmenu_filter_jump_target);
  optionmenu_filter_jump_target_menu = gtk_menu_new ();
  glade_menuitem = gtk_menu_item_new_with_label ("");
  gtk_widget_show (glade_menuitem);
  gtk_menu_append (GTK_MENU (optionmenu_filter_jump_target_menu), glade_menuitem);
  gtk_option_menu_set_menu (GTK_OPTION_MENU (optionmenu_filter_jump_target), optionmenu_filter_jump_target_menu);

  vbox63 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox63, "vbox63");
  gtk_widget_ref (vbox63);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "vbox63", vbox63,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox63);
  gtk_box_pack_start (GTK_BOX (hbox114), vbox63, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (vbox63), 2);

  hbox141 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox141, "hbox141");
  gtk_widget_ref (hbox141);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "hbox141", hbox141,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox141);
  gtk_box_pack_start (GTK_BOX (vbox63), hbox141, FALSE, TRUE, 4);
  gtk_container_set_border_width (GTK_CONTAINER (hbox141), 4);

  button8 = gtk_button_new_with_label (_("Save"));
  gtk_widget_set_name (button8, "button8");
  gtk_widget_ref (button8);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "button8", button8,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button8);
  gtk_box_pack_start (GTK_BOX (hbox141), button8, TRUE, TRUE, 0);

  button9 = gtk_button_new_with_label (_("Remove"));
  gtk_widget_set_name (button9, "button9");
  gtk_widget_ref (button9);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "button9", button9,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button9);
  gtk_box_pack_start (GTK_BOX (hbox141), button9, TRUE, TRUE, 0);

  button19 = gtk_button_new_with_label (_("Abort"));
  gtk_widget_set_name (button19, "button19");
  gtk_widget_ref (button19);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "button19", button19,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button19);
  gtk_box_pack_start (GTK_BOX (hbox141), button19, TRUE, TRUE, 0);

  vseparator13 = gtk_vseparator_new ();
  gtk_widget_set_name (vseparator13, "vseparator13");
  gtk_widget_ref (vseparator13);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "vseparator13", vseparator13,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vseparator13);
  gtk_box_pack_start (GTK_BOX (hbox141), vseparator13, TRUE, TRUE, 0);

  button_filter_jump_reset = gtk_button_new_with_label ("");
  button_filter_jump_reset_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (button_filter_jump_reset)->child),
                                   _("_Reset stats"));
  gtk_widget_add_accelerator (button_filter_jump_reset, "clicked", accel_group,
                              button_filter_jump_reset_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (button_filter_jump_reset, "button_filter_jump_reset");
  gtk_widget_ref (button_filter_jump_reset);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "button_filter_jump_reset", button_filter_jump_reset,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_filter_jump_reset);
  gtk_box_pack_start (GTK_BOX (hbox141), button_filter_jump_reset, TRUE, TRUE, 0);

  label728 = gtk_label_new (_("[Jump]"));
  gtk_widget_set_name (label728, "label728");
  gtk_widget_ref (label728);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "label728", label728,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label728);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_filter_detail), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_filter_detail), 4), label728);

  vbox64 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox64, "vbox64");
  gtk_widget_ref (vbox64);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "vbox64", vbox64,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox64);
  gtk_container_add (GTK_CONTAINER (notebook_filter_detail), vbox64);

  alignment20 = gtk_alignment_new (0.5, 0, 1, 1);
  gtk_widget_set_name (alignment20, "alignment20");
  gtk_widget_ref (alignment20);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "alignment20", alignment20,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (alignment20);
  gtk_box_pack_start (GTK_BOX (vbox64), alignment20, TRUE, TRUE, 0);

  hbox126 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox126, "hbox126");
  gtk_widget_ref (hbox126);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "hbox126", hbox126,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox126);
  gtk_container_add (GTK_CONTAINER (alignment20), hbox126);

  frame35 = gtk_frame_new (_("Flags"));
  gtk_widget_set_name (frame35, "frame35");
  gtk_widget_ref (frame35);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "frame35", frame35,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame35);
  gtk_box_pack_start (GTK_BOX (hbox126), frame35, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame35), 2);

  vbox65 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox65, "vbox65");
  gtk_widget_ref (vbox65);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "vbox65", vbox65,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox65);
  gtk_container_add (GTK_CONTAINER (frame35), vbox65);

  checkbutton_filter_sha1_invert_cond = gtk_check_button_new_with_label (_("invert condition"));
  gtk_widget_set_name (checkbutton_filter_sha1_invert_cond, "checkbutton_filter_sha1_invert_cond");
  gtk_widget_ref (checkbutton_filter_sha1_invert_cond);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "checkbutton_filter_sha1_invert_cond", checkbutton_filter_sha1_invert_cond,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_box_pack_start (GTK_BOX (vbox65), checkbutton_filter_sha1_invert_cond, FALSE, FALSE, 0);

  checkbutton_filter_sha1_active = gtk_check_button_new_with_label (_("active"));
  gtk_widget_set_name (checkbutton_filter_sha1_active, "checkbutton_filter_sha1_active");
  gtk_widget_ref (checkbutton_filter_sha1_active);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "checkbutton_filter_sha1_active", checkbutton_filter_sha1_active,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_filter_sha1_active);
  gtk_box_pack_start (GTK_BOX (vbox65), checkbutton_filter_sha1_active, FALSE, FALSE, 0);
  gtk_widget_set_sensitive (checkbutton_filter_sha1_active, FALSE);

  checkbutton_filter_sha1_soft = gtk_check_button_new_with_label (_("mark only"));
  gtk_widget_set_name (checkbutton_filter_sha1_soft, "checkbutton_filter_sha1_soft");
  gtk_widget_ref (checkbutton_filter_sha1_soft);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "checkbutton_filter_sha1_soft", checkbutton_filter_sha1_soft,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_box_pack_start (GTK_BOX (vbox65), checkbutton_filter_sha1_soft, FALSE, FALSE, 0);

  frame36 = gtk_frame_new (_("Condition: If urn:sha1 matches"));
  gtk_widget_set_name (frame36, "frame36");
  gtk_widget_ref (frame36);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "frame36", frame36,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame36);
  gtk_box_pack_start (GTK_BOX (hbox126), frame36, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame36), 2);

  hbox127 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox127, "hbox127");
  gtk_widget_ref (hbox127);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "hbox127", hbox127,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox127);
  gtk_container_add (GTK_CONTAINER (frame36), hbox127);

  table25 = gtk_table_new (3, 1, FALSE);
  gtk_widget_set_name (table25, "table25");
  gtk_widget_ref (table25);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "table25", table25,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table25);
  gtk_box_pack_start (GTK_BOX (hbox127), table25, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (table25), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table25), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table25), 4);

  label226 = gtk_label_new (_("SHA1 hash (not editable, add from search popup)"));
  gtk_widget_set_name (label226, "label226");
  gtk_widget_ref (label226);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "label226", label226,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label226);
  gtk_table_attach (GTK_TABLE (table25), label226, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label226), 0, 0.5);

  entry_filter_sha1_hash = gtk_entry_new ();
  gtk_widget_set_name (entry_filter_sha1_hash, "entry_filter_sha1_hash");
  gtk_widget_ref (entry_filter_sha1_hash);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "entry_filter_sha1_hash", entry_filter_sha1_hash,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_filter_sha1_hash);
  gtk_table_attach (GTK_TABLE (table25), entry_filter_sha1_hash, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_entry_set_editable (GTK_ENTRY (entry_filter_sha1_hash), FALSE);

  hbox132 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox132, "hbox132");
  gtk_widget_ref (hbox132);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "hbox132", hbox132,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox132);
  gtk_table_attach (GTK_TABLE (table25), hbox132, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  label245 = gtk_label_new (_("Originally obtained from"));
  gtk_widget_set_name (label245, "label245");
  gtk_widget_ref (label245);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "label245", label245,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label245);
  gtk_box_pack_start (GTK_BOX (hbox132), label245, FALSE, FALSE, 0);

  entry_filter_sha1_origfile = gtk_entry_new ();
  gtk_widget_set_name (entry_filter_sha1_origfile, "entry_filter_sha1_origfile");
  gtk_widget_ref (entry_filter_sha1_origfile);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "entry_filter_sha1_origfile", entry_filter_sha1_origfile,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_filter_sha1_origfile);
  gtk_box_pack_start (GTK_BOX (hbox132), entry_filter_sha1_origfile, TRUE, TRUE, 0);
  gtk_entry_set_editable (GTK_ENTRY (entry_filter_sha1_origfile), FALSE);

  hbox128 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox128, "hbox128");
  gtk_widget_ref (hbox128);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "hbox128", hbox128,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox128);
  gtk_box_pack_start (GTK_BOX (vbox64), hbox128, FALSE, FALSE, 0);

  frame37 = gtk_frame_new (_("Target"));
  gtk_widget_set_name (frame37, "frame37");
  gtk_widget_ref (frame37);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "frame37", frame37,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame37);
  gtk_box_pack_start (GTK_BOX (hbox128), frame37, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame37), 2);

  optionmenu_filter_sha1_target = gtk_option_menu_new ();
  gtk_widget_set_name (optionmenu_filter_sha1_target, "optionmenu_filter_sha1_target");
  gtk_widget_ref (optionmenu_filter_sha1_target);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "optionmenu_filter_sha1_target", optionmenu_filter_sha1_target,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (optionmenu_filter_sha1_target);
  gtk_container_add (GTK_CONTAINER (frame37), optionmenu_filter_sha1_target);
  gtk_widget_set_sensitive (optionmenu_filter_sha1_target, FALSE);
  optionmenu_filter_sha1_target_menu = gtk_menu_new ();
  glade_menuitem = gtk_menu_item_new_with_label ("");
  gtk_widget_show (glade_menuitem);
  gtk_menu_append (GTK_MENU (optionmenu_filter_sha1_target_menu), glade_menuitem);
  gtk_option_menu_set_menu (GTK_OPTION_MENU (optionmenu_filter_sha1_target), optionmenu_filter_sha1_target_menu);

  vbox66 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox66, "vbox66");
  gtk_widget_ref (vbox66);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "vbox66", vbox66,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox66);
  gtk_box_pack_start (GTK_BOX (hbox128), vbox66, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (vbox66), 2);

  hbox142 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox142, "hbox142");
  gtk_widget_ref (hbox142);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "hbox142", hbox142,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox142);
  gtk_box_pack_start (GTK_BOX (vbox66), hbox142, FALSE, TRUE, 4);
  gtk_container_set_border_width (GTK_CONTAINER (hbox142), 4);

  button10 = gtk_button_new_with_label (_("Save"));
  gtk_widget_set_name (button10, "button10");
  gtk_widget_ref (button10);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "button10", button10,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button10);
  gtk_box_pack_start (GTK_BOX (hbox142), button10, TRUE, TRUE, 0);

  button11 = gtk_button_new_with_label (_("Remove"));
  gtk_widget_set_name (button11, "button11");
  gtk_widget_ref (button11);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "button11", button11,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button11);
  gtk_box_pack_start (GTK_BOX (hbox142), button11, TRUE, TRUE, 0);

  button20 = gtk_button_new_with_label (_("Abort"));
  gtk_widget_set_name (button20, "button20");
  gtk_widget_ref (button20);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "button20", button20,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button20);
  gtk_box_pack_start (GTK_BOX (hbox142), button20, TRUE, TRUE, 0);

  vseparator14 = gtk_vseparator_new ();
  gtk_widget_set_name (vseparator14, "vseparator14");
  gtk_widget_ref (vseparator14);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "vseparator14", vseparator14,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vseparator14);
  gtk_box_pack_start (GTK_BOX (hbox142), vseparator14, TRUE, TRUE, 0);

  button_filter_sha1_reset = gtk_button_new_with_label ("");
  button_filter_sha1_reset_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (button_filter_sha1_reset)->child),
                                   _("_Reset stats"));
  gtk_widget_add_accelerator (button_filter_sha1_reset, "clicked", accel_group,
                              button_filter_sha1_reset_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (button_filter_sha1_reset, "button_filter_sha1_reset");
  gtk_widget_ref (button_filter_sha1_reset);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "button_filter_sha1_reset", button_filter_sha1_reset,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_filter_sha1_reset);
  gtk_box_pack_start (GTK_BOX (hbox142), button_filter_sha1_reset, TRUE, TRUE, 0);

  label729 = gtk_label_new (_("[SHA1]"));
  gtk_widget_set_name (label729, "label729");
  gtk_widget_ref (label729);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "label729", label729,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label729);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_filter_detail), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_filter_detail), 5), label729);

  vbox68 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox68, "vbox68");
  gtk_widget_ref (vbox68);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "vbox68", vbox68,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox68);
  gtk_container_add (GTK_CONTAINER (notebook_filter_detail), vbox68);

  alignment21 = gtk_alignment_new (0.5, 0, 1, 1);
  gtk_widget_set_name (alignment21, "alignment21");
  gtk_widget_ref (alignment21);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "alignment21", alignment21,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (alignment21);
  gtk_box_pack_start (GTK_BOX (vbox68), alignment21, TRUE, TRUE, 0);

  hbox129 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox129, "hbox129");
  gtk_widget_ref (hbox129);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "hbox129", hbox129,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox129);
  gtk_container_add (GTK_CONTAINER (alignment21), hbox129);

  frame38 = gtk_frame_new (_("Flags"));
  gtk_widget_set_name (frame38, "frame38");
  gtk_widget_ref (frame38);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "frame38", frame38,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame38);
  gtk_box_pack_start (GTK_BOX (hbox129), frame38, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame38), 2);

  vbox69 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox69, "vbox69");
  gtk_widget_ref (vbox69);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "vbox69", vbox69,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox69);
  gtk_container_add (GTK_CONTAINER (frame38), vbox69);

  checkbutton_filter_flag_active = gtk_check_button_new_with_label (_("active"));
  gtk_widget_set_name (checkbutton_filter_flag_active, "checkbutton_filter_flag_active");
  gtk_widget_ref (checkbutton_filter_flag_active);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "checkbutton_filter_flag_active", checkbutton_filter_flag_active,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_filter_flag_active);
  gtk_box_pack_start (GTK_BOX (vbox69), checkbutton_filter_flag_active, FALSE, FALSE, 0);

  checkbutton_filter_flag_soft = gtk_check_button_new_with_label (_("mark only"));
  gtk_widget_set_name (checkbutton_filter_flag_soft, "checkbutton_filter_flag_soft");
  gtk_widget_ref (checkbutton_filter_flag_soft);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "checkbutton_filter_flag_soft", checkbutton_filter_flag_soft,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_filter_flag_soft);
  gtk_box_pack_start (GTK_BOX (vbox69), checkbutton_filter_flag_soft, FALSE, FALSE, 0);

  frame39 = gtk_frame_new (_("Condition: If result has flags"));
  gtk_widget_set_name (frame39, "frame39");
  gtk_widget_ref (frame39);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "frame39", frame39,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame39);
  gtk_box_pack_start (GTK_BOX (hbox129), frame39, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame39), 2);

  hbox130 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox130, "hbox130");
  gtk_widget_ref (hbox130);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "hbox130", hbox130,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox130);
  gtk_container_add (GTK_CONTAINER (frame39), hbox130);

  table26 = gtk_table_new (3, 4, TRUE);
  gtk_widget_set_name (table26, "table26");
  gtk_widget_ref (table26);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "table26", table26,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table26);
  gtk_box_pack_start (GTK_BOX (hbox130), table26, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (table26), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table26), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table26), 4);

  label230 = gtk_label_new (_("Busy"));
  gtk_widget_set_name (label230, "label230");
  gtk_widget_ref (label230);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "label230", label230,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label230);
  gtk_table_attach (GTK_TABLE (table26), label230, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label230), 0, 0.5);

  label231 = gtk_label_new (_("Push"));
  gtk_widget_set_name (label231, "label231");
  gtk_widget_ref (label231);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "label231", label231,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label231);
  gtk_table_attach (GTK_TABLE (table26), label231, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label231), 0, 0.5);

  radiobutton_filter_flag_busy_unset = gtk_radio_button_new (filter_busy_group_group);
  filter_busy_group_group = gtk_radio_button_group (GTK_RADIO_BUTTON (radiobutton_filter_flag_busy_unset));
  gtk_widget_set_name (radiobutton_filter_flag_busy_unset, "radiobutton_filter_flag_busy_unset");
  gtk_widget_ref (radiobutton_filter_flag_busy_unset);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "radiobutton_filter_flag_busy_unset", radiobutton_filter_flag_busy_unset,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (radiobutton_filter_flag_busy_unset);
  gtk_table_attach (GTK_TABLE (table26), radiobutton_filter_flag_busy_unset, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (radiobutton_filter_flag_busy_unset), FALSE);

  label241 = gtk_label_new (_("unset"));
  gtk_widget_set_name (label241, "label241");
  gtk_widget_ref (label241);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "label241", label241,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label241);
  gtk_container_add (GTK_CONTAINER (radiobutton_filter_flag_busy_unset), label241);

  radiobutton_filter_flag_busy_ignore = gtk_radio_button_new (filter_busy_group_group);
  filter_busy_group_group = gtk_radio_button_group (GTK_RADIO_BUTTON (radiobutton_filter_flag_busy_ignore));
  gtk_widget_set_name (radiobutton_filter_flag_busy_ignore, "radiobutton_filter_flag_busy_ignore");
  gtk_widget_ref (radiobutton_filter_flag_busy_ignore);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "radiobutton_filter_flag_busy_ignore", radiobutton_filter_flag_busy_ignore,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (radiobutton_filter_flag_busy_ignore);
  gtk_table_attach (GTK_TABLE (table26), radiobutton_filter_flag_busy_ignore, 3, 4, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (radiobutton_filter_flag_busy_ignore), FALSE);

  label242 = gtk_label_new (_("ignored"));
  gtk_widget_set_name (label242, "label242");
  gtk_widget_ref (label242);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "label242", label242,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label242);
  gtk_container_add (GTK_CONTAINER (radiobutton_filter_flag_busy_ignore), label242);

  radiobutton_filter_flag_push_ignore = gtk_radio_button_new (filter_push_group_group);
  filter_push_group_group = gtk_radio_button_group (GTK_RADIO_BUTTON (radiobutton_filter_flag_push_ignore));
  gtk_widget_set_name (radiobutton_filter_flag_push_ignore, "radiobutton_filter_flag_push_ignore");
  gtk_widget_ref (radiobutton_filter_flag_push_ignore);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "radiobutton_filter_flag_push_ignore", radiobutton_filter_flag_push_ignore,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (radiobutton_filter_flag_push_ignore);
  gtk_table_attach (GTK_TABLE (table26), radiobutton_filter_flag_push_ignore, 3, 4, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (radiobutton_filter_flag_push_ignore), FALSE);

  label243 = gtk_label_new (_("ignored"));
  gtk_widget_set_name (label243, "label243");
  gtk_widget_ref (label243);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "label243", label243,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label243);
  gtk_container_add (GTK_CONTAINER (radiobutton_filter_flag_push_ignore), label243);

  radiobutton_filter_flag_push_unset = gtk_radio_button_new (filter_push_group_group);
  filter_push_group_group = gtk_radio_button_group (GTK_RADIO_BUTTON (radiobutton_filter_flag_push_unset));
  gtk_widget_set_name (radiobutton_filter_flag_push_unset, "radiobutton_filter_flag_push_unset");
  gtk_widget_ref (radiobutton_filter_flag_push_unset);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "radiobutton_filter_flag_push_unset", radiobutton_filter_flag_push_unset,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (radiobutton_filter_flag_push_unset);
  gtk_table_attach (GTK_TABLE (table26), radiobutton_filter_flag_push_unset, 2, 3, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (radiobutton_filter_flag_push_unset), FALSE);

  label240 = gtk_label_new (_("unset"));
  gtk_widget_set_name (label240, "label240");
  gtk_widget_ref (label240);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "label240", label240,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label240);
  gtk_container_add (GTK_CONTAINER (radiobutton_filter_flag_push_unset), label240);

  radiobutton_filter_flag_push_set = gtk_radio_button_new (filter_push_group_group);
  filter_push_group_group = gtk_radio_button_group (GTK_RADIO_BUTTON (radiobutton_filter_flag_push_set));
  gtk_widget_set_name (radiobutton_filter_flag_push_set, "radiobutton_filter_flag_push_set");
  gtk_widget_ref (radiobutton_filter_flag_push_set);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "radiobutton_filter_flag_push_set", radiobutton_filter_flag_push_set,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (radiobutton_filter_flag_push_set);
  gtk_table_attach (GTK_TABLE (table26), radiobutton_filter_flag_push_set, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (radiobutton_filter_flag_push_set), FALSE);

  label237 = gtk_label_new (_("set"));
  gtk_widget_set_name (label237, "label237");
  gtk_widget_ref (label237);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "label237", label237,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label237);
  gtk_container_add (GTK_CONTAINER (radiobutton_filter_flag_push_set), label237);

  radiobutton_filter_flag_busy_set = gtk_radio_button_new (filter_busy_group_group);
  filter_busy_group_group = gtk_radio_button_group (GTK_RADIO_BUTTON (radiobutton_filter_flag_busy_set));
  gtk_widget_set_name (radiobutton_filter_flag_busy_set, "radiobutton_filter_flag_busy_set");
  gtk_widget_ref (radiobutton_filter_flag_busy_set);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "radiobutton_filter_flag_busy_set", radiobutton_filter_flag_busy_set,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (radiobutton_filter_flag_busy_set);
  gtk_table_attach (GTK_TABLE (table26), radiobutton_filter_flag_busy_set, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND), 0, 0);
  gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (radiobutton_filter_flag_busy_set), FALSE);

  label236 = gtk_label_new (_("set"));
  gtk_widget_set_name (label236, "label236");
  gtk_widget_ref (label236);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "label236", label236,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label236);
  gtk_container_add (GTK_CONTAINER (radiobutton_filter_flag_busy_set), label236);

  label232 = gtk_label_new (_("Stable"));
  gtk_widget_set_name (label232, "label232");
  gtk_widget_ref (label232);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "label232", label232,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label232);
  gtk_table_attach (GTK_TABLE (table26), label232, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label232), 0, 0.5);

  radiobutton_filter_flag_stable_set = gtk_radio_button_new (filter_stable_group_group);
  filter_stable_group_group = gtk_radio_button_group (GTK_RADIO_BUTTON (radiobutton_filter_flag_stable_set));
  gtk_widget_set_name (radiobutton_filter_flag_stable_set, "radiobutton_filter_flag_stable_set");
  gtk_widget_ref (radiobutton_filter_flag_stable_set);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "radiobutton_filter_flag_stable_set", radiobutton_filter_flag_stable_set,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (radiobutton_filter_flag_stable_set);
  gtk_table_attach (GTK_TABLE (table26), radiobutton_filter_flag_stable_set, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (radiobutton_filter_flag_stable_set), FALSE);

  label238 = gtk_label_new (_("set"));
  gtk_widget_set_name (label238, "label238");
  gtk_widget_ref (label238);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "label238", label238,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label238);
  gtk_container_add (GTK_CONTAINER (radiobutton_filter_flag_stable_set), label238);

  radiobutton_filter_flag_stable_unset = gtk_radio_button_new (filter_stable_group_group);
  filter_stable_group_group = gtk_radio_button_group (GTK_RADIO_BUTTON (radiobutton_filter_flag_stable_unset));
  gtk_widget_set_name (radiobutton_filter_flag_stable_unset, "radiobutton_filter_flag_stable_unset");
  gtk_widget_ref (radiobutton_filter_flag_stable_unset);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "radiobutton_filter_flag_stable_unset", radiobutton_filter_flag_stable_unset,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (radiobutton_filter_flag_stable_unset);
  gtk_table_attach (GTK_TABLE (table26), radiobutton_filter_flag_stable_unset, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (radiobutton_filter_flag_stable_unset), FALSE);

  label239 = gtk_label_new (_("unset"));
  gtk_widget_set_name (label239, "label239");
  gtk_widget_ref (label239);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "label239", label239,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label239);
  gtk_container_add (GTK_CONTAINER (radiobutton_filter_flag_stable_unset), label239);

  radiobutton_filter_flag_stable_ignore = gtk_radio_button_new (filter_stable_group_group);
  filter_stable_group_group = gtk_radio_button_group (GTK_RADIO_BUTTON (radiobutton_filter_flag_stable_ignore));
  gtk_widget_set_name (radiobutton_filter_flag_stable_ignore, "radiobutton_filter_flag_stable_ignore");
  gtk_widget_ref (radiobutton_filter_flag_stable_ignore);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "radiobutton_filter_flag_stable_ignore", radiobutton_filter_flag_stable_ignore,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (radiobutton_filter_flag_stable_ignore);
  gtk_table_attach (GTK_TABLE (table26), radiobutton_filter_flag_stable_ignore, 3, 4, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (radiobutton_filter_flag_stable_ignore), FALSE);

  label244 = gtk_label_new (_("ignored"));
  gtk_widget_set_name (label244, "label244");
  gtk_widget_ref (label244);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "label244", label244,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label244);
  gtk_container_add (GTK_CONTAINER (radiobutton_filter_flag_stable_ignore), label244);

  hbox131 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox131, "hbox131");
  gtk_widget_ref (hbox131);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "hbox131", hbox131,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox131);
  gtk_box_pack_start (GTK_BOX (vbox68), hbox131, FALSE, FALSE, 0);

  frame40 = gtk_frame_new (_("Target"));
  gtk_widget_set_name (frame40, "frame40");
  gtk_widget_ref (frame40);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "frame40", frame40,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame40);
  gtk_box_pack_start (GTK_BOX (hbox131), frame40, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame40), 2);

  optionmenu_filter_flag_target = gtk_option_menu_new ();
  gtk_widget_set_name (optionmenu_filter_flag_target, "optionmenu_filter_flag_target");
  gtk_widget_ref (optionmenu_filter_flag_target);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "optionmenu_filter_flag_target", optionmenu_filter_flag_target,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (optionmenu_filter_flag_target);
  gtk_container_add (GTK_CONTAINER (frame40), optionmenu_filter_flag_target);
  optionmenu_filter_flag_target_menu = gtk_menu_new ();
  glade_menuitem = gtk_menu_item_new_with_label ("");
  gtk_widget_show (glade_menuitem);
  gtk_menu_append (GTK_MENU (optionmenu_filter_flag_target_menu), glade_menuitem);
  gtk_option_menu_set_menu (GTK_OPTION_MENU (optionmenu_filter_flag_target), optionmenu_filter_flag_target_menu);

  vbox70 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox70, "vbox70");
  gtk_widget_ref (vbox70);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "vbox70", vbox70,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox70);
  gtk_box_pack_start (GTK_BOX (hbox131), vbox70, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (vbox70), 2);

  hbox143 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox143, "hbox143");
  gtk_widget_ref (hbox143);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "hbox143", hbox143,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox143);
  gtk_box_pack_start (GTK_BOX (vbox70), hbox143, FALSE, TRUE, 4);
  gtk_container_set_border_width (GTK_CONTAINER (hbox143), 4);

  button12 = gtk_button_new_with_label (_("Save"));
  gtk_widget_set_name (button12, "button12");
  gtk_widget_ref (button12);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "button12", button12,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button12);
  gtk_box_pack_start (GTK_BOX (hbox143), button12, TRUE, TRUE, 0);

  button13 = gtk_button_new_with_label (_("Remove"));
  gtk_widget_set_name (button13, "button13");
  gtk_widget_ref (button13);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "button13", button13,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button13);
  gtk_box_pack_start (GTK_BOX (hbox143), button13, TRUE, TRUE, 0);

  button21 = gtk_button_new_with_label (_("Abort"));
  gtk_widget_set_name (button21, "button21");
  gtk_widget_ref (button21);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "button21", button21,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button21);
  gtk_box_pack_start (GTK_BOX (hbox143), button21, TRUE, TRUE, 0);

  vseparator8 = gtk_vseparator_new ();
  gtk_widget_set_name (vseparator8, "vseparator8");
  gtk_widget_ref (vseparator8);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "vseparator8", vseparator8,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vseparator8);
  gtk_box_pack_start (GTK_BOX (hbox143), vseparator8, TRUE, TRUE, 0);

  button_filter_flag_reset = gtk_button_new_with_label ("");
  button_filter_flag_reset_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (button_filter_flag_reset)->child),
                                   _("_Reset stats"));
  gtk_widget_add_accelerator (button_filter_flag_reset, "clicked", accel_group,
                              button_filter_flag_reset_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (button_filter_flag_reset, "button_filter_flag_reset");
  gtk_widget_ref (button_filter_flag_reset);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "button_filter_flag_reset", button_filter_flag_reset,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_filter_flag_reset);
  gtk_box_pack_start (GTK_BOX (hbox143), button_filter_flag_reset, TRUE, TRUE, 0);

  label730 = gtk_label_new (_("[Flags]"));
  gtk_widget_set_name (label730, "label730");
  gtk_widget_ref (label730);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "label730", label730,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label730);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_filter_detail), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_filter_detail), 6), label730);

  vbox71 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox71, "vbox71");
  gtk_widget_ref (vbox71);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "vbox71", vbox71,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox71);
  gtk_container_add (GTK_CONTAINER (notebook_filter_detail), vbox71);

  alignment22 = gtk_alignment_new (0.5, 0, 1, 1);
  gtk_widget_set_name (alignment22, "alignment22");
  gtk_widget_ref (alignment22);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "alignment22", alignment22,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (alignment22);
  gtk_box_pack_start (GTK_BOX (vbox71), alignment22, TRUE, TRUE, 0);

  hbox133 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox133, "hbox133");
  gtk_widget_ref (hbox133);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "hbox133", hbox133,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox133);
  gtk_container_add (GTK_CONTAINER (alignment22), hbox133);

  frame41 = gtk_frame_new (_("Flags"));
  gtk_widget_set_name (frame41, "frame41");
  gtk_widget_ref (frame41);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "frame41", frame41,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame41);
  gtk_box_pack_start (GTK_BOX (hbox133), frame41, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame41), 2);

  vbox74 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox74, "vbox74");
  gtk_widget_ref (vbox74);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "vbox74", vbox74,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox74);
  gtk_container_add (GTK_CONTAINER (frame41), vbox74);

  checkbutton_filter_state_invert_cond = gtk_check_button_new_with_label (_("invert condition"));
  gtk_widget_set_name (checkbutton_filter_state_invert_cond, "checkbutton_filter_state_invert_cond");
  gtk_widget_ref (checkbutton_filter_state_invert_cond);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "checkbutton_filter_state_invert_cond", checkbutton_filter_state_invert_cond,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_filter_state_invert_cond);
  gtk_box_pack_start (GTK_BOX (vbox74), checkbutton_filter_state_invert_cond, FALSE, FALSE, 0);

  checkbutton_filter_state_active = gtk_check_button_new_with_label (_("active"));
  gtk_widget_set_name (checkbutton_filter_state_active, "checkbutton_filter_state_active");
  gtk_widget_ref (checkbutton_filter_state_active);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "checkbutton_filter_state_active", checkbutton_filter_state_active,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_filter_state_active);
  gtk_box_pack_start (GTK_BOX (vbox74), checkbutton_filter_state_active, FALSE, FALSE, 0);

  checkbutton_filter_state_soft = gtk_check_button_new_with_label (_("mark only"));
  gtk_widget_set_name (checkbutton_filter_state_soft, "checkbutton_filter_state_soft");
  gtk_widget_ref (checkbutton_filter_state_soft);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "checkbutton_filter_state_soft", checkbutton_filter_state_soft,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_filter_state_soft);
  gtk_box_pack_start (GTK_BOX (vbox74), checkbutton_filter_state_soft, FALSE, FALSE, 0);

  frame42 = gtk_frame_new (_("Condition: If current filter result properties match"));
  gtk_widget_set_name (frame42, "frame42");
  gtk_widget_ref (frame42);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "frame42", frame42,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame42);
  gtk_box_pack_start (GTK_BOX (hbox133), frame42, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame42), 2);

  alignment23 = gtk_alignment_new (0, 0, 1, 0);
  gtk_widget_set_name (alignment23, "alignment23");
  gtk_widget_ref (alignment23);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "alignment23", alignment23,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (alignment23);
  gtk_container_add (GTK_CONTAINER (frame42), alignment23);

  table27 = gtk_table_new (2, 5, FALSE);
  gtk_widget_set_name (table27, "table27");
  gtk_widget_ref (table27);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "table27", table27,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table27);
  gtk_container_add (GTK_CONTAINER (alignment23), table27);
  gtk_container_set_border_width (GTK_CONTAINER (table27), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table27), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table27), 4);

  label249 = gtk_label_new (_("DOWNLOAD"));
  gtk_widget_set_name (label249, "label249");
  gtk_widget_ref (label249);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "label249", label249,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label249);
  gtk_table_attach (GTK_TABLE (table27), label249, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label249), 0, 0.5);

  radiobutton_filter_state_download_dont = gtk_radio_button_new (filter_download_group_group);
  filter_download_group_group = gtk_radio_button_group (GTK_RADIO_BUTTON (radiobutton_filter_state_download_dont));
  gtk_widget_set_name (radiobutton_filter_state_download_dont, "radiobutton_filter_state_download_dont");
  gtk_widget_ref (radiobutton_filter_state_download_dont);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "radiobutton_filter_state_download_dont", radiobutton_filter_state_download_dont,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (radiobutton_filter_state_download_dont);
  gtk_table_attach (GTK_TABLE (table27), radiobutton_filter_state_download_dont, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (radiobutton_filter_state_download_dont), FALSE);

  label251 = gtk_label_new (_("don't"));
  gtk_widget_set_name (label251, "label251");
  gtk_widget_ref (label251);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "label251", label251,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label251);
  gtk_container_add (GTK_CONTAINER (radiobutton_filter_state_download_dont), label251);

  radiobutton_filter_state_download_undef = gtk_radio_button_new (filter_download_group_group);
  filter_download_group_group = gtk_radio_button_group (GTK_RADIO_BUTTON (radiobutton_filter_state_download_undef));
  gtk_widget_set_name (radiobutton_filter_state_download_undef, "radiobutton_filter_state_download_undef");
  gtk_widget_ref (radiobutton_filter_state_download_undef);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "radiobutton_filter_state_download_undef", radiobutton_filter_state_download_undef,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (radiobutton_filter_state_download_undef);
  gtk_table_attach (GTK_TABLE (table27), radiobutton_filter_state_download_undef, 3, 4, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (radiobutton_filter_state_download_undef), FALSE);

  label252 = gtk_label_new (_("undefined"));
  gtk_widget_set_name (label252, "label252");
  gtk_widget_ref (label252);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "label252", label252,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label252);
  gtk_container_add (GTK_CONTAINER (radiobutton_filter_state_download_undef), label252);

  label257 = gtk_label_new (_("DISPLAY"));
  gtk_widget_set_name (label257, "label257");
  gtk_widget_ref (label257);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "label257", label257,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label257);
  gtk_table_attach (GTK_TABLE (table27), label257, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label257), 0, 0.5);

  radiobutton_filter_state_download_do = gtk_radio_button_new (filter_download_group_group);
  filter_download_group_group = gtk_radio_button_group (GTK_RADIO_BUTTON (radiobutton_filter_state_download_do));
  gtk_widget_set_name (radiobutton_filter_state_download_do, "radiobutton_filter_state_download_do");
  gtk_widget_ref (radiobutton_filter_state_download_do);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "radiobutton_filter_state_download_do", radiobutton_filter_state_download_do,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (radiobutton_filter_state_download_do);
  gtk_table_attach (GTK_TABLE (table27), radiobutton_filter_state_download_do, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (radiobutton_filter_state_download_do), FALSE);

  label256 = gtk_label_new (_("do"));
  gtk_widget_set_name (label256, "label256");
  gtk_widget_ref (label256);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "label256", label256,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label256);
  gtk_container_add (GTK_CONTAINER (radiobutton_filter_state_download_do), label256);

  radiobutton_filter_state_display_do = gtk_radio_button_new (filter_display_group_group);
  filter_display_group_group = gtk_radio_button_group (GTK_RADIO_BUTTON (radiobutton_filter_state_display_do));
  gtk_widget_set_name (radiobutton_filter_state_display_do, "radiobutton_filter_state_display_do");
  gtk_widget_ref (radiobutton_filter_state_display_do);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "radiobutton_filter_state_display_do", radiobutton_filter_state_display_do,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (radiobutton_filter_state_display_do);
  gtk_table_attach (GTK_TABLE (table27), radiobutton_filter_state_display_do, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (radiobutton_filter_state_display_do), FALSE);

  label258 = gtk_label_new (_("do"));
  gtk_widget_set_name (label258, "label258");
  gtk_widget_ref (label258);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "label258", label258,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label258);
  gtk_container_add (GTK_CONTAINER (radiobutton_filter_state_display_do), label258);

  radiobutton_filter_state_display_dont = gtk_radio_button_new (filter_display_group_group);
  filter_display_group_group = gtk_radio_button_group (GTK_RADIO_BUTTON (radiobutton_filter_state_display_dont));
  gtk_widget_set_name (radiobutton_filter_state_display_dont, "radiobutton_filter_state_display_dont");
  gtk_widget_ref (radiobutton_filter_state_display_dont);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "radiobutton_filter_state_display_dont", radiobutton_filter_state_display_dont,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (radiobutton_filter_state_display_dont);
  gtk_table_attach (GTK_TABLE (table27), radiobutton_filter_state_display_dont, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (radiobutton_filter_state_display_dont), FALSE);

  label259 = gtk_label_new (_("don't"));
  gtk_widget_set_name (label259, "label259");
  gtk_widget_ref (label259);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "label259", label259,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label259);
  gtk_container_add (GTK_CONTAINER (radiobutton_filter_state_display_dont), label259);

  radiobutton_filter_state_display_undef = gtk_radio_button_new (filter_display_group_group);
  filter_display_group_group = gtk_radio_button_group (GTK_RADIO_BUTTON (radiobutton_filter_state_display_undef));
  gtk_widget_set_name (radiobutton_filter_state_display_undef, "radiobutton_filter_state_display_undef");
  gtk_widget_ref (radiobutton_filter_state_display_undef);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "radiobutton_filter_state_display_undef", radiobutton_filter_state_display_undef,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (radiobutton_filter_state_display_undef);
  gtk_table_attach (GTK_TABLE (table27), radiobutton_filter_state_display_undef, 3, 4, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (radiobutton_filter_state_display_undef), FALSE);

  label260 = gtk_label_new (_("undefined"));
  gtk_widget_set_name (label260, "label260");
  gtk_widget_ref (label260);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "label260", label260,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label260);
  gtk_container_add (GTK_CONTAINER (radiobutton_filter_state_display_undef), label260);

  radiobutton_filter_state_display_ignore = gtk_radio_button_new (filter_display_group_group);
  filter_display_group_group = gtk_radio_button_group (GTK_RADIO_BUTTON (radiobutton_filter_state_display_ignore));
  gtk_widget_set_name (radiobutton_filter_state_display_ignore, "radiobutton_filter_state_display_ignore");
  gtk_widget_ref (radiobutton_filter_state_display_ignore);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "radiobutton_filter_state_display_ignore", radiobutton_filter_state_display_ignore,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (radiobutton_filter_state_display_ignore);
  gtk_table_attach (GTK_TABLE (table27), radiobutton_filter_state_display_ignore, 4, 5, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (radiobutton_filter_state_display_ignore), FALSE);

  label261 = gtk_label_new (_("ignore"));
  gtk_widget_set_name (label261, "label261");
  gtk_widget_ref (label261);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "label261", label261,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label261);
  gtk_container_add (GTK_CONTAINER (radiobutton_filter_state_display_ignore), label261);

  radiobutton_filter_state_download_ignore = gtk_radio_button_new (filter_download_group_group);
  filter_download_group_group = gtk_radio_button_group (GTK_RADIO_BUTTON (radiobutton_filter_state_download_ignore));
  gtk_widget_set_name (radiobutton_filter_state_download_ignore, "radiobutton_filter_state_download_ignore");
  gtk_widget_ref (radiobutton_filter_state_download_ignore);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "radiobutton_filter_state_download_ignore", radiobutton_filter_state_download_ignore,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (radiobutton_filter_state_download_ignore);
  gtk_table_attach (GTK_TABLE (table27), radiobutton_filter_state_download_ignore, 4, 5, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (radiobutton_filter_state_download_ignore), FALSE);

  label262 = gtk_label_new (_("ignore"));
  gtk_widget_set_name (label262, "label262");
  gtk_widget_ref (label262);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "label262", label262,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label262);
  gtk_container_add (GTK_CONTAINER (radiobutton_filter_state_download_ignore), label262);

  hbox136 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox136, "hbox136");
  gtk_widget_ref (hbox136);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "hbox136", hbox136,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox136);
  gtk_box_pack_start (GTK_BOX (vbox71), hbox136, FALSE, TRUE, 0);

  frame43 = gtk_frame_new (_("Target"));
  gtk_widget_set_name (frame43, "frame43");
  gtk_widget_ref (frame43);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "frame43", frame43,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame43);
  gtk_box_pack_start (GTK_BOX (hbox136), frame43, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame43), 2);

  optionmenu_filter_state_target = gtk_option_menu_new ();
  gtk_widget_set_name (optionmenu_filter_state_target, "optionmenu_filter_state_target");
  gtk_widget_ref (optionmenu_filter_state_target);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "optionmenu_filter_state_target", optionmenu_filter_state_target,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (optionmenu_filter_state_target);
  gtk_container_add (GTK_CONTAINER (frame43), optionmenu_filter_state_target);
  optionmenu_filter_state_target_menu = gtk_menu_new ();
  glade_menuitem = gtk_menu_item_new_with_label ("");
  gtk_widget_show (glade_menuitem);
  gtk_menu_append (GTK_MENU (optionmenu_filter_state_target_menu), glade_menuitem);
  gtk_option_menu_set_menu (GTK_OPTION_MENU (optionmenu_filter_state_target), optionmenu_filter_state_target_menu);

  vbox73 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox73, "vbox73");
  gtk_widget_ref (vbox73);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "vbox73", vbox73,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox73);
  gtk_box_pack_start (GTK_BOX (hbox136), vbox73, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (vbox73), 2);

  hbox144 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox144, "hbox144");
  gtk_widget_ref (hbox144);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "hbox144", hbox144,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox144);
  gtk_box_pack_start (GTK_BOX (vbox73), hbox144, FALSE, TRUE, 4);
  gtk_container_set_border_width (GTK_CONTAINER (hbox144), 4);

  button14 = gtk_button_new_with_label (_("Save"));
  gtk_widget_set_name (button14, "button14");
  gtk_widget_ref (button14);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "button14", button14,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button14);
  gtk_box_pack_start (GTK_BOX (hbox144), button14, TRUE, TRUE, 0);

  button15 = gtk_button_new_with_label (_("Remove"));
  gtk_widget_set_name (button15, "button15");
  gtk_widget_ref (button15);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "button15", button15,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button15);
  gtk_box_pack_start (GTK_BOX (hbox144), button15, TRUE, TRUE, 0);

  button22 = gtk_button_new_with_label (_("Abort"));
  gtk_widget_set_name (button22, "button22");
  gtk_widget_ref (button22);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "button22", button22,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button22);
  gtk_box_pack_start (GTK_BOX (hbox144), button22, TRUE, TRUE, 0);

  vseparator9 = gtk_vseparator_new ();
  gtk_widget_set_name (vseparator9, "vseparator9");
  gtk_widget_ref (vseparator9);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "vseparator9", vseparator9,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vseparator9);
  gtk_box_pack_start (GTK_BOX (hbox144), vseparator9, TRUE, TRUE, 0);

  button_filter_state_reset = gtk_button_new_with_label ("");
  button_filter_state_reset_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (button_filter_state_reset)->child),
                                   _("_Reset stats"));
  gtk_widget_add_accelerator (button_filter_state_reset, "clicked", accel_group,
                              button_filter_state_reset_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (button_filter_state_reset, "button_filter_state_reset");
  gtk_widget_ref (button_filter_state_reset);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "button_filter_state_reset", button_filter_state_reset,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_filter_state_reset);
  gtk_box_pack_start (GTK_BOX (hbox144), button_filter_state_reset, TRUE, TRUE, 0);

  label731 = gtk_label_new (_("[State]"));
  gtk_widget_set_name (label731, "label731");
  gtk_widget_ref (label731);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "label731", label731,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label731);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_filter_detail), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_filter_detail), 7), label731);

  hseparator5 = gtk_hseparator_new ();
  gtk_widget_set_name (hseparator5, "hseparator5");
  gtk_widget_ref (hseparator5);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "hseparator5", hseparator5,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hseparator5);
  gtk_box_pack_start (GTK_BOX (vbox_filter_main), hseparator5, FALSE, TRUE, 4);

  hbox103 = gtk_hbox_new (TRUE, 4);
  gtk_widget_set_name (hbox103, "hbox103");
  gtk_widget_ref (hbox103);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "hbox103", hbox103,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox103);
  gtk_box_pack_start (GTK_BOX (vbox_filter_main), hbox103, FALSE, TRUE, 0);

  button_filter_apply = gtk_button_new_with_label (_("Apply"));
  gtk_widget_set_name (button_filter_apply, "button_filter_apply");
  gtk_widget_ref (button_filter_apply);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "button_filter_apply", button_filter_apply,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_filter_apply);
  gtk_box_pack_start (GTK_BOX (hbox103), button_filter_apply, FALSE, TRUE, 0);
  GTK_WIDGET_SET_FLAGS (button_filter_apply, GTK_CAN_DEFAULT);

  button_filter_revert = gtk_button_new_with_label (_("Revert"));
  gtk_widget_set_name (button_filter_revert, "button_filter_revert");
  gtk_widget_ref (button_filter_revert);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "button_filter_revert", button_filter_revert,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_filter_revert);
  gtk_box_pack_start (GTK_BOX (hbox103), button_filter_revert, FALSE, TRUE, 0);
  GTK_WIDGET_SET_FLAGS (button_filter_revert, GTK_CAN_DEFAULT);

  button_filter_ok = gtk_button_new_with_label (_("Ok"));
  gtk_widget_set_name (button_filter_ok, "button_filter_ok");
  gtk_widget_ref (button_filter_ok);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "button_filter_ok", button_filter_ok,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_filter_ok);
  gtk_box_pack_start (GTK_BOX (hbox103), button_filter_ok, FALSE, TRUE, 0);
  GTK_WIDGET_SET_FLAGS (button_filter_ok, GTK_CAN_DEFAULT);

  button_filter_cancel = gtk_button_new_with_label (_("Cancel"));
  gtk_widget_set_name (button_filter_cancel, "button_filter_cancel");
  gtk_widget_ref (button_filter_cancel);
  gtk_object_set_data_full (GTK_OBJECT (dlg_filters), "button_filter_cancel", button_filter_cancel,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_filter_cancel);
  gtk_box_pack_start (GTK_BOX (hbox103), button_filter_cancel, FALSE, TRUE, 0);
  GTK_WIDGET_SET_FLAGS (button_filter_cancel, GTK_CAN_DEFAULT);

  gtk_signal_connect (GTK_OBJECT (dlg_filters), "delete_event",
                      GTK_SIGNAL_FUNC (on_dlg_filters_delete_event),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (entry_filter_new), "activate",
                      GTK_SIGNAL_FUNC (on_entry_filter_new_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button_filter_create), "clicked",
                      GTK_SIGNAL_FUNC (on_button_filter_create_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (ctree_filter_filters), "tree_select_row",
                      GTK_SIGNAL_FUNC (on_ctree_filter_filters_tree_select_row),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (checkbutton_filter_enabled), "toggled",
                      GTK_SIGNAL_FUNC (on_checkbutton_filter_enabled_toggled),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button_filter_remove), "clicked",
                      GTK_SIGNAL_FUNC (on_button_filter_remove_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (clist_filter_rules), "unselect_row",
                      GTK_SIGNAL_FUNC (on_clist_filter_rules_unselect_row),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (clist_filter_rules), "drag_end",
                      GTK_SIGNAL_FUNC (on_clist_filter_rules_drag_end),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (clist_filter_rules), "select_row",
                      GTK_SIGNAL_FUNC (on_clist_filter_rules_select_row),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (clist_filter_rules), "button_press_event",
                      GTK_SIGNAL_FUNC (on_clist_filter_rules_button_press_event),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button_filter_clear), "clicked",
                      GTK_SIGNAL_FUNC (on_button_filter_clear_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button_filter_reset_all_rules), "clicked",
                      GTK_SIGNAL_FUNC (on_button_filter_reset_all_rules_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button_filter_reset), "clicked",
                      GTK_SIGNAL_FUNC (on_button_filter_reset_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button_filter_reset_all), "clicked",
                      GTK_SIGNAL_FUNC (on_button_filter_reset_all_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button_filter_add_rule_text), "clicked",
                      GTK_SIGNAL_FUNC (on_button_filter_add_rule_text_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button_filter_add_rule_size), "clicked",
                      GTK_SIGNAL_FUNC (on_button_filter_add_rule_size_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button_filter_add_rule_flag), "clicked",
                      GTK_SIGNAL_FUNC (on_button_filter_add_rule_flag_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button_filter_add_rule_jump), "clicked",
                      GTK_SIGNAL_FUNC (on_button_filter_add_rule_jump_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button_filter_add_rule_ip), "clicked",
                      GTK_SIGNAL_FUNC (on_button_filter_add_rule_ip_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button_filter_add_rule_state), "clicked",
                      GTK_SIGNAL_FUNC (on_button_filter_add_rule_state_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button_filter_text_add), "clicked",
                      GTK_SIGNAL_FUNC (on_button_filter_add_rule_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button_filter_text_remove), "clicked",
                      GTK_SIGNAL_FUNC (on_button_filter_remove_rule_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button16), "clicked",
                      GTK_SIGNAL_FUNC (on_button_filter_abort_rule_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button_filter_text_reset), "clicked",
                      GTK_SIGNAL_FUNC (on_button_filter_reset_rule_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button4), "clicked",
                      GTK_SIGNAL_FUNC (on_button_filter_add_rule_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button5), "clicked",
                      GTK_SIGNAL_FUNC (on_button_filter_remove_rule_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button17), "clicked",
                      GTK_SIGNAL_FUNC (on_button_filter_abort_rule_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button_filter_ip_reset), "clicked",
                      GTK_SIGNAL_FUNC (on_button_filter_reset_rule_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (entry_filter_size_min), "focus_out_event",
                      GTK_SIGNAL_FUNC (on_entry_filter_size_focus_out_event),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (entry_filter_size_min), "key_press_event",
                      GTK_SIGNAL_FUNC (on_entry_filter_size_key_press_event),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (entry_filter_size_max), "focus_out_event",
                      GTK_SIGNAL_FUNC (on_entry_filter_size_focus_out_event),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (entry_filter_size_max), "key_press_event",
                      GTK_SIGNAL_FUNC (on_entry_filter_size_key_press_event),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button6), "clicked",
                      GTK_SIGNAL_FUNC (on_button_filter_add_rule_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button7), "clicked",
                      GTK_SIGNAL_FUNC (on_button_filter_remove_rule_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button18), "clicked",
                      GTK_SIGNAL_FUNC (on_button_filter_abort_rule_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button_filter_size_reset), "clicked",
                      GTK_SIGNAL_FUNC (on_button_filter_reset_rule_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button8), "clicked",
                      GTK_SIGNAL_FUNC (on_button_filter_add_rule_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button9), "clicked",
                      GTK_SIGNAL_FUNC (on_button_filter_remove_rule_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button19), "clicked",
                      GTK_SIGNAL_FUNC (on_button_filter_abort_rule_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button_filter_jump_reset), "clicked",
                      GTK_SIGNAL_FUNC (on_button_filter_reset_rule_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button10), "clicked",
                      GTK_SIGNAL_FUNC (on_button_filter_add_rule_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button11), "clicked",
                      GTK_SIGNAL_FUNC (on_button_filter_remove_rule_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button20), "clicked",
                      GTK_SIGNAL_FUNC (on_button_filter_abort_rule_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button_filter_sha1_reset), "clicked",
                      GTK_SIGNAL_FUNC (on_button_filter_reset_rule_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button12), "clicked",
                      GTK_SIGNAL_FUNC (on_button_filter_add_rule_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button13), "clicked",
                      GTK_SIGNAL_FUNC (on_button_filter_remove_rule_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button21), "clicked",
                      GTK_SIGNAL_FUNC (on_button_filter_abort_rule_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button_filter_flag_reset), "clicked",
                      GTK_SIGNAL_FUNC (on_button_filter_reset_rule_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button14), "clicked",
                      GTK_SIGNAL_FUNC (on_button_filter_add_rule_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button15), "clicked",
                      GTK_SIGNAL_FUNC (on_button_filter_remove_rule_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button22), "clicked",
                      GTK_SIGNAL_FUNC (on_button_filter_abort_rule_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button_filter_state_reset), "clicked",
                      GTK_SIGNAL_FUNC (on_button_filter_reset_rule_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button_filter_apply), "clicked",
                      GTK_SIGNAL_FUNC (on_button_filter_apply_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button_filter_revert), "clicked",
                      GTK_SIGNAL_FUNC (on_button_filter_revert_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button_filter_ok), "clicked",
                      GTK_SIGNAL_FUNC (on_button_filter_ok_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button_filter_cancel), "clicked",
                      GTK_SIGNAL_FUNC (on_button_filter_cancel_clicked),
                      NULL);

  gtk_widget_grab_default (button_filter_ok);
  gtk_object_set_data (GTK_OBJECT (dlg_filters), "tooltips", tooltips);

  gtk_window_add_accel_group (GTK_WINDOW (dlg_filters), accel_group);

  return dlg_filters;
}

GtkWidget*
create_shutdown_window (void)
{
  GtkWidget *shutdown_window;
  GtkWidget *frame30;
  GtkWidget *vbox44;
  GtkWidget *label184;
  GtkWidget *label_shutdown_count;

  shutdown_window = gtk_window_new (GTK_WINDOW_DIALOG);
  gtk_widget_set_name (shutdown_window, "shutdown_window");
  gtk_object_set_data (GTK_OBJECT (shutdown_window), "shutdown_window", shutdown_window);
  gtk_window_set_title (GTK_WINDOW (shutdown_window), _("gtk-gnutella shutdown"));
  gtk_window_set_position (GTK_WINDOW (shutdown_window), GTK_WIN_POS_CENTER);
  gtk_window_set_policy (GTK_WINDOW (shutdown_window), FALSE, FALSE, FALSE);

  frame30 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame30, "frame30");
  gtk_widget_ref (frame30);
  gtk_object_set_data_full (GTK_OBJECT (shutdown_window), "frame30", frame30,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame30);
  gtk_container_add (GTK_CONTAINER (shutdown_window), frame30);
  gtk_container_set_border_width (GTK_CONTAINER (frame30), 6);

  vbox44 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox44, "vbox44");
  gtk_widget_ref (vbox44);
  gtk_object_set_data_full (GTK_OBJECT (shutdown_window), "vbox44", vbox44,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox44);
  gtk_container_add (GTK_CONTAINER (frame30), vbox44);
  gtk_container_set_border_width (GTK_CONTAINER (vbox44), 30);

  label184 = gtk_label_new (_("gtk-gnutella is shutting down.\nSending bye messages to peers.\n\nGrace time remaining:"));
  gtk_widget_set_name (label184, "label184");
  gtk_widget_ref (label184);
  gtk_object_set_data_full (GTK_OBJECT (shutdown_window), "label184", label184,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label184);
  gtk_box_pack_start (GTK_BOX (vbox44), label184, FALSE, FALSE, 0);

  label_shutdown_count = gtk_label_new (_("[time]"));
  gtk_widget_set_name (label_shutdown_count, "label_shutdown_count");
  gtk_widget_ref (label_shutdown_count);
  gtk_object_set_data_full (GTK_OBJECT (shutdown_window), "label_shutdown_count", label_shutdown_count,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_shutdown_count);
  gtk_box_pack_start (GTK_BOX (vbox44), label_shutdown_count, FALSE, FALSE, 0);

  gtk_signal_connect (GTK_OBJECT (shutdown_window), "delete_event",
                      GTK_SIGNAL_FUNC (gtk_true),
                      NULL);

  return shutdown_window;
}

GtkWidget*
create_dlg_about (void)
{
  GtkWidget *dlg_about;
  GtkWidget *vbox67;
  GtkWidget *frame44;
  GtkWidget *vbox98;
  GtkWidget *hbox170;
  GtkWidget *pixmap4;
  GtkWidget *label_about_title;
  GtkWidget *label_about_rcsid;
  GtkWidget *hseparator7;
  GtkWidget *hbox161;
  GtkWidget *table28;
  GtkWidget *label264;
  GtkWidget *label270;
  GtkWidget *label527;
  GtkWidget *label266;
  GtkWidget *label271;
  GtkWidget *label291;
  GtkWidget *vseparator5;
  GtkWidget *label292;
  GtkWidget *label272;
  GtkWidget *label267;
  GtkWidget *label265;
  GtkWidget *label273;
  GtkWidget *label528;
  GtkWidget *label_about_translation;
  GtkWidget *frame46;
  GtkWidget *scrolledwindow18;
  GtkWidget *textview_about_contributors;
  GtkWidget *vbox133;
  GtkWidget *label719;
  GtkWidget *label716;
  GtkWidget *label717;
  GtkWidget *label718;
  GtkWidget *hbox137;
  GtkWidget *hseparator9;
  GtkWidget *vbox134;
  GtkWidget *label700;
  GtkWidget *hseparator15;
  GtkWidget *button_about_close;
  GtkAccelGroup *accel_group;

  accel_group = gtk_accel_group_new ();

  dlg_about = gtk_window_new (GTK_WINDOW_DIALOG);
  gtk_widget_set_name (dlg_about, "dlg_about");
  gtk_object_set_data (GTK_OBJECT (dlg_about), "dlg_about", dlg_about);
  gtk_window_set_title (GTK_WINDOW (dlg_about), _("About gtk-gnutella"));
  gtk_window_set_position (GTK_WINDOW (dlg_about), GTK_WIN_POS_CENTER);

  vbox67 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox67, "vbox67");
  gtk_widget_ref (vbox67);
  gtk_object_set_data_full (GTK_OBJECT (dlg_about), "vbox67", vbox67,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox67);
  gtk_container_add (GTK_CONTAINER (dlg_about), vbox67);

  frame44 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame44, "frame44");
  gtk_widget_ref (frame44);
  gtk_object_set_data_full (GTK_OBJECT (dlg_about), "frame44", frame44,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame44);
  gtk_box_pack_start (GTK_BOX (vbox67), frame44, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame44), 10);

  vbox98 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox98, "vbox98");
  gtk_widget_ref (vbox98);
  gtk_object_set_data_full (GTK_OBJECT (dlg_about), "vbox98", vbox98,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox98);
  gtk_container_add (GTK_CONTAINER (frame44), vbox98);
  gtk_container_set_border_width (GTK_CONTAINER (vbox98), 10);

  hbox170 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox170, "hbox170");
  gtk_widget_ref (hbox170);
  gtk_object_set_data_full (GTK_OBJECT (dlg_about), "hbox170", hbox170,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox170);
  gtk_box_pack_start (GTK_BOX (vbox98), hbox170, TRUE, TRUE, 0);

  pixmap4 = create_pixmap (dlg_about, "icon.48x48.xpm");
  gtk_widget_set_name (pixmap4, "pixmap4");
  gtk_widget_ref (pixmap4);
  gtk_object_set_data_full (GTK_OBJECT (dlg_about), "pixmap4", pixmap4,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (pixmap4);
  gtk_box_pack_start (GTK_BOX (hbox170), pixmap4, FALSE, TRUE, 0);
  gtk_pixmap_set_build_insensitive (GTK_PIXMAP (pixmap4), FALSE);

  label_about_title = gtk_label_new (_("[name and version]"));
  gtk_widget_set_name (label_about_title, "label_about_title");
  gtk_widget_ref (label_about_title);
  gtk_object_set_data_full (GTK_OBJECT (dlg_about), "label_about_title", label_about_title,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_about_title);
  gtk_box_pack_start (GTK_BOX (hbox170), label_about_title, TRUE, TRUE, 0);

  label_about_rcsid = gtk_label_new (_("$Id$"));
  gtk_widget_set_name (label_about_rcsid, "label_about_rcsid");
  gtk_widget_ref (label_about_rcsid);
  gtk_object_set_data_full (GTK_OBJECT (dlg_about), "label_about_rcsid", label_about_rcsid,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_box_pack_start (GTK_BOX (vbox98), label_about_rcsid, FALSE, FALSE, 0);

  hseparator7 = gtk_hseparator_new ();
  gtk_widget_set_name (hseparator7, "hseparator7");
  gtk_widget_ref (hseparator7);
  gtk_object_set_data_full (GTK_OBJECT (dlg_about), "hseparator7", hseparator7,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hseparator7);
  gtk_box_pack_start (GTK_BOX (vbox67), hseparator7, FALSE, TRUE, 0);

  hbox161 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox161, "hbox161");
  gtk_widget_ref (hbox161);
  gtk_object_set_data_full (GTK_OBJECT (dlg_about), "hbox161", hbox161,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox161);
  gtk_box_pack_start (GTK_BOX (vbox67), hbox161, FALSE, FALSE, 0);

  table28 = gtk_table_new (3, 5, FALSE);
  gtk_widget_set_name (table28, "table28");
  gtk_widget_ref (table28);
  gtk_object_set_data_full (GTK_OBJECT (dlg_about), "table28", table28,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table28);
  gtk_box_pack_start (GTK_BOX (hbox161), table28, TRUE, TRUE, 4);
  gtk_container_set_border_width (GTK_CONTAINER (table28), 4);
  gtk_table_set_row_spacings (GTK_TABLE (table28), 2);

  label264 = gtk_label_new (_("Original author:"));
  gtk_widget_set_name (label264, "label264");
  gtk_widget_ref (label264);
  gtk_object_set_data_full (GTK_OBJECT (dlg_about), "label264", label264,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label264);
  gtk_table_attach (GTK_TABLE (table28), label264, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label264), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label264), 4, 0);

  label270 = gtk_label_new (_("Core development:"));
  gtk_widget_set_name (label270, "label270");
  gtk_widget_ref (label270);
  gtk_object_set_data_full (GTK_OBJECT (dlg_about), "label270", label270,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label270);
  gtk_table_attach (GTK_TABLE (table28), label270, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label270), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label270), 4, 0);

  label527 = gtk_label_new (_("PARQ development:"));
  gtk_widget_set_name (label527, "label527");
  gtk_widget_ref (label527);
  gtk_object_set_data_full (GTK_OBJECT (dlg_about), "label527", label527,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label527);
  gtk_table_attach (GTK_TABLE (table28), label527, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label527), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label527), 4, 0);

  label266 = gtk_label_new (_("Project leader:"));
  gtk_widget_set_name (label266, "label266");
  gtk_widget_ref (label266);
  gtk_object_set_data_full (GTK_OBJECT (dlg_about), "label266", label266,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label266);
  gtk_table_attach (GTK_TABLE (table28), label266, 3, 4, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label266), 0, 0.5);

  label271 = gtk_label_new (_("GUI development:"));
  gtk_widget_set_name (label271, "label271");
  gtk_widget_ref (label271);
  gtk_object_set_data_full (GTK_OBJECT (dlg_about), "label271", label271,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label271);
  gtk_table_attach (GTK_TABLE (table28), label271, 3, 4, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label271), 0, 0.5);

  label291 = gtk_label_new (_("Swarming development:"));
  gtk_widget_set_name (label291, "label291");
  gtk_widget_ref (label291);
  gtk_object_set_data_full (GTK_OBJECT (dlg_about), "label291", label291,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label291);
  gtk_table_attach (GTK_TABLE (table28), label291, 3, 4, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label291), 0, 0.5);

  vseparator5 = gtk_vseparator_new ();
  gtk_widget_set_name (vseparator5, "vseparator5");
  gtk_widget_ref (vseparator5);
  gtk_object_set_data_full (GTK_OBJECT (dlg_about), "vseparator5", vseparator5,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vseparator5);
  gtk_table_attach (GTK_TABLE (table28), vseparator5, 2, 3, 0, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 4, 0);

  label292 = gtk_label_new (_("Vidar Madsen"));
  gtk_widget_set_name (label292, "label292");
  gtk_widget_ref (label292);
  gtk_object_set_data_full (GTK_OBJECT (dlg_about), "label292", label292,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label292);
  gtk_table_attach (GTK_TABLE (table28), label292, 4, 5, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 4, 0);
  gtk_misc_set_alignment (GTK_MISC (label292), 0, 0.5);

  label272 = gtk_label_new (_("Richard Eckart"));
  gtk_widget_set_name (label272, "label272");
  gtk_widget_ref (label272);
  gtk_object_set_data_full (GTK_OBJECT (dlg_about), "label272", label272,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label272);
  gtk_table_attach (GTK_TABLE (table28), label272, 4, 5, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 4, 0);
  gtk_misc_set_alignment (GTK_MISC (label272), 0, 0.5);

  label267 = gtk_label_new (_("Raphael Manfredi"));
  gtk_widget_set_name (label267, "label267");
  gtk_widget_ref (label267);
  gtk_object_set_data_full (GTK_OBJECT (dlg_about), "label267", label267,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label267);
  gtk_table_attach (GTK_TABLE (table28), label267, 4, 5, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 4, 0);
  gtk_misc_set_alignment (GTK_MISC (label267), 0, 0.5);

  label265 = gtk_label_new (_("Yann Grossel"));
  gtk_widget_set_name (label265, "label265");
  gtk_widget_ref (label265);
  gtk_object_set_data_full (GTK_OBJECT (dlg_about), "label265", label265,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label265);
  gtk_table_attach (GTK_TABLE (table28), label265, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 4, 0);
  gtk_misc_set_alignment (GTK_MISC (label265), 0, 0.5);

  label273 = gtk_label_new (_("Raphael Manfredi"));
  gtk_widget_set_name (label273, "label273");
  gtk_widget_ref (label273);
  gtk_object_set_data_full (GTK_OBJECT (dlg_about), "label273", label273,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label273);
  gtk_table_attach (GTK_TABLE (table28), label273, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 4, 0);
  gtk_misc_set_alignment (GTK_MISC (label273), 0, 0.5);

  label528 = gtk_label_new (_("Jeroen Asselman"));
  gtk_widget_set_name (label528, "label528");
  gtk_widget_ref (label528);
  gtk_object_set_data_full (GTK_OBJECT (dlg_about), "label528", label528,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label528);
  gtk_table_attach (GTK_TABLE (table28), label528, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 4, 0);
  gtk_misc_set_alignment (GTK_MISC (label528), 0, 0.5);

  label_about_translation = gtk_label_new ("");
  gtk_widget_set_name (label_about_translation, "label_about_translation");
  gtk_widget_ref (label_about_translation);
  gtk_object_set_data_full (GTK_OBJECT (dlg_about), "label_about_translation", label_about_translation,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_about_translation);
  gtk_box_pack_start (GTK_BOX (vbox67), label_about_translation, FALSE, FALSE, 0);

  frame46 = gtk_frame_new (_("Contributors:"));
  gtk_widget_set_name (frame46, "frame46");
  gtk_widget_ref (frame46);
  gtk_object_set_data_full (GTK_OBJECT (dlg_about), "frame46", frame46,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame46);
  gtk_box_pack_start (GTK_BOX (vbox67), frame46, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame46), 3);

  scrolledwindow18 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow18, "scrolledwindow18");
  gtk_widget_ref (scrolledwindow18);
  gtk_object_set_data_full (GTK_OBJECT (dlg_about), "scrolledwindow18", scrolledwindow18,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (scrolledwindow18);
  gtk_container_add (GTK_CONTAINER (frame46), scrolledwindow18);
  gtk_container_set_border_width (GTK_CONTAINER (scrolledwindow18), 2);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow18), GTK_POLICY_NEVER, GTK_POLICY_ALWAYS);

  textview_about_contributors = gtk_text_new (NULL, NULL);
  gtk_widget_set_name (textview_about_contributors, "textview_about_contributors");
  gtk_widget_ref (textview_about_contributors);
  gtk_object_set_data_full (GTK_OBJECT (dlg_about), "textview_about_contributors", textview_about_contributors,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (textview_about_contributors);
  gtk_container_add (GTK_CONTAINER (scrolledwindow18), textview_about_contributors);
  gtk_widget_set_usize (textview_about_contributors, 240, 100);

  vbox133 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox133, "vbox133");
  gtk_widget_ref (vbox133);
  gtk_object_set_data_full (GTK_OBJECT (dlg_about), "vbox133", vbox133,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox133);
  gtk_box_pack_start (GTK_BOX (vbox67), vbox133, FALSE, FALSE, 4);

  label719 = gtk_label_new (_("==> We are looking for people who want to contribute to this fine tool. <=="));
  gtk_widget_set_name (label719, "label719");
  gtk_widget_ref (label719);
  gtk_object_set_data_full (GTK_OBJECT (dlg_about), "label719", label719,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label719);
  gtk_box_pack_start (GTK_BOX (vbox133), label719, FALSE, FALSE, 0);

  label716 = gtk_label_new (_("Visit http://gtk-gnutella.sourceforge.net/."));
  gtk_widget_set_name (label716, "label716");
  gtk_widget_ref (label716);
  gtk_object_set_data_full (GTK_OBJECT (dlg_about), "label716", label716,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label716);
  gtk_box_pack_start (GTK_BOX (vbox133), label716, FALSE, FALSE, 0);

  label717 = gtk_label_new (_("Join the users or developers mailing lists."));
  gtk_widget_set_name (label717, "label717");
  gtk_widget_ref (label717);
  gtk_object_set_data_full (GTK_OBJECT (dlg_about), "label717", label717,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label717);
  gtk_box_pack_start (GTK_BOX (vbox133), label717, FALSE, FALSE, 0);

  label718 = gtk_label_new (_("Meet us on #gtk-gnutella at irc.freenode.net."));
  gtk_widget_set_name (label718, "label718");
  gtk_widget_ref (label718);
  gtk_object_set_data_full (GTK_OBJECT (dlg_about), "label718", label718,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label718);
  gtk_box_pack_start (GTK_BOX (vbox133), label718, FALSE, FALSE, 0);

  hbox137 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox137, "hbox137");
  gtk_widget_ref (hbox137);
  gtk_object_set_data_full (GTK_OBJECT (dlg_about), "hbox137", hbox137,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox137);
  gtk_box_pack_start (GTK_BOX (vbox67), hbox137, FALSE, TRUE, 0);

  hseparator9 = gtk_hseparator_new ();
  gtk_widget_set_name (hseparator9, "hseparator9");
  gtk_widget_ref (hseparator9);
  gtk_object_set_data_full (GTK_OBJECT (dlg_about), "hseparator9", hseparator9,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hseparator9);
  gtk_box_pack_start (GTK_BOX (hbox137), hseparator9, TRUE, TRUE, 0);

  vbox134 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox134, "vbox134");
  gtk_widget_ref (vbox134);
  gtk_object_set_data_full (GTK_OBJECT (dlg_about), "vbox134", vbox134,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox134);
  gtk_box_pack_start (GTK_BOX (vbox67), vbox134, FALSE, FALSE, 4);

  label700 = gtk_label_new (_("This product includes GeoIP data created by MaxMind, available from\nhttp://maxmind.com/"));
  gtk_widget_set_name (label700, "label700");
  gtk_widget_ref (label700);
  gtk_object_set_data_full (GTK_OBJECT (dlg_about), "label700", label700,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label700);
  gtk_box_pack_start (GTK_BOX (vbox134), label700, FALSE, FALSE, 0);

  hseparator15 = gtk_hseparator_new ();
  gtk_widget_set_name (hseparator15, "hseparator15");
  gtk_widget_ref (hseparator15);
  gtk_object_set_data_full (GTK_OBJECT (dlg_about), "hseparator15", hseparator15,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hseparator15);
  gtk_box_pack_start (GTK_BOX (vbox67), hseparator15, FALSE, TRUE, 0);

  button_about_close = gtk_button_new_with_label (_("Close"));
  gtk_widget_set_name (button_about_close, "button_about_close");
  gtk_widget_ref (button_about_close);
  gtk_object_set_data_full (GTK_OBJECT (dlg_about), "button_about_close", button_about_close,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_about_close);
  gtk_box_pack_start (GTK_BOX (vbox67), button_about_close, FALSE, FALSE, 0);
  GTK_WIDGET_SET_FLAGS (button_about_close, GTK_CAN_DEFAULT);
  gtk_widget_add_accelerator (button_about_close, "clicked", accel_group,
                              GDK_c, GDK_CONTROL_MASK,
                              GTK_ACCEL_VISIBLE);

  gtk_signal_connect (GTK_OBJECT (dlg_about), "delete_event",
                      GTK_SIGNAL_FUNC (on_dlg_about_delete_event),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button_about_close), "clicked",
                      GTK_SIGNAL_FUNC (on_button_about_close_clicked),
                      NULL);

  gtk_window_add_accel_group (GTK_WINDOW (dlg_about), accel_group);

  return dlg_about;
}

GtkWidget*
create_popup_filter_rule (void)
{
  GtkWidget *popup_filter_rule;
  GtkAccelGroup *popup_filter_rule_accels;
  GtkWidget *popup_filter_rule_copy;
  GtkWidget *popup_filter_rule_paste;

  popup_filter_rule = gtk_menu_new ();
  gtk_widget_set_name (popup_filter_rule, "popup_filter_rule");
  gtk_object_set_data (GTK_OBJECT (popup_filter_rule), "popup_filter_rule", popup_filter_rule);
  popup_filter_rule_accels = gtk_menu_ensure_uline_accel_group (GTK_MENU (popup_filter_rule));

  popup_filter_rule_copy = gtk_menu_item_new_with_label (_("Copy rule"));
  gtk_widget_set_name (popup_filter_rule_copy, "popup_filter_rule_copy");
  gtk_widget_ref (popup_filter_rule_copy);
  gtk_object_set_data_full (GTK_OBJECT (popup_filter_rule), "popup_filter_rule_copy", popup_filter_rule_copy,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (popup_filter_rule_copy);
  gtk_container_add (GTK_CONTAINER (popup_filter_rule), popup_filter_rule_copy);

  popup_filter_rule_paste = gtk_menu_item_new_with_label (_("Paste rule"));
  gtk_widget_set_name (popup_filter_rule_paste, "popup_filter_rule_paste");
  gtk_widget_ref (popup_filter_rule_paste);
  gtk_object_set_data_full (GTK_OBJECT (popup_filter_rule), "popup_filter_rule_paste", popup_filter_rule_paste,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (popup_filter_rule_paste);
  gtk_container_add (GTK_CONTAINER (popup_filter_rule), popup_filter_rule_paste);

  gtk_signal_connect (GTK_OBJECT (popup_filter_rule_copy), "activate",
                      GTK_SIGNAL_FUNC (on_popup_filter_rule_copy_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (popup_filter_rule_paste), "activate",
                      GTK_SIGNAL_FUNC (on_popup_filter_rule_paste_activate),
                      NULL);

  return popup_filter_rule;
}

GtkWidget*
create_dlg_quit (void)
{
  GtkWidget *dlg_quit;
  GtkWidget *dialog_vbox1;
  GtkWidget *frame51;
  GtkWidget *label295;
  GtkWidget *dialog_action_area1;
  guint button_abort_quit_key;
  GtkWidget *button_abort_quit;
  guint button_really_quit_key;
  GtkWidget *button_really_quit;
  GtkAccelGroup *accel_group;

  accel_group = gtk_accel_group_new ();

  dlg_quit = gtk_dialog_new ();
  gtk_widget_set_name (dlg_quit, "dlg_quit");
  gtk_object_set_data (GTK_OBJECT (dlg_quit), "dlg_quit", dlg_quit);
  gtk_window_set_title (GTK_WINDOW (dlg_quit), _("gtk-gnutella: Quit?"));
  GTK_WINDOW (dlg_quit)->type = GTK_WINDOW_DIALOG;
  gtk_window_set_position (GTK_WINDOW (dlg_quit), GTK_WIN_POS_MOUSE);
  gtk_window_set_modal (GTK_WINDOW (dlg_quit), TRUE);
  gtk_window_set_policy (GTK_WINDOW (dlg_quit), FALSE, FALSE, TRUE);

  dialog_vbox1 = GTK_DIALOG (dlg_quit)->vbox;
  gtk_widget_set_name (dialog_vbox1, "dialog_vbox1");
  gtk_object_set_data (GTK_OBJECT (dlg_quit), "dialog_vbox1", dialog_vbox1);
  gtk_widget_show (dialog_vbox1);

  frame51 = gtk_frame_new (_("Please confirm:"));
  gtk_widget_set_name (frame51, "frame51");
  gtk_widget_ref (frame51);
  gtk_object_set_data_full (GTK_OBJECT (dlg_quit), "frame51", frame51,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame51);
  gtk_box_pack_start (GTK_BOX (dialog_vbox1), frame51, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame51), 10);

  label295 = gtk_label_new (_("Do you really want to quit?"));
  gtk_widget_set_name (label295, "label295");
  gtk_widget_ref (label295);
  gtk_object_set_data_full (GTK_OBJECT (dlg_quit), "label295", label295,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label295);
  gtk_container_add (GTK_CONTAINER (frame51), label295);
  gtk_misc_set_padding (GTK_MISC (label295), 10, 10);

  dialog_action_area1 = GTK_DIALOG (dlg_quit)->action_area;
  gtk_widget_set_name (dialog_action_area1, "dialog_action_area1");
  gtk_object_set_data (GTK_OBJECT (dlg_quit), "dialog_action_area1", dialog_action_area1);
  gtk_widget_show (dialog_action_area1);
  gtk_container_set_border_width (GTK_CONTAINER (dialog_action_area1), 10);

  button_abort_quit = gtk_button_new_with_label ("");
  button_abort_quit_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (button_abort_quit)->child),
                                   _("_Cancel"));
  gtk_widget_add_accelerator (button_abort_quit, "clicked", accel_group,
                              button_abort_quit_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (button_abort_quit, "button_abort_quit");
  gtk_widget_ref (button_abort_quit);
  gtk_object_set_data_full (GTK_OBJECT (dlg_quit), "button_abort_quit", button_abort_quit,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_abort_quit);
  gtk_box_pack_start (GTK_BOX (dialog_action_area1), button_abort_quit, TRUE, TRUE, 0);
  GTK_WIDGET_SET_FLAGS (button_abort_quit, GTK_CAN_DEFAULT);
  gtk_widget_add_accelerator (button_abort_quit, "clicked", accel_group,
                              GDK_n, GDK_CONTROL_MASK,
                              GTK_ACCEL_VISIBLE);

  button_really_quit = gtk_button_new_with_label ("");
  button_really_quit_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (button_really_quit)->child),
                                   _("_Quit"));
  gtk_widget_add_accelerator (button_really_quit, "clicked", accel_group,
                              button_really_quit_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (button_really_quit, "button_really_quit");
  gtk_widget_ref (button_really_quit);
  gtk_object_set_data_full (GTK_OBJECT (dlg_quit), "button_really_quit", button_really_quit,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_really_quit);
  gtk_box_pack_start (GTK_BOX (dialog_action_area1), button_really_quit, TRUE, TRUE, 0);
  GTK_WIDGET_SET_FLAGS (button_really_quit, GTK_CAN_DEFAULT);
  gtk_widget_add_accelerator (button_really_quit, "clicked", accel_group,
                              GDK_y, GDK_CONTROL_MASK,
                              GTK_ACCEL_VISIBLE);

  gtk_signal_connect (GTK_OBJECT (dlg_quit), "delete_event",
                      GTK_SIGNAL_FUNC (on_dlg_quit_delete_event),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button_abort_quit), "clicked",
                      GTK_SIGNAL_FUNC (on_button_abort_quit_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button_really_quit), "clicked",
                      GTK_SIGNAL_FUNC (on_button_really_quit_clicked),
                      NULL);

  gtk_widget_grab_default (button_abort_quit);
  gtk_window_add_accel_group (GTK_WINDOW (dlg_quit), accel_group);

  return dlg_quit;
}

GtkWidget*
create_dlg_prefs (void)
{
  GtkWidget *dlg_prefs;
  GtkWidget *dialog_vbox2;
  GtkWidget *notebook_prefs;
  GtkWidget *scrolledwindow32;
  GtkWidget *viewport3;
  GtkWidget *vbox24;
  GtkWidget *frame13;
  GtkWidget *vbox30;
  GtkWidget *hbox79;
  GtkWidget *label128;
  GtkWidget *frame116;
  GtkWidget *label_current_port;
  GtkWidget *hseparator2;
  GtkWidget *table5;
  guint label129_key;
  GtkWidget *label129;
  GtkObject *spinbutton_config_port_adj;
  GtkWidget *spinbutton_config_port;
  guint checkbutton_give_server_hostname_key;
  GtkWidget *checkbutton_give_server_hostname;
  GtkWidget *entry_server_hostname;
  guint checkbutton_enable_udp_key;
  GtkWidget *checkbutton_enable_udp;
  GtkWidget *label778;
  GtkWidget *option_menu_config_network_protocol;
  GtkWidget *option_menu_config_network_protocol_menu;
  GtkWidget *label35;
  guint checkbutton_enable_dht_key;
  GtkWidget *checkbutton_enable_dht;
  GtkWidget *frame147;
  GtkWidget *hbox2108;
  guint checkbutton_config_force_ip_key;
  GtkWidget *checkbutton_config_force_ip;
  GtkWidget *entry_config_force_ip;
  GtkWidget *checkbutton_config_bind_ipv4;
  GtkWidget *frame148;
  GtkWidget *table97;
  guint checkbutton_config_force_ipv6_key;
  GtkWidget *checkbutton_config_force_ipv6;
  GtkWidget *entry_config_force_ipv6;
  GtkWidget *checkbutton_config_bind_ipv6;
  GtkWidget *entry_config_ipv6_trt_prefix;
  GtkWidget *checkbutton_config_ipv6_trt_enable;
  GtkWidget *frame_expert_nw_port_mapping;
  GtkWidget *table102;
  GtkWidget *checkbutton_enable_natpmp;
  GtkWidget *checkbutton_enable_upnp;
  GtkWidget *label8034;
  GtkObject *spinbutton_config_upnp_mapping_lease_time_adj;
  GtkWidget *spinbutton_config_upnp_mapping_lease_time;
  GtkWidget *frame_proxy_settings;
  GtkWidget *vbox100;
  GtkWidget *table53;
  guint label91_key;
  GtkWidget *label91;
  guint label92_key;
  GtkWidget *label92;
  guint label90_key;
  GtkWidget *label90;
  GtkObject *spinbutton_config_proxy_port_adj;
  GtkWidget *spinbutton_config_proxy_port;
  GtkWidget *entry_config_proxy_hostname;
  GtkWidget *option_menu_config_proxy_protocol;
  GtkWidget *option_menu_config_proxy_protocol_menu;
  GtkWidget *table54;
  guint checkbutton_config_proxy_auth_key;
  GtkWidget *checkbutton_config_proxy_auth;
  guint label93_key;
  GtkWidget *label93;
  guint label94_key;
  GtkWidget *label94;
  GtkWidget *entry_config_socks_password;
  GtkWidget *entry_config_socks_username;
  GtkWidget *frame_expert_nw_local;
  GtkWidget *vbox23_2;
  GtkWidget *hbox77;
  guint checkbutton_config_use_netmasks_key;
  GtkWidget *checkbutton_config_use_netmasks;
  guint checkbutton_config_no_rfc1918_key;
  GtkWidget *checkbutton_config_no_rfc1918;
  GtkWidget *hbox78;
  GtkWidget *label126_2;
  GtkWidget *entry_config_netmasks;
  GtkWidget *frame_expert_nw_misc;
  GtkWidget *table48;
  guint label441_key;
  GtkWidget *label441;
  guint label442_key;
  GtkWidget *label442;
  GtkObject *spinbutton_config_ban_max_fds_adj;
  GtkWidget *spinbutton_config_ban_max_fds;
  GtkObject *spinbutton_config_ban_ratio_fds_adj;
  GtkWidget *spinbutton_config_ban_ratio_fds;
  guint label502_key;
  GtkWidget *label502;
  GtkWidget *entry_config_max_banned_fd;
  GtkWidget *label654;
  GtkWidget *frame120;
  GtkWidget *label_banned_count;
  GtkWidget *checkbutton_use_global_hostiles;
  GtkWidget *frame80;
  GtkWidget *table62;
  guint checkbutton_host_runs_ntp_key;
  GtkWidget *checkbutton_host_runs_ntp;
  GtkWidget *label529;
  GtkWidget *frame117;
  GtkWidget *label_clock_skew;
  GtkWidget *frame86;
  GtkWidget *vbox120;
  guint checkbutton_enable_remote_shell_key;
  GtkWidget *checkbutton_enable_remote_shell;
  GtkWidget *frame_expert_rx_buffers;
  GtkWidget *table67;
  guint label553_key;
  GtkWidget *label553;
  GtkWidget *label554;
  GtkWidget *label555;
  guint label552_key;
  GtkWidget *label552;
  GtkObject *spinbutton_node_rx_size_adj;
  GtkWidget *spinbutton_node_rx_size;
  GtkObject *spinbutton_download_rx_size_adj;
  GtkWidget *spinbutton_download_rx_size;
  GtkWidget *label682;
  GtkWidget *scrolledwindow19;
  GtkWidget *viewport5;
  GtkWidget *vbox25;
  GtkWidget *frame71;
  GtkWidget *hbox186;
  GtkWidget *alignment30;
  GtkWidget *table82;
  GtkWidget *label439;
  GtkWidget *checkbutton_gnet_monitor_ip;
  GtkWidget *checkbutton_gnet_monitor_servents;
  GtkWidget *alignment34;
  GtkWidget *frame72;
  GtkWidget *table87;
  GtkWidget *label459;
  GtkWidget *label504;
  GtkObject *spinbutton_normal_connections_adj;
  GtkWidget *spinbutton_normal_connections;
  GtkObject *spinbutton_config_max_leaves_adj;
  GtkWidget *spinbutton_config_max_leaves;
  GtkWidget *option_menu_config_peermode;
  GtkWidget *option_menu_config_peermode_menu;
  GtkWidget *vbox121;
  GtkWidget *frame_gnet_can_become_ultra;
  GtkWidget *vbox116;
  GtkWidget *table73;
  GtkWidget *label577;
  GtkWidget *label579;
  GtkWidget *frame107;
  GtkWidget *label_node_last_ultracheck;
  GtkWidget *frame108;
  GtkWidget *label_last_ultra_leaf_switch;
  GtkWidget *hseparator14;
  GtkWidget *table74;
  GtkWidget *label584;
  GtkWidget *label591;
  GtkWidget *label592;
  GtkWidget *label593;
  GtkWidget *label594;
  GtkWidget *label583;
  GtkWidget *label581;
  GtkWidget *frame109;
  GtkWidget *label_up_req_avg_servent_uptime;
  GtkWidget *frame110;
  GtkWidget *label_up_req_node_uptime;
  GtkWidget *frame111;
  GtkWidget *label_up_req_enough_fd;
  GtkWidget *frame112;
  GtkWidget *label_up_req_enough_bw;
  GtkWidget *frame113;
  GtkWidget *label_up_req_avg_ip_uptime;
  GtkWidget *frame114;
  GtkWidget *label_up_req_not_firewalled;
  GtkWidget *frame115;
  GtkWidget *label_up_req_enough_mem;
  GtkWidget *label681;
  GtkWidget *frame132;
  GtkWidget *label_up_req_enough_conn;
  GtkWidget *vseparator2;
  GtkWidget *label784;
  GtkWidget *frame145;
  GtkWidget *label_up_req_good_udp;
  GtkWidget *frame_searches;
  GtkWidget *hbox188;
  GtkWidget *alignment31;
  GtkWidget *table83;
  guint label37_key;
  GtkWidget *label37;
  GtkObject *spinbutton_config_search_items_adj;
  GtkWidget *spinbutton_config_search_items;
  GtkWidget *label38;
  guint label567_key;
  GtkWidget *label567;
  GtkObject *spinbutton_config_search_reissue_timeout_adj;
  GtkWidget *spinbutton_config_search_reissue_timeout;
  GtkWidget *label568;
  GtkWidget *checkbutton_enable_guess;
  GtkWidget *checkbutton_enable_guess_client;
  GtkWidget *checkbutton_enable_g2;
  GtkWidget *frame_expert_oob_queries;
  GtkWidget *vbox131;
  GtkWidget *checkbutton_send_oob_queries;
  GtkWidget *checkbutton_process_oob_queries;
  GtkWidget *checkbutton_proxy_oob_queries;
  GtkWidget *vbox122;
  GtkWidget *frame_expert_search_queue;
  GtkWidget *table75;
  GtkWidget *label595;
  GtkWidget *label596;
  GtkObject *spinbutton_search_queue_spacing_adj;
  GtkWidget *spinbutton_search_queue_spacing;
  GtkObject *spinbutton_search_queue_size_adj;
  GtkWidget *spinbutton_search_queue_size;
  GtkWidget *checkbutton_config_query_request_partials;
  GtkWidget *checkbutton_config_search_smart_stop;
  GtkWidget *checkbutton_search_restart_when_pending;
  GtkWidget *frame_expert_gnet_timeout;
  GtkWidget *table10;
  guint label175_key;
  GtkWidget *label175;
  guint label176_key;
  GtkWidget *label176;
  guint label177_key;
  GtkWidget *label177;
  GtkObject *spinbutton_config_node_tx_flowc_timeout_adj;
  GtkWidget *spinbutton_config_node_tx_flowc_timeout;
  GtkObject *spinbutton_config_node_connecting_timeout_adj;
  GtkWidget *spinbutton_config_node_connecting_timeout;
  GtkObject *spinbutton_config_node_connected_timeout_adj;
  GtkWidget *spinbutton_config_node_connected_timeout;
  GtkWidget *label503;
  GtkObject *spinbutton_config_incoming_connecting_timeout_adj;
  GtkWidget *spinbutton_config_incoming_connecting_timeout;
  GtkWidget *alignment26;
  GtkWidget *frame_expert_gnet_ttl;
  GtkWidget *table9;
  guint label84_key;
  GtkWidget *label84;
  guint label85_key;
  GtkWidget *label85;
  guint label158_key;
  GtkWidget *label158;
  guint label157_key;
  GtkWidget *label157;
  guint label159_key;
  GtkWidget *label159;
  GtkObject *spinbutton_config_maxttl_adj;
  GtkWidget *spinbutton_config_maxttl;
  GtkObject *spinbutton_config_max_high_ttl_msg_adj;
  GtkWidget *spinbutton_config_max_high_ttl_msg;
  GtkObject *spinbutton_config_hard_ttl_limit_adj;
  GtkWidget *spinbutton_config_hard_ttl_limit;
  GtkObject *spinbutton_config_myttl_adj;
  GtkWidget *spinbutton_config_myttl;
  GtkObject *spinbutton_config_max_high_ttl_radius_adj;
  GtkWidget *spinbutton_config_max_high_ttl_radius;
  GtkWidget *label160;
  GtkWidget *frame_expert_gnet_dht;
  GtkWidget *table104;
  GtkWidget *label8032;
  GtkWidget *option_menu_config_dht_mode;
  GtkWidget *option_menu_config_dht_mode_menu;
  GtkWidget *checkbutton_config_dht_storage_in_memory;
  GtkWidget *frame_expert_gnet_quality;
  GtkWidget *table30;
  guint label279_key;
  GtkWidget *label279;
  guint label278_key;
  GtkWidget *label278;
  GtkObject *spinbutton_config_min_dup_msg_adj;
  GtkWidget *spinbutton_config_min_dup_msg;
  GtkObject *spinbutton_config_min_dup_ratio_adj;
  GtkWidget *spinbutton_config_min_dup_ratio;
  GtkWidget *label457;
  GtkObject *spinbutton_config_node_rx_flowc_ratio_adj;
  GtkWidget *spinbutton_config_node_rx_flowc_ratio;
  GtkWidget *label280;
  GtkWidget *label281;
  GtkWidget *label458;
  GtkWidget *checkbutton_node_watch_similar_queries;
  GtkWidget *label597;
  GtkObject *spinbutton_node_queries_half_life_adj;
  GtkWidget *spinbutton_node_queries_half_life;
  GtkWidget *label598;
  GtkObject *spinbutton_node_requery_threshold_adj;
  GtkWidget *spinbutton_node_requery_threshold;
  GtkWidget *vseparator3;
  GtkWidget *label8033;
  GtkObject *spinbutton_config_search_muid_track_amount_adj;
  GtkWidget *spinbutton_config_search_muid_track_amount;
  GtkWidget *frame_expert_gnet_connections;
  GtkWidget *table66;
  GtkWidget *label550;
  GtkWidget *label551;
  GtkObject *spinbutton_config_reserve_gtkg_nodes_adj;
  GtkWidget *spinbutton_config_reserve_gtkg_nodes;
  GtkObject *spinbutton_config_unique_nodes_adj;
  GtkWidget *spinbutton_config_unique_nodes;
  GtkWidget *label548;
  GtkWidget *label549;
  GtkWidget *frame_expert_gnet_other;
  GtkWidget *table33;
  GtkWidget *label290;
  GtkWidget *checkbutton_gnet_compact_query;
  GtkObject *spinbutton_config_hops_random_factor_adj;
  GtkWidget *spinbutton_config_hops_random_factor;
  GtkWidget *checkbutton_config_spam_lut_in_memory;
  GtkWidget *frame_expert_gnet_message_size;
  GtkWidget *table69;
  GtkWidget *label569;
  GtkWidget *label571;
  GtkWidget *label572;
  GtkWidget *label573;
  GtkWidget *label574;
  GtkWidget *label575;
  GtkObject *spinbutton_search_answers_forward_size_adj;
  GtkWidget *spinbutton_search_answers_forward_size;
  GtkObject *spinbutton_search_queries_forward_size_adj;
  GtkWidget *spinbutton_search_queries_forward_size;
  GtkWidget *label570;
  GtkObject *spinbutton_search_queries_kick_size_adj;
  GtkWidget *spinbutton_search_queries_kick_size;
  GtkObject *spinbutton_search_answers_kick_size_adj;
  GtkWidget *spinbutton_search_answers_kick_size;
  GtkObject *spinbutton_other_messages_kick_size_adj;
  GtkWidget *spinbutton_other_messages_kick_size;
  GtkWidget *label683;
  GtkWidget *scrolledwindow33;
  GtkWidget *viewport4;
  GtkWidget *vbox29;
  GtkWidget *frame70;
  GtkWidget *hbox183;
  GtkWidget *vbox115;
  guint checkbutton_config_bw_allow_stealing_key;
  GtkWidget *checkbutton_config_bw_allow_stealing;
  guint checkbutton_prefer_compressed_gnet_key;
  GtkWidget *checkbutton_prefer_compressed_gnet;
  guint checkbutton_config_use_ip_tos_key;
  GtkWidget *checkbutton_config_use_ip_tos;
  GtkWidget *frame83;
  GtkWidget *table69a;
  GtkWidget *label558;
  GtkWidget *label560;
  GtkWidget *label561;
  GtkWidget *label563;
  GtkWidget *label564;
  GtkWidget *label566;
  GtkWidget *viewport14;
  GtkWidget *label_output_bw_limit;
  GtkWidget *viewport15;
  GtkWidget *label_dl_http_latency;
  GtkWidget *viewport13;
  GtkWidget *label_input_bw_limit;
  GtkWidget *frame20;
  GtkWidget *hbox208;
  GtkWidget *frame138;
  GtkWidget *table13;
  GtkWidget *label181;
  GtkWidget *label182;
  GtkObject *spinbutton_config_bws_gin_adj;
  GtkWidget *spinbutton_config_bws_gin;
  GtkObject *spinbutton_config_bws_gout_adj;
  GtkWidget *spinbutton_config_bws_gout;
  guint checkbutton_config_bws_gout_key;
  GtkWidget *checkbutton_config_bws_gout;
  guint checkbutton_config_bws_gin_key;
  GtkWidget *checkbutton_config_bws_gin;
  GtkWidget *frame74;
  GtkWidget *table58;
  GtkObject *spinbutton_config_bws_glin_adj;
  GtkWidget *spinbutton_config_bws_glin;
  GtkWidget *label556;
  guint checkbutton_config_bws_glin_key;
  GtkWidget *checkbutton_config_bws_glin;
  GtkWidget *label8018;
  GtkWidget *viewport54;
  GtkWidget *label_http_out_avail;
  GtkWidget *label8019;
  guint checkbutton_config_bws_glout_key;
  GtkWidget *checkbutton_config_bws_glout;
  GtkObject *spinbutton_config_bws_glout_adj;
  GtkWidget *spinbutton_config_bws_glout;
  GtkWidget *label557;
  GtkWidget *label8021;
  GtkWidget *label8022;
  GtkWidget *viewport55;
  GtkWidget *label_http_in_avail;
  GtkWidget *frame153;
  GtkWidget *vbox146;
  GtkWidget *table100;
  GtkWidget *label8012;
  GtkObject *spinbutton_config_bws_dht_out_adj;
  GtkWidget *spinbutton_config_bws_dht_out;
  GtkWidget *checkbutton_config_bws_dht_out;
  GtkWidget *frame154;
  GtkWidget *table101;
  GtkWidget *label8014;
  GtkWidget *label8015;
  GtkObject *spinbutton_config_input_dht_lookup_bw_adj;
  GtkWidget *spinbutton_config_input_dht_lookup_bw;
  GtkObject *spinbutton_config_output_dht_lookup_bw_adj;
  GtkWidget *spinbutton_config_output_dht_lookup_bw;
  GtkWidget *label8016;
  GtkWidget *label8017;
  GtkWidget *frame12;
  GtkWidget *table4;
  GtkWidget *label126;
  GtkObject *spinbutton_config_bws_in_adj;
  GtkWidget *spinbutton_config_bws_in;
  GtkObject *spinbutton_config_bws_out_adj;
  GtkWidget *spinbutton_config_bws_out;
  guint checkbutton_config_bws_in_key;
  GtkWidget *checkbutton_config_bws_in;
  guint checkbutton_config_bws_out_key;
  GtkWidget *checkbutton_config_bws_out;
  guint checkbutton_config_bw_ul_usage_enabled_key;
  GtkWidget *checkbutton_config_bw_ul_usage_enabled;
  GtkObject *spinbutton_config_ul_usage_min_percentage_adj;
  GtkWidget *spinbutton_config_ul_usage_min_percentage;
  GtkWidget *label210;
  GtkWidget *label125;
  guint label156_key;
  GtkWidget *label156;
  GtkObject *spinbutton_config_speed_adj;
  GtkWidget *spinbutton_config_speed;
  GtkWidget *label36;
  GtkWidget *hseparator8;
  guint checkbutton_compute_connection_speed_key;
  GtkWidget *checkbutton_compute_connection_speed;
  GtkWidget *frame155;
  GtkWidget *table103;
  GtkWidget *label8028;
  GtkWidget *label8029;
  GtkObject *spinbutton_config_bw_guess_out_adj;
  GtkWidget *spinbutton_config_bw_guess_out;
  GtkWidget *checkbutton_guess_maximize_bw;
  GtkWidget *label684;
  GtkWidget *scrolledwindow34;
  GtkWidget *viewport6;
  GtkWidget *vbox38;
  GtkWidget *frame_save_new_files;
  GtkWidget *hbox96;
  GtkWidget *entry_config_save_path;
  guint button_config_save_path_key;
  GtkWidget *button_config_save_path;
  GtkWidget *frame_move_downloaded_files;
  GtkWidget *hbox95;
  GtkWidget *entry_config_move_path;
  guint button_config_move_path_key;
  GtkWidget *button_config_move_path;
  GtkWidget *frame66;
  GtkWidget *hbox158;
  GtkWidget *entry_config_bad_path;
  guint button_config_bad_path_key;
  GtkWidget *button_config_bad_path;
  GtkWidget *frame136;
  GtkWidget *table94;
  GtkWidget *checkbutton_config_convert_spaces;
  GtkWidget *checkbutton_config_convert_evil_chars;
  GtkWidget *checkbutton_config_convert_old_filenames;
  GtkWidget *checkbutton_config_beautify_filenames;
  GtkWidget *frame16;
  GtkWidget *table46;
  guint label171_key;
  GtkWidget *label171;
  guint label172_key;
  GtkWidget *label172;
  GtkObject *spinbutton_config_download_max_retries_adj;
  GtkWidget *spinbutton_config_download_max_retries;
  GtkObject *spinbutton_config_download_overlap_range_adj;
  GtkWidget *spinbutton_config_download_overlap_range;
  GtkWidget *label173;
  GtkWidget *frame_expert_dl_source_quality;
  GtkWidget *table47;
  guint checkbutton_config_download_optimistic_start_key;
  GtkWidget *checkbutton_config_download_optimistic_start;
  guint checkbutton_config_req_urn_key;
  GtkWidget *checkbutton_config_req_urn;
  guint checkbutton_config_req_srv_name_key;
  GtkWidget *checkbutton_config_req_srv_name;
  GtkWidget *frame_expert_dl_timeout;
  GtkWidget *table8;
  GtkWidget *label162;
  GtkWidget *label163;
  GtkWidget *label164;
  GtkWidget *label165;
  GtkWidget *label166;
  GtkWidget *label167;
  guint label168_key;
  GtkWidget *label168;
  guint label169_key;
  GtkWidget *label169;
  guint label170_key;
  GtkWidget *label170;
  GtkObject *spinbutton_config_download_retry_stopped_delay_adj;
  GtkWidget *spinbutton_config_download_retry_stopped_delay;
  GtkObject *spinbutton_config_download_retry_refused_delay_adj;
  GtkWidget *spinbutton_config_download_retry_refused_delay;
  GtkObject *spinbutton_config_download_retry_busy_delay_adj;
  GtkWidget *spinbutton_config_download_retry_busy_delay;
  GtkObject *spinbutton_config_download_retry_timeout_delay_adj;
  GtkWidget *spinbutton_config_download_retry_timeout_delay;
  GtkObject *spinbutton_config_download_retry_timeout_max_adj;
  GtkWidget *spinbutton_config_download_retry_timeout_max;
  GtkObject *spinbutton_config_download_retry_timeout_min_adj;
  GtkWidget *spinbutton_config_download_retry_timeout_min;
  GtkObject *spinbutton_config_download_connecting_timeout_adj;
  GtkWidget *spinbutton_config_download_connecting_timeout;
  GtkObject *spinbutton_config_download_push_sent_timeout_adj;
  GtkWidget *spinbutton_config_download_push_sent_timeout;
  GtkObject *spinbutton_config_download_connected_timeout_adj;
  GtkWidget *spinbutton_config_download_connected_timeout;
  GtkWidget *frame48;
  GtkWidget *vbox99;
  guint checkbutton_config_use_swarming_key;
  GtkWidget *checkbutton_config_use_swarming;
  GtkWidget *hseparator11;
  GtkWidget *table51;
  guint checkbutton_config_aggressive_swarming_key;
  GtkWidget *checkbutton_config_aggressive_swarming;
  GtkWidget *vseparator1;
  guint label283_key;
  GtkWidget *label283;
  guint label284_key;
  GtkWidget *label284;
  GtkWidget *label732;
  GtkWidget *label733;
  GtkWidget *vseparator6;
  GtkObject *spinbutton_dl_minchunksize_adj;
  GtkWidget *spinbutton_dl_minchunksize;
  GtkObject *spinbutton_dl_maxchunksize_adj;
  GtkWidget *spinbutton_dl_maxchunksize;
  GtkWidget *label761;
  GtkWidget *label763;
  GtkWidget *checkbutton_config_enable_http_pipelining;
  GtkWidget *label8026;
  GtkWidget *label8027;
  GtkObject *spinbutton_download_buffer_size_adj;
  GtkWidget *spinbutton_download_buffer_size;
  GtkObject *spinbutton_dl_pipeline_maxchunksize_adj;
  GtkWidget *spinbutton_dl_pipeline_maxchunksize;
  GtkWidget *hseparator12;
  GtkWidget *table52;
  guint checkbutton_config_strict_sha1_matching_key;
  GtkWidget *checkbutton_config_strict_sha1_matching;
  guint checkbutton_config_use_alternate_sources_key;
  GtkWidget *checkbutton_config_use_alternate_sources;
  guint checkbutton_auto_feed_dmesh_key;
  GtkWidget *checkbutton_auto_feed_dmesh;
  GtkWidget *checkbutton_config_tth_auto_discovery;
  GtkWidget *label685;
  GtkWidget *scrolledwindow35;
  GtkWidget *viewport7;
  GtkWidget *vbox40;
  GtkWidget *frame_path_to_files;
  GtkWidget *vbox_path_to_files;
  GtkWidget *entry_config_path;
  GtkWidget *hbox_path_buttons;
  guint button_config_add_dir_key;
  GtkWidget *button_config_add_dir;
  guint button_config_rescan_dir_key;
  GtkWidget *button_config_rescan_dir;
  GtkWidget *label_files_scanned;
  GtkWidget *hbox173;
  GtkWidget *hbox174;
  guint checkbutton_scan_ignore_symlink_dirs_key;
  GtkWidget *checkbutton_scan_ignore_symlink_dirs;
  guint checkbutton_scan_ignore_symlink_regfiles_key;
  GtkWidget *checkbutton_scan_ignore_symlink_regfiles;
  GtkWidget *hbox27;
  guint label41_key;
  GtkWidget *label41;
  GtkWidget *entry_config_extensions;
  GtkWidget *frame149;
  GtkWidget *table98;
  guint checkbutton_enable_browse_host_key;
  GtkWidget *checkbutton_enable_browse_host;
  guint checkbutton_expose_relative_paths_key;
  GtkWidget *checkbutton_expose_relative_paths;
  GtkWidget *frame_expert_ul_timeout;
  GtkWidget *table12;
  guint label179_key;
  GtkWidget *label179;
  guint label180_key;
  GtkWidget *label180;
  GtkObject *spinbutton_config_upload_connecting_timeout_adj;
  GtkWidget *spinbutton_config_upload_connecting_timeout;
  GtkObject *spinbutton_config_upload_connected_timeout_adj;
  GtkWidget *spinbutton_config_upload_connected_timeout;
  GtkWidget *frame_partial_file_sharing;
  GtkWidget *table65;
  guint label547_key;
  GtkWidget *label547;
  guint checkbutton_pfsp_server_key;
  GtkWidget *checkbutton_pfsp_server;
  GtkObject *spinbutton_pfsp_first_chunk_adj;
  GtkWidget *spinbutton_pfsp_first_chunk;
  GtkWidget *label770;
  GtkObject *spinbutton_pfsp_minimum_filesize_adj;
  GtkWidget *spinbutton_pfsp_minimum_filesize;
  GtkWidget *label8011;
  GtkObject *spinbutton_pfsp_last_chunk_adj;
  GtkWidget *spinbutton_pfsp_last_chunk;
  GtkWidget *checkbutton_pfsp_rare_server;
  GtkWidget *checkbutton_config_query_answer_partials;
  GtkWidget *checkbutton_config_query_answer_whats_new;
  GtkWidget *frame140;
  GtkWidget *table96;
  GtkWidget *label753;
  GtkObject *spinbutton_parq_min_time_adj;
  GtkWidget *spinbutton_parq_min_time;
  GtkWidget *label752;
  GtkObject *spinbutton_parq_min_size_adj;
  GtkWidget *spinbutton_parq_min_size;
  GtkWidget *checkbutton_parq_optimistic;
  GtkWidget *frame_expert_share_statistics;
  GtkWidget *vbox117;
  GtkWidget *alignment36;
  GtkWidget *hbox184;
  GtkWidget *frame88;
  GtkWidget *table78;
  GtkWidget *label601;
  GtkWidget *label602;
  GtkWidget *frame99;
  GtkWidget *label_library_rescan_time;
  GtkWidget *frame100;
  GtkWidget *label_library_rescan_timestamp;
  GtkWidget *frame_qrp_statistics;
  GtkWidget *table79;
  GtkWidget *label606;
  GtkWidget *label608;
  GtkWidget *label611;
  GtkWidget *label613;
  GtkWidget *label616;
  GtkWidget *label618;
  GtkWidget *frame101;
  GtkWidget *label_qrp_indexing_timestamp;
  GtkWidget *frame102;
  GtkWidget *label_qrp_timestamp;
  GtkWidget *frame103;
  GtkWidget *label_qrp_patch_timestamp;
  GtkWidget *frame104;
  GtkWidget *label_qrp_indexing_time;
  GtkWidget *frame105;
  GtkWidget *label_qrp_computation_time;
  GtkWidget *frame106;
  GtkWidget *label_qrp_patch_computation_time;
  GtkWidget *alignment35;
  GtkWidget *hbox191;
  GtkWidget *frame_qrp_table_info;
  GtkWidget *table80;
  GtkWidget *label621;
  GtkWidget *label623;
  GtkWidget *label625;
  GtkWidget *label630;
  GtkWidget *label628;
  GtkWidget *label629;
  GtkWidget *label633;
  GtkWidget *label634;
  GtkWidget *vseparator4;
  GtkWidget *frame90;
  GtkWidget *label_qrp_hashed_keywords;
  GtkWidget *frame91;
  GtkWidget *label_qrp_slots;
  GtkWidget *frame92;
  GtkWidget *label_qrp_slots_filled;
  GtkWidget *frame93;
  GtkWidget *label_qrp_generation;
  GtkWidget *frame94;
  GtkWidget *label_qrp_fill_ratio;
  GtkWidget *frame95;
  GtkWidget *label_qrp_conflict_ratio;
  GtkWidget *frame_qrp_patch_info;
  GtkWidget *table81;
  GtkWidget *label635;
  GtkWidget *label636;
  GtkWidget *label637;
  GtkWidget *label638;
  GtkWidget *frame96;
  GtkWidget *label_qrp_patch_raw_length;
  GtkWidget *frame97;
  GtkWidget *label_qrp_patch_length;
  GtkWidget *frame98;
  GtkWidget *label_qrp_patch_comp_ratio;
  GtkWidget *label686;
  GtkWidget *scrolledwindow36;
  GtkWidget *viewport8;
  GtkWidget *vbox77;
  GtkWidget *frame52;
  GtkWidget *table35;
  guint checkbutton_config_confirm_quit_key;
  GtkWidget *checkbutton_config_confirm_quit;
  guint checkbutton_config_show_tooltips_key;
  GtkWidget *checkbutton_config_show_tooltips;
  guint checkbutton_config_metric_key;
  GtkWidget *checkbutton_config_metric;
  GtkWidget *checkbutton_search_jump_to_created;
  GtkWidget *label657;
  GtkWidget *option_menu_config_toolbar_style;
  GtkWidget *option_menu_config_toolbar_style_menu;
  GtkWidget *label652;
  GtkObject *spinbutton_search_accumulation_period_adj;
  GtkWidget *spinbutton_search_accumulation_period;
  GtkWidget *label653;
  GtkObject *spinbutton_entry_removal_timeout_adj;
  GtkWidget *spinbutton_entry_removal_timeout;
  GtkWidget *label600;
  GtkWidget *label599;
  GtkWidget *frame64;
  GtkWidget *table45;
  guint checkbutton_expert_mode_key;
  GtkWidget *checkbutton_expert_mode;
  GtkWidget *frame84;
  GtkWidget *hbox190;
  GtkWidget *alignment33;
  GtkWidget *vbox119;
  GtkWidget *checkbutton_node_show_detailed_info;
  GtkWidget *vbox123;
  GtkWidget *frame_gnet_detailed_traffic;
  GtkWidget *table71;
  GtkWidget *checkbutton_gnet_info_txc;
  GtkWidget *checkbutton_gnet_info_rxc;
  GtkWidget *checkbutton_gnet_info_tx_speed;
  GtkWidget *checkbutton_gnet_info_rx_speed;
  GtkWidget *checkbutton_gnet_info_tx_queries;
  GtkWidget *checkbutton_gnet_info_rx_queries;
  GtkWidget *checkbutton_gnet_info_tx_hits;
  GtkWidget *checkbutton_gnet_info_rx_hits;
  GtkWidget *checkbutton_gnet_info_gen_queries;
  GtkWidget *checkbutton_gnet_info_sq_queries;
  GtkWidget *checkbutton_gnet_info_tx_dropped;
  GtkWidget *checkbutton_gnet_info_rx_dropped;
  GtkWidget *checkbutton_gnet_info_qrp_stats;
  GtkWidget *checkbutton_gnet_info_dbw;
  GtkWidget *checkbutton_gnet_info_rt;
  GtkWidget *checkbutton_gnet_info_shared_size;
  GtkWidget *checkbutton_gnet_info_shared_files;
  GtkWidget *checkbutton_gnet_info_rx_wire;
  GtkWidget *checkbutton_gnet_info_tx_wire;
  GtkWidget *label687;
  GtkWidget *scrolledwindow37;
  GtkWidget *viewport9;
  GtkWidget *vbox75;
  GtkWidget *frame49;
  GtkWidget *vbox139;
  GtkWidget *hbox2102;
  GtkWidget *label765;
  GtkWidget *entry_dbg_property_pattern;
  GtkWidget *scrolledwindow492;
  GtkWidget *clist_dbg_property;
  GtkWidget *label766;
  GtkWidget *label767;
  GtkWidget *label_767;
  GtkWidget *label_768;
  GtkWidget *hbox2103;
  GtkWidget *label769;
  GtkWidget *label_dbg_property_name;
  GtkWidget *label771;
  GtkWidget *label_dbg_property_limits;
  GtkWidget *hbox2104;
  GtkWidget *label773;
  GtkWidget *entry_dbg_property_default;
  GtkWidget *hbox2105;
  GtkWidget *label774;
  GtkWidget *entry_dbg_property_value;
  GtkWidget *frame_expert_unmapped;
  GtkWidget *table57;
  GtkWidget *label466;
  GtkWidget *label468;
  GtkWidget *entry_average_ip_uptime;
  GtkWidget *entry_average_servent_uptime;
  GtkWidget *label480;
  GtkWidget *entry_sys_physmem;
  GtkWidget *label8025;
  GtkWidget *entry_average_servent_downtime;
  GtkWidget *label688;
  GtkWidget *dialog_action_area2;
  GtkWidget *hbox205;
  GtkWidget *button_prefs_close;
  GtkAccelGroup *accel_group;
  GtkTooltips *tooltips;

  tooltips = gtk_tooltips_new ();

  accel_group = gtk_accel_group_new ();

  dlg_prefs = gtk_dialog_new ();
  gtk_widget_set_name (dlg_prefs, "dlg_prefs");
  gtk_object_set_data (GTK_OBJECT (dlg_prefs), "dlg_prefs", dlg_prefs);
  gtk_window_set_title (GTK_WINDOW (dlg_prefs), _("Preferences"));
  gtk_window_set_default_size (GTK_WINDOW (dlg_prefs), 640, 480);
  gtk_window_set_policy (GTK_WINDOW (dlg_prefs), TRUE, TRUE, FALSE);

  dialog_vbox2 = GTK_DIALOG (dlg_prefs)->vbox;
  gtk_widget_set_name (dialog_vbox2, "dialog_vbox2");
  gtk_object_set_data (GTK_OBJECT (dlg_prefs), "dialog_vbox2", dialog_vbox2);
  gtk_widget_show (dialog_vbox2);

  notebook_prefs = gtk_notebook_new ();
  gtk_widget_set_name (notebook_prefs, "notebook_prefs");
  gtk_widget_ref (notebook_prefs);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "notebook_prefs", notebook_prefs,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (notebook_prefs);
  gtk_box_pack_start (GTK_BOX (dialog_vbox2), notebook_prefs, TRUE, TRUE, 0);

  scrolledwindow32 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow32, "scrolledwindow32");
  gtk_widget_ref (scrolledwindow32);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "scrolledwindow32", scrolledwindow32,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (scrolledwindow32);
  gtk_container_add (GTK_CONTAINER (notebook_prefs), scrolledwindow32);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow32), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);

  viewport3 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport3, "viewport3");
  gtk_widget_ref (viewport3);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "viewport3", viewport3,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (viewport3);
  gtk_container_add (GTK_CONTAINER (scrolledwindow32), viewport3);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport3), GTK_SHADOW_NONE);

  vbox24 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox24, "vbox24");
  gtk_widget_ref (vbox24);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "vbox24", vbox24,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox24);
  gtk_container_add (GTK_CONTAINER (viewport3), vbox24);
  gtk_container_set_border_width (GTK_CONTAINER (vbox24), 2);

  frame13 = gtk_frame_new (_("IP settings"));
  gtk_widget_set_name (frame13, "frame13");
  gtk_widget_ref (frame13);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame13", frame13,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame13);
  gtk_box_pack_start (GTK_BOX (vbox24), frame13, FALSE, TRUE, 0);

  vbox30 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox30, "vbox30");
  gtk_widget_ref (vbox30);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "vbox30", vbox30,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox30);
  gtk_container_add (GTK_CONTAINER (frame13), vbox30);
  gtk_container_set_border_width (GTK_CONTAINER (vbox30), 2);

  hbox79 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox79, "hbox79");
  gtk_widget_ref (hbox79);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "hbox79", hbox79,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox79);
  gtk_box_pack_start (GTK_BOX (vbox30), hbox79, FALSE, TRUE, 0);

  label128 = gtk_label_new (_("Current IP settings (Address:Port):"));
  gtk_widget_set_name (label128, "label128");
  gtk_widget_ref (label128);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label128", label128,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label128);
  gtk_box_pack_start (GTK_BOX (hbox79), label128, FALSE, FALSE, 0);

  frame116 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame116, "frame116");
  gtk_widget_ref (frame116);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame116", frame116,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame116);
  gtk_box_pack_start (GTK_BOX (hbox79), frame116, FALSE, FALSE, 0);
  gtk_frame_set_shadow_type (GTK_FRAME (frame116), GTK_SHADOW_IN);

  label_current_port = gtk_label_new (_("not yet determined"));
  gtk_widget_set_name (label_current_port, "label_current_port");
  gtk_widget_ref (label_current_port);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label_current_port", label_current_port,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_current_port);
  gtk_container_add (GTK_CONTAINER (frame116), label_current_port);
  gtk_misc_set_padding (GTK_MISC (label_current_port), 5, 0);

  hseparator2 = gtk_hseparator_new ();
  gtk_widget_set_name (hseparator2, "hseparator2");
  gtk_widget_ref (hseparator2);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "hseparator2", hseparator2,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hseparator2);
  gtk_box_pack_start (GTK_BOX (vbox30), hseparator2, FALSE, TRUE, 3);

  table5 = gtk_table_new (2, 7, FALSE);
  gtk_widget_set_name (table5, "table5");
  gtk_widget_ref (table5);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "table5", table5,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table5);
  gtk_box_pack_start (GTK_BOX (vbox30), table5, TRUE, TRUE, 0);
  gtk_table_set_row_spacings (GTK_TABLE (table5), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table5), 4);

  label129 = gtk_label_new ("");
  label129_key = gtk_label_parse_uline (GTK_LABEL (label129),
                                   _("_Listen port"));
  gtk_widget_set_name (label129, "label129");
  gtk_widget_ref (label129);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label129", label129,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label129);
  gtk_table_attach (GTK_TABLE (table5), label129, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label129), 0, 0.5);

  spinbutton_config_port_adj = gtk_adjustment_new (6346, 0, 65535, 1, 10, 10);
  spinbutton_config_port = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_port_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_port, "spinbutton_config_port");
  gtk_widget_ref (spinbutton_config_port);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_config_port", spinbutton_config_port,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_config_port);
  gtk_table_attach (GTK_TABLE (table5), spinbutton_config_port, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_usize (spinbutton_config_port, 64, -2);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_port), TRUE);

  checkbutton_give_server_hostname = gtk_check_button_new_with_label ("");
  checkbutton_give_server_hostname_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (checkbutton_give_server_hostname)->child),
                                   _("Public _hostname"));
  gtk_widget_add_accelerator (checkbutton_give_server_hostname, "clicked", accel_group,
                              checkbutton_give_server_hostname_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (checkbutton_give_server_hostname, "checkbutton_give_server_hostname");
  gtk_widget_ref (checkbutton_give_server_hostname);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_give_server_hostname", checkbutton_give_server_hostname,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_give_server_hostname);
  gtk_table_attach (GTK_TABLE (table5), checkbutton_give_server_hostname, 0, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_server_hostname = gtk_entry_new_with_max_length (255);
  gtk_widget_set_name (entry_server_hostname, "entry_server_hostname");
  gtk_widget_ref (entry_server_hostname);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "entry_server_hostname", entry_server_hostname,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_server_hostname);
  gtk_table_attach (GTK_TABLE (table5), entry_server_hostname, 2, 4, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_enable_udp = gtk_check_button_new_with_label ("");
  checkbutton_enable_udp_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (checkbutton_enable_udp)->child),
                                   _("Enable _UDP"));
  gtk_widget_add_accelerator (checkbutton_enable_udp, "clicked", accel_group,
                              checkbutton_enable_udp_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (checkbutton_enable_udp, "checkbutton_enable_udp");
  gtk_widget_ref (checkbutton_enable_udp);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_enable_udp", checkbutton_enable_udp,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_enable_udp);
  gtk_table_attach (GTK_TABLE (table5), checkbutton_enable_udp, 6, 7, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label778 = gtk_label_new (_("Network protocol:"));
  gtk_widget_set_name (label778, "label778");
  gtk_widget_ref (label778);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label778", label778,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label778);
  gtk_table_attach (GTK_TABLE (table5), label778, 3, 4, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label778), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label778), 4, 0);

  option_menu_config_network_protocol = gtk_option_menu_new ();
  gtk_widget_set_name (option_menu_config_network_protocol, "option_menu_config_network_protocol");
  gtk_widget_ref (option_menu_config_network_protocol);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "option_menu_config_network_protocol", option_menu_config_network_protocol,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (option_menu_config_network_protocol);
  gtk_table_attach (GTK_TABLE (table5), option_menu_config_network_protocol, 4, 6, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  option_menu_config_network_protocol_menu = gtk_menu_new ();
  gtk_option_menu_set_menu (GTK_OPTION_MENU (option_menu_config_network_protocol), option_menu_config_network_protocol_menu);

  label35 = gtk_label_new (_("(Disable: 0, Random: 1)"));
  gtk_widget_set_name (label35, "label35");
  gtk_widget_ref (label35);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label35", label35,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label35);
  gtk_table_attach (GTK_TABLE (table5), label35, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label35), 0, 0.5);

  checkbutton_enable_dht = gtk_check_button_new_with_label ("");
  checkbutton_enable_dht_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (checkbutton_enable_dht)->child),
                                   _("Enable _DHT"));
  gtk_widget_add_accelerator (checkbutton_enable_dht, "clicked", accel_group,
                              checkbutton_enable_dht_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (checkbutton_enable_dht, "checkbutton_enable_dht");
  gtk_widget_ref (checkbutton_enable_dht);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_enable_dht", checkbutton_enable_dht,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_enable_dht);
  gtk_table_attach (GTK_TABLE (table5), checkbutton_enable_dht, 6, 7, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  frame147 = gtk_frame_new (_("IPv4 settings"));
  gtk_widget_set_name (frame147, "frame147");
  gtk_widget_ref (frame147);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame147", frame147,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame147);
  gtk_box_pack_start (GTK_BOX (vbox24), frame147, FALSE, TRUE, 0);

  hbox2108 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox2108, "hbox2108");
  gtk_widget_ref (hbox2108);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "hbox2108", hbox2108,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox2108);
  gtk_container_add (GTK_CONTAINER (frame147), hbox2108);

  checkbutton_config_force_ip = gtk_check_button_new_with_label ("");
  checkbutton_config_force_ip_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (checkbutton_config_force_ip)->child),
                                   _("Force external IPv_4 address to"));
  gtk_widget_add_accelerator (checkbutton_config_force_ip, "clicked", accel_group,
                              checkbutton_config_force_ip_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (checkbutton_config_force_ip, "checkbutton_config_force_ip");
  gtk_widget_ref (checkbutton_config_force_ip);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_config_force_ip", checkbutton_config_force_ip,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_config_force_ip);
  gtk_box_pack_start (GTK_BOX (hbox2108), checkbutton_config_force_ip, FALSE, TRUE, 0);

  entry_config_force_ip = gtk_entry_new ();
  gtk_widget_set_name (entry_config_force_ip, "entry_config_force_ip");
  gtk_widget_ref (entry_config_force_ip);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "entry_config_force_ip", entry_config_force_ip,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_config_force_ip);
  gtk_box_pack_start (GTK_BOX (hbox2108), entry_config_force_ip, TRUE, TRUE, 0);

  checkbutton_config_bind_ipv4 = gtk_check_button_new_with_label (_("Bind to this address"));
  gtk_widget_set_name (checkbutton_config_bind_ipv4, "checkbutton_config_bind_ipv4");
  gtk_widget_ref (checkbutton_config_bind_ipv4);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_config_bind_ipv4", checkbutton_config_bind_ipv4,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_config_bind_ipv4);
  gtk_box_pack_start (GTK_BOX (hbox2108), checkbutton_config_bind_ipv4, FALSE, TRUE, 0);

  frame148 = gtk_frame_new (_("IPv6 settings"));
  gtk_widget_set_name (frame148, "frame148");
  gtk_widget_ref (frame148);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame148", frame148,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame148);
  gtk_box_pack_start (GTK_BOX (vbox24), frame148, FALSE, FALSE, 0);

  table97 = gtk_table_new (2, 3, FALSE);
  gtk_widget_set_name (table97, "table97");
  gtk_widget_ref (table97);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "table97", table97,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table97);
  gtk_container_add (GTK_CONTAINER (frame148), table97);

  checkbutton_config_force_ipv6 = gtk_check_button_new_with_label ("");
  checkbutton_config_force_ipv6_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (checkbutton_config_force_ipv6)->child),
                                   _("Force external IPv_6 address to"));
  gtk_widget_add_accelerator (checkbutton_config_force_ipv6, "clicked", accel_group,
                              checkbutton_config_force_ipv6_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (checkbutton_config_force_ipv6, "checkbutton_config_force_ipv6");
  gtk_widget_ref (checkbutton_config_force_ipv6);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_config_force_ipv6", checkbutton_config_force_ipv6,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_config_force_ipv6);
  gtk_table_attach (GTK_TABLE (table97), checkbutton_config_force_ipv6, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_config_force_ipv6 = gtk_entry_new ();
  gtk_widget_set_name (entry_config_force_ipv6, "entry_config_force_ipv6");
  gtk_widget_ref (entry_config_force_ipv6);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "entry_config_force_ipv6", entry_config_force_ipv6,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_config_force_ipv6);
  gtk_table_attach (GTK_TABLE (table97), entry_config_force_ipv6, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_config_bind_ipv6 = gtk_check_button_new_with_label (_("Bind to this address"));
  gtk_widget_set_name (checkbutton_config_bind_ipv6, "checkbutton_config_bind_ipv6");
  gtk_widget_ref (checkbutton_config_bind_ipv6);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_config_bind_ipv6", checkbutton_config_bind_ipv6,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_config_bind_ipv6);
  gtk_table_attach (GTK_TABLE (table97), checkbutton_config_bind_ipv6, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_config_ipv6_trt_prefix = gtk_entry_new ();
  gtk_widget_set_name (entry_config_ipv6_trt_prefix, "entry_config_ipv6_trt_prefix");
  gtk_widget_ref (entry_config_ipv6_trt_prefix);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "entry_config_ipv6_trt_prefix", entry_config_ipv6_trt_prefix,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_config_ipv6_trt_prefix);
  gtk_table_attach (GTK_TABLE (table97), entry_config_ipv6_trt_prefix, 1, 3, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_config_ipv6_trt_enable = gtk_check_button_new_with_label (_("Use IPv6-to-IPv4 TRT prefix:"));
  gtk_widget_set_name (checkbutton_config_ipv6_trt_enable, "checkbutton_config_ipv6_trt_enable");
  gtk_widget_ref (checkbutton_config_ipv6_trt_enable);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_config_ipv6_trt_enable", checkbutton_config_ipv6_trt_enable,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_config_ipv6_trt_enable);
  gtk_table_attach (GTK_TABLE (table97), checkbutton_config_ipv6_trt_enable, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  frame_expert_nw_port_mapping = gtk_frame_new (_("Port Mapping"));
  gtk_widget_set_name (frame_expert_nw_port_mapping, "frame_expert_nw_port_mapping");
  gtk_widget_ref (frame_expert_nw_port_mapping);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame_expert_nw_port_mapping", frame_expert_nw_port_mapping,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame_expert_nw_port_mapping);
  gtk_box_pack_start (GTK_BOX (vbox24), frame_expert_nw_port_mapping, TRUE, TRUE, 0);

  table102 = gtk_table_new (2, 2, FALSE);
  gtk_widget_set_name (table102, "table102");
  gtk_widget_ref (table102);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "table102", table102,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table102);
  gtk_container_add (GTK_CONTAINER (frame_expert_nw_port_mapping), table102);
  gtk_container_set_border_width (GTK_CONTAINER (table102), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table102), 4);

  checkbutton_enable_natpmp = gtk_check_button_new_with_label (_("Enable NAT-PMP"));
  gtk_widget_set_name (checkbutton_enable_natpmp, "checkbutton_enable_natpmp");
  gtk_widget_ref (checkbutton_enable_natpmp);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_enable_natpmp", checkbutton_enable_natpmp,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_enable_natpmp);
  gtk_table_attach (GTK_TABLE (table102), checkbutton_enable_natpmp, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_enable_upnp = gtk_check_button_new_with_label (_("Enable UPnP"));
  gtk_widget_set_name (checkbutton_enable_upnp, "checkbutton_enable_upnp");
  gtk_widget_ref (checkbutton_enable_upnp);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_enable_upnp", checkbutton_enable_upnp,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_enable_upnp);
  gtk_table_attach (GTK_TABLE (table102), checkbutton_enable_upnp, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label8034 = gtk_label_new (_("Mapping lease time"));
  gtk_widget_set_name (label8034, "label8034");
  gtk_widget_ref (label8034);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label8034", label8034,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label8034);
  gtk_table_attach (GTK_TABLE (table102), label8034, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label8034), 0, 0.5);

  spinbutton_config_upnp_mapping_lease_time_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 10);
  spinbutton_config_upnp_mapping_lease_time = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_upnp_mapping_lease_time_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_upnp_mapping_lease_time, "spinbutton_config_upnp_mapping_lease_time");
  gtk_widget_ref (spinbutton_config_upnp_mapping_lease_time);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_config_upnp_mapping_lease_time", spinbutton_config_upnp_mapping_lease_time,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_config_upnp_mapping_lease_time);
  gtk_table_attach (GTK_TABLE (table102), spinbutton_config_upnp_mapping_lease_time, 1, 2, 1, 2,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_usize (spinbutton_config_upnp_mapping_lease_time, 64, -2);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_upnp_mapping_lease_time), TRUE);

  frame_proxy_settings = gtk_frame_new (_("Proxy settings"));
  gtk_widget_set_name (frame_proxy_settings, "frame_proxy_settings");
  gtk_widget_ref (frame_proxy_settings);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame_proxy_settings", frame_proxy_settings,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame_proxy_settings);
  gtk_box_pack_start (GTK_BOX (vbox24), frame_proxy_settings, FALSE, TRUE, 0);

  vbox100 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox100, "vbox100");
  gtk_widget_ref (vbox100);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "vbox100", vbox100,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox100);
  gtk_container_add (GTK_CONTAINER (frame_proxy_settings), vbox100);
  gtk_container_set_border_width (GTK_CONTAINER (vbox100), 2);

  table53 = gtk_table_new (2, 4, FALSE);
  gtk_widget_set_name (table53, "table53");
  gtk_widget_ref (table53);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "table53", table53,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table53);
  gtk_box_pack_start (GTK_BOX (vbox100), table53, FALSE, TRUE, 0);
  gtk_table_set_row_spacings (GTK_TABLE (table53), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table53), 4);

  label91 = gtk_label_new ("");
  label91_key = gtk_label_parse_uline (GTK_LABEL (label91),
                                   _("H_ost:"));
  gtk_widget_set_name (label91, "label91");
  gtk_widget_ref (label91);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label91", label91,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label91);
  gtk_table_attach (GTK_TABLE (table53), label91, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label91), 0, 0.5);

  label92 = gtk_label_new ("");
  label92_key = gtk_label_parse_uline (GTK_LABEL (label92),
                                   _("TCP _Port:"));
  gtk_widget_set_name (label92, "label92");
  gtk_widget_ref (label92);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label92", label92,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label92);
  gtk_table_attach (GTK_TABLE (table53), label92, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label90 = gtk_label_new ("");
  label90_key = gtk_label_parse_uline (GTK_LABEL (label90),
                                   _("Proxy _type:"));
  gtk_widget_set_name (label90, "label90");
  gtk_widget_ref (label90);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label90", label90,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label90);
  gtk_table_attach (GTK_TABLE (table53), label90, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  spinbutton_config_proxy_port_adj = gtk_adjustment_new (3128, 1, 65535, 1, 10, 10);
  spinbutton_config_proxy_port = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_proxy_port_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_proxy_port, "spinbutton_config_proxy_port");
  gtk_widget_ref (spinbutton_config_proxy_port);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_config_proxy_port", spinbutton_config_proxy_port,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_config_proxy_port);
  gtk_table_attach (GTK_TABLE (table53), spinbutton_config_proxy_port, 3, 4, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_usize (spinbutton_config_proxy_port, 64, -2);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_proxy_port), TRUE);

  entry_config_proxy_hostname = gtk_entry_new ();
  gtk_widget_set_name (entry_config_proxy_hostname, "entry_config_proxy_hostname");
  gtk_widget_ref (entry_config_proxy_hostname);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "entry_config_proxy_hostname", entry_config_proxy_hostname,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_config_proxy_hostname);
  gtk_table_attach (GTK_TABLE (table53), entry_config_proxy_hostname, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  option_menu_config_proxy_protocol = gtk_option_menu_new ();
  gtk_widget_set_name (option_menu_config_proxy_protocol, "option_menu_config_proxy_protocol");
  gtk_widget_ref (option_menu_config_proxy_protocol);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "option_menu_config_proxy_protocol", option_menu_config_proxy_protocol,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (option_menu_config_proxy_protocol);
  gtk_table_attach (GTK_TABLE (table53), option_menu_config_proxy_protocol, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  option_menu_config_proxy_protocol_menu = gtk_menu_new ();
  gtk_option_menu_set_menu (GTK_OPTION_MENU (option_menu_config_proxy_protocol), option_menu_config_proxy_protocol_menu);

  table54 = gtk_table_new (2, 4, FALSE);
  gtk_widget_set_name (table54, "table54");
  gtk_widget_ref (table54);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "table54", table54,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table54);
  gtk_box_pack_start (GTK_BOX (vbox100), table54, FALSE, TRUE, 0);
  gtk_table_set_row_spacings (GTK_TABLE (table54), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table54), 4);

  checkbutton_config_proxy_auth = gtk_check_button_new_with_label ("");
  checkbutton_config_proxy_auth_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (checkbutton_config_proxy_auth)->child),
                                   _("Use username and password to _authenticate to proxy"));
  gtk_widget_add_accelerator (checkbutton_config_proxy_auth, "clicked", accel_group,
                              checkbutton_config_proxy_auth_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (checkbutton_config_proxy_auth, "checkbutton_config_proxy_auth");
  gtk_widget_ref (checkbutton_config_proxy_auth);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_config_proxy_auth", checkbutton_config_proxy_auth,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_config_proxy_auth);
  gtk_table_attach (GTK_TABLE (table54), checkbutton_config_proxy_auth, 0, 4, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label93 = gtk_label_new ("");
  label93_key = gtk_label_parse_uline (GTK_LABEL (label93),
                                   _("_Username"));
  gtk_widget_set_name (label93, "label93");
  gtk_widget_ref (label93);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label93", label93,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label93);
  gtk_table_attach (GTK_TABLE (table54), label93, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label93), 0, 0.5);

  label94 = gtk_label_new ("");
  label94_key = gtk_label_parse_uline (GTK_LABEL (label94),
                                   _("Pass_word"));
  gtk_widget_set_name (label94, "label94");
  gtk_widget_ref (label94);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label94", label94,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label94);
  gtk_table_attach (GTK_TABLE (table54), label94, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label94), 0, 0.5);

  entry_config_socks_password = gtk_entry_new ();
  gtk_widget_set_name (entry_config_socks_password, "entry_config_socks_password");
  gtk_widget_ref (entry_config_socks_password);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "entry_config_socks_password", entry_config_socks_password,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_config_socks_password);
  gtk_table_attach (GTK_TABLE (table54), entry_config_socks_password, 3, 4, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_usize (entry_config_socks_password, 82, -2);

  entry_config_socks_username = gtk_entry_new ();
  gtk_widget_set_name (entry_config_socks_username, "entry_config_socks_username");
  gtk_widget_ref (entry_config_socks_username);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "entry_config_socks_username", entry_config_socks_username,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_config_socks_username);
  gtk_table_attach (GTK_TABLE (table54), entry_config_socks_username, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_usize (entry_config_socks_username, 82, -2);

  frame_expert_nw_local = gtk_frame_new (_("Local networks"));
  gtk_widget_set_name (frame_expert_nw_local, "frame_expert_nw_local");
  gtk_widget_ref (frame_expert_nw_local);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame_expert_nw_local", frame_expert_nw_local,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame_expert_nw_local);
  gtk_box_pack_start (GTK_BOX (vbox24), frame_expert_nw_local, FALSE, TRUE, 0);

  vbox23_2 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox23_2, "vbox23_2");
  gtk_widget_ref (vbox23_2);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "vbox23_2", vbox23_2,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox23_2);
  gtk_container_add (GTK_CONTAINER (frame_expert_nw_local), vbox23_2);
  gtk_container_set_border_width (GTK_CONTAINER (vbox23_2), 2);

  hbox77 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox77, "hbox77");
  gtk_widget_ref (hbox77);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "hbox77", hbox77,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox77);
  gtk_box_pack_start (GTK_BOX (vbox23_2), hbox77, FALSE, FALSE, 0);

  checkbutton_config_use_netmasks = gtk_check_button_new_with_label ("");
  checkbutton_config_use_netmasks_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (checkbutton_config_use_netmasks)->child),
                                   _("_Try to connect to local networks first"));
  gtk_widget_add_accelerator (checkbutton_config_use_netmasks, "clicked", accel_group,
                              checkbutton_config_use_netmasks_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (checkbutton_config_use_netmasks, "checkbutton_config_use_netmasks");
  gtk_widget_ref (checkbutton_config_use_netmasks);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_config_use_netmasks", checkbutton_config_use_netmasks,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_config_use_netmasks);
  gtk_box_pack_start (GTK_BOX (hbox77), checkbutton_config_use_netmasks, FALSE, FALSE, 0);

  checkbutton_config_no_rfc1918 = gtk_check_button_new_with_label ("");
  checkbutton_config_no_rfc1918_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (checkbutton_config_no_rfc1918)->child),
                                   _("Allow connections from and to _LAN addresses"));
  gtk_widget_add_accelerator (checkbutton_config_no_rfc1918, "clicked", accel_group,
                              checkbutton_config_no_rfc1918_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (checkbutton_config_no_rfc1918, "checkbutton_config_no_rfc1918");
  gtk_widget_ref (checkbutton_config_no_rfc1918);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_config_no_rfc1918", checkbutton_config_no_rfc1918,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_config_no_rfc1918);
  gtk_box_pack_start (GTK_BOX (hbox77), checkbutton_config_no_rfc1918, FALSE, FALSE, 0);

  hbox78 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox78, "hbox78");
  gtk_widget_ref (hbox78);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "hbox78", hbox78,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox78);
  gtk_box_pack_start (GTK_BOX (vbox23_2), hbox78, FALSE, FALSE, 0);

  label126_2 = gtk_label_new (_("Local networks"));
  gtk_widget_set_name (label126_2, "label126_2");
  gtk_widget_ref (label126_2);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label126_2", label126_2,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label126_2);
  gtk_box_pack_start (GTK_BOX (hbox78), label126_2, FALSE, FALSE, 0);

  entry_config_netmasks = gtk_entry_new ();
  gtk_widget_set_name (entry_config_netmasks, "entry_config_netmasks");
  gtk_widget_ref (entry_config_netmasks);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "entry_config_netmasks", entry_config_netmasks,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_config_netmasks);
  gtk_box_pack_start (GTK_BOX (hbox78), entry_config_netmasks, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, entry_config_netmasks, _("Enter a semicolon separated list of networks that are local to you in the form of ip/bits or ip/netmask (eg 192.168.1.0/24 or 192.168.1.0/255.255.255.0)"), NULL);

  frame_expert_nw_misc = gtk_frame_new (_("Banning"));
  gtk_widget_set_name (frame_expert_nw_misc, "frame_expert_nw_misc");
  gtk_widget_ref (frame_expert_nw_misc);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame_expert_nw_misc", frame_expert_nw_misc,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame_expert_nw_misc);
  gtk_box_pack_start (GTK_BOX (vbox24), frame_expert_nw_misc, FALSE, TRUE, 0);

  table48 = gtk_table_new (4, 4, FALSE);
  gtk_widget_set_name (table48, "table48");
  gtk_widget_ref (table48);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "table48", table48,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table48);
  gtk_container_add (GTK_CONTAINER (frame_expert_nw_misc), table48);
  gtk_container_set_border_width (GTK_CONTAINER (table48), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table48), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table48), 4);

  label441 = gtk_label_new ("");
  label441_key = gtk_label_parse_uline (GTK_LABEL (label441),
                                   _("Max. file _descriptors reserved"));
  gtk_widget_set_name (label441, "label441");
  gtk_widget_ref (label441);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label441", label441,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label441);
  gtk_table_attach (GTK_TABLE (table48), label441, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label441), 0, 0.5);

  label442 = gtk_label_new ("");
  label442_key = gtk_label_parse_uline (GTK_LABEL (label442),
                                   _("Max. _percentage of file descriptors"));
  gtk_widget_set_name (label442, "label442");
  gtk_widget_ref (label442);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label442", label442,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label442);
  gtk_table_attach (GTK_TABLE (table48), label442, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label442), 0, 0.5);

  spinbutton_config_ban_max_fds_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 10);
  spinbutton_config_ban_max_fds = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_ban_max_fds_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_ban_max_fds, "spinbutton_config_ban_max_fds");
  gtk_widget_ref (spinbutton_config_ban_max_fds);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_config_ban_max_fds", spinbutton_config_ban_max_fds,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_config_ban_max_fds);
  gtk_table_attach (GTK_TABLE (table48), spinbutton_config_ban_max_fds, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_usize (spinbutton_config_ban_max_fds, 64, -2);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_ban_max_fds), TRUE);

  spinbutton_config_ban_ratio_fds_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 10);
  spinbutton_config_ban_ratio_fds = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_ban_ratio_fds_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_ban_ratio_fds, "spinbutton_config_ban_ratio_fds");
  gtk_widget_ref (spinbutton_config_ban_ratio_fds);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_config_ban_ratio_fds", spinbutton_config_ban_ratio_fds,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_config_ban_ratio_fds);
  gtk_table_attach (GTK_TABLE (table48), spinbutton_config_ban_ratio_fds, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_ban_ratio_fds), TRUE);

  label502 = gtk_label_new ("");
  label502_key = gtk_label_parse_uline (GTK_LABEL (label502),
                                   _("Hard limit of _file descriptors used"));
  gtk_widget_set_name (label502, "label502");
  gtk_widget_ref (label502);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label502", label502,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label502);
  gtk_table_attach (GTK_TABLE (table48), label502, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label502), 0, 0.5);

  entry_config_max_banned_fd = gtk_entry_new ();
  gtk_widget_set_name (entry_config_max_banned_fd, "entry_config_max_banned_fd");
  gtk_widget_ref (entry_config_max_banned_fd);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "entry_config_max_banned_fd", entry_config_max_banned_fd,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_config_max_banned_fd);
  gtk_table_attach (GTK_TABLE (table48), entry_config_max_banned_fd, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_sensitive (entry_config_max_banned_fd, FALSE);
  gtk_tooltips_set_tip (tooltips, entry_config_max_banned_fd, _("Actual amount of file descriptors used -- cannot be changed at runtime"), NULL);
  gtk_entry_set_editable (GTK_ENTRY (entry_config_max_banned_fd), FALSE);

  label654 = gtk_label_new (_("Currently used"));
  gtk_widget_set_name (label654, "label654");
  gtk_widget_ref (label654);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label654", label654,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label654);
  gtk_table_attach (GTK_TABLE (table48), label654, 2, 3, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label654), 0, 0.5);

  frame120 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame120, "frame120");
  gtk_widget_ref (frame120);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame120", frame120,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame120);
  gtk_table_attach (GTK_TABLE (table48), frame120, 3, 4, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_frame_set_shadow_type (GTK_FRAME (frame120), GTK_SHADOW_IN);

  label_banned_count = gtk_label_new (_("[place holder]"));
  gtk_widget_set_name (label_banned_count, "label_banned_count");
  gtk_widget_ref (label_banned_count);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label_banned_count", label_banned_count,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_banned_count);
  gtk_container_add (GTK_CONTAINER (frame120), label_banned_count);
  gtk_misc_set_padding (GTK_MISC (label_banned_count), 5, 0);

  checkbutton_use_global_hostiles = gtk_check_button_new_with_label (_("Use global hostiles.txt"));
  gtk_widget_set_name (checkbutton_use_global_hostiles, "checkbutton_use_global_hostiles");
  gtk_widget_ref (checkbutton_use_global_hostiles);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_use_global_hostiles", checkbutton_use_global_hostiles,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_use_global_hostiles);
  gtk_table_attach (GTK_TABLE (table48), checkbutton_use_global_hostiles, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  frame80 = gtk_frame_new (_("Clock synchronization"));
  gtk_widget_set_name (frame80, "frame80");
  gtk_widget_ref (frame80);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame80", frame80,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame80);
  gtk_box_pack_start (GTK_BOX (vbox24), frame80, FALSE, TRUE, 0);

  table62 = gtk_table_new (1, 3, FALSE);
  gtk_widget_set_name (table62, "table62");
  gtk_widget_ref (table62);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "table62", table62,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table62);
  gtk_container_add (GTK_CONTAINER (frame80), table62);
  gtk_container_set_border_width (GTK_CONTAINER (table62), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table62), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table62), 4);

  checkbutton_host_runs_ntp = gtk_check_button_new_with_label ("");
  checkbutton_host_runs_ntp_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (checkbutton_host_runs_ntp)->child),
                                   _("Host runs _NTP"));
  gtk_widget_add_accelerator (checkbutton_host_runs_ntp, "clicked", accel_group,
                              checkbutton_host_runs_ntp_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (checkbutton_host_runs_ntp, "checkbutton_host_runs_ntp");
  gtk_widget_ref (checkbutton_host_runs_ntp);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_host_runs_ntp", checkbutton_host_runs_ntp,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_host_runs_ntp);
  gtk_table_attach (GTK_TABLE (table62), checkbutton_host_runs_ntp, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label529 = gtk_label_new (_("Clock skew:"));
  gtk_widget_set_name (label529, "label529");
  gtk_widget_ref (label529);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label529", label529,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label529);
  gtk_table_attach (GTK_TABLE (table62), label529, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label529), 0, 0.5);

  frame117 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame117, "frame117");
  gtk_widget_ref (frame117);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame117", frame117,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame117);
  gtk_table_attach (GTK_TABLE (table62), frame117, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_frame_set_shadow_type (GTK_FRAME (frame117), GTK_SHADOW_IN);

  label_clock_skew = gtk_label_new (_("[place holder]"));
  gtk_widget_set_name (label_clock_skew, "label_clock_skew");
  gtk_widget_ref (label_clock_skew);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label_clock_skew", label_clock_skew,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_clock_skew);
  gtk_container_add (GTK_CONTAINER (frame117), label_clock_skew);
  gtk_misc_set_padding (GTK_MISC (label_clock_skew), 5, 0);

  frame86 = gtk_frame_new (_("Miscellaneous"));
  gtk_widget_set_name (frame86, "frame86");
  gtk_widget_ref (frame86);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame86", frame86,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame86);
  gtk_box_pack_start (GTK_BOX (vbox24), frame86, FALSE, TRUE, 0);

  vbox120 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox120, "vbox120");
  gtk_widget_ref (vbox120);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "vbox120", vbox120,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox120);
  gtk_container_add (GTK_CONTAINER (frame86), vbox120);

  checkbutton_enable_remote_shell = gtk_check_button_new_with_label ("");
  checkbutton_enable_remote_shell_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (checkbutton_enable_remote_shell)->child),
                                   _("Enable remote _shell control interface"));
  gtk_widget_add_accelerator (checkbutton_enable_remote_shell, "clicked", accel_group,
                              checkbutton_enable_remote_shell_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (checkbutton_enable_remote_shell, "checkbutton_enable_remote_shell");
  gtk_widget_ref (checkbutton_enable_remote_shell);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_enable_remote_shell", checkbutton_enable_remote_shell,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_enable_remote_shell);
  gtk_box_pack_start (GTK_BOX (vbox120), checkbutton_enable_remote_shell, FALSE, FALSE, 0);

  frame_expert_rx_buffers = gtk_frame_new (_("Socket receive buffer size"));
  gtk_widget_set_name (frame_expert_rx_buffers, "frame_expert_rx_buffers");
  gtk_widget_ref (frame_expert_rx_buffers);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame_expert_rx_buffers", frame_expert_rx_buffers,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame_expert_rx_buffers);
  gtk_box_pack_start (GTK_BOX (vbox24), frame_expert_rx_buffers, FALSE, TRUE, 0);

  table67 = gtk_table_new (2, 3, FALSE);
  gtk_widget_set_name (table67, "table67");
  gtk_widget_ref (table67);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "table67", table67,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table67);
  gtk_container_add (GTK_CONTAINER (frame_expert_rx_buffers), table67);
  gtk_container_set_border_width (GTK_CONTAINER (table67), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table67), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table67), 4);

  label553 = gtk_label_new ("");
  label553_key = gtk_label_parse_uline (GTK_LABEL (label553),
                                   _("_Gnutella RX buffer:"));
  gtk_widget_set_name (label553, "label553");
  gtk_widget_ref (label553);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label553", label553,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label553);
  gtk_table_attach (GTK_TABLE (table67), label553, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label553), 0, 0.5);

  label554 = gtk_label_new (_("KiB"));
  gtk_widget_set_name (label554, "label554");
  gtk_widget_ref (label554);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label554", label554,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label554);
  gtk_table_attach (GTK_TABLE (table67), label554, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label554), 0, 0.5);

  label555 = gtk_label_new (_("KiB"));
  gtk_widget_set_name (label555, "label555");
  gtk_widget_ref (label555);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label555", label555,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label555);
  gtk_table_attach (GTK_TABLE (table67), label555, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label555), 0, 0.5);

  label552 = gtk_label_new ("");
  label552_key = gtk_label_parse_uline (GTK_LABEL (label552),
                                   _("_Download RX buffer:"));
  gtk_widget_set_name (label552, "label552");
  gtk_widget_ref (label552);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label552", label552,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label552);
  gtk_table_attach (GTK_TABLE (table67), label552, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label552), 0, 0.5);

  spinbutton_node_rx_size_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 10);
  spinbutton_node_rx_size = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_node_rx_size_adj), 1, 0);
  gtk_widget_set_name (spinbutton_node_rx_size, "spinbutton_node_rx_size");
  gtk_widget_ref (spinbutton_node_rx_size);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_node_rx_size", spinbutton_node_rx_size,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_node_rx_size);
  gtk_table_attach (GTK_TABLE (table67), spinbutton_node_rx_size, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_node_rx_size), TRUE);

  spinbutton_download_rx_size_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 10);
  spinbutton_download_rx_size = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_download_rx_size_adj), 1, 0);
  gtk_widget_set_name (spinbutton_download_rx_size, "spinbutton_download_rx_size");
  gtk_widget_ref (spinbutton_download_rx_size);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_download_rx_size", spinbutton_download_rx_size,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_download_rx_size);
  gtk_table_attach (GTK_TABLE (table67), spinbutton_download_rx_size, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_download_rx_size), TRUE);

  label682 = gtk_label_new (_("Network"));
  gtk_widget_set_name (label682, "label682");
  gtk_widget_ref (label682);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label682", label682,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label682);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_prefs), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_prefs), 0), label682);

  scrolledwindow19 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow19, "scrolledwindow19");
  gtk_widget_ref (scrolledwindow19);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "scrolledwindow19", scrolledwindow19,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (scrolledwindow19);
  gtk_container_add (GTK_CONTAINER (notebook_prefs), scrolledwindow19);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow19), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);

  viewport5 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport5, "viewport5");
  gtk_widget_ref (viewport5);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "viewport5", viewport5,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (viewport5);
  gtk_container_add (GTK_CONTAINER (scrolledwindow19), viewport5);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport5), GTK_SHADOW_NONE);

  vbox25 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox25, "vbox25");
  gtk_widget_ref (vbox25);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "vbox25", vbox25,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox25);
  gtk_container_add (GTK_CONTAINER (viewport5), vbox25);
  gtk_container_set_border_width (GTK_CONTAINER (vbox25), 2);

  frame71 = gtk_frame_new (_("Gnutella network mode"));
  gtk_widget_set_name (frame71, "frame71");
  gtk_widget_ref (frame71);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame71", frame71,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame71);
  gtk_box_pack_start (GTK_BOX (vbox25), frame71, FALSE, FALSE, 0);

  hbox186 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox186, "hbox186");
  gtk_widget_ref (hbox186);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "hbox186", hbox186,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox186);
  gtk_container_add (GTK_CONTAINER (frame71), hbox186);
  gtk_container_set_border_width (GTK_CONTAINER (hbox186), 2);

  alignment30 = gtk_alignment_new (0, 0.5, 0, 1);
  gtk_widget_set_name (alignment30, "alignment30");
  gtk_widget_ref (alignment30);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "alignment30", alignment30,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (alignment30);
  gtk_box_pack_start (GTK_BOX (hbox186), alignment30, TRUE, TRUE, 0);

  table82 = gtk_table_new (4, 2, FALSE);
  gtk_widget_set_name (table82, "table82");
  gtk_widget_ref (table82);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "table82", table82,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table82);
  gtk_container_add (GTK_CONTAINER (alignment30), table82);

  label439 = gtk_label_new (_("Configured peermode"));
  gtk_widget_set_name (label439, "label439");
  gtk_widget_ref (label439);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label439", label439,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label439);
  gtk_table_attach (GTK_TABLE (table82), label439, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label439), GTK_JUSTIFY_LEFT);
  gtk_misc_set_alignment (GTK_MISC (label439), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label439), 2, 0);

  checkbutton_gnet_monitor_ip = gtk_check_button_new_with_label (_("Monitor bad node IP addresses"));
  gtk_widget_set_name (checkbutton_gnet_monitor_ip, "checkbutton_gnet_monitor_ip");
  gtk_widget_ref (checkbutton_gnet_monitor_ip);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_gnet_monitor_ip", checkbutton_gnet_monitor_ip,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_gnet_monitor_ip);
  gtk_table_attach (GTK_TABLE (table82), checkbutton_gnet_monitor_ip, 0, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_gnet_monitor_servents = gtk_check_button_new_with_label (_("Monitor and auto-ban unstable servent types"));
  gtk_widget_set_name (checkbutton_gnet_monitor_servents, "checkbutton_gnet_monitor_servents");
  gtk_widget_ref (checkbutton_gnet_monitor_servents);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_gnet_monitor_servents", checkbutton_gnet_monitor_servents,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_gnet_monitor_servents);
  gtk_table_attach (GTK_TABLE (table82), checkbutton_gnet_monitor_servents, 0, 2, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  alignment34 = gtk_alignment_new (0, 0.5, 0, 1);
  gtk_widget_set_name (alignment34, "alignment34");
  gtk_widget_ref (alignment34);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "alignment34", alignment34,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (alignment34);
  gtk_table_attach (GTK_TABLE (table82), alignment34, 0, 2, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  frame72 = gtk_frame_new (_("Ultrapeer mode settings"));
  gtk_widget_set_name (frame72, "frame72");
  gtk_widget_ref (frame72);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame72", frame72,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame72);
  gtk_container_add (GTK_CONTAINER (alignment34), frame72);
  gtk_frame_set_shadow_type (GTK_FRAME (frame72), GTK_SHADOW_OUT);

  table87 = gtk_table_new (2, 2, FALSE);
  gtk_widget_set_name (table87, "table87");
  gtk_widget_ref (table87);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "table87", table87,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table87);
  gtk_container_add (GTK_CONTAINER (frame72), table87);
  gtk_container_set_border_width (GTK_CONTAINER (table87), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table87), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table87), 4);

  label459 = gtk_label_new (_("Legacy connections"));
  gtk_widget_set_name (label459, "label459");
  gtk_widget_ref (label459);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label459", label459,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label459);
  gtk_table_attach (GTK_TABLE (table87), label459, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label504 = gtk_label_new (_("Maximum # of leaves"));
  gtk_widget_set_name (label504, "label504");
  gtk_widget_ref (label504);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label504", label504,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label504);
  gtk_table_attach (GTK_TABLE (table87), label504, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label504), 0, 0.5);

  spinbutton_normal_connections_adj = gtk_adjustment_new (0, 0, 100, 1, 10, 10);
  spinbutton_normal_connections = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_normal_connections_adj), 1, 0);
  gtk_widget_set_name (spinbutton_normal_connections, "spinbutton_normal_connections");
  gtk_widget_ref (spinbutton_normal_connections);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_normal_connections", spinbutton_normal_connections,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_normal_connections);
  gtk_table_attach (GTK_TABLE (table87), spinbutton_normal_connections, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  spinbutton_config_max_leaves_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 10);
  spinbutton_config_max_leaves = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_max_leaves_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_max_leaves, "spinbutton_config_max_leaves");
  gtk_widget_ref (spinbutton_config_max_leaves);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_config_max_leaves", spinbutton_config_max_leaves,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_config_max_leaves);
  gtk_table_attach (GTK_TABLE (table87), spinbutton_config_max_leaves, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  option_menu_config_peermode = gtk_option_menu_new ();
  gtk_widget_set_name (option_menu_config_peermode, "option_menu_config_peermode");
  gtk_widget_ref (option_menu_config_peermode);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "option_menu_config_peermode", option_menu_config_peermode,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (option_menu_config_peermode);
  gtk_table_attach (GTK_TABLE (table82), option_menu_config_peermode, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  option_menu_config_peermode_menu = gtk_menu_new ();
  gtk_option_menu_set_menu (GTK_OPTION_MENU (option_menu_config_peermode), option_menu_config_peermode_menu);

  vbox121 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox121, "vbox121");
  gtk_widget_ref (vbox121);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "vbox121", vbox121,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox121);
  gtk_box_pack_start (GTK_BOX (hbox186), vbox121, FALSE, TRUE, 0);

  frame_gnet_can_become_ultra = gtk_frame_new (_("Ultrapeer promotion statistics"));
  gtk_widget_set_name (frame_gnet_can_become_ultra, "frame_gnet_can_become_ultra");
  gtk_widget_ref (frame_gnet_can_become_ultra);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame_gnet_can_become_ultra", frame_gnet_can_become_ultra,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame_gnet_can_become_ultra);
  gtk_box_pack_start (GTK_BOX (vbox121), frame_gnet_can_become_ultra, FALSE, TRUE, 0);
  gtk_frame_set_shadow_type (GTK_FRAME (frame_gnet_can_become_ultra), GTK_SHADOW_OUT);

  vbox116 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox116, "vbox116");
  gtk_widget_ref (vbox116);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "vbox116", vbox116,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox116);
  gtk_container_add (GTK_CONTAINER (frame_gnet_can_become_ultra), vbox116);
  gtk_container_set_border_width (GTK_CONTAINER (vbox116), 2);

  table73 = gtk_table_new (1, 4, FALSE);
  gtk_widget_set_name (table73, "table73");
  gtk_widget_ref (table73);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "table73", table73,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table73);
  gtk_box_pack_start (GTK_BOX (vbox116), table73, TRUE, TRUE, 0);
  gtk_table_set_row_spacings (GTK_TABLE (table73), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table73), 4);

  label577 = gtk_label_new (_("Last check"));
  gtk_widget_set_name (label577, "label577");
  gtk_widget_ref (label577);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label577", label577,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label577);
  gtk_table_attach (GTK_TABLE (table73), label577, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label577), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label577), 2, 0);

  label579 = gtk_label_new (_("Last switch"));
  gtk_widget_set_name (label579, "label579");
  gtk_widget_ref (label579);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label579", label579,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label579);
  gtk_table_attach (GTK_TABLE (table73), label579, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label579), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label579), 2, 0);

  frame107 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame107, "frame107");
  gtk_widget_ref (frame107);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame107", frame107,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame107);
  gtk_table_attach (GTK_TABLE (table73), frame107, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_frame_set_shadow_type (GTK_FRAME (frame107), GTK_SHADOW_IN);

  label_node_last_ultracheck = gtk_label_new (_("[place holder]"));
  gtk_widget_set_name (label_node_last_ultracheck, "label_node_last_ultracheck");
  gtk_widget_ref (label_node_last_ultracheck);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label_node_last_ultracheck", label_node_last_ultracheck,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_node_last_ultracheck);
  gtk_container_add (GTK_CONTAINER (frame107), label_node_last_ultracheck);
  gtk_misc_set_padding (GTK_MISC (label_node_last_ultracheck), 5, 0);

  frame108 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame108, "frame108");
  gtk_widget_ref (frame108);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame108", frame108,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame108);
  gtk_table_attach (GTK_TABLE (table73), frame108, 3, 4, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_frame_set_shadow_type (GTK_FRAME (frame108), GTK_SHADOW_IN);

  label_last_ultra_leaf_switch = gtk_label_new (_("[place holder]"));
  gtk_widget_set_name (label_last_ultra_leaf_switch, "label_last_ultra_leaf_switch");
  gtk_widget_ref (label_last_ultra_leaf_switch);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label_last_ultra_leaf_switch", label_last_ultra_leaf_switch,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_last_ultra_leaf_switch);
  gtk_container_add (GTK_CONTAINER (frame108), label_last_ultra_leaf_switch);
  gtk_misc_set_padding (GTK_MISC (label_last_ultra_leaf_switch), 5, 0);

  hseparator14 = gtk_hseparator_new ();
  gtk_widget_set_name (hseparator14, "hseparator14");
  gtk_widget_ref (hseparator14);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "hseparator14", hseparator14,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hseparator14);
  gtk_box_pack_start (GTK_BOX (vbox116), hseparator14, FALSE, TRUE, 0);

  table74 = gtk_table_new (5, 5, FALSE);
  gtk_widget_set_name (table74, "table74");
  gtk_widget_ref (table74);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "table74", table74,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table74);
  gtk_box_pack_start (GTK_BOX (vbox116), table74, TRUE, TRUE, 0);
  gtk_table_set_col_spacings (GTK_TABLE (table74), 2);

  label584 = gtk_label_new (_("Large enough uptime"));
  gtk_widget_set_name (label584, "label584");
  gtk_widget_ref (label584);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label584", label584,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label584);
  gtk_table_attach (GTK_TABLE (table74), label584, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label584), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label584), 2, 0);

  label591 = gtk_label_new (_("Not firewalled"));
  gtk_widget_set_name (label591, "label591");
  gtk_widget_ref (label591);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label591", label591,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label591);
  gtk_table_attach (GTK_TABLE (table74), label591, 3, 4, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label591), 0, 0.5);

  label592 = gtk_label_new (_("Enough file descriptors"));
  gtk_widget_set_name (label592, "label592");
  gtk_widget_ref (label592);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label592", label592,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label592);
  gtk_table_attach (GTK_TABLE (table74), label592, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label592), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label592), 2, 0);

  label593 = gtk_label_new (_("Enough physical memory"));
  gtk_widget_set_name (label593, "label593");
  gtk_widget_ref (label593);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label593", label593,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label593);
  gtk_table_attach (GTK_TABLE (table74), label593, 3, 4, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label593), 0, 0.5);

  label594 = gtk_label_new (_("Enough available bandwidth"));
  gtk_widget_set_name (label594, "label594");
  gtk_widget_ref (label594);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label594", label594,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label594);
  gtk_table_attach (GTK_TABLE (table74), label594, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label594), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label594), 2, 0);

  label583 = gtk_label_new (_("IP address stability"));
  gtk_widget_set_name (label583, "label583");
  gtk_widget_ref (label583);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label583", label583,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label583);
  gtk_table_attach (GTK_TABLE (table74), label583, 3, 4, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label583), 0, 0.5);

  label581 = gtk_label_new (_("Sufficient average uptime"));
  gtk_widget_set_name (label581, "label581");
  gtk_widget_ref (label581);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label581", label581,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label581);
  gtk_table_attach (GTK_TABLE (table74), label581, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label581), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label581), 2, 0);

  frame109 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame109, "frame109");
  gtk_widget_ref (frame109);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame109", frame109,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame109);
  gtk_table_attach (GTK_TABLE (table74), frame109, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_frame_set_shadow_type (GTK_FRAME (frame109), GTK_SHADOW_IN);

  label_up_req_avg_servent_uptime = gtk_label_new (_("[place holder]"));
  gtk_widget_set_name (label_up_req_avg_servent_uptime, "label_up_req_avg_servent_uptime");
  gtk_widget_ref (label_up_req_avg_servent_uptime);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label_up_req_avg_servent_uptime", label_up_req_avg_servent_uptime,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_up_req_avg_servent_uptime);
  gtk_container_add (GTK_CONTAINER (frame109), label_up_req_avg_servent_uptime);
  gtk_misc_set_alignment (GTK_MISC (label_up_req_avg_servent_uptime), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_up_req_avg_servent_uptime), 5, 0);

  frame110 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame110, "frame110");
  gtk_widget_ref (frame110);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame110", frame110,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame110);
  gtk_table_attach (GTK_TABLE (table74), frame110, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_frame_set_shadow_type (GTK_FRAME (frame110), GTK_SHADOW_IN);

  label_up_req_node_uptime = gtk_label_new (_("[place holder]"));
  gtk_widget_set_name (label_up_req_node_uptime, "label_up_req_node_uptime");
  gtk_widget_ref (label_up_req_node_uptime);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label_up_req_node_uptime", label_up_req_node_uptime,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_up_req_node_uptime);
  gtk_container_add (GTK_CONTAINER (frame110), label_up_req_node_uptime);
  gtk_misc_set_alignment (GTK_MISC (label_up_req_node_uptime), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_up_req_node_uptime), 5, 0);

  frame111 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame111, "frame111");
  gtk_widget_ref (frame111);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame111", frame111,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame111);
  gtk_table_attach (GTK_TABLE (table74), frame111, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_frame_set_shadow_type (GTK_FRAME (frame111), GTK_SHADOW_IN);

  label_up_req_enough_fd = gtk_label_new (_("[place holder]"));
  gtk_widget_set_name (label_up_req_enough_fd, "label_up_req_enough_fd");
  gtk_widget_ref (label_up_req_enough_fd);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label_up_req_enough_fd", label_up_req_enough_fd,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_up_req_enough_fd);
  gtk_container_add (GTK_CONTAINER (frame111), label_up_req_enough_fd);
  gtk_misc_set_alignment (GTK_MISC (label_up_req_enough_fd), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_up_req_enough_fd), 5, 0);

  frame112 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame112, "frame112");
  gtk_widget_ref (frame112);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame112", frame112,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame112);
  gtk_table_attach (GTK_TABLE (table74), frame112, 1, 2, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_frame_set_shadow_type (GTK_FRAME (frame112), GTK_SHADOW_IN);

  label_up_req_enough_bw = gtk_label_new (_("[place holder]"));
  gtk_widget_set_name (label_up_req_enough_bw, "label_up_req_enough_bw");
  gtk_widget_ref (label_up_req_enough_bw);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label_up_req_enough_bw", label_up_req_enough_bw,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_up_req_enough_bw);
  gtk_container_add (GTK_CONTAINER (frame112), label_up_req_enough_bw);
  gtk_misc_set_alignment (GTK_MISC (label_up_req_enough_bw), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_up_req_enough_bw), 5, 0);

  frame113 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame113, "frame113");
  gtk_widget_ref (frame113);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame113", frame113,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame113);
  gtk_table_attach (GTK_TABLE (table74), frame113, 4, 5, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_frame_set_shadow_type (GTK_FRAME (frame113), GTK_SHADOW_IN);

  label_up_req_avg_ip_uptime = gtk_label_new (_("[place holder]"));
  gtk_widget_set_name (label_up_req_avg_ip_uptime, "label_up_req_avg_ip_uptime");
  gtk_widget_ref (label_up_req_avg_ip_uptime);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label_up_req_avg_ip_uptime", label_up_req_avg_ip_uptime,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_up_req_avg_ip_uptime);
  gtk_container_add (GTK_CONTAINER (frame113), label_up_req_avg_ip_uptime);
  gtk_misc_set_alignment (GTK_MISC (label_up_req_avg_ip_uptime), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_up_req_avg_ip_uptime), 5, 0);

  frame114 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame114, "frame114");
  gtk_widget_ref (frame114);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame114", frame114,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame114);
  gtk_table_attach (GTK_TABLE (table74), frame114, 4, 5, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_frame_set_shadow_type (GTK_FRAME (frame114), GTK_SHADOW_IN);

  label_up_req_not_firewalled = gtk_label_new (_("[place holder]"));
  gtk_widget_set_name (label_up_req_not_firewalled, "label_up_req_not_firewalled");
  gtk_widget_ref (label_up_req_not_firewalled);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label_up_req_not_firewalled", label_up_req_not_firewalled,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_up_req_not_firewalled);
  gtk_container_add (GTK_CONTAINER (frame114), label_up_req_not_firewalled);
  gtk_misc_set_alignment (GTK_MISC (label_up_req_not_firewalled), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_up_req_not_firewalled), 5, 0);

  frame115 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame115, "frame115");
  gtk_widget_ref (frame115);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame115", frame115,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame115);
  gtk_table_attach (GTK_TABLE (table74), frame115, 4, 5, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_frame_set_shadow_type (GTK_FRAME (frame115), GTK_SHADOW_IN);

  label_up_req_enough_mem = gtk_label_new (_("[place holder]"));
  gtk_widget_set_name (label_up_req_enough_mem, "label_up_req_enough_mem");
  gtk_widget_ref (label_up_req_enough_mem);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label_up_req_enough_mem", label_up_req_enough_mem,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_up_req_enough_mem);
  gtk_container_add (GTK_CONTAINER (frame115), label_up_req_enough_mem);
  gtk_misc_set_alignment (GTK_MISC (label_up_req_enough_mem), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_up_req_enough_mem), 5, 0);

  label681 = gtk_label_new (_("Enough min # of connections"));
  gtk_widget_set_name (label681, "label681");
  gtk_widget_ref (label681);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label681", label681,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label681);
  gtk_table_attach (GTK_TABLE (table74), label681, 3, 4, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label681), 0, 0.5);

  frame132 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame132, "frame132");
  gtk_widget_ref (frame132);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame132", frame132,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame132);
  gtk_table_attach (GTK_TABLE (table74), frame132, 4, 5, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_frame_set_shadow_type (GTK_FRAME (frame132), GTK_SHADOW_IN);

  label_up_req_enough_conn = gtk_label_new (_("[place holder]"));
  gtk_widget_set_name (label_up_req_enough_conn, "label_up_req_enough_conn");
  gtk_widget_ref (label_up_req_enough_conn);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label_up_req_enough_conn", label_up_req_enough_conn,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_up_req_enough_conn);
  gtk_container_add (GTK_CONTAINER (frame132), label_up_req_enough_conn);
  gtk_misc_set_alignment (GTK_MISC (label_up_req_enough_conn), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_up_req_enough_conn), 5, 0);

  vseparator2 = gtk_vseparator_new ();
  gtk_widget_set_name (vseparator2, "vseparator2");
  gtk_widget_ref (vseparator2);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "vseparator2", vseparator2,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vseparator2);
  gtk_table_attach (GTK_TABLE (table74), vseparator2, 2, 3, 0, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  label784 = gtk_label_new (_("Enough UDP support"));
  gtk_widget_set_name (label784, "label784");
  gtk_widget_ref (label784);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label784", label784,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label784);
  gtk_table_attach (GTK_TABLE (table74), label784, 0, 1, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label784), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label784), 2, 0);

  frame145 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame145, "frame145");
  gtk_widget_ref (frame145);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame145", frame145,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame145);
  gtk_table_attach (GTK_TABLE (table74), frame145, 1, 2, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_frame_set_shadow_type (GTK_FRAME (frame145), GTK_SHADOW_IN);

  label_up_req_good_udp = gtk_label_new (_("[place holder]"));
  gtk_widget_set_name (label_up_req_good_udp, "label_up_req_good_udp");
  gtk_widget_ref (label_up_req_good_udp);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label_up_req_good_udp", label_up_req_good_udp,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_up_req_good_udp);
  gtk_container_add (GTK_CONTAINER (frame145), label_up_req_good_udp);
  gtk_misc_set_alignment (GTK_MISC (label_up_req_good_udp), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_up_req_good_udp), 5, 0);

  frame_searches = gtk_frame_new (_("Searches"));
  gtk_widget_set_name (frame_searches, "frame_searches");
  gtk_widget_ref (frame_searches);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame_searches", frame_searches,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame_searches);
  gtk_box_pack_start (GTK_BOX (vbox25), frame_searches, FALSE, TRUE, 0);

  hbox188 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox188, "hbox188");
  gtk_widget_ref (hbox188);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "hbox188", hbox188,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox188);
  gtk_container_add (GTK_CONTAINER (frame_searches), hbox188);
  gtk_container_set_border_width (GTK_CONTAINER (hbox188), 2);

  alignment31 = gtk_alignment_new (0, 0.5, 0, 1);
  gtk_widget_set_name (alignment31, "alignment31");
  gtk_widget_ref (alignment31);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "alignment31", alignment31,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (alignment31);
  gtk_box_pack_start (GTK_BOX (hbox188), alignment31, FALSE, TRUE, 0);

  table83 = gtk_table_new (5, 3, FALSE);
  gtk_widget_set_name (table83, "table83");
  gtk_widget_ref (table83);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "table83", table83,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table83);
  gtk_container_add (GTK_CONTAINER (alignment31), table83);
  gtk_table_set_row_spacings (GTK_TABLE (table83), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table83), 4);

  label37 = gtk_label_new ("");
  label37_key = gtk_label_parse_uline (GTK_LABEL (label37),
                                   _("Limit search _results to "));
  gtk_widget_set_name (label37, "label37");
  gtk_widget_ref (label37);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label37", label37,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label37);
  gtk_table_attach (GTK_TABLE (table83), label37, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label37), 0, 0.5);

  spinbutton_config_search_items_adj = gtk_adjustment_new (1, 1, 255, 1, 10, 10);
  spinbutton_config_search_items = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_search_items_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_search_items, "spinbutton_config_search_items");
  gtk_widget_ref (spinbutton_config_search_items);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_config_search_items", spinbutton_config_search_items,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_config_search_items);
  gtk_table_attach (GTK_TABLE (table83), spinbutton_config_search_items, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_usize (spinbutton_config_search_items, 64, -2);
  gtk_tooltips_set_tip (tooltips, spinbutton_config_search_items, _("This limits how many results gnutella returns to other people searching your files."), NULL);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_search_items), TRUE);

  label38 = gtk_label_new (_("items"));
  gtk_widget_set_name (label38, "label38");
  gtk_widget_ref (label38);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label38", label38,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label38);
  gtk_table_attach (GTK_TABLE (table83), label38, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label38), 0, 0.5);

  label567 = gtk_label_new ("");
  label567_key = gtk_label_parse_uline (GTK_LABEL (label567),
                                   _("Default search _reissue timeout"));
  gtk_widget_set_name (label567, "label567");
  gtk_widget_ref (label567);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label567", label567,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label567);
  gtk_table_attach (GTK_TABLE (table83), label567, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label567), 0, 0.5);

  spinbutton_config_search_reissue_timeout_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 10);
  spinbutton_config_search_reissue_timeout = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_search_reissue_timeout_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_search_reissue_timeout, "spinbutton_config_search_reissue_timeout");
  gtk_widget_ref (spinbutton_config_search_reissue_timeout);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_config_search_reissue_timeout", spinbutton_config_search_reissue_timeout,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_config_search_reissue_timeout);
  gtk_table_attach (GTK_TABLE (table83), spinbutton_config_search_reissue_timeout, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_search_reissue_timeout), TRUE);

  label568 = gtk_label_new (_("seconds"));
  gtk_widget_set_name (label568, "label568");
  gtk_widget_ref (label568);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label568", label568,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label568);
  gtk_table_attach (GTK_TABLE (table83), label568, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label568), 0, 0.5);

  checkbutton_enable_guess = gtk_check_button_new_with_label (_("Enable GUESS (additional querying)"));
  gtk_widget_set_name (checkbutton_enable_guess, "checkbutton_enable_guess");
  gtk_widget_ref (checkbutton_enable_guess);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_enable_guess", checkbutton_enable_guess,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_enable_guess);
  gtk_table_attach (GTK_TABLE (table83), checkbutton_enable_guess, 0, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_enable_guess_client = gtk_check_button_new_with_label (_("Issue GUESS queries as well"));
  gtk_widget_set_name (checkbutton_enable_guess_client, "checkbutton_enable_guess_client");
  gtk_widget_ref (checkbutton_enable_guess_client);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_enable_guess_client", checkbutton_enable_guess_client,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_enable_guess_client);
  gtk_table_attach (GTK_TABLE (table83), checkbutton_enable_guess_client, 0, 2, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_enable_g2 = gtk_check_button_new_with_label (_("Enable the G2 network"));
  gtk_widget_set_name (checkbutton_enable_g2, "checkbutton_enable_g2");
  gtk_widget_ref (checkbutton_enable_g2);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_enable_g2", checkbutton_enable_g2,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_enable_g2);
  gtk_table_attach (GTK_TABLE (table83), checkbutton_enable_g2, 0, 2, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  frame_expert_oob_queries = gtk_frame_new (_("Out of Band Querying"));
  gtk_widget_set_name (frame_expert_oob_queries, "frame_expert_oob_queries");
  gtk_widget_ref (frame_expert_oob_queries);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame_expert_oob_queries", frame_expert_oob_queries,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame_expert_oob_queries);
  gtk_box_pack_start (GTK_BOX (hbox188), frame_expert_oob_queries, FALSE, TRUE, 0);
  gtk_frame_set_shadow_type (GTK_FRAME (frame_expert_oob_queries), GTK_SHADOW_OUT);

  vbox131 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox131, "vbox131");
  gtk_widget_ref (vbox131);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "vbox131", vbox131,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox131);
  gtk_container_add (GTK_CONTAINER (frame_expert_oob_queries), vbox131);

  checkbutton_send_oob_queries = gtk_check_button_new_with_label (_("Queries ask for OOB results"));
  gtk_widget_set_name (checkbutton_send_oob_queries, "checkbutton_send_oob_queries");
  gtk_widget_ref (checkbutton_send_oob_queries);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_send_oob_queries", checkbutton_send_oob_queries,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_send_oob_queries);
  gtk_box_pack_start (GTK_BOX (vbox131), checkbutton_send_oob_queries, FALSE, FALSE, 0);

  checkbutton_process_oob_queries = gtk_check_button_new_with_label (_("Honor OOB flag in queries"));
  gtk_widget_set_name (checkbutton_process_oob_queries, "checkbutton_process_oob_queries");
  gtk_widget_ref (checkbutton_process_oob_queries);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_process_oob_queries", checkbutton_process_oob_queries,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_process_oob_queries);
  gtk_box_pack_start (GTK_BOX (vbox131), checkbutton_process_oob_queries, FALSE, FALSE, 0);

  checkbutton_proxy_oob_queries = gtk_check_button_new_with_label (_("Act as OOB proxy for leaves"));
  gtk_widget_set_name (checkbutton_proxy_oob_queries, "checkbutton_proxy_oob_queries");
  gtk_widget_ref (checkbutton_proxy_oob_queries);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_proxy_oob_queries", checkbutton_proxy_oob_queries,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_proxy_oob_queries);
  gtk_box_pack_start (GTK_BOX (vbox131), checkbutton_proxy_oob_queries, FALSE, FALSE, 0);

  vbox122 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox122, "vbox122");
  gtk_widget_ref (vbox122);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "vbox122", vbox122,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox122);
  gtk_box_pack_start (GTK_BOX (hbox188), vbox122, TRUE, TRUE, 0);

  frame_expert_search_queue = gtk_frame_new (_("Search queue"));
  gtk_widget_set_name (frame_expert_search_queue, "frame_expert_search_queue");
  gtk_widget_ref (frame_expert_search_queue);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame_expert_search_queue", frame_expert_search_queue,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame_expert_search_queue);
  gtk_box_pack_start (GTK_BOX (vbox122), frame_expert_search_queue, FALSE, TRUE, 0);
  gtk_frame_set_shadow_type (GTK_FRAME (frame_expert_search_queue), GTK_SHADOW_OUT);

  table75 = gtk_table_new (1, 4, FALSE);
  gtk_widget_set_name (table75, "table75");
  gtk_widget_ref (table75);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "table75", table75,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table75);
  gtk_container_add (GTK_CONTAINER (frame_expert_search_queue), table75);
  gtk_container_set_border_width (GTK_CONTAINER (table75), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table75), 4);

  label595 = gtk_label_new (_("Size"));
  gtk_widget_set_name (label595, "label595");
  gtk_widget_ref (label595);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label595", label595,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label595);
  gtk_table_attach (GTK_TABLE (table75), label595, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label595), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label595), 2, 0);

  label596 = gtk_label_new (_("Spacing"));
  gtk_widget_set_name (label596, "label596");
  gtk_widget_ref (label596);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label596", label596,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label596);
  gtk_table_attach (GTK_TABLE (table75), label596, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label596), 0, 0.5);

  spinbutton_search_queue_spacing_adj = gtk_adjustment_new (60, 0, 100, 1, 10, 10);
  spinbutton_search_queue_spacing = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_search_queue_spacing_adj), 1, 0);
  gtk_widget_set_name (spinbutton_search_queue_spacing, "spinbutton_search_queue_spacing");
  gtk_widget_ref (spinbutton_search_queue_spacing);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_search_queue_spacing", spinbutton_search_queue_spacing,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_search_queue_spacing);
  gtk_table_attach (GTK_TABLE (table75), spinbutton_search_queue_spacing, 3, 4, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_usize (spinbutton_search_queue_spacing, 45, -2);

  spinbutton_search_queue_size_adj = gtk_adjustment_new (1000, 0, 1000, 1, 10, 10);
  spinbutton_search_queue_size = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_search_queue_size_adj), 1, 0);
  gtk_widget_set_name (spinbutton_search_queue_size, "spinbutton_search_queue_size");
  gtk_widget_ref (spinbutton_search_queue_size);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_search_queue_size", spinbutton_search_queue_size,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_search_queue_size);
  gtk_table_attach (GTK_TABLE (table75), spinbutton_search_queue_size, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_usize (spinbutton_search_queue_size, 59, -2);

  checkbutton_config_query_request_partials = gtk_check_button_new_with_label (_("Query for partial files as well"));
  gtk_widget_set_name (checkbutton_config_query_request_partials, "checkbutton_config_query_request_partials");
  gtk_widget_ref (checkbutton_config_query_request_partials);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_config_query_request_partials", checkbutton_config_query_request_partials,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_config_query_request_partials);
  gtk_box_pack_start (GTK_BOX (vbox122), checkbutton_config_query_request_partials, FALSE, FALSE, 0);

  checkbutton_config_search_smart_stop = gtk_check_button_new_with_label (_("Stop search when last download completes"));
  gtk_widget_set_name (checkbutton_config_search_smart_stop, "checkbutton_config_search_smart_stop");
  gtk_widget_ref (checkbutton_config_search_smart_stop);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_config_search_smart_stop", checkbutton_config_search_smart_stop,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_config_search_smart_stop);
  gtk_box_pack_start (GTK_BOX (vbox122), checkbutton_config_search_smart_stop, FALSE, FALSE, 0);

  checkbutton_search_restart_when_pending = gtk_check_button_new_with_label (_("Restart session-only searches with pending downloads"));
  gtk_widget_set_name (checkbutton_search_restart_when_pending, "checkbutton_search_restart_when_pending");
  gtk_widget_ref (checkbutton_search_restart_when_pending);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_search_restart_when_pending", checkbutton_search_restart_when_pending,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_search_restart_when_pending);
  gtk_box_pack_start (GTK_BOX (vbox122), checkbutton_search_restart_when_pending, FALSE, FALSE, 0);

  frame_expert_gnet_timeout = gtk_frame_new (_("Gnutella timeouts (all values in seconds)"));
  gtk_widget_set_name (frame_expert_gnet_timeout, "frame_expert_gnet_timeout");
  gtk_widget_ref (frame_expert_gnet_timeout);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame_expert_gnet_timeout", frame_expert_gnet_timeout,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame_expert_gnet_timeout);
  gtk_box_pack_start (GTK_BOX (vbox25), frame_expert_gnet_timeout, FALSE, TRUE, 0);

  table10 = gtk_table_new (2, 4, FALSE);
  gtk_widget_set_name (table10, "table10");
  gtk_widget_ref (table10);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "table10", table10,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table10);
  gtk_container_add (GTK_CONTAINER (frame_expert_gnet_timeout), table10);
  gtk_container_set_border_width (GTK_CONTAINER (table10), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table10), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table10), 4);

  label175 = gtk_label_new ("");
  label175_key = gtk_label_parse_uline (GTK_LABEL (label175),
                                   _("Connectin_g timeout"));
  gtk_widget_set_name (label175, "label175");
  gtk_widget_ref (label175);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label175", label175,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label175);
  gtk_table_attach (GTK_TABLE (table10), label175, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label175), 0, 0.5);

  label176 = gtk_label_new ("");
  label176_key = gtk_label_parse_uline (GTK_LABEL (label176),
                                   _("Connected time_out"));
  gtk_widget_set_name (label176, "label176");
  gtk_widget_ref (label176);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label176", label176,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label176);
  gtk_table_attach (GTK_TABLE (table10), label176, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label176), 0, 0.5);

  label177 = gtk_label_new ("");
  label177_key = gtk_label_parse_uline (GTK_LABEL (label177),
                                   _("T_X flow control timeout"));
  gtk_widget_set_name (label177, "label177");
  gtk_widget_ref (label177);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label177", label177,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label177);
  gtk_table_attach (GTK_TABLE (table10), label177, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label177), 0, 0.5);

  spinbutton_config_node_tx_flowc_timeout_adj = gtk_adjustment_new (1, 1, 100000, 1, 10, 10);
  spinbutton_config_node_tx_flowc_timeout = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_node_tx_flowc_timeout_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_node_tx_flowc_timeout, "spinbutton_config_node_tx_flowc_timeout");
  gtk_widget_ref (spinbutton_config_node_tx_flowc_timeout);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_config_node_tx_flowc_timeout", spinbutton_config_node_tx_flowc_timeout,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_config_node_tx_flowc_timeout);
  gtk_table_attach (GTK_TABLE (table10), spinbutton_config_node_tx_flowc_timeout, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_usize (spinbutton_config_node_tx_flowc_timeout, 64, -2);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_node_tx_flowc_timeout), TRUE);

  spinbutton_config_node_connecting_timeout_adj = gtk_adjustment_new (1, 1, 100000, 1, 10, 10);
  spinbutton_config_node_connecting_timeout = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_node_connecting_timeout_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_node_connecting_timeout, "spinbutton_config_node_connecting_timeout");
  gtk_widget_ref (spinbutton_config_node_connecting_timeout);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_config_node_connecting_timeout", spinbutton_config_node_connecting_timeout,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_config_node_connecting_timeout);
  gtk_table_attach (GTK_TABLE (table10), spinbutton_config_node_connecting_timeout, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_usize (spinbutton_config_node_connecting_timeout, 64, -2);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_node_connecting_timeout), TRUE);

  spinbutton_config_node_connected_timeout_adj = gtk_adjustment_new (1, 1, 100000, 1, 10, 10);
  spinbutton_config_node_connected_timeout = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_node_connected_timeout_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_node_connected_timeout, "spinbutton_config_node_connected_timeout");
  gtk_widget_ref (spinbutton_config_node_connected_timeout);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_config_node_connected_timeout", spinbutton_config_node_connected_timeout,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_config_node_connected_timeout);
  gtk_table_attach (GTK_TABLE (table10), spinbutton_config_node_connected_timeout, 3, 4, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_usize (spinbutton_config_node_connected_timeout, 64, -2);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_node_connected_timeout), TRUE);

  label503 = gtk_label_new (_("Incoming connecting timeout"));
  gtk_widget_set_name (label503, "label503");
  gtk_widget_ref (label503);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label503", label503,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label503);
  gtk_table_attach (GTK_TABLE (table10), label503, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label503), 0, 0.5);

  spinbutton_config_incoming_connecting_timeout_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 10);
  spinbutton_config_incoming_connecting_timeout = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_incoming_connecting_timeout_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_incoming_connecting_timeout, "spinbutton_config_incoming_connecting_timeout");
  gtk_widget_ref (spinbutton_config_incoming_connecting_timeout);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_config_incoming_connecting_timeout", spinbutton_config_incoming_connecting_timeout,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_config_incoming_connecting_timeout);
  gtk_table_attach (GTK_TABLE (table10), spinbutton_config_incoming_connecting_timeout, 3, 4, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  alignment26 = gtk_alignment_new (0.5, 0.5, 1, 1);
  gtk_widget_set_name (alignment26, "alignment26");
  gtk_widget_ref (alignment26);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "alignment26", alignment26,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (alignment26);
  gtk_box_pack_start (GTK_BOX (vbox25), alignment26, FALSE, TRUE, 0);

  frame_expert_gnet_ttl = gtk_frame_new (_("Gnutella TTL settings"));
  gtk_widget_set_name (frame_expert_gnet_ttl, "frame_expert_gnet_ttl");
  gtk_widget_ref (frame_expert_gnet_ttl);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame_expert_gnet_ttl", frame_expert_gnet_ttl,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame_expert_gnet_ttl);
  gtk_container_add (GTK_CONTAINER (alignment26), frame_expert_gnet_ttl);

  table9 = gtk_table_new (3, 5, FALSE);
  gtk_widget_set_name (table9, "table9");
  gtk_widget_ref (table9);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "table9", table9,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table9);
  gtk_container_add (GTK_CONTAINER (frame_expert_gnet_ttl), table9);
  gtk_container_set_border_width (GTK_CONTAINER (table9), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table9), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table9), 4);

  label84 = gtk_label_new ("");
  label84_key = gtk_label_parse_uline (GTK_LABEL (label84),
                                   _("Max _TTL"));
  gtk_widget_set_name (label84, "label84");
  gtk_widget_ref (label84);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label84", label84,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label84);
  gtk_table_attach (GTK_TABLE (table9), label84, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label84), 0, 0.5);

  label85 = gtk_label_new ("");
  label85_key = gtk_label_parse_uline (GTK_LABEL (label85),
                                   _("M_y TTL"));
  gtk_widget_set_name (label85, "label85");
  gtk_widget_ref (label85);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label85", label85,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label85);
  gtk_table_attach (GTK_TABLE (table9), label85, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label85), 0, 0.5);

  label158 = gtk_label_new ("");
  label158_key = gtk_label_parse_uline (GTK_LABEL (label158),
                                   _("from _nodes within a"));
  gtk_widget_set_name (label158, "label158");
  gtk_widget_ref (label158);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label158", label158,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label158);
  gtk_table_attach (GTK_TABLE (table9), label158, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label158), 0, 0.5);

  label157 = gtk_label_new ("");
  label157_key = gtk_label_parse_uline (GTK_LABEL (label157),
                                   _("Max # of _high TTL msg"));
  gtk_widget_set_name (label157, "label157");
  gtk_widget_ref (label157);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label157", label157,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label157);
  gtk_table_attach (GTK_TABLE (table9), label157, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label157), 0, 0.5);

  label159 = gtk_label_new ("");
  label159_key = gtk_label_parse_uline (GTK_LABEL (label159),
                                   _("H_ard TTL limit"));
  gtk_widget_set_name (label159, "label159");
  gtk_widget_ref (label159);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label159", label159,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label159);
  gtk_table_attach (GTK_TABLE (table9), label159, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label159), 0, 0.5);

  spinbutton_config_maxttl_adj = gtk_adjustment_new (1, 1, 99, 1, 5, 5);
  spinbutton_config_maxttl = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_maxttl_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_maxttl, "spinbutton_config_maxttl");
  gtk_widget_ref (spinbutton_config_maxttl);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_config_maxttl", spinbutton_config_maxttl,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_config_maxttl);
  gtk_table_attach (GTK_TABLE (table9), spinbutton_config_maxttl, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_usize (spinbutton_config_maxttl, 64, -2);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_maxttl), TRUE);

  spinbutton_config_max_high_ttl_msg_adj = gtk_adjustment_new (1, 0, 99, 1, 10, 10);
  spinbutton_config_max_high_ttl_msg = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_max_high_ttl_msg_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_max_high_ttl_msg, "spinbutton_config_max_high_ttl_msg");
  gtk_widget_ref (spinbutton_config_max_high_ttl_msg);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_config_max_high_ttl_msg", spinbutton_config_max_high_ttl_msg,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_config_max_high_ttl_msg);
  gtk_table_attach (GTK_TABLE (table9), spinbutton_config_max_high_ttl_msg, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_tooltips_set_tip (tooltips, spinbutton_config_max_high_ttl_msg, _("Amount of tolerable messages above hard TTL limit per node"), NULL);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_max_high_ttl_msg), TRUE);

  spinbutton_config_hard_ttl_limit_adj = gtk_adjustment_new (1, 5, 99, 1, 10, 10);
  spinbutton_config_hard_ttl_limit = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_hard_ttl_limit_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_hard_ttl_limit, "spinbutton_config_hard_ttl_limit");
  gtk_widget_ref (spinbutton_config_hard_ttl_limit);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_config_hard_ttl_limit", spinbutton_config_hard_ttl_limit,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_config_hard_ttl_limit);
  gtk_table_attach (GTK_TABLE (table9), spinbutton_config_hard_ttl_limit, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_tooltips_set_tip (tooltips, spinbutton_config_hard_ttl_limit, _("Max hard TTL limit (hop+ttl) on message"), NULL);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_hard_ttl_limit), TRUE);

  spinbutton_config_myttl_adj = gtk_adjustment_new (1, 1, 99, 1, 5, 5);
  spinbutton_config_myttl = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_myttl_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_myttl, "spinbutton_config_myttl");
  gtk_widget_ref (spinbutton_config_myttl);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_config_myttl", spinbutton_config_myttl,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_config_myttl);
  gtk_table_attach (GTK_TABLE (table9), spinbutton_config_myttl, 3, 4, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_usize (spinbutton_config_myttl, 64, -2);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_myttl), TRUE);

  spinbutton_config_max_high_ttl_radius_adj = gtk_adjustment_new (1, 1, 99, 1, 10, 10);
  spinbutton_config_max_high_ttl_radius = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_max_high_ttl_radius_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_max_high_ttl_radius, "spinbutton_config_max_high_ttl_radius");
  gtk_widget_ref (spinbutton_config_max_high_ttl_radius);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_config_max_high_ttl_radius", spinbutton_config_max_high_ttl_radius,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_config_max_high_ttl_radius);
  gtk_table_attach (GTK_TABLE (table9), spinbutton_config_max_high_ttl_radius, 3, 4, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_tooltips_set_tip (tooltips, spinbutton_config_max_high_ttl_radius, _("Hop radius for counting high TTL limit messages (#hops lower than...)"), NULL);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_max_high_ttl_radius), TRUE);

  label160 = gtk_label_new (_("hops radius"));
  gtk_widget_set_name (label160, "label160");
  gtk_widget_ref (label160);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label160", label160,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label160);
  gtk_table_attach (GTK_TABLE (table9), label160, 4, 5, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  frame_expert_gnet_dht = gtk_frame_new (_("Gnutella Distributed Hash Table"));
  gtk_widget_set_name (frame_expert_gnet_dht, "frame_expert_gnet_dht");
  gtk_widget_ref (frame_expert_gnet_dht);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame_expert_gnet_dht", frame_expert_gnet_dht,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame_expert_gnet_dht);
  gtk_box_pack_start (GTK_BOX (vbox25), frame_expert_gnet_dht, TRUE, TRUE, 0);

  table104 = gtk_table_new (2, 2, FALSE);
  gtk_widget_set_name (table104, "table104");
  gtk_widget_ref (table104);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "table104", table104,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table104);
  gtk_container_add (GTK_CONTAINER (frame_expert_gnet_dht), table104);

  label8032 = gtk_label_new (_("Configured DHT mode"));
  gtk_widget_set_name (label8032, "label8032");
  gtk_widget_ref (label8032);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label8032", label8032,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label8032);
  gtk_table_attach (GTK_TABLE (table104), label8032, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label8032), 0, 0.5);

  option_menu_config_dht_mode = gtk_option_menu_new ();
  gtk_widget_set_name (option_menu_config_dht_mode, "option_menu_config_dht_mode");
  gtk_widget_ref (option_menu_config_dht_mode);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "option_menu_config_dht_mode", option_menu_config_dht_mode,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (option_menu_config_dht_mode);
  gtk_table_attach (GTK_TABLE (table104), option_menu_config_dht_mode, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  option_menu_config_dht_mode_menu = gtk_menu_new ();
  gtk_option_menu_set_menu (GTK_OPTION_MENU (option_menu_config_dht_mode), option_menu_config_dht_mode_menu);

  checkbutton_config_dht_storage_in_memory = gtk_check_button_new_with_label (_("Store DHT keys/values in memory"));
  gtk_widget_set_name (checkbutton_config_dht_storage_in_memory, "checkbutton_config_dht_storage_in_memory");
  gtk_widget_ref (checkbutton_config_dht_storage_in_memory);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_config_dht_storage_in_memory", checkbutton_config_dht_storage_in_memory,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_config_dht_storage_in_memory);
  gtk_table_attach (GTK_TABLE (table104), checkbutton_config_dht_storage_in_memory, 0, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  frame_expert_gnet_quality = gtk_frame_new (_("Quality management"));
  gtk_widget_set_name (frame_expert_gnet_quality, "frame_expert_gnet_quality");
  gtk_widget_ref (frame_expert_gnet_quality);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame_expert_gnet_quality", frame_expert_gnet_quality,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame_expert_gnet_quality);
  gtk_box_pack_start (GTK_BOX (vbox25), frame_expert_gnet_quality, FALSE, TRUE, 0);

  table30 = gtk_table_new (4, 6, FALSE);
  gtk_widget_set_name (table30, "table30");
  gtk_widget_ref (table30);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "table30", table30,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table30);
  gtk_container_add (GTK_CONTAINER (frame_expert_gnet_quality), table30);
  gtk_container_set_border_width (GTK_CONTAINER (table30), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table30), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table30), 4);

  label279 = gtk_label_new ("");
  label279_key = gtk_label_parse_uline (GTK_LABEL (label279),
                                   _("Ratio of tolerable duplicate messages per _node"));
  gtk_widget_set_name (label279, "label279");
  gtk_widget_ref (label279);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label279", label279,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label279);
  gtk_table_attach (GTK_TABLE (table30), label279, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label279), 0, 0.5);

  label278 = gtk_label_new ("");
  label278_key = gtk_label_parse_uline (GTK_LABEL (label278),
                                   _("Number of tolerable _duplicate messages per node"));
  gtk_widget_set_name (label278, "label278");
  gtk_widget_ref (label278);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label278", label278,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label278);
  gtk_table_attach (GTK_TABLE (table30), label278, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label278), 0, 0.5);

  spinbutton_config_min_dup_msg_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 10);
  spinbutton_config_min_dup_msg = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_min_dup_msg_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_min_dup_msg, "spinbutton_config_min_dup_msg");
  gtk_widget_ref (spinbutton_config_min_dup_msg);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_config_min_dup_msg", spinbutton_config_min_dup_msg,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_config_min_dup_msg);
  gtk_table_attach (GTK_TABLE (table30), spinbutton_config_min_dup_msg, 1, 2, 0, 1,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_min_dup_msg), TRUE);

  spinbutton_config_min_dup_ratio_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 10);
  spinbutton_config_min_dup_ratio = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_min_dup_ratio_adj), 1, 2);
  gtk_widget_set_name (spinbutton_config_min_dup_ratio, "spinbutton_config_min_dup_ratio");
  gtk_widget_ref (spinbutton_config_min_dup_ratio);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_config_min_dup_ratio", spinbutton_config_min_dup_ratio,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_config_min_dup_ratio);
  gtk_table_attach (GTK_TABLE (table30), spinbutton_config_min_dup_ratio, 1, 2, 1, 2,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_min_dup_ratio), TRUE);

  label457 = gtk_label_new (_("RX flow control ratio"));
  gtk_widget_set_name (label457, "label457");
  gtk_widget_ref (label457);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label457", label457,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label457);
  gtk_table_attach (GTK_TABLE (table30), label457, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label457), 0, 0.5);

  spinbutton_config_node_rx_flowc_ratio_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 10);
  spinbutton_config_node_rx_flowc_ratio = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_node_rx_flowc_ratio_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_node_rx_flowc_ratio, "spinbutton_config_node_rx_flowc_ratio");
  gtk_widget_ref (spinbutton_config_node_rx_flowc_ratio);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_config_node_rx_flowc_ratio", spinbutton_config_node_rx_flowc_ratio,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_config_node_rx_flowc_ratio);
  gtk_table_attach (GTK_TABLE (table30), spinbutton_config_node_rx_flowc_ratio, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label280 = gtk_label_new ("");
  gtk_label_parse_uline (GTK_LABEL (label280),
                         _("_Messages"));
  gtk_widget_set_name (label280, "label280");
  gtk_widget_ref (label280);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label280", label280,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label280);
  gtk_table_attach (GTK_TABLE (table30), label280, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label280), 0, 0.5);

  label281 = gtk_label_new (_("%"));
  gtk_widget_set_name (label281, "label281");
  gtk_widget_ref (label281);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label281", label281,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label281);
  gtk_table_attach (GTK_TABLE (table30), label281, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label281), 0, 0.5);

  label458 = gtk_label_new (_("%"));
  gtk_widget_set_name (label458, "label458");
  gtk_widget_ref (label458);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label458", label458,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label458);
  gtk_table_attach (GTK_TABLE (table30), label458, 2, 3, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label458), 0, 0.5);

  checkbutton_node_watch_similar_queries = gtk_check_button_new_with_label (_("Watch for similar queries"));
  gtk_widget_set_name (checkbutton_node_watch_similar_queries, "checkbutton_node_watch_similar_queries");
  gtk_widget_ref (checkbutton_node_watch_similar_queries);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_node_watch_similar_queries", checkbutton_node_watch_similar_queries,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_node_watch_similar_queries);
  gtk_table_attach (GTK_TABLE (table30), checkbutton_node_watch_similar_queries, 4, 6, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label597 = gtk_label_new (_("Similar query half-life"));
  gtk_widget_set_name (label597, "label597");
  gtk_widget_ref (label597);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label597", label597,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label597);
  gtk_table_attach (GTK_TABLE (table30), label597, 4, 5, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label597), 0, 0.5);

  spinbutton_node_queries_half_life_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 10);
  spinbutton_node_queries_half_life = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_node_queries_half_life_adj), 1, 0);
  gtk_widget_set_name (spinbutton_node_queries_half_life, "spinbutton_node_queries_half_life");
  gtk_widget_ref (spinbutton_node_queries_half_life);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_node_queries_half_life", spinbutton_node_queries_half_life,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_node_queries_half_life);
  gtk_table_attach (GTK_TABLE (table30), spinbutton_node_queries_half_life, 5, 6, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label598 = gtk_label_new (_("Leaf requery threshold"));
  gtk_widget_set_name (label598, "label598");
  gtk_widget_ref (label598);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label598", label598,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label598);
  gtk_table_attach (GTK_TABLE (table30), label598, 4, 5, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label598), 0, 0.5);

  spinbutton_node_requery_threshold_adj = gtk_adjustment_new (1700, 0, 1800, 1, 10, 10);
  spinbutton_node_requery_threshold = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_node_requery_threshold_adj), 1, 0);
  gtk_widget_set_name (spinbutton_node_requery_threshold, "spinbutton_node_requery_threshold");
  gtk_widget_ref (spinbutton_node_requery_threshold);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_node_requery_threshold", spinbutton_node_requery_threshold,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_node_requery_threshold);
  gtk_table_attach (GTK_TABLE (table30), spinbutton_node_requery_threshold, 5, 6, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_usize (spinbutton_node_requery_threshold, 56, -2);

  vseparator3 = gtk_vseparator_new ();
  gtk_widget_set_name (vseparator3, "vseparator3");
  gtk_widget_ref (vseparator3);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "vseparator3", vseparator3,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vseparator3);
  gtk_table_attach (GTK_TABLE (table30), vseparator3, 3, 4, 0, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  label8033 = gtk_label_new (_("Relayed queries remembered"));
  gtk_widget_set_name (label8033, "label8033");
  gtk_widget_ref (label8033);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label8033", label8033,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label8033);
  gtk_table_attach (GTK_TABLE (table30), label8033, 4, 5, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label8033), 0, 0.5);

  spinbutton_config_search_muid_track_amount_adj = gtk_adjustment_new (1700, 0, 1800, 1, 10, 10);
  spinbutton_config_search_muid_track_amount = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_search_muid_track_amount_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_search_muid_track_amount, "spinbutton_config_search_muid_track_amount");
  gtk_widget_ref (spinbutton_config_search_muid_track_amount);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_config_search_muid_track_amount", spinbutton_config_search_muid_track_amount,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_config_search_muid_track_amount);
  gtk_table_attach (GTK_TABLE (table30), spinbutton_config_search_muid_track_amount, 5, 6, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_usize (spinbutton_config_search_muid_track_amount, 56, -2);

  frame_expert_gnet_connections = gtk_frame_new (_("Connection settings"));
  gtk_widget_set_name (frame_expert_gnet_connections, "frame_expert_gnet_connections");
  gtk_widget_ref (frame_expert_gnet_connections);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame_expert_gnet_connections", frame_expert_gnet_connections,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame_expert_gnet_connections);
  gtk_box_pack_start (GTK_BOX (vbox25), frame_expert_gnet_connections, FALSE, TRUE, 0);

  table66 = gtk_table_new (2, 3, FALSE);
  gtk_widget_set_name (table66, "table66");
  gtk_widget_ref (table66);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "table66", table66,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table66);
  gtk_container_add (GTK_CONTAINER (frame_expert_gnet_connections), table66);
  gtk_container_set_border_width (GTK_CONTAINER (table66), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table66), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table66), 4);

  label550 = gtk_label_new (_("%"));
  gtk_widget_set_name (label550, "label550");
  gtk_widget_ref (label550);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label550", label550,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label550);
  gtk_table_attach (GTK_TABLE (table66), label550, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label550), 0, 0.5);

  label551 = gtk_label_new (_("%"));
  gtk_widget_set_name (label551, "label551");
  gtk_widget_ref (label551);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label551", label551,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label551);
  gtk_table_attach (GTK_TABLE (table66), label551, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label551), 0, 0.5);

  spinbutton_config_reserve_gtkg_nodes_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 10);
  spinbutton_config_reserve_gtkg_nodes = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_reserve_gtkg_nodes_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_reserve_gtkg_nodes, "spinbutton_config_reserve_gtkg_nodes");
  gtk_widget_ref (spinbutton_config_reserve_gtkg_nodes);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_config_reserve_gtkg_nodes", spinbutton_config_reserve_gtkg_nodes,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_config_reserve_gtkg_nodes);
  gtk_table_attach (GTK_TABLE (table66), spinbutton_config_reserve_gtkg_nodes, 1, 2, 0, 1,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);

  spinbutton_config_unique_nodes_adj = gtk_adjustment_new (1, 1, 100, 1, 10, 10);
  spinbutton_config_unique_nodes = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_unique_nodes_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_unique_nodes, "spinbutton_config_unique_nodes");
  gtk_widget_ref (spinbutton_config_unique_nodes);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_config_unique_nodes", spinbutton_config_unique_nodes,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_config_unique_nodes);
  gtk_table_attach (GTK_TABLE (table66), spinbutton_config_unique_nodes, 1, 2, 1, 2,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);

  label548 = gtk_label_new (_("Connections reserved for gtk-gnutella nodes"));
  gtk_widget_set_name (label548, "label548");
  gtk_widget_ref (label548);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label548", label548,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label548);
  gtk_table_attach (GTK_TABLE (table66), label548, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label548), 0, 0.5);

  label549 = gtk_label_new (_("Max connections allowed per unique vendor"));
  gtk_widget_set_name (label549, "label549");
  gtk_widget_ref (label549);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label549", label549,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label549);
  gtk_table_attach (GTK_TABLE (table66), label549, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label549), GTK_JUSTIFY_LEFT);
  gtk_misc_set_alignment (GTK_MISC (label549), 0, 0.5);

  frame_expert_gnet_other = gtk_frame_new (_("Other"));
  gtk_widget_set_name (frame_expert_gnet_other, "frame_expert_gnet_other");
  gtk_widget_ref (frame_expert_gnet_other);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame_expert_gnet_other", frame_expert_gnet_other,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame_expert_gnet_other);
  gtk_box_pack_start (GTK_BOX (vbox25), frame_expert_gnet_other, FALSE, TRUE, 0);

  table33 = gtk_table_new (3, 2, FALSE);
  gtk_widget_set_name (table33, "table33");
  gtk_widget_ref (table33);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "table33", table33,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table33);
  gtk_container_add (GTK_CONTAINER (frame_expert_gnet_other), table33);
  gtk_container_set_border_width (GTK_CONTAINER (table33), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table33), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table33), 4);

  label290 = gtk_label_new (_("Hops random factor"));
  gtk_widget_set_name (label290, "label290");
  gtk_widget_ref (label290);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label290", label290,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label290);
  gtk_table_attach (GTK_TABLE (table33), label290, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label290), 0, 0.5);

  checkbutton_gnet_compact_query = gtk_check_button_new_with_label (_("Clean up queries before processing"));
  gtk_widget_set_name (checkbutton_gnet_compact_query, "checkbutton_gnet_compact_query");
  gtk_widget_ref (checkbutton_gnet_compact_query);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_gnet_compact_query", checkbutton_gnet_compact_query,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_gnet_compact_query);
  gtk_table_attach (GTK_TABLE (table33), checkbutton_gnet_compact_query, 0, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  spinbutton_config_hops_random_factor_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 10);
  spinbutton_config_hops_random_factor = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_hops_random_factor_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_hops_random_factor, "spinbutton_config_hops_random_factor");
  gtk_widget_ref (spinbutton_config_hops_random_factor);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_config_hops_random_factor", spinbutton_config_hops_random_factor,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_config_hops_random_factor);
  gtk_table_attach (GTK_TABLE (table33), spinbutton_config_hops_random_factor, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_hops_random_factor), TRUE);

  checkbutton_config_spam_lut_in_memory = gtk_check_button_new_with_label (_("Store SPAM SHA1 table in memory"));
  gtk_widget_set_name (checkbutton_config_spam_lut_in_memory, "checkbutton_config_spam_lut_in_memory");
  gtk_widget_ref (checkbutton_config_spam_lut_in_memory);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_config_spam_lut_in_memory", checkbutton_config_spam_lut_in_memory,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_config_spam_lut_in_memory);
  gtk_table_attach (GTK_TABLE (table33), checkbutton_config_spam_lut_in_memory, 0, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  frame_expert_gnet_message_size = gtk_frame_new (_("Gnutella message size limits"));
  gtk_widget_set_name (frame_expert_gnet_message_size, "frame_expert_gnet_message_size");
  gtk_widget_ref (frame_expert_gnet_message_size);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame_expert_gnet_message_size", frame_expert_gnet_message_size,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame_expert_gnet_message_size);
  gtk_box_pack_start (GTK_BOX (vbox25), frame_expert_gnet_message_size, TRUE, TRUE, 0);

  table69 = gtk_table_new (4, 3, FALSE);
  gtk_widget_set_name (table69, "table69");
  gtk_widget_ref (table69);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "table69", table69,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table69);
  gtk_container_add (GTK_CONTAINER (frame_expert_gnet_message_size), table69);
  gtk_container_set_border_width (GTK_CONTAINER (table69), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table69), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table69), 4);

  label569 = gtk_label_new (_("Forwarded\nmessage"));
  gtk_widget_set_name (label569, "label569");
  gtk_widget_ref (label569);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label569", label569,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label569);
  gtk_table_attach (GTK_TABLE (table69), label569, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label569), 0, 0.5);

  label571 = gtk_label_new (_("Size threshold\nbefore kicking"));
  gtk_widget_set_name (label571, "label571");
  gtk_widget_ref (label571);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label571", label571,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label571);
  gtk_table_attach (GTK_TABLE (table69), label571, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label571), 0, 0.5);

  label572 = gtk_label_new (_("Query"));
  gtk_widget_set_name (label572, "label572");
  gtk_widget_ref (label572);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label572", label572,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label572);
  gtk_table_attach (GTK_TABLE (table69), label572, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label572), 0, 0.5);

  label573 = gtk_label_new (_("Query hit"));
  gtk_widget_set_name (label573, "label573");
  gtk_widget_ref (label573);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label573", label573,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label573);
  gtk_table_attach (GTK_TABLE (table69), label573, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label573), 0, 0.5);

  label574 = gtk_label_new (_("Unknown"));
  gtk_widget_set_name (label574, "label574");
  gtk_widget_ref (label574);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label574", label574,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label574);
  gtk_table_attach (GTK_TABLE (table69), label574, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label574), 0, 0.5);

  label575 = gtk_label_new (_("(not forwarded)"));
  gtk_widget_set_name (label575, "label575");
  gtk_widget_ref (label575);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label575", label575,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label575);
  gtk_table_attach (GTK_TABLE (table69), label575, 1, 2, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label575), 0, 0.5);

  spinbutton_search_answers_forward_size_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 10);
  spinbutton_search_answers_forward_size = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_search_answers_forward_size_adj), 1, 0);
  gtk_widget_set_name (spinbutton_search_answers_forward_size, "spinbutton_search_answers_forward_size");
  gtk_widget_ref (spinbutton_search_answers_forward_size);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_search_answers_forward_size", spinbutton_search_answers_forward_size,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_search_answers_forward_size);
  gtk_table_attach (GTK_TABLE (table69), spinbutton_search_answers_forward_size, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  spinbutton_search_queries_forward_size_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 10);
  spinbutton_search_queries_forward_size = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_search_queries_forward_size_adj), 1, 0);
  gtk_widget_set_name (spinbutton_search_queries_forward_size, "spinbutton_search_queries_forward_size");
  gtk_widget_ref (spinbutton_search_queries_forward_size);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_search_queries_forward_size", spinbutton_search_queries_forward_size,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_search_queries_forward_size);
  gtk_table_attach (GTK_TABLE (table69), spinbutton_search_queries_forward_size, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label570 = gtk_label_new (_("Maximum size\nallowed"));
  gtk_widget_set_name (label570, "label570");
  gtk_widget_ref (label570);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label570", label570,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label570);
  gtk_table_attach (GTK_TABLE (table69), label570, 1, 2, 0, 1,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label570), 0, 0.5);

  spinbutton_search_queries_kick_size_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 10);
  spinbutton_search_queries_kick_size = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_search_queries_kick_size_adj), 1, 0);
  gtk_widget_set_name (spinbutton_search_queries_kick_size, "spinbutton_search_queries_kick_size");
  gtk_widget_ref (spinbutton_search_queries_kick_size);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_search_queries_kick_size", spinbutton_search_queries_kick_size,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_search_queries_kick_size);
  gtk_table_attach (GTK_TABLE (table69), spinbutton_search_queries_kick_size, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  spinbutton_search_answers_kick_size_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 10);
  spinbutton_search_answers_kick_size = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_search_answers_kick_size_adj), 1, 0);
  gtk_widget_set_name (spinbutton_search_answers_kick_size, "spinbutton_search_answers_kick_size");
  gtk_widget_ref (spinbutton_search_answers_kick_size);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_search_answers_kick_size", spinbutton_search_answers_kick_size,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_search_answers_kick_size);
  gtk_table_attach (GTK_TABLE (table69), spinbutton_search_answers_kick_size, 2, 3, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  spinbutton_other_messages_kick_size_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 10);
  spinbutton_other_messages_kick_size = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_other_messages_kick_size_adj), 1, 0);
  gtk_widget_set_name (spinbutton_other_messages_kick_size, "spinbutton_other_messages_kick_size");
  gtk_widget_ref (spinbutton_other_messages_kick_size);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_other_messages_kick_size", spinbutton_other_messages_kick_size,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_other_messages_kick_size);
  gtk_table_attach (GTK_TABLE (table69), spinbutton_other_messages_kick_size, 2, 3, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label683 = gtk_label_new (_("Gnutella"));
  gtk_widget_set_name (label683, "label683");
  gtk_widget_ref (label683);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label683", label683,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label683);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_prefs), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_prefs), 1), label683);

  scrolledwindow33 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow33, "scrolledwindow33");
  gtk_widget_ref (scrolledwindow33);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "scrolledwindow33", scrolledwindow33,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (scrolledwindow33);
  gtk_container_add (GTK_CONTAINER (notebook_prefs), scrolledwindow33);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow33), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);

  viewport4 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport4, "viewport4");
  gtk_widget_ref (viewport4);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "viewport4", viewport4,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (viewport4);
  gtk_container_add (GTK_CONTAINER (scrolledwindow33), viewport4);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport4), GTK_SHADOW_NONE);

  vbox29 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox29, "vbox29");
  gtk_widget_ref (vbox29);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "vbox29", vbox29,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox29);
  gtk_container_add (GTK_CONTAINER (viewport4), vbox29);
  gtk_container_set_border_width (GTK_CONTAINER (vbox29), 2);

  frame70 = gtk_frame_new (_("General"));
  gtk_widget_set_name (frame70, "frame70");
  gtk_widget_ref (frame70);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame70", frame70,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame70);
  gtk_box_pack_start (GTK_BOX (vbox29), frame70, FALSE, TRUE, 0);

  hbox183 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox183, "hbox183");
  gtk_widget_ref (hbox183);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "hbox183", hbox183,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox183);
  gtk_container_add (GTK_CONTAINER (frame70), hbox183);

  vbox115 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox115, "vbox115");
  gtk_widget_ref (vbox115);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "vbox115", vbox115,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox115);
  gtk_box_pack_start (GTK_BOX (hbox183), vbox115, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (vbox115), 2);

  checkbutton_config_bw_allow_stealing = gtk_check_button_new_with_label ("");
  checkbutton_config_bw_allow_stealing_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (checkbutton_config_bw_allow_stealing)->child),
                                   _("Use _surplus bandwidth"));
  gtk_widget_add_accelerator (checkbutton_config_bw_allow_stealing, "clicked", accel_group,
                              checkbutton_config_bw_allow_stealing_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (checkbutton_config_bw_allow_stealing, "checkbutton_config_bw_allow_stealing");
  gtk_widget_ref (checkbutton_config_bw_allow_stealing);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_config_bw_allow_stealing", checkbutton_config_bw_allow_stealing,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_config_bw_allow_stealing);
  gtk_box_pack_start (GTK_BOX (vbox115), checkbutton_config_bw_allow_stealing, FALSE, FALSE, 0);

  checkbutton_prefer_compressed_gnet = gtk_check_button_new_with_label ("");
  checkbutton_prefer_compressed_gnet_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (checkbutton_prefer_compressed_gnet)->child),
                                   _("Prefer _compressed connections"));
  gtk_widget_add_accelerator (checkbutton_prefer_compressed_gnet, "clicked", accel_group,
                              checkbutton_prefer_compressed_gnet_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (checkbutton_prefer_compressed_gnet, "checkbutton_prefer_compressed_gnet");
  gtk_widget_ref (checkbutton_prefer_compressed_gnet);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_prefer_compressed_gnet", checkbutton_prefer_compressed_gnet,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_prefer_compressed_gnet);
  gtk_box_pack_start (GTK_BOX (vbox115), checkbutton_prefer_compressed_gnet, FALSE, FALSE, 0);

  checkbutton_config_use_ip_tos = gtk_check_button_new_with_label ("");
  checkbutton_config_use_ip_tos_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (checkbutton_config_use_ip_tos)->child),
                                   _("Use IP _Type of Service (TOS)"));
  gtk_widget_add_accelerator (checkbutton_config_use_ip_tos, "clicked", accel_group,
                              checkbutton_config_use_ip_tos_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (checkbutton_config_use_ip_tos, "checkbutton_config_use_ip_tos");
  gtk_widget_ref (checkbutton_config_use_ip_tos);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_config_use_ip_tos", checkbutton_config_use_ip_tos,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_config_use_ip_tos);
  gtk_box_pack_start (GTK_BOX (vbox115), checkbutton_config_use_ip_tos, FALSE, FALSE, 0);

  frame83 = gtk_frame_new (_("Available bandwidth"));
  gtk_widget_set_name (frame83, "frame83");
  gtk_widget_ref (frame83);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame83", frame83,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame83);
  gtk_box_pack_start (GTK_BOX (hbox183), frame83, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame83), 2);
  gtk_frame_set_shadow_type (GTK_FRAME (frame83), GTK_SHADOW_OUT);

  table69a = gtk_table_new (3, 3, FALSE);
  gtk_widget_set_name (table69a, "table69a");
  gtk_widget_ref (table69a);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "table69a", table69a,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table69a);
  gtk_container_add (GTK_CONTAINER (frame83), table69a);
  gtk_container_set_border_width (GTK_CONTAINER (table69a), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table69a), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table69a), 4);

  label558 = gtk_label_new (_("Total input bandwidth limit:"));
  gtk_widget_set_name (label558, "label558");
  gtk_widget_ref (label558);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label558", label558,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label558);
  gtk_table_attach (GTK_TABLE (table69a), label558, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label558), 0, 0.5);

  label560 = gtk_label_new (_("KiB/s"));
  gtk_widget_set_name (label560, "label560");
  gtk_widget_ref (label560);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label560", label560,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label560);
  gtk_table_attach (GTK_TABLE (table69a), label560, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label561 = gtk_label_new (_("Total output bandwidth limit:"));
  gtk_widget_set_name (label561, "label561");
  gtk_widget_ref (label561);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label561", label561,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label561);
  gtk_table_attach (GTK_TABLE (table69a), label561, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label561), 0, 0.5);

  label563 = gtk_label_new (_("KiB/s"));
  gtk_widget_set_name (label563, "label563");
  gtk_widget_ref (label563);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label563", label563,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label563);
  gtk_table_attach (GTK_TABLE (table69a), label563, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label564 = gtk_label_new (_("Measured HTTP latency:"));
  gtk_widget_set_name (label564, "label564");
  gtk_widget_ref (label564);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label564", label564,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label564);
  gtk_table_attach (GTK_TABLE (table69a), label564, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label564), 0, 0.5);

  label566 = gtk_label_new (_("secs"));
  gtk_widget_set_name (label566, "label566");
  gtk_widget_ref (label566);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label566", label566,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label566);
  gtk_table_attach (GTK_TABLE (table69a), label566, 2, 3, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  viewport14 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport14, "viewport14");
  gtk_widget_ref (viewport14);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "viewport14", viewport14,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (viewport14);
  gtk_table_attach (GTK_TABLE (table69a), viewport14, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  label_output_bw_limit = gtk_label_new (_("[place holder]"));
  gtk_widget_set_name (label_output_bw_limit, "label_output_bw_limit");
  gtk_widget_ref (label_output_bw_limit);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label_output_bw_limit", label_output_bw_limit,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_output_bw_limit);
  gtk_container_add (GTK_CONTAINER (viewport14), label_output_bw_limit);
  gtk_misc_set_alignment (GTK_MISC (label_output_bw_limit), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_output_bw_limit), 5, 0);

  viewport15 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport15, "viewport15");
  gtk_widget_ref (viewport15);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "viewport15", viewport15,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (viewport15);
  gtk_table_attach (GTK_TABLE (table69a), viewport15, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  label_dl_http_latency = gtk_label_new (_("[place holder]"));
  gtk_widget_set_name (label_dl_http_latency, "label_dl_http_latency");
  gtk_widget_ref (label_dl_http_latency);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label_dl_http_latency", label_dl_http_latency,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_dl_http_latency);
  gtk_container_add (GTK_CONTAINER (viewport15), label_dl_http_latency);
  gtk_misc_set_alignment (GTK_MISC (label_dl_http_latency), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_dl_http_latency), 5, 0);

  viewport13 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport13, "viewport13");
  gtk_widget_ref (viewport13);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "viewport13", viewport13,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (viewport13);
  gtk_table_attach (GTK_TABLE (table69a), viewport13, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  label_input_bw_limit = gtk_label_new (_("[place holder]"));
  gtk_widget_set_name (label_input_bw_limit, "label_input_bw_limit");
  gtk_widget_ref (label_input_bw_limit);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label_input_bw_limit", label_input_bw_limit,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_input_bw_limit);
  gtk_container_add (GTK_CONTAINER (viewport13), label_input_bw_limit);
  gtk_misc_set_alignment (GTK_MISC (label_input_bw_limit), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_input_bw_limit), 5, 0);

  frame20 = gtk_frame_new (_("Bandwidth limits for Gnutella traffic"));
  gtk_widget_set_name (frame20, "frame20");
  gtk_widget_ref (frame20);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame20", frame20,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame20);
  gtk_box_pack_start (GTK_BOX (vbox29), frame20, FALSE, TRUE, 0);

  hbox208 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox208, "hbox208");
  gtk_widget_ref (hbox208);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "hbox208", hbox208,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox208);
  gtk_container_add (GTK_CONTAINER (frame20), hbox208);
  gtk_container_set_border_width (GTK_CONTAINER (hbox208), 2);

  frame138 = gtk_frame_new (_("General"));
  gtk_widget_set_name (frame138, "frame138");
  gtk_widget_ref (frame138);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame138", frame138,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame138);
  gtk_box_pack_start (GTK_BOX (hbox208), frame138, TRUE, TRUE, 0);
  gtk_frame_set_shadow_type (GTK_FRAME (frame138), GTK_SHADOW_OUT);

  table13 = gtk_table_new (2, 3, FALSE);
  gtk_widget_set_name (table13, "table13");
  gtk_widget_ref (table13);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "table13", table13,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table13);
  gtk_container_add (GTK_CONTAINER (frame138), table13);
  gtk_table_set_row_spacings (GTK_TABLE (table13), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table13), 4);

  label181 = gtk_label_new (_("KiB/s"));
  gtk_widget_set_name (label181, "label181");
  gtk_widget_ref (label181);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label181", label181,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label181);
  gtk_table_attach (GTK_TABLE (table13), label181, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label181), 0, 0.5);

  label182 = gtk_label_new (_("KiB/s"));
  gtk_widget_set_name (label182, "label182");
  gtk_widget_ref (label182);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label182", label182,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label182);
  gtk_table_attach (GTK_TABLE (table13), label182, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label182), 0, 0.5);

  spinbutton_config_bws_gin_adj = gtk_adjustment_new (1, 1, 2000, 1, 5, 16);
  spinbutton_config_bws_gin = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_bws_gin_adj), 1, 2);
  gtk_widget_set_name (spinbutton_config_bws_gin, "spinbutton_config_bws_gin");
  gtk_widget_ref (spinbutton_config_bws_gin);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_config_bws_gin", spinbutton_config_bws_gin,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_config_bws_gin);
  gtk_table_attach (GTK_TABLE (table13), spinbutton_config_bws_gin, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_usize (spinbutton_config_bws_gin, 64, -2);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_bws_gin), TRUE);

  spinbutton_config_bws_gout_adj = gtk_adjustment_new (1, 1, 2000, 1, 5, 16);
  spinbutton_config_bws_gout = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_bws_gout_adj), 1, 2);
  gtk_widget_set_name (spinbutton_config_bws_gout, "spinbutton_config_bws_gout");
  gtk_widget_ref (spinbutton_config_bws_gout);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_config_bws_gout", spinbutton_config_bws_gout,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_config_bws_gout);
  gtk_table_attach (GTK_TABLE (table13), spinbutton_config_bws_gout, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_usize (spinbutton_config_bws_gout, 64, -2);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_bws_gout), TRUE);

  checkbutton_config_bws_gout = gtk_check_button_new_with_label ("");
  checkbutton_config_bws_gout_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (checkbutton_config_bws_gout)->child),
                                   _("_Outgoing traffic"));
  gtk_widget_add_accelerator (checkbutton_config_bws_gout, "clicked", accel_group,
                              checkbutton_config_bws_gout_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (checkbutton_config_bws_gout, "checkbutton_config_bws_gout");
  gtk_widget_ref (checkbutton_config_bws_gout);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_config_bws_gout", checkbutton_config_bws_gout,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_config_bws_gout);
  gtk_table_attach (GTK_TABLE (table13), checkbutton_config_bws_gout, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_config_bws_gin = gtk_check_button_new_with_label ("");
  checkbutton_config_bws_gin_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (checkbutton_config_bws_gin)->child),
                                   _("_Incoming traffic"));
  gtk_widget_add_accelerator (checkbutton_config_bws_gin, "clicked", accel_group,
                              checkbutton_config_bws_gin_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (checkbutton_config_bws_gin, "checkbutton_config_bws_gin");
  gtk_widget_ref (checkbutton_config_bws_gin);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_config_bws_gin", checkbutton_config_bws_gin,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_config_bws_gin);
  gtk_table_attach (GTK_TABLE (table13), checkbutton_config_bws_gin, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  frame74 = gtk_frame_new (_("Ultrapeer mode"));
  gtk_widget_set_name (frame74, "frame74");
  gtk_widget_ref (frame74);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame74", frame74,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame74);
  gtk_box_pack_start (GTK_BOX (hbox208), frame74, TRUE, TRUE, 0);
  gtk_frame_set_shadow_type (GTK_FRAME (frame74), GTK_SHADOW_OUT);

  table58 = gtk_table_new (4, 3, FALSE);
  gtk_widget_set_name (table58, "table58");
  gtk_widget_ref (table58);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "table58", table58,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table58);
  gtk_container_add (GTK_CONTAINER (frame74), table58);
  gtk_container_set_border_width (GTK_CONTAINER (table58), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table58), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table58), 4);

  spinbutton_config_bws_glin_adj = gtk_adjustment_new (1, 0, 100, 1, 5, 10);
  spinbutton_config_bws_glin = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_bws_glin_adj), 1, 2);
  gtk_widget_set_name (spinbutton_config_bws_glin, "spinbutton_config_bws_glin");
  gtk_widget_ref (spinbutton_config_bws_glin);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_config_bws_glin", spinbutton_config_bws_glin,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_config_bws_glin);
  gtk_table_attach (GTK_TABLE (table58), spinbutton_config_bws_glin, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_usize (spinbutton_config_bws_glin, 64, -2);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_bws_glin), TRUE);

  label556 = gtk_label_new (_("KiB/s"));
  gtk_widget_set_name (label556, "label556");
  gtk_widget_ref (label556);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label556", label556,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label556);
  gtk_table_attach (GTK_TABLE (table58), label556, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label556), 0, 0.5);

  checkbutton_config_bws_glin = gtk_check_button_new_with_label ("");
  checkbutton_config_bws_glin_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (checkbutton_config_bws_glin)->child),
                                   _("Incoming traffic from _leaves"));
  gtk_widget_add_accelerator (checkbutton_config_bws_glin, "clicked", accel_group,
                              checkbutton_config_bws_glin_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (checkbutton_config_bws_glin, "checkbutton_config_bws_glin");
  gtk_widget_ref (checkbutton_config_bws_glin);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_config_bws_glin", checkbutton_config_bws_glin,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_config_bws_glin);
  gtk_table_attach (GTK_TABLE (table58), checkbutton_config_bws_glin, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label8018 = gtk_label_new (_("Available HTTP output bandwidth"));
  gtk_widget_set_name (label8018, "label8018");
  gtk_widget_ref (label8018);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label8018", label8018,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label8018);
  gtk_table_attach (GTK_TABLE (table58), label8018, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label8018), 0, 0.5);

  viewport54 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport54, "viewport54");
  gtk_widget_ref (viewport54);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "viewport54", viewport54,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (viewport54);
  gtk_table_attach (GTK_TABLE (table58), viewport54, 1, 2, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  label_http_out_avail = gtk_label_new (_("[place holder]"));
  gtk_widget_set_name (label_http_out_avail, "label_http_out_avail");
  gtk_widget_ref (label_http_out_avail);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label_http_out_avail", label_http_out_avail,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_http_out_avail);
  gtk_container_add (GTK_CONTAINER (viewport54), label_http_out_avail);
  gtk_misc_set_alignment (GTK_MISC (label_http_out_avail), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_http_out_avail), 5, 0);

  label8019 = gtk_label_new (_("KiB/s"));
  gtk_widget_set_name (label8019, "label8019");
  gtk_widget_ref (label8019);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label8019", label8019,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label8019);
  gtk_table_attach (GTK_TABLE (table58), label8019, 2, 3, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label8019), 0, 0.5);

  checkbutton_config_bws_glout = gtk_check_button_new_with_label ("");
  checkbutton_config_bws_glout_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (checkbutton_config_bws_glout)->child),
                                   _("Outgoing traffic to lea_ves"));
  gtk_widget_add_accelerator (checkbutton_config_bws_glout, "clicked", accel_group,
                              checkbutton_config_bws_glout_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (checkbutton_config_bws_glout, "checkbutton_config_bws_glout");
  gtk_widget_ref (checkbutton_config_bws_glout);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_config_bws_glout", checkbutton_config_bws_glout,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_config_bws_glout);
  gtk_table_attach (GTK_TABLE (table58), checkbutton_config_bws_glout, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  spinbutton_config_bws_glout_adj = gtk_adjustment_new (1, 0, 100, 1, 5, 10);
  spinbutton_config_bws_glout = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_bws_glout_adj), 1, 2);
  gtk_widget_set_name (spinbutton_config_bws_glout, "spinbutton_config_bws_glout");
  gtk_widget_ref (spinbutton_config_bws_glout);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_config_bws_glout", spinbutton_config_bws_glout,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_config_bws_glout);
  gtk_table_attach (GTK_TABLE (table58), spinbutton_config_bws_glout, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_usize (spinbutton_config_bws_glout, 64, -2);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_bws_glout), TRUE);

  label557 = gtk_label_new (_("KiB/s"));
  gtk_widget_set_name (label557, "label557");
  gtk_widget_ref (label557);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label557", label557,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label557);
  gtk_table_attach (GTK_TABLE (table58), label557, 2, 3, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label557), 0, 0.5);

  label8021 = gtk_label_new (_("Available HTTP input bandwidth"));
  gtk_widget_set_name (label8021, "label8021");
  gtk_widget_ref (label8021);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label8021", label8021,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label8021);
  gtk_table_attach (GTK_TABLE (table58), label8021, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label8021), 0, 0.5);

  label8022 = gtk_label_new (_("KiB/s"));
  gtk_widget_set_name (label8022, "label8022");
  gtk_widget_ref (label8022);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label8022", label8022,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label8022);
  gtk_table_attach (GTK_TABLE (table58), label8022, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label8022), 0, 0.5);

  viewport55 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport55, "viewport55");
  gtk_widget_ref (viewport55);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "viewport55", viewport55,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (viewport55);
  gtk_table_attach (GTK_TABLE (table58), viewport55, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  label_http_in_avail = gtk_label_new (_("[place holder]"));
  gtk_widget_set_name (label_http_in_avail, "label_http_in_avail");
  gtk_widget_ref (label_http_in_avail);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label_http_in_avail", label_http_in_avail,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_http_in_avail);
  gtk_container_add (GTK_CONTAINER (viewport55), label_http_in_avail);
  gtk_misc_set_alignment (GTK_MISC (label_http_in_avail), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_http_in_avail), 5, 0);

  frame153 = gtk_frame_new (_("Bandwidth limits for the Distributed Hash Table"));
  gtk_widget_set_name (frame153, "frame153");
  gtk_widget_ref (frame153);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame153", frame153,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame153);
  gtk_box_pack_start (GTK_BOX (vbox29), frame153, FALSE, TRUE, 0);

  vbox146 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox146, "vbox146");
  gtk_widget_ref (vbox146);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "vbox146", vbox146,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox146);
  gtk_container_add (GTK_CONTAINER (frame153), vbox146);

  table100 = gtk_table_new (1, 3, FALSE);
  gtk_widget_set_name (table100, "table100");
  gtk_widget_ref (table100);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "table100", table100,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table100);
  gtk_box_pack_start (GTK_BOX (vbox146), table100, TRUE, TRUE, 0);
  gtk_table_set_row_spacings (GTK_TABLE (table100), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table100), 4);

  label8012 = gtk_label_new (_("KiB/s"));
  gtk_widget_set_name (label8012, "label8012");
  gtk_widget_ref (label8012);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label8012", label8012,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label8012);
  gtk_table_attach (GTK_TABLE (table100), label8012, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label8012), 0, 0.5);

  spinbutton_config_bws_dht_out_adj = gtk_adjustment_new (1, 1, 2000, 1, 5, 16);
  spinbutton_config_bws_dht_out = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_bws_dht_out_adj), 1, 2);
  gtk_widget_set_name (spinbutton_config_bws_dht_out, "spinbutton_config_bws_dht_out");
  gtk_widget_ref (spinbutton_config_bws_dht_out);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_config_bws_dht_out", spinbutton_config_bws_dht_out,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_config_bws_dht_out);
  gtk_table_attach (GTK_TABLE (table100), spinbutton_config_bws_dht_out, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_usize (spinbutton_config_bws_dht_out, 64, -2);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_bws_dht_out), TRUE);

  checkbutton_config_bws_dht_out = gtk_check_button_new_with_label (_("Global DHT outgoing traffic"));
  gtk_widget_set_name (checkbutton_config_bws_dht_out, "checkbutton_config_bws_dht_out");
  gtk_widget_ref (checkbutton_config_bws_dht_out);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_config_bws_dht_out", checkbutton_config_bws_dht_out,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_config_bws_dht_out);
  gtk_table_attach (GTK_TABLE (table100), checkbutton_config_bws_dht_out, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  frame154 = gtk_frame_new (_("Bandwidth targets for node lookups"));
  gtk_widget_set_name (frame154, "frame154");
  gtk_widget_ref (frame154);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame154", frame154,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame154);
  gtk_box_pack_start (GTK_BOX (vbox146), frame154, TRUE, TRUE, 0);

  table101 = gtk_table_new (2, 3, FALSE);
  gtk_widget_set_name (table101, "table101");
  gtk_widget_ref (table101);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "table101", table101,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table101);
  gtk_container_add (GTK_CONTAINER (frame154), table101);
  gtk_table_set_row_spacings (GTK_TABLE (table101), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table101), 4);

  label8014 = gtk_label_new (_("KiB/s"));
  gtk_widget_set_name (label8014, "label8014");
  gtk_widget_ref (label8014);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label8014", label8014,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label8014);
  gtk_table_attach (GTK_TABLE (table101), label8014, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label8014), 0, 0.5);

  label8015 = gtk_label_new (_("KiB/s"));
  gtk_widget_set_name (label8015, "label8015");
  gtk_widget_ref (label8015);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label8015", label8015,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label8015);
  gtk_table_attach (GTK_TABLE (table101), label8015, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label8015), 0, 0.5);

  spinbutton_config_input_dht_lookup_bw_adj = gtk_adjustment_new (1, 1, 2000, 1, 5, 16);
  spinbutton_config_input_dht_lookup_bw = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_input_dht_lookup_bw_adj), 1, 2);
  gtk_widget_set_name (spinbutton_config_input_dht_lookup_bw, "spinbutton_config_input_dht_lookup_bw");
  gtk_widget_ref (spinbutton_config_input_dht_lookup_bw);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_config_input_dht_lookup_bw", spinbutton_config_input_dht_lookup_bw,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_config_input_dht_lookup_bw);
  gtk_table_attach (GTK_TABLE (table101), spinbutton_config_input_dht_lookup_bw, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_usize (spinbutton_config_input_dht_lookup_bw, 64, -2);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_input_dht_lookup_bw), TRUE);

  spinbutton_config_output_dht_lookup_bw_adj = gtk_adjustment_new (1, 1, 2000, 1, 5, 16);
  spinbutton_config_output_dht_lookup_bw = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_output_dht_lookup_bw_adj), 1, 2);
  gtk_widget_set_name (spinbutton_config_output_dht_lookup_bw, "spinbutton_config_output_dht_lookup_bw");
  gtk_widget_ref (spinbutton_config_output_dht_lookup_bw);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_config_output_dht_lookup_bw", spinbutton_config_output_dht_lookup_bw,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_config_output_dht_lookup_bw);
  gtk_table_attach (GTK_TABLE (table101), spinbutton_config_output_dht_lookup_bw, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_usize (spinbutton_config_output_dht_lookup_bw, 64, -2);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_output_dht_lookup_bw), TRUE);

  label8016 = gtk_label_new (_("Input bandwidth average"));
  gtk_widget_set_name (label8016, "label8016");
  gtk_widget_ref (label8016);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label8016", label8016,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label8016);
  gtk_table_attach (GTK_TABLE (table101), label8016, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label8016), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label8016), 4, 0);

  label8017 = gtk_label_new (_("Output bandwidth average"));
  gtk_widget_set_name (label8017, "label8017");
  gtk_widget_ref (label8017);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label8017", label8017,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label8017);
  gtk_table_attach (GTK_TABLE (table101), label8017, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label8017), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label8017), 4, 0);

  frame12 = gtk_frame_new (_("Bandwidth limits for HTTP traffic"));
  gtk_widget_set_name (frame12, "frame12");
  gtk_widget_ref (frame12);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame12", frame12,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame12);
  gtk_box_pack_start (GTK_BOX (vbox29), frame12, FALSE, TRUE, 0);

  table4 = gtk_table_new (6, 3, FALSE);
  gtk_widget_set_name (table4, "table4");
  gtk_widget_ref (table4);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "table4", table4,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table4);
  gtk_container_add (GTK_CONTAINER (frame12), table4);
  gtk_container_set_border_width (GTK_CONTAINER (table4), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table4), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table4), 4);

  label126 = gtk_label_new (_("KiB/s"));
  gtk_widget_set_name (label126, "label126");
  gtk_widget_ref (label126);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label126", label126,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label126);
  gtk_table_attach (GTK_TABLE (table4), label126, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label126), 0, 0.5);

  spinbutton_config_bws_in_adj = gtk_adjustment_new (1, 1, 2000, 1, 5, 16);
  spinbutton_config_bws_in = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_bws_in_adj), 1, 2);
  gtk_widget_set_name (spinbutton_config_bws_in, "spinbutton_config_bws_in");
  gtk_widget_ref (spinbutton_config_bws_in);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_config_bws_in", spinbutton_config_bws_in,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_config_bws_in);
  gtk_table_attach (GTK_TABLE (table4), spinbutton_config_bws_in, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_usize (spinbutton_config_bws_in, 64, -2);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_bws_in), TRUE);

  spinbutton_config_bws_out_adj = gtk_adjustment_new (1, 1, 2000, 1, 5, 1024);
  spinbutton_config_bws_out = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_bws_out_adj), 1, 2);
  gtk_widget_set_name (spinbutton_config_bws_out, "spinbutton_config_bws_out");
  gtk_widget_ref (spinbutton_config_bws_out);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_config_bws_out", spinbutton_config_bws_out,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_config_bws_out);
  gtk_table_attach (GTK_TABLE (table4), spinbutton_config_bws_out, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_usize (spinbutton_config_bws_out, 64, -2);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_bws_out), TRUE);

  checkbutton_config_bws_in = gtk_check_button_new_with_label ("");
  checkbutton_config_bws_in_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (checkbutton_config_bws_in)->child),
                                   _("Cumulative _download rate"));
  gtk_widget_add_accelerator (checkbutton_config_bws_in, "clicked", accel_group,
                              checkbutton_config_bws_in_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (checkbutton_config_bws_in, "checkbutton_config_bws_in");
  gtk_widget_ref (checkbutton_config_bws_in);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_config_bws_in", checkbutton_config_bws_in,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_config_bws_in);
  gtk_table_attach (GTK_TABLE (table4), checkbutton_config_bws_in, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_config_bws_out = gtk_check_button_new_with_label ("");
  checkbutton_config_bws_out_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (checkbutton_config_bws_out)->child),
                                   _("Cumulative _upload rate"));
  gtk_widget_add_accelerator (checkbutton_config_bws_out, "clicked", accel_group,
                              checkbutton_config_bws_out_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (checkbutton_config_bws_out, "checkbutton_config_bws_out");
  gtk_widget_ref (checkbutton_config_bws_out);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_config_bws_out", checkbutton_config_bws_out,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_config_bws_out);
  gtk_table_attach (GTK_TABLE (table4), checkbutton_config_bws_out, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_config_bw_ul_usage_enabled = gtk_check_button_new_with_label ("");
  checkbutton_config_bw_ul_usage_enabled_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (checkbutton_config_bw_ul_usage_enabled)->child),
                                   _("Enable dynamic upload slots _allocation"));
  gtk_widget_add_accelerator (checkbutton_config_bw_ul_usage_enabled, "clicked", accel_group,
                              checkbutton_config_bw_ul_usage_enabled_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (checkbutton_config_bw_ul_usage_enabled, "checkbutton_config_bw_ul_usage_enabled");
  gtk_widget_ref (checkbutton_config_bw_ul_usage_enabled);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_config_bw_ul_usage_enabled", checkbutton_config_bw_ul_usage_enabled,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_config_bw_ul_usage_enabled);
  gtk_table_attach (GTK_TABLE (table4), checkbutton_config_bw_ul_usage_enabled, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  spinbutton_config_ul_usage_min_percentage_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 10);
  spinbutton_config_ul_usage_min_percentage = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_ul_usage_min_percentage_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_ul_usage_min_percentage, "spinbutton_config_ul_usage_min_percentage");
  gtk_widget_ref (spinbutton_config_ul_usage_min_percentage);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_config_ul_usage_min_percentage", spinbutton_config_ul_usage_min_percentage,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_config_ul_usage_min_percentage);
  gtk_table_attach (GTK_TABLE (table4), spinbutton_config_ul_usage_min_percentage, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_tooltips_set_tip (tooltips, spinbutton_config_ul_usage_min_percentage, _("Until the configured percentage of outgoing HTTP bandwidth is in use, open additional upload slots on request."), NULL);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_ul_usage_min_percentage), TRUE);

  label210 = gtk_label_new (_("%"));
  gtk_widget_set_name (label210, "label210");
  gtk_widget_ref (label210);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label210", label210,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label210);
  gtk_table_attach (GTK_TABLE (table4), label210, 2, 3, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label210), 0, 0.5);

  label125 = gtk_label_new (_("KiB/s"));
  gtk_widget_set_name (label125, "label125");
  gtk_widget_ref (label125);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label125", label125,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label125);
  gtk_table_attach (GTK_TABLE (table4), label125, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label125), 0, 0.5);

  label156 = gtk_label_new ("");
  label156_key = gtk_label_parse_uline (GTK_LABEL (label156),
                                   _("Report an upload connection _speed of"));
  gtk_widget_set_name (label156, "label156");
  gtk_widget_ref (label156);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label156", label156,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label156);
  gtk_table_attach (GTK_TABLE (table4), label156, 0, 1, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label156), 0, 0.5);

  spinbutton_config_speed_adj = gtk_adjustment_new (64, 0, 2e+06, 1, 8, 16);
  spinbutton_config_speed = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_speed_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_speed, "spinbutton_config_speed");
  gtk_widget_ref (spinbutton_config_speed);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_config_speed", spinbutton_config_speed,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_config_speed);
  gtk_table_attach (GTK_TABLE (table4), spinbutton_config_speed, 1, 2, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_usize (spinbutton_config_speed, 64, -2);
  gtk_tooltips_set_tip (tooltips, spinbutton_config_speed, _("What other people see as your connection speed."), NULL);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_speed), TRUE);

  label36 = gtk_label_new (_("kbps to peers"));
  gtk_widget_set_name (label36, "label36");
  gtk_widget_ref (label36);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label36", label36,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label36);
  gtk_table_attach (GTK_TABLE (table4), label36, 2, 3, 4, 5,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label36), 0, 0.5);

  hseparator8 = gtk_hseparator_new ();
  gtk_widget_set_name (hseparator8, "hseparator8");
  gtk_widget_ref (hseparator8);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "hseparator8", hseparator8,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hseparator8);
  gtk_table_attach (GTK_TABLE (table4), hseparator8, 0, 3, 3, 4,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  checkbutton_compute_connection_speed = gtk_check_button_new_with_label ("");
  checkbutton_compute_connection_speed_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (checkbutton_compute_connection_speed)->child),
                                   _("_Compute upload connection speed"));
  gtk_widget_add_accelerator (checkbutton_compute_connection_speed, "clicked", accel_group,
                              checkbutton_compute_connection_speed_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (checkbutton_compute_connection_speed, "checkbutton_compute_connection_speed");
  gtk_widget_ref (checkbutton_compute_connection_speed);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_compute_connection_speed", checkbutton_compute_connection_speed,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_compute_connection_speed);
  gtk_table_attach (GTK_TABLE (table4), checkbutton_compute_connection_speed, 0, 3, 5, 6,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  frame155 = gtk_frame_new (_("Bandwidth limits for GUESS queries"));
  gtk_widget_set_name (frame155, "frame155");
  gtk_widget_ref (frame155);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame155", frame155,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame155);
  gtk_box_pack_start (GTK_BOX (vbox29), frame155, TRUE, TRUE, 0);

  table103 = gtk_table_new (2, 3, FALSE);
  gtk_widget_set_name (table103, "table103");
  gtk_widget_ref (table103);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "table103", table103,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table103);
  gtk_container_add (GTK_CONTAINER (frame155), table103);
  gtk_table_set_row_spacings (GTK_TABLE (table103), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table103), 4);

  label8028 = gtk_label_new (_("Output bandwidth hint"));
  gtk_widget_set_name (label8028, "label8028");
  gtk_widget_ref (label8028);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label8028", label8028,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label8028);
  gtk_table_attach (GTK_TABLE (table103), label8028, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label8028), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label8028), 4, 0);

  label8029 = gtk_label_new (_("KiB/s"));
  gtk_widget_set_name (label8029, "label8029");
  gtk_widget_ref (label8029);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label8029", label8029,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label8029);
  gtk_table_attach (GTK_TABLE (table103), label8029, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label8029), 0, 0.5);

  spinbutton_config_bw_guess_out_adj = gtk_adjustment_new (1, 1, 2000, 1, 5, 16);
  spinbutton_config_bw_guess_out = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_bw_guess_out_adj), 1, 2);
  gtk_widget_set_name (spinbutton_config_bw_guess_out, "spinbutton_config_bw_guess_out");
  gtk_widget_ref (spinbutton_config_bw_guess_out);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_config_bw_guess_out", spinbutton_config_bw_guess_out,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_config_bw_guess_out);
  gtk_table_attach (GTK_TABLE (table103), spinbutton_config_bw_guess_out, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_usize (spinbutton_config_bw_guess_out, 64, -2);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_bw_guess_out), TRUE);

  checkbutton_guess_maximize_bw = gtk_check_button_new_with_label (_("Allow unused Gnutella outgoing bandwidth to supersede hint"));
  gtk_widget_set_name (checkbutton_guess_maximize_bw, "checkbutton_guess_maximize_bw");
  gtk_widget_ref (checkbutton_guess_maximize_bw);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_guess_maximize_bw", checkbutton_guess_maximize_bw,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_guess_maximize_bw);
  gtk_table_attach (GTK_TABLE (table103), checkbutton_guess_maximize_bw, 0, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label684 = gtk_label_new (_("Bandwidth"));
  gtk_widget_set_name (label684, "label684");
  gtk_widget_ref (label684);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label684", label684,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label684);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_prefs), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_prefs), 2), label684);

  scrolledwindow34 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow34, "scrolledwindow34");
  gtk_widget_ref (scrolledwindow34);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "scrolledwindow34", scrolledwindow34,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (scrolledwindow34);
  gtk_container_add (GTK_CONTAINER (notebook_prefs), scrolledwindow34);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow34), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);

  viewport6 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport6, "viewport6");
  gtk_widget_ref (viewport6);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "viewport6", viewport6,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (viewport6);
  gtk_container_add (GTK_CONTAINER (scrolledwindow34), viewport6);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport6), GTK_SHADOW_NONE);

  vbox38 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox38, "vbox38");
  gtk_widget_ref (vbox38);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "vbox38", vbox38,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox38);
  gtk_container_add (GTK_CONTAINER (viewport6), vbox38);
  gtk_container_set_border_width (GTK_CONTAINER (vbox38), 2);

  frame_save_new_files = gtk_frame_new (_("Keep downloading/incomplete files in"));
  gtk_widget_set_name (frame_save_new_files, "frame_save_new_files");
  gtk_widget_ref (frame_save_new_files);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame_save_new_files", frame_save_new_files,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame_save_new_files);
  gtk_box_pack_start (GTK_BOX (vbox38), frame_save_new_files, FALSE, TRUE, 0);

  hbox96 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox96, "hbox96");
  gtk_widget_ref (hbox96);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "hbox96", hbox96,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox96);
  gtk_container_add (GTK_CONTAINER (frame_save_new_files), hbox96);
  gtk_container_set_border_width (GTK_CONTAINER (hbox96), 2);

  entry_config_save_path = gtk_entry_new ();
  gtk_widget_set_name (entry_config_save_path, "entry_config_save_path");
  gtk_widget_ref (entry_config_save_path);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "entry_config_save_path", entry_config_save_path,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_config_save_path);
  gtk_box_pack_start (GTK_BOX (hbox96), entry_config_save_path, TRUE, TRUE, 0);
  gtk_entry_set_editable (GTK_ENTRY (entry_config_save_path), FALSE);

  button_config_save_path = gtk_button_new_with_label ("");
  button_config_save_path_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (button_config_save_path)->child),
                                   _("_Browse"));
  gtk_widget_add_accelerator (button_config_save_path, "clicked", accel_group,
                              button_config_save_path_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (button_config_save_path, "button_config_save_path");
  gtk_widget_ref (button_config_save_path);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "button_config_save_path", button_config_save_path,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_config_save_path);
  gtk_box_pack_start (GTK_BOX (hbox96), button_config_save_path, FALSE, FALSE, 0);

  frame_move_downloaded_files = gtk_frame_new (_("Move completely downloaded files to"));
  gtk_widget_set_name (frame_move_downloaded_files, "frame_move_downloaded_files");
  gtk_widget_ref (frame_move_downloaded_files);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame_move_downloaded_files", frame_move_downloaded_files,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame_move_downloaded_files);
  gtk_box_pack_start (GTK_BOX (vbox38), frame_move_downloaded_files, FALSE, TRUE, 0);

  hbox95 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox95, "hbox95");
  gtk_widget_ref (hbox95);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "hbox95", hbox95,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox95);
  gtk_container_add (GTK_CONTAINER (frame_move_downloaded_files), hbox95);
  gtk_container_set_border_width (GTK_CONTAINER (hbox95), 2);

  entry_config_move_path = gtk_entry_new ();
  gtk_widget_set_name (entry_config_move_path, "entry_config_move_path");
  gtk_widget_ref (entry_config_move_path);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "entry_config_move_path", entry_config_move_path,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_config_move_path);
  gtk_box_pack_start (GTK_BOX (hbox95), entry_config_move_path, TRUE, TRUE, 0);
  gtk_entry_set_editable (GTK_ENTRY (entry_config_move_path), FALSE);

  button_config_move_path = gtk_button_new_with_label ("");
  button_config_move_path_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (button_config_move_path)->child),
                                   _("_Browse"));
  gtk_widget_add_accelerator (button_config_move_path, "clicked", accel_group,
                              button_config_move_path_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (button_config_move_path, "button_config_move_path");
  gtk_widget_ref (button_config_move_path);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "button_config_move_path", button_config_move_path,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_config_move_path);
  gtk_box_pack_start (GTK_BOX (hbox95), button_config_move_path, FALSE, FALSE, 0);

  frame66 = gtk_frame_new (_("Move corrupted downloaded files to"));
  gtk_widget_set_name (frame66, "frame66");
  gtk_widget_ref (frame66);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame66", frame66,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame66);
  gtk_box_pack_start (GTK_BOX (vbox38), frame66, FALSE, TRUE, 0);

  hbox158 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox158, "hbox158");
  gtk_widget_ref (hbox158);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "hbox158", hbox158,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox158);
  gtk_container_add (GTK_CONTAINER (frame66), hbox158);
  gtk_container_set_border_width (GTK_CONTAINER (hbox158), 2);

  entry_config_bad_path = gtk_entry_new ();
  gtk_widget_set_name (entry_config_bad_path, "entry_config_bad_path");
  gtk_widget_ref (entry_config_bad_path);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "entry_config_bad_path", entry_config_bad_path,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_config_bad_path);
  gtk_box_pack_start (GTK_BOX (hbox158), entry_config_bad_path, TRUE, TRUE, 0);
  gtk_entry_set_editable (GTK_ENTRY (entry_config_bad_path), FALSE);

  button_config_bad_path = gtk_button_new_with_label ("");
  button_config_bad_path_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (button_config_bad_path)->child),
                                   _("_Browse"));
  gtk_widget_add_accelerator (button_config_bad_path, "clicked", accel_group,
                              button_config_bad_path_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (button_config_bad_path, "button_config_bad_path");
  gtk_widget_ref (button_config_bad_path);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "button_config_bad_path", button_config_bad_path,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_config_bad_path);
  gtk_box_pack_start (GTK_BOX (hbox158), button_config_bad_path, FALSE, FALSE, 0);

  frame136 = gtk_frame_new (_("Miscellaneous"));
  gtk_widget_set_name (frame136, "frame136");
  gtk_widget_ref (frame136);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame136", frame136,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame136);
  gtk_box_pack_start (GTK_BOX (vbox38), frame136, TRUE, TRUE, 0);

  table94 = gtk_table_new (4, 1, FALSE);
  gtk_widget_set_name (table94, "table94");
  gtk_widget_ref (table94);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "table94", table94,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table94);
  gtk_container_add (GTK_CONTAINER (frame136), table94);

  checkbutton_config_convert_spaces = gtk_check_button_new_with_label (_("Convert spaces to underscores in generated filenames"));
  gtk_widget_set_name (checkbutton_config_convert_spaces, "checkbutton_config_convert_spaces");
  gtk_widget_ref (checkbutton_config_convert_spaces);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_config_convert_spaces", checkbutton_config_convert_spaces,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_config_convert_spaces);
  gtk_table_attach (GTK_TABLE (table94), checkbutton_config_convert_spaces, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_config_convert_evil_chars = gtk_check_button_new_with_label (_("Convert \"evil\" characters (like shell meta characters) to underscores in generated filenames"));
  gtk_widget_set_name (checkbutton_config_convert_evil_chars, "checkbutton_config_convert_evil_chars");
  gtk_widget_ref (checkbutton_config_convert_evil_chars);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_config_convert_evil_chars", checkbutton_config_convert_evil_chars,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_config_convert_evil_chars);
  gtk_table_attach (GTK_TABLE (table94), checkbutton_config_convert_evil_chars, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_config_convert_old_filenames = gtk_check_button_new_with_label (_("Apply above conversions, upon startup, to existing files in the downloading directory"));
  gtk_widget_set_name (checkbutton_config_convert_old_filenames, "checkbutton_config_convert_old_filenames");
  gtk_widget_ref (checkbutton_config_convert_old_filenames);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_config_convert_old_filenames", checkbutton_config_convert_old_filenames,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_config_convert_old_filenames);
  gtk_table_attach (GTK_TABLE (table94), checkbutton_config_convert_old_filenames, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_config_beautify_filenames = gtk_check_button_new_with_label (_("Beautify filenames by removing needless underscores"));
  gtk_widget_set_name (checkbutton_config_beautify_filenames, "checkbutton_config_beautify_filenames");
  gtk_widget_ref (checkbutton_config_beautify_filenames);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_config_beautify_filenames", checkbutton_config_beautify_filenames,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_config_beautify_filenames);
  gtk_table_attach (GTK_TABLE (table94), checkbutton_config_beautify_filenames, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  frame16 = gtk_frame_new (_("Resume and retry"));
  gtk_widget_set_name (frame16, "frame16");
  gtk_widget_ref (frame16);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame16", frame16,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame16);
  gtk_box_pack_start (GTK_BOX (vbox38), frame16, FALSE, TRUE, 0);

  table46 = gtk_table_new (2, 3, FALSE);
  gtk_widget_set_name (table46, "table46");
  gtk_widget_ref (table46);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "table46", table46,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table46);
  gtk_container_add (GTK_CONTAINER (frame16), table46);
  gtk_container_set_border_width (GTK_CONTAINER (table46), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table46), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table46), 4);

  label171 = gtk_label_new ("");
  label171_key = gtk_label_parse_uline (GTK_LABEL (label171),
                                   _("_Overlap when resuming"));
  gtk_widget_set_name (label171, "label171");
  gtk_widget_ref (label171);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label171", label171,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label171);
  gtk_table_attach (GTK_TABLE (table46), label171, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label171), 0, 0.5);

  label172 = gtk_label_new ("");
  label172_key = gtk_label_parse_uline (GTK_LABEL (label172),
                                   _("Maximum number of _retries"));
  gtk_widget_set_name (label172, "label172");
  gtk_widget_ref (label172);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label172", label172,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label172);
  gtk_table_attach (GTK_TABLE (table46), label172, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label172), 0, 0.5);

  spinbutton_config_download_max_retries_adj = gtk_adjustment_new (1, 0, 100000, 1, 10, 10);
  spinbutton_config_download_max_retries = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_download_max_retries_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_download_max_retries, "spinbutton_config_download_max_retries");
  gtk_widget_ref (spinbutton_config_download_max_retries);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_config_download_max_retries", spinbutton_config_download_max_retries,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_config_download_max_retries);
  gtk_table_attach (GTK_TABLE (table46), spinbutton_config_download_max_retries, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_usize (spinbutton_config_download_max_retries, 64, -2);
  gtk_tooltips_set_tip (tooltips, spinbutton_config_download_max_retries, _("Maximum attempts to make, not counting HTTP busy indications"), NULL);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_download_max_retries), TRUE);

  spinbutton_config_download_overlap_range_adj = gtk_adjustment_new (1, 128, 4096, 1, 10, 10);
  spinbutton_config_download_overlap_range = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_download_overlap_range_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_download_overlap_range, "spinbutton_config_download_overlap_range");
  gtk_widget_ref (spinbutton_config_download_overlap_range);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_config_download_overlap_range", spinbutton_config_download_overlap_range,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_config_download_overlap_range);
  gtk_table_attach (GTK_TABLE (table46), spinbutton_config_download_overlap_range, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_usize (spinbutton_config_download_overlap_range, 96, -2);
  gtk_tooltips_set_tip (tooltips, spinbutton_config_download_overlap_range, _("Amount of bytes to overlap when resuming download"), NULL);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_download_overlap_range), TRUE);

  label173 = gtk_label_new (_("bytes"));
  gtk_widget_set_name (label173, "label173");
  gtk_widget_ref (label173);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label173", label173,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label173);
  gtk_table_attach (GTK_TABLE (table46), label173, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label173), 0, 0.5);

  frame_expert_dl_source_quality = gtk_frame_new (_("Source quality"));
  gtk_widget_set_name (frame_expert_dl_source_quality, "frame_expert_dl_source_quality");
  gtk_widget_ref (frame_expert_dl_source_quality);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame_expert_dl_source_quality", frame_expert_dl_source_quality,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame_expert_dl_source_quality);
  gtk_box_pack_start (GTK_BOX (vbox38), frame_expert_dl_source_quality, FALSE, TRUE, 0);

  table47 = gtk_table_new (1, 3, FALSE);
  gtk_widget_set_name (table47, "table47");
  gtk_widget_ref (table47);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "table47", table47,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table47);
  gtk_container_add (GTK_CONTAINER (frame_expert_dl_source_quality), table47);
  gtk_container_set_border_width (GTK_CONTAINER (table47), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table47), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table47), 4);

  checkbutton_config_download_optimistic_start = gtk_check_button_new_with_label ("");
  checkbutton_config_download_optimistic_start_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (checkbutton_config_download_optimistic_start)->child),
                                   _("Optimistic first _chunk"));
  gtk_widget_add_accelerator (checkbutton_config_download_optimistic_start, "clicked", accel_group,
                              checkbutton_config_download_optimistic_start_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (checkbutton_config_download_optimistic_start, "checkbutton_config_download_optimistic_start");
  gtk_widget_ref (checkbutton_config_download_optimistic_start);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_config_download_optimistic_start", checkbutton_config_download_optimistic_start,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_config_download_optimistic_start);
  gtk_table_attach (GTK_TABLE (table47), checkbutton_config_download_optimistic_start, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_config_req_urn = gtk_check_button_new_with_label ("");
  checkbutton_config_req_urn_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (checkbutton_config_req_urn)->child),
                                   _("Require _URN"));
  gtk_widget_add_accelerator (checkbutton_config_req_urn, "clicked", accel_group,
                              checkbutton_config_req_urn_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (checkbutton_config_req_urn, "checkbutton_config_req_urn");
  gtk_widget_ref (checkbutton_config_req_urn);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_config_req_urn", checkbutton_config_req_urn,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_config_req_urn);
  gtk_table_attach (GTK_TABLE (table47), checkbutton_config_req_urn, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_config_req_srv_name = gtk_check_button_new_with_label ("");
  checkbutton_config_req_srv_name_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (checkbutton_config_req_srv_name)->child),
                                   _("Require _server name"));
  gtk_widget_add_accelerator (checkbutton_config_req_srv_name, "clicked", accel_group,
                              checkbutton_config_req_srv_name_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (checkbutton_config_req_srv_name, "checkbutton_config_req_srv_name");
  gtk_widget_ref (checkbutton_config_req_srv_name);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_config_req_srv_name", checkbutton_config_req_srv_name,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_config_req_srv_name);
  gtk_table_attach (GTK_TABLE (table47), checkbutton_config_req_srv_name, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  frame_expert_dl_timeout = gtk_frame_new (_("Delays and timeouts (all values in seconds)"));
  gtk_widget_set_name (frame_expert_dl_timeout, "frame_expert_dl_timeout");
  gtk_widget_ref (frame_expert_dl_timeout);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame_expert_dl_timeout", frame_expert_dl_timeout,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame_expert_dl_timeout);
  gtk_box_pack_start (GTK_BOX (vbox38), frame_expert_dl_timeout, FALSE, TRUE, 0);

  table8 = gtk_table_new (3, 6, FALSE);
  gtk_widget_set_name (table8, "table8");
  gtk_widget_ref (table8);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "table8", table8,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table8);
  gtk_container_add (GTK_CONTAINER (frame_expert_dl_timeout), table8);
  gtk_container_set_border_width (GTK_CONTAINER (table8), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table8), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table8), 4);

  label162 = gtk_label_new (_("Retry stopped delay"));
  gtk_widget_set_name (label162, "label162");
  gtk_widget_ref (label162);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label162", label162,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label162);
  gtk_table_attach (GTK_TABLE (table8), label162, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label162), 0, 0.5);

  label163 = gtk_label_new (_("Retry refused delay"));
  gtk_widget_set_name (label163, "label163");
  gtk_widget_ref (label163);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label163", label163,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label163);
  gtk_table_attach (GTK_TABLE (table8), label163, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label163), 0, 0.5);

  label164 = gtk_label_new (_("Retry busy delay"));
  gtk_widget_set_name (label164, "label164");
  gtk_widget_ref (label164);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label164", label164,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label164);
  gtk_table_attach (GTK_TABLE (table8), label164, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label164), 0, 0.5);

  label165 = gtk_label_new (_("Retry timeout delay"));
  gtk_widget_set_name (label165, "label165");
  gtk_widget_ref (label165);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label165", label165,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label165);
  gtk_table_attach (GTK_TABLE (table8), label165, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label165), 0, 0.5);

  label166 = gtk_label_new (_("Retry timeout max"));
  gtk_widget_set_name (label166, "label166");
  gtk_widget_ref (label166);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label166", label166,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label166);
  gtk_table_attach (GTK_TABLE (table8), label166, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label166), 0, 0.5);

  label167 = gtk_label_new (_("Retry timeout min"));
  gtk_widget_set_name (label167, "label167");
  gtk_widget_ref (label167);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label167", label167,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label167);
  gtk_table_attach (GTK_TABLE (table8), label167, 2, 3, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label167), 0, 0.5);

  label168 = gtk_label_new ("");
  label168_key = gtk_label_parse_uline (GTK_LABEL (label168),
                                   _("Connectin_g timeout"));
  gtk_widget_set_name (label168, "label168");
  gtk_widget_ref (label168);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label168", label168,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label168);
  gtk_table_attach (GTK_TABLE (table8), label168, 4, 5, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label168), 0, 0.5);

  label169 = gtk_label_new ("");
  label169_key = gtk_label_parse_uline (GTK_LABEL (label169),
                                   _("_Push sent timeout"));
  gtk_widget_set_name (label169, "label169");
  gtk_widget_ref (label169);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label169", label169,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label169);
  gtk_table_attach (GTK_TABLE (table8), label169, 4, 5, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label169), 0, 0.5);

  label170 = gtk_label_new ("");
  label170_key = gtk_label_parse_uline (GTK_LABEL (label170),
                                   _("Connected time_out"));
  gtk_widget_set_name (label170, "label170");
  gtk_widget_ref (label170);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label170", label170,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label170);
  gtk_table_attach (GTK_TABLE (table8), label170, 4, 5, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label170), 0, 0.5);

  spinbutton_config_download_retry_stopped_delay_adj = gtk_adjustment_new (15, 15, 100000, 1, 10, 10);
  spinbutton_config_download_retry_stopped_delay = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_download_retry_stopped_delay_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_download_retry_stopped_delay, "spinbutton_config_download_retry_stopped_delay");
  gtk_widget_ref (spinbutton_config_download_retry_stopped_delay);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_config_download_retry_stopped_delay", spinbutton_config_download_retry_stopped_delay,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_config_download_retry_stopped_delay);
  gtk_table_attach (GTK_TABLE (table8), spinbutton_config_download_retry_stopped_delay, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_tooltips_set_tip (tooltips, spinbutton_config_download_retry_stopped_delay, _("Delay in seconds to wait when running download stops"), NULL);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_download_retry_stopped_delay), TRUE);

  spinbutton_config_download_retry_refused_delay_adj = gtk_adjustment_new (1, 15, 100000, 1, 10, 10);
  spinbutton_config_download_retry_refused_delay = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_download_retry_refused_delay_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_download_retry_refused_delay, "spinbutton_config_download_retry_refused_delay");
  gtk_widget_ref (spinbutton_config_download_retry_refused_delay);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_config_download_retry_refused_delay", spinbutton_config_download_retry_refused_delay,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_config_download_retry_refused_delay);
  gtk_table_attach (GTK_TABLE (table8), spinbutton_config_download_retry_refused_delay, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_usize (spinbutton_config_download_retry_refused_delay, 50, -2);
  gtk_tooltips_set_tip (tooltips, spinbutton_config_download_retry_refused_delay, _("Delay in seconds to wait if connection is refused"), NULL);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_download_retry_refused_delay), TRUE);

  spinbutton_config_download_retry_busy_delay_adj = gtk_adjustment_new (1, 15, 100000, 1, 10, 10);
  spinbutton_config_download_retry_busy_delay = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_download_retry_busy_delay_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_download_retry_busy_delay, "spinbutton_config_download_retry_busy_delay");
  gtk_widget_ref (spinbutton_config_download_retry_busy_delay);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_config_download_retry_busy_delay", spinbutton_config_download_retry_busy_delay,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_config_download_retry_busy_delay);
  gtk_table_attach (GTK_TABLE (table8), spinbutton_config_download_retry_busy_delay, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_tooltips_set_tip (tooltips, spinbutton_config_download_retry_busy_delay, _("Delay in seconds to wait after HTTP busy indication"), NULL);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_download_retry_busy_delay), TRUE);

  spinbutton_config_download_retry_timeout_delay_adj = gtk_adjustment_new (1, 15, 100000, 1, 10, 10);
  spinbutton_config_download_retry_timeout_delay = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_download_retry_timeout_delay_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_download_retry_timeout_delay, "spinbutton_config_download_retry_timeout_delay");
  gtk_widget_ref (spinbutton_config_download_retry_timeout_delay);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_config_download_retry_timeout_delay", spinbutton_config_download_retry_timeout_delay,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_config_download_retry_timeout_delay);
  gtk_table_attach (GTK_TABLE (table8), spinbutton_config_download_retry_timeout_delay, 3, 4, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_usize (spinbutton_config_download_retry_timeout_delay, 50, -2);
  gtk_tooltips_set_tip (tooltips, spinbutton_config_download_retry_timeout_delay, _("Delay in seconds to wait after connection failure"), NULL);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_download_retry_timeout_delay), TRUE);

  spinbutton_config_download_retry_timeout_max_adj = gtk_adjustment_new (15, 15, 100000, 1, 10, 10);
  spinbutton_config_download_retry_timeout_max = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_download_retry_timeout_max_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_download_retry_timeout_max, "spinbutton_config_download_retry_timeout_max");
  gtk_widget_ref (spinbutton_config_download_retry_timeout_max);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_config_download_retry_timeout_max", spinbutton_config_download_retry_timeout_max,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_config_download_retry_timeout_max);
  gtk_table_attach (GTK_TABLE (table8), spinbutton_config_download_retry_timeout_max, 3, 4, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_tooltips_set_tip (tooltips, spinbutton_config_download_retry_timeout_max, _("Maximum seconds to wait on auto-retry timeouts"), NULL);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_download_retry_timeout_max), TRUE);

  spinbutton_config_download_retry_timeout_min_adj = gtk_adjustment_new (1, 15, 100000, 1, 10, 10);
  spinbutton_config_download_retry_timeout_min = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_download_retry_timeout_min_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_download_retry_timeout_min, "spinbutton_config_download_retry_timeout_min");
  gtk_widget_ref (spinbutton_config_download_retry_timeout_min);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_config_download_retry_timeout_min", spinbutton_config_download_retry_timeout_min,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_config_download_retry_timeout_min);
  gtk_table_attach (GTK_TABLE (table8), spinbutton_config_download_retry_timeout_min, 3, 4, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_tooltips_set_tip (tooltips, spinbutton_config_download_retry_timeout_min, _("Minimum seconds to wait on auto-retry timeouts"), NULL);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_download_retry_timeout_min), TRUE);

  spinbutton_config_download_connecting_timeout_adj = gtk_adjustment_new (1, 1, 100000, 1, 10, 10);
  spinbutton_config_download_connecting_timeout = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_download_connecting_timeout_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_download_connecting_timeout, "spinbutton_config_download_connecting_timeout");
  gtk_widget_ref (spinbutton_config_download_connecting_timeout);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_config_download_connecting_timeout", spinbutton_config_download_connecting_timeout,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_config_download_connecting_timeout);
  gtk_table_attach (GTK_TABLE (table8), spinbutton_config_download_connecting_timeout, 5, 6, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_tooltips_set_tip (tooltips, spinbutton_config_download_connecting_timeout, _("Number of seconds before timeout for a connecting download"), NULL);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_download_connecting_timeout), TRUE);

  spinbutton_config_download_push_sent_timeout_adj = gtk_adjustment_new (1, 1, 100000, 1, 10, 10);
  spinbutton_config_download_push_sent_timeout = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_download_push_sent_timeout_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_download_push_sent_timeout, "spinbutton_config_download_push_sent_timeout");
  gtk_widget_ref (spinbutton_config_download_push_sent_timeout);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_config_download_push_sent_timeout", spinbutton_config_download_push_sent_timeout,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_config_download_push_sent_timeout);
  gtk_table_attach (GTK_TABLE (table8), spinbutton_config_download_push_sent_timeout, 5, 6, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_tooltips_set_tip (tooltips, spinbutton_config_download_push_sent_timeout, _("Number of seconds before timeout for a 'push sent' download"), NULL);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_download_push_sent_timeout), TRUE);

  spinbutton_config_download_connected_timeout_adj = gtk_adjustment_new (1, 1, 100000, 1, 10, 10);
  spinbutton_config_download_connected_timeout = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_download_connected_timeout_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_download_connected_timeout, "spinbutton_config_download_connected_timeout");
  gtk_widget_ref (spinbutton_config_download_connected_timeout);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_config_download_connected_timeout", spinbutton_config_download_connected_timeout,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_config_download_connected_timeout);
  gtk_table_attach (GTK_TABLE (table8), spinbutton_config_download_connected_timeout, 5, 6, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_tooltips_set_tip (tooltips, spinbutton_config_download_connected_timeout, _("Number of seconds before timeout for a connected download"), NULL);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_download_connected_timeout), TRUE);

  frame48 = gtk_frame_new (_("Downloading from multiple sources (swarming)"));
  gtk_widget_set_name (frame48, "frame48");
  gtk_widget_ref (frame48);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame48", frame48,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame48);
  gtk_box_pack_start (GTK_BOX (vbox38), frame48, FALSE, TRUE, 0);

  vbox99 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox99, "vbox99");
  gtk_widget_ref (vbox99);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "vbox99", vbox99,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox99);
  gtk_container_add (GTK_CONTAINER (frame48), vbox99);
  gtk_container_set_border_width (GTK_CONTAINER (vbox99), 2);

  checkbutton_config_use_swarming = gtk_check_button_new_with_label ("");
  checkbutton_config_use_swarming_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (checkbutton_config_use_swarming)->child),
                                   _("Enable s_warming"));
  gtk_widget_add_accelerator (checkbutton_config_use_swarming, "clicked", accel_group,
                              checkbutton_config_use_swarming_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (checkbutton_config_use_swarming, "checkbutton_config_use_swarming");
  gtk_widget_ref (checkbutton_config_use_swarming);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_config_use_swarming", checkbutton_config_use_swarming,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_config_use_swarming);
  gtk_box_pack_start (GTK_BOX (vbox99), checkbutton_config_use_swarming, FALSE, FALSE, 0);

  hseparator11 = gtk_hseparator_new ();
  gtk_widget_set_name (hseparator11, "hseparator11");
  gtk_widget_ref (hseparator11);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "hseparator11", hseparator11,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hseparator11);
  gtk_box_pack_start (GTK_BOX (vbox99), hseparator11, FALSE, TRUE, 0);

  table51 = gtk_table_new (2, 9, FALSE);
  gtk_widget_set_name (table51, "table51");
  gtk_widget_ref (table51);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "table51", table51,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table51);
  gtk_box_pack_start (GTK_BOX (vbox99), table51, FALSE, TRUE, 0);
  gtk_table_set_row_spacings (GTK_TABLE (table51), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table51), 4);

  checkbutton_config_aggressive_swarming = gtk_check_button_new_with_label ("");
  checkbutton_config_aggressive_swarming_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (checkbutton_config_aggressive_swarming)->child),
                                   _("A_ggressive mode"));
  gtk_widget_add_accelerator (checkbutton_config_aggressive_swarming, "clicked", accel_group,
                              checkbutton_config_aggressive_swarming_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (checkbutton_config_aggressive_swarming, "checkbutton_config_aggressive_swarming");
  gtk_widget_ref (checkbutton_config_aggressive_swarming);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_config_aggressive_swarming", checkbutton_config_aggressive_swarming,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_config_aggressive_swarming);
  gtk_table_attach (GTK_TABLE (table51), checkbutton_config_aggressive_swarming, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  vseparator1 = gtk_vseparator_new ();
  gtk_widget_set_name (vseparator1, "vseparator1");
  gtk_widget_ref (vseparator1);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "vseparator1", vseparator1,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vseparator1);
  gtk_table_attach (GTK_TABLE (table51), vseparator1, 1, 2, 0, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);

  label283 = gtk_label_new ("");
  label283_key = gtk_label_parse_uline (GTK_LABEL (label283),
                                   _("M_inimum chunk size"));
  gtk_widget_set_name (label283, "label283");
  gtk_widget_ref (label283);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label283", label283,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label283);
  gtk_table_attach (GTK_TABLE (table51), label283, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label283), 0, 0.5);

  label284 = gtk_label_new ("");
  label284_key = gtk_label_parse_uline (GTK_LABEL (label284),
                                   _("Ma_ximum chunk size"));
  gtk_widget_set_name (label284, "label284");
  gtk_widget_ref (label284);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label284", label284,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label284);
  gtk_table_attach (GTK_TABLE (table51), label284, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label284), 0, 0.5);

  label732 = gtk_label_new (_("bytes"));
  gtk_widget_set_name (label732, "label732");
  gtk_widget_ref (label732);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label732", label732,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label732);
  gtk_table_attach (GTK_TABLE (table51), label732, 4, 5, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label732), 0, 0.5);

  label733 = gtk_label_new (_("bytes"));
  gtk_widget_set_name (label733, "label733");
  gtk_widget_ref (label733);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label733", label733,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label733);
  gtk_table_attach (GTK_TABLE (table51), label733, 4, 5, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label733), 0, 0.5);

  vseparator6 = gtk_vseparator_new ();
  gtk_widget_set_name (vseparator6, "vseparator6");
  gtk_widget_ref (vseparator6);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "vseparator6", vseparator6,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vseparator6);
  gtk_table_attach (GTK_TABLE (table51), vseparator6, 5, 6, 0, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);

  spinbutton_dl_minchunksize_adj = gtk_adjustment_new (1, 0, 100, 1, 1024, 1024);
  spinbutton_dl_minchunksize = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_dl_minchunksize_adj), 1, 0);
  gtk_widget_set_name (spinbutton_dl_minchunksize, "spinbutton_dl_minchunksize");
  gtk_widget_ref (spinbutton_dl_minchunksize);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_dl_minchunksize", spinbutton_dl_minchunksize,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_dl_minchunksize);
  gtk_table_attach (GTK_TABLE (table51), spinbutton_dl_minchunksize, 3, 4, 0, 1,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_usize (spinbutton_dl_minchunksize, 90, -2);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_dl_minchunksize), TRUE);

  spinbutton_dl_maxchunksize_adj = gtk_adjustment_new (1, 0, 100, 1, 1024, 1024);
  spinbutton_dl_maxchunksize = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_dl_maxchunksize_adj), 1, 0);
  gtk_widget_set_name (spinbutton_dl_maxchunksize, "spinbutton_dl_maxchunksize");
  gtk_widget_ref (spinbutton_dl_maxchunksize);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_dl_maxchunksize", spinbutton_dl_maxchunksize,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_dl_maxchunksize);
  gtk_table_attach (GTK_TABLE (table51), spinbutton_dl_maxchunksize, 3, 4, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_dl_maxchunksize), TRUE);

  label761 = gtk_label_new (_("Write buffer size"));
  gtk_widget_set_name (label761, "label761");
  gtk_widget_ref (label761);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label761", label761,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label761);
  gtk_table_attach (GTK_TABLE (table51), label761, 6, 7, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label761), 0, 0.5);

  label763 = gtk_label_new (_("bytes"));
  gtk_widget_set_name (label763, "label763");
  gtk_widget_ref (label763);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label763", label763,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label763);
  gtk_table_attach (GTK_TABLE (table51), label763, 8, 9, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label763), 0, 0.5);

  checkbutton_config_enable_http_pipelining = gtk_check_button_new_with_label (_("Enable HTTP request pipelining"));
  gtk_widget_set_name (checkbutton_config_enable_http_pipelining, "checkbutton_config_enable_http_pipelining");
  gtk_widget_ref (checkbutton_config_enable_http_pipelining);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_config_enable_http_pipelining", checkbutton_config_enable_http_pipelining,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_config_enable_http_pipelining);
  gtk_table_attach (GTK_TABLE (table51), checkbutton_config_enable_http_pipelining, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label8026 = gtk_label_new (_("Pipelining max chunk size"));
  gtk_widget_set_name (label8026, "label8026");
  gtk_widget_ref (label8026);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label8026", label8026,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label8026);
  gtk_table_attach (GTK_TABLE (table51), label8026, 6, 7, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label8026), 0, 0.5);

  label8027 = gtk_label_new (_("bytes"));
  gtk_widget_set_name (label8027, "label8027");
  gtk_widget_ref (label8027);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label8027", label8027,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label8027);
  gtk_table_attach (GTK_TABLE (table51), label8027, 8, 9, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label8027), 0, 0.5);

  spinbutton_download_buffer_size_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 10);
  spinbutton_download_buffer_size = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_download_buffer_size_adj), 1, 0);
  gtk_widget_set_name (spinbutton_download_buffer_size, "spinbutton_download_buffer_size");
  gtk_widget_ref (spinbutton_download_buffer_size);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_download_buffer_size", spinbutton_download_buffer_size,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_download_buffer_size);
  gtk_table_attach (GTK_TABLE (table51), spinbutton_download_buffer_size, 7, 8, 0, 1,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_usize (spinbutton_download_buffer_size, 90, -2);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_download_buffer_size), TRUE);

  spinbutton_dl_pipeline_maxchunksize_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 10);
  spinbutton_dl_pipeline_maxchunksize = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_dl_pipeline_maxchunksize_adj), 1, 0);
  gtk_widget_set_name (spinbutton_dl_pipeline_maxchunksize, "spinbutton_dl_pipeline_maxchunksize");
  gtk_widget_ref (spinbutton_dl_pipeline_maxchunksize);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_dl_pipeline_maxchunksize", spinbutton_dl_pipeline_maxchunksize,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_dl_pipeline_maxchunksize);
  gtk_table_attach (GTK_TABLE (table51), spinbutton_dl_pipeline_maxchunksize, 7, 8, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_dl_pipeline_maxchunksize), TRUE);

  hseparator12 = gtk_hseparator_new ();
  gtk_widget_set_name (hseparator12, "hseparator12");
  gtk_widget_ref (hseparator12);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "hseparator12", hseparator12,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hseparator12);
  gtk_box_pack_start (GTK_BOX (vbox99), hseparator12, FALSE, TRUE, 0);

  table52 = gtk_table_new (3, 4, FALSE);
  gtk_widget_set_name (table52, "table52");
  gtk_widget_ref (table52);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "table52", table52,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table52);
  gtk_box_pack_start (GTK_BOX (vbox99), table52, FALSE, TRUE, 0);
  gtk_table_set_row_spacings (GTK_TABLE (table52), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table52), 4);

  checkbutton_config_strict_sha1_matching = gtk_check_button_new_with_label ("");
  checkbutton_config_strict_sha1_matching_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (checkbutton_config_strict_sha1_matching)->child),
                                   _("Strict SHA_1 matching"));
  gtk_widget_add_accelerator (checkbutton_config_strict_sha1_matching, "clicked", accel_group,
                              checkbutton_config_strict_sha1_matching_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (checkbutton_config_strict_sha1_matching, "checkbutton_config_strict_sha1_matching");
  gtk_widget_ref (checkbutton_config_strict_sha1_matching);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_config_strict_sha1_matching", checkbutton_config_strict_sha1_matching,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_config_strict_sha1_matching);
  gtk_table_attach (GTK_TABLE (table52), checkbutton_config_strict_sha1_matching, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_config_use_alternate_sources = gtk_check_button_new_with_label ("");
  checkbutton_config_use_alternate_sources_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (checkbutton_config_use_alternate_sources)->child),
                                   _("Watch hits for _alternate sources"));
  gtk_widget_add_accelerator (checkbutton_config_use_alternate_sources, "clicked", accel_group,
                              checkbutton_config_use_alternate_sources_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (checkbutton_config_use_alternate_sources, "checkbutton_config_use_alternate_sources");
  gtk_widget_ref (checkbutton_config_use_alternate_sources);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_config_use_alternate_sources", checkbutton_config_use_alternate_sources,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_config_use_alternate_sources);
  gtk_table_attach (GTK_TABLE (table52), checkbutton_config_use_alternate_sources, 0, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_auto_feed_dmesh = gtk_check_button_new_with_label ("");
  checkbutton_auto_feed_dmesh_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (checkbutton_auto_feed_dmesh)->child),
                                   _("_Feed mesh from hits"));
  gtk_widget_add_accelerator (checkbutton_auto_feed_dmesh, "clicked", accel_group,
                              checkbutton_auto_feed_dmesh_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (checkbutton_auto_feed_dmesh, "checkbutton_auto_feed_dmesh");
  gtk_widget_ref (checkbutton_auto_feed_dmesh);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_auto_feed_dmesh", checkbutton_auto_feed_dmesh,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_auto_feed_dmesh);
  gtk_table_attach (GTK_TABLE (table52), checkbutton_auto_feed_dmesh, 2, 4, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_config_tth_auto_discovery = gtk_check_button_new_with_label (_("Allow TTH discovery"));
  gtk_widget_set_name (checkbutton_config_tth_auto_discovery, "checkbutton_config_tth_auto_discovery");
  gtk_widget_ref (checkbutton_config_tth_auto_discovery);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_config_tth_auto_discovery", checkbutton_config_tth_auto_discovery,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_config_tth_auto_discovery);
  gtk_table_attach (GTK_TABLE (table52), checkbutton_config_tth_auto_discovery, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label685 = gtk_label_new (_("Downloads"));
  gtk_widget_set_name (label685, "label685");
  gtk_widget_ref (label685);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label685", label685,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label685);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_prefs), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_prefs), 3), label685);

  scrolledwindow35 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow35, "scrolledwindow35");
  gtk_widget_ref (scrolledwindow35);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "scrolledwindow35", scrolledwindow35,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (scrolledwindow35);
  gtk_container_add (GTK_CONTAINER (notebook_prefs), scrolledwindow35);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow35), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);

  viewport7 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport7, "viewport7");
  gtk_widget_ref (viewport7);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "viewport7", viewport7,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (viewport7);
  gtk_container_add (GTK_CONTAINER (scrolledwindow35), viewport7);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport7), GTK_SHADOW_NONE);

  vbox40 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox40, "vbox40");
  gtk_widget_ref (vbox40);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "vbox40", vbox40,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox40);
  gtk_container_add (GTK_CONTAINER (viewport7), vbox40);
  gtk_container_set_border_width (GTK_CONTAINER (vbox40), 4);

  frame_path_to_files = gtk_frame_new (_("_Path(s) to files"));
  gtk_widget_set_name (frame_path_to_files, "frame_path_to_files");
  gtk_widget_ref (frame_path_to_files);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame_path_to_files", frame_path_to_files,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame_path_to_files);
  gtk_box_pack_start (GTK_BOX (vbox40), frame_path_to_files, FALSE, TRUE, 0);

  vbox_path_to_files = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox_path_to_files, "vbox_path_to_files");
  gtk_widget_ref (vbox_path_to_files);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "vbox_path_to_files", vbox_path_to_files,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox_path_to_files);
  gtk_container_add (GTK_CONTAINER (frame_path_to_files), vbox_path_to_files);
  gtk_container_set_border_width (GTK_CONTAINER (vbox_path_to_files), 2);

  entry_config_path = gtk_entry_new ();
  gtk_widget_set_name (entry_config_path, "entry_config_path");
  gtk_widget_ref (entry_config_path);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "entry_config_path", entry_config_path,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_config_path);
  gtk_box_pack_start (GTK_BOX (vbox_path_to_files), entry_config_path, FALSE, FALSE, 0);

  hbox_path_buttons = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox_path_buttons, "hbox_path_buttons");
  gtk_widget_ref (hbox_path_buttons);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "hbox_path_buttons", hbox_path_buttons,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox_path_buttons);
  gtk_box_pack_start (GTK_BOX (vbox_path_to_files), hbox_path_buttons, FALSE, FALSE, 0);

  button_config_add_dir = gtk_button_new_with_label ("");
  button_config_add_dir_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (button_config_add_dir)->child),
                                   _("_Add directory"));
  gtk_widget_add_accelerator (button_config_add_dir, "clicked", accel_group,
                              button_config_add_dir_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (button_config_add_dir, "button_config_add_dir");
  gtk_widget_ref (button_config_add_dir);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "button_config_add_dir", button_config_add_dir,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_config_add_dir);
  gtk_box_pack_start (GTK_BOX (hbox_path_buttons), button_config_add_dir, FALSE, TRUE, 0);

  button_config_rescan_dir = gtk_button_new_with_label ("");
  button_config_rescan_dir_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (button_config_rescan_dir)->child),
                                   _("_Rescan"));
  gtk_widget_add_accelerator (button_config_rescan_dir, "clicked", accel_group,
                              button_config_rescan_dir_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (button_config_rescan_dir, "button_config_rescan_dir");
  gtk_widget_ref (button_config_rescan_dir);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "button_config_rescan_dir", button_config_rescan_dir,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_config_rescan_dir);
  gtk_box_pack_start (GTK_BOX (hbox_path_buttons), button_config_rescan_dir, FALSE, TRUE, 0);

  label_files_scanned = gtk_label_new (_("Files scanned"));
  gtk_widget_set_name (label_files_scanned, "label_files_scanned");
  gtk_widget_ref (label_files_scanned);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label_files_scanned", label_files_scanned,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_files_scanned);
  gtk_box_pack_start (GTK_BOX (hbox_path_buttons), label_files_scanned, TRUE, TRUE, 0);
  gtk_misc_set_alignment (GTK_MISC (label_files_scanned), 0, 0.5);

  hbox173 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox173, "hbox173");
  gtk_widget_ref (hbox173);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "hbox173", hbox173,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox173);
  gtk_box_pack_start (GTK_BOX (vbox_path_to_files), hbox173, TRUE, TRUE, 0);

  hbox174 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox174, "hbox174");
  gtk_widget_ref (hbox174);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "hbox174", hbox174,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox174);
  gtk_box_pack_start (GTK_BOX (hbox173), hbox174, TRUE, TRUE, 0);

  checkbutton_scan_ignore_symlink_dirs = gtk_check_button_new_with_label ("");
  checkbutton_scan_ignore_symlink_dirs_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (checkbutton_scan_ignore_symlink_dirs)->child),
                                   _("Ignore symbolically linked _directories"));
  gtk_widget_add_accelerator (checkbutton_scan_ignore_symlink_dirs, "clicked", accel_group,
                              checkbutton_scan_ignore_symlink_dirs_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (checkbutton_scan_ignore_symlink_dirs, "checkbutton_scan_ignore_symlink_dirs");
  gtk_widget_ref (checkbutton_scan_ignore_symlink_dirs);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_scan_ignore_symlink_dirs", checkbutton_scan_ignore_symlink_dirs,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_scan_ignore_symlink_dirs);
  gtk_box_pack_start (GTK_BOX (hbox174), checkbutton_scan_ignore_symlink_dirs, FALSE, FALSE, 0);

  checkbutton_scan_ignore_symlink_regfiles = gtk_check_button_new_with_label ("");
  checkbutton_scan_ignore_symlink_regfiles_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (checkbutton_scan_ignore_symlink_regfiles)->child),
                                   _("Ignore symbolically linked regular _files"));
  gtk_widget_add_accelerator (checkbutton_scan_ignore_symlink_regfiles, "clicked", accel_group,
                              checkbutton_scan_ignore_symlink_regfiles_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (checkbutton_scan_ignore_symlink_regfiles, "checkbutton_scan_ignore_symlink_regfiles");
  gtk_widget_ref (checkbutton_scan_ignore_symlink_regfiles);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_scan_ignore_symlink_regfiles", checkbutton_scan_ignore_symlink_regfiles,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_scan_ignore_symlink_regfiles);
  gtk_box_pack_start (GTK_BOX (hbox174), checkbutton_scan_ignore_symlink_regfiles, FALSE, FALSE, 0);

  hbox27 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox27, "hbox27");
  gtk_widget_ref (hbox27);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "hbox27", hbox27,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox27);
  gtk_box_pack_start (GTK_BOX (vbox_path_to_files), hbox27, FALSE, TRUE, 0);

  label41 = gtk_label_new ("");
  label41_key = gtk_label_parse_uline (GTK_LABEL (label41),
                                   _("Search _extensions"));
  gtk_widget_set_name (label41, "label41");
  gtk_widget_ref (label41);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label41", label41,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label41);
  gtk_box_pack_start (GTK_BOX (hbox27), label41, FALSE, FALSE, 0);

  entry_config_extensions = gtk_entry_new ();
  gtk_widget_set_name (entry_config_extensions, "entry_config_extensions");
  gtk_widget_ref (entry_config_extensions);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "entry_config_extensions", entry_config_extensions,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_config_extensions);
  gtk_box_pack_start (GTK_BOX (hbox27), entry_config_extensions, TRUE, TRUE, 0);

  frame149 = gtk_frame_new (_("Miscellaneous"));
  gtk_widget_set_name (frame149, "frame149");
  gtk_widget_ref (frame149);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame149", frame149,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame149);
  gtk_box_pack_start (GTK_BOX (vbox40), frame149, FALSE, TRUE, 0);

  table98 = gtk_table_new (2, 1, FALSE);
  gtk_widget_set_name (table98, "table98");
  gtk_widget_ref (table98);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "table98", table98,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table98);
  gtk_container_add (GTK_CONTAINER (frame149), table98);
  gtk_table_set_row_spacings (GTK_TABLE (table98), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table98), 4);

  checkbutton_enable_browse_host = gtk_check_button_new_with_label ("");
  checkbutton_enable_browse_host_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (checkbutton_enable_browse_host)->child),
                                   _("Enable \"_Browse Host\" feature"));
  gtk_widget_add_accelerator (checkbutton_enable_browse_host, "clicked", accel_group,
                              checkbutton_enable_browse_host_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (checkbutton_enable_browse_host, "checkbutton_enable_browse_host");
  gtk_widget_ref (checkbutton_enable_browse_host);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_enable_browse_host", checkbutton_enable_browse_host,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_enable_browse_host);
  gtk_table_attach (GTK_TABLE (table98), checkbutton_enable_browse_host, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_expose_relative_paths = gtk_check_button_new_with_label ("");
  checkbutton_expose_relative_paths_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (checkbutton_expose_relative_paths)->child),
                                   _("E_xpose relative paths"));
  gtk_widget_add_accelerator (checkbutton_expose_relative_paths, "clicked", accel_group,
                              checkbutton_expose_relative_paths_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (checkbutton_expose_relative_paths, "checkbutton_expose_relative_paths");
  gtk_widget_ref (checkbutton_expose_relative_paths);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_expose_relative_paths", checkbutton_expose_relative_paths,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_expose_relative_paths);
  gtk_table_attach (GTK_TABLE (table98), checkbutton_expose_relative_paths, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  frame_expert_ul_timeout = gtk_frame_new (_("Timeouts (all values in seconds)"));
  gtk_widget_set_name (frame_expert_ul_timeout, "frame_expert_ul_timeout");
  gtk_widget_ref (frame_expert_ul_timeout);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame_expert_ul_timeout", frame_expert_ul_timeout,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame_expert_ul_timeout);
  gtk_box_pack_start (GTK_BOX (vbox40), frame_expert_ul_timeout, FALSE, TRUE, 0);

  table12 = gtk_table_new (1, 4, FALSE);
  gtk_widget_set_name (table12, "table12");
  gtk_widget_ref (table12);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "table12", table12,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table12);
  gtk_container_add (GTK_CONTAINER (frame_expert_ul_timeout), table12);
  gtk_container_set_border_width (GTK_CONTAINER (table12), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table12), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table12), 4);

  label179 = gtk_label_new ("");
  label179_key = gtk_label_parse_uline (GTK_LABEL (label179),
                                   _("Connectin_g timeout"));
  gtk_widget_set_name (label179, "label179");
  gtk_widget_ref (label179);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label179", label179,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label179);
  gtk_table_attach (GTK_TABLE (table12), label179, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label179), 0, 0.5);

  label180 = gtk_label_new ("");
  label180_key = gtk_label_parse_uline (GTK_LABEL (label180),
                                   _("Connected time_out"));
  gtk_widget_set_name (label180, "label180");
  gtk_widget_ref (label180);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label180", label180,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label180);
  gtk_table_attach (GTK_TABLE (table12), label180, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label180), 0, 0.5);

  spinbutton_config_upload_connecting_timeout_adj = gtk_adjustment_new (1, 1, 100000, 1, 10, 10);
  spinbutton_config_upload_connecting_timeout = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_upload_connecting_timeout_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_upload_connecting_timeout, "spinbutton_config_upload_connecting_timeout");
  gtk_widget_ref (spinbutton_config_upload_connecting_timeout);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_config_upload_connecting_timeout", spinbutton_config_upload_connecting_timeout,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_config_upload_connecting_timeout);
  gtk_table_attach (GTK_TABLE (table12), spinbutton_config_upload_connecting_timeout, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_upload_connecting_timeout), TRUE);

  spinbutton_config_upload_connected_timeout_adj = gtk_adjustment_new (1, 1, 100000, 1, 10, 10);
  spinbutton_config_upload_connected_timeout = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_upload_connected_timeout_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_upload_connected_timeout, "spinbutton_config_upload_connected_timeout");
  gtk_widget_ref (spinbutton_config_upload_connected_timeout);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_config_upload_connected_timeout", spinbutton_config_upload_connected_timeout,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_config_upload_connected_timeout);
  gtk_table_attach (GTK_TABLE (table12), spinbutton_config_upload_connected_timeout, 3, 4, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_upload_connected_timeout), TRUE);

  frame_partial_file_sharing = gtk_frame_new (_("Partial File Sharing"));
  gtk_widget_set_name (frame_partial_file_sharing, "frame_partial_file_sharing");
  gtk_widget_ref (frame_partial_file_sharing);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame_partial_file_sharing", frame_partial_file_sharing,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame_partial_file_sharing);
  gtk_box_pack_start (GTK_BOX (vbox40), frame_partial_file_sharing, FALSE, TRUE, 0);

  table65 = gtk_table_new (3, 5, FALSE);
  gtk_widget_set_name (table65, "table65");
  gtk_widget_ref (table65);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "table65", table65,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table65);
  gtk_container_add (GTK_CONTAINER (frame_partial_file_sharing), table65);
  gtk_container_set_border_width (GTK_CONTAINER (table65), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table65), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table65), 4);

  label547 = gtk_label_new ("");
  label547_key = gtk_label_parse_uline (GTK_LABEL (label547),
                                   _("First chunk _size"));
  gtk_widget_set_name (label547, "label547");
  gtk_widget_ref (label547);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label547", label547,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label547);
  gtk_table_attach (GTK_TABLE (table65), label547, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label547), 0, 0.5);

  checkbutton_pfsp_server = gtk_check_button_new_with_label ("");
  checkbutton_pfsp_server_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (checkbutton_pfsp_server)->child),
                                   _("Enable upload of _partially downloaded files"));
  gtk_widget_add_accelerator (checkbutton_pfsp_server, "clicked", accel_group,
                              checkbutton_pfsp_server_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (checkbutton_pfsp_server, "checkbutton_pfsp_server");
  gtk_widget_ref (checkbutton_pfsp_server);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_pfsp_server", checkbutton_pfsp_server,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_pfsp_server);
  gtk_table_attach (GTK_TABLE (table65), checkbutton_pfsp_server, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  spinbutton_pfsp_first_chunk_adj = gtk_adjustment_new (1, 0, 1e+06, 1, 1024, 1024);
  spinbutton_pfsp_first_chunk = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_pfsp_first_chunk_adj), 1, 0);
  gtk_widget_set_name (spinbutton_pfsp_first_chunk, "spinbutton_pfsp_first_chunk");
  gtk_widget_ref (spinbutton_pfsp_first_chunk);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_pfsp_first_chunk", spinbutton_pfsp_first_chunk,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_pfsp_first_chunk);
  gtk_table_attach (GTK_TABLE (table65), spinbutton_pfsp_first_chunk, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_usize (spinbutton_pfsp_first_chunk, 76, -2);

  label770 = gtk_label_new (_("Minimum file size"));
  gtk_widget_set_name (label770, "label770");
  gtk_widget_ref (label770);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label770", label770,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label770);
  gtk_table_attach (GTK_TABLE (table65), label770, 3, 4, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label770), 0, 0.5);

  spinbutton_pfsp_minimum_filesize_adj = gtk_adjustment_new (1, 0, 1e+06, 1, 1024, 1024);
  spinbutton_pfsp_minimum_filesize = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_pfsp_minimum_filesize_adj), 1, 0);
  gtk_widget_set_name (spinbutton_pfsp_minimum_filesize, "spinbutton_pfsp_minimum_filesize");
  gtk_widget_ref (spinbutton_pfsp_minimum_filesize);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_pfsp_minimum_filesize", spinbutton_pfsp_minimum_filesize,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_pfsp_minimum_filesize);
  gtk_table_attach (GTK_TABLE (table65), spinbutton_pfsp_minimum_filesize, 4, 5, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label8011 = gtk_label_new (_("Last chunk size"));
  gtk_widget_set_name (label8011, "label8011");
  gtk_widget_ref (label8011);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label8011", label8011,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label8011);
  gtk_table_attach (GTK_TABLE (table65), label8011, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label8011), 0, 0.5);

  spinbutton_pfsp_last_chunk_adj = gtk_adjustment_new (1, 0, 1e+06, 1, 1024, 1024);
  spinbutton_pfsp_last_chunk = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_pfsp_last_chunk_adj), 1, 0);
  gtk_widget_set_name (spinbutton_pfsp_last_chunk, "spinbutton_pfsp_last_chunk");
  gtk_widget_ref (spinbutton_pfsp_last_chunk);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_pfsp_last_chunk", spinbutton_pfsp_last_chunk,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_pfsp_last_chunk);
  gtk_table_attach (GTK_TABLE (table65), spinbutton_pfsp_last_chunk, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_pfsp_rare_server = gtk_check_button_new_with_label (_("Enable upload of partial files deemed rare"));
  gtk_widget_set_name (checkbutton_pfsp_rare_server, "checkbutton_pfsp_rare_server");
  gtk_widget_ref (checkbutton_pfsp_rare_server);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_pfsp_rare_server", checkbutton_pfsp_rare_server,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_pfsp_rare_server);
  gtk_table_attach (GTK_TABLE (table65), checkbutton_pfsp_rare_server, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_config_query_answer_partials = gtk_check_button_new_with_label (_("Answer to queries for partial files"));
  gtk_widget_set_name (checkbutton_config_query_answer_partials, "checkbutton_config_query_answer_partials");
  gtk_widget_ref (checkbutton_config_query_answer_partials);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_config_query_answer_partials", checkbutton_config_query_answer_partials,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_config_query_answer_partials);
  gtk_table_attach (GTK_TABLE (table65), checkbutton_config_query_answer_partials, 3, 5, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_config_query_answer_whats_new = gtk_check_button_new_with_label (_("Answer to what's-new? queries"));
  gtk_widget_set_name (checkbutton_config_query_answer_whats_new, "checkbutton_config_query_answer_whats_new");
  gtk_widget_ref (checkbutton_config_query_answer_whats_new);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_config_query_answer_whats_new", checkbutton_config_query_answer_whats_new,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_config_query_answer_whats_new);
  gtk_table_attach (GTK_TABLE (table65), checkbutton_config_query_answer_whats_new, 3, 5, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  frame140 = gtk_frame_new (_("Queuing details"));
  gtk_widget_set_name (frame140, "frame140");
  gtk_widget_ref (frame140);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame140", frame140,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame140);
  gtk_box_pack_start (GTK_BOX (vbox40), frame140, FALSE, TRUE, 0);

  table96 = gtk_table_new (3, 2, FALSE);
  gtk_widget_set_name (table96, "table96");
  gtk_widget_ref (table96);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "table96", table96,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table96);
  gtk_container_add (GTK_CONTAINER (frame140), table96);
  gtk_container_set_border_width (GTK_CONTAINER (table96), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table96), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table96), 4);

  label753 = gtk_label_new (_("Minimum upload time"));
  gtk_widget_set_name (label753, "label753");
  gtk_widget_ref (label753);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label753", label753,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label753);
  gtk_table_attach (GTK_TABLE (table96), label753, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label753), 0, 0.5);

  spinbutton_parq_min_time_adj = gtk_adjustment_new (1, 1, 100000, 1, 10, 10);
  spinbutton_parq_min_time = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_parq_min_time_adj), 1, 0);
  gtk_widget_set_name (spinbutton_parq_min_time, "spinbutton_parq_min_time");
  gtk_widget_ref (spinbutton_parq_min_time);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_parq_min_time", spinbutton_parq_min_time,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_parq_min_time);
  gtk_table_attach (GTK_TABLE (table96), spinbutton_parq_min_time, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_parq_min_time), TRUE);

  label752 = gtk_label_new (_("Minimum chunk size"));
  gtk_widget_set_name (label752, "label752");
  gtk_widget_ref (label752);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label752", label752,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label752);
  gtk_table_attach (GTK_TABLE (table96), label752, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label752), 0, 0.5);

  spinbutton_parq_min_size_adj = gtk_adjustment_new (1, 1, 100000, 1, 10, 10);
  spinbutton_parq_min_size = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_parq_min_size_adj), 1, 0);
  gtk_widget_set_name (spinbutton_parq_min_size, "spinbutton_parq_min_size");
  gtk_widget_ref (spinbutton_parq_min_size);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_parq_min_size", spinbutton_parq_min_size,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_parq_min_size);
  gtk_table_attach (GTK_TABLE (table96), spinbutton_parq_min_size, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_parq_min_size), TRUE);

  checkbutton_parq_optimistic = gtk_check_button_new_with_label (_("Use realistic PARQ estimates"));
  gtk_widget_set_name (checkbutton_parq_optimistic, "checkbutton_parq_optimistic");
  gtk_widget_ref (checkbutton_parq_optimistic);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_parq_optimistic", checkbutton_parq_optimistic,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_parq_optimistic);
  gtk_table_attach (GTK_TABLE (table96), checkbutton_parq_optimistic, 0, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  frame_expert_share_statistics = gtk_frame_new (_("Statistics:"));
  gtk_widget_set_name (frame_expert_share_statistics, "frame_expert_share_statistics");
  gtk_widget_ref (frame_expert_share_statistics);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame_expert_share_statistics", frame_expert_share_statistics,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame_expert_share_statistics);
  gtk_box_pack_start (GTK_BOX (vbox40), frame_expert_share_statistics, FALSE, FALSE, 0);

  vbox117 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox117, "vbox117");
  gtk_widget_ref (vbox117);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "vbox117", vbox117,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox117);
  gtk_container_add (GTK_CONTAINER (frame_expert_share_statistics), vbox117);
  gtk_container_set_border_width (GTK_CONTAINER (vbox117), 2);

  alignment36 = gtk_alignment_new (0.5, 0.5, 0, 1);
  gtk_widget_set_name (alignment36, "alignment36");
  gtk_widget_ref (alignment36);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "alignment36", alignment36,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (alignment36);
  gtk_box_pack_start (GTK_BOX (vbox117), alignment36, FALSE, TRUE, 0);

  hbox184 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox184, "hbox184");
  gtk_widget_ref (hbox184);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "hbox184", hbox184,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox184);
  gtk_container_add (GTK_CONTAINER (alignment36), hbox184);

  frame88 = gtk_frame_new (_("Library scanning:"));
  gtk_widget_set_name (frame88, "frame88");
  gtk_widget_ref (frame88);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame88", frame88,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame88);
  gtk_box_pack_start (GTK_BOX (hbox184), frame88, FALSE, TRUE, 0);
  gtk_frame_set_shadow_type (GTK_FRAME (frame88), GTK_SHADOW_OUT);

  table78 = gtk_table_new (2, 2, FALSE);
  gtk_widget_set_name (table78, "table78");
  gtk_widget_ref (table78);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "table78", table78,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table78);
  gtk_container_add (GTK_CONTAINER (frame88), table78);
  gtk_container_set_border_width (GTK_CONTAINER (table78), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table78), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table78), 4);

  label601 = gtk_label_new (_("Last scan initiated on:"));
  gtk_widget_set_name (label601, "label601");
  gtk_widget_ref (label601);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label601", label601,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label601);
  gtk_table_attach (GTK_TABLE (table78), label601, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label601), 0, 0.5);

  label602 = gtk_label_new (_("File scanning time:"));
  gtk_widget_set_name (label602, "label602");
  gtk_widget_ref (label602);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label602", label602,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label602);
  gtk_table_attach (GTK_TABLE (table78), label602, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label602), 0, 0.5);

  frame99 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame99, "frame99");
  gtk_widget_ref (frame99);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame99", frame99,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame99);
  gtk_table_attach (GTK_TABLE (table78), frame99, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_frame_set_shadow_type (GTK_FRAME (frame99), GTK_SHADOW_IN);

  label_library_rescan_time = gtk_label_new (_("[place holder]"));
  gtk_widget_set_name (label_library_rescan_time, "label_library_rescan_time");
  gtk_widget_ref (label_library_rescan_time);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label_library_rescan_time", label_library_rescan_time,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_library_rescan_time);
  gtk_container_add (GTK_CONTAINER (frame99), label_library_rescan_time);
  gtk_misc_set_alignment (GTK_MISC (label_library_rescan_time), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_library_rescan_time), 5, 0);

  frame100 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame100, "frame100");
  gtk_widget_ref (frame100);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame100", frame100,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame100);
  gtk_table_attach (GTK_TABLE (table78), frame100, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_frame_set_shadow_type (GTK_FRAME (frame100), GTK_SHADOW_IN);

  label_library_rescan_timestamp = gtk_label_new (_("[place holder]"));
  gtk_widget_set_name (label_library_rescan_timestamp, "label_library_rescan_timestamp");
  gtk_widget_ref (label_library_rescan_timestamp);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label_library_rescan_timestamp", label_library_rescan_timestamp,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_library_rescan_timestamp);
  gtk_container_add (GTK_CONTAINER (frame100), label_library_rescan_timestamp);
  gtk_misc_set_alignment (GTK_MISC (label_library_rescan_timestamp), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_library_rescan_timestamp), 5, 0);

  frame_qrp_statistics = gtk_frame_new (_("Query Routing Protocol:"));
  gtk_widget_set_name (frame_qrp_statistics, "frame_qrp_statistics");
  gtk_widget_ref (frame_qrp_statistics);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame_qrp_statistics", frame_qrp_statistics,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame_qrp_statistics);
  gtk_box_pack_start (GTK_BOX (hbox184), frame_qrp_statistics, FALSE, TRUE, 0);
  gtk_frame_set_shadow_type (GTK_FRAME (frame_qrp_statistics), GTK_SHADOW_OUT);

  table79 = gtk_table_new (3, 4, FALSE);
  gtk_widget_set_name (table79, "table79");
  gtk_widget_ref (table79);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "table79", table79,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table79);
  gtk_container_add (GTK_CONTAINER (frame_qrp_statistics), table79);
  gtk_container_set_border_width (GTK_CONTAINER (table79), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table79), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table79), 4);

  label606 = gtk_label_new (_("Indexing started on:"));
  gtk_widget_set_name (label606, "label606");
  gtk_widget_ref (label606);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label606", label606,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label606);
  gtk_table_attach (GTK_TABLE (table79), label606, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label606), 0, 0.5);

  label608 = gtk_label_new (_("and lasted"));
  gtk_widget_set_name (label608, "label608");
  gtk_widget_ref (label608);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label608", label608,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label608);
  gtk_table_attach (GTK_TABLE (table79), label608, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label608), 0, 0.5);

  label611 = gtk_label_new (_("Table generation started on:"));
  gtk_widget_set_name (label611, "label611");
  gtk_widget_ref (label611);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label611", label611,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label611);
  gtk_table_attach (GTK_TABLE (table79), label611, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label611), 0, 0.5);

  label613 = gtk_label_new (_("and lasted"));
  gtk_widget_set_name (label613, "label613");
  gtk_widget_ref (label613);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label613", label613,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label613);
  gtk_table_attach (GTK_TABLE (table79), label613, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label613), 0, 0.5);

  label616 = gtk_label_new (_("Patch generation started on:"));
  gtk_widget_set_name (label616, "label616");
  gtk_widget_ref (label616);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label616", label616,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label616);
  gtk_table_attach (GTK_TABLE (table79), label616, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label616), 0, 0.5);

  label618 = gtk_label_new (_("and lasted"));
  gtk_widget_set_name (label618, "label618");
  gtk_widget_ref (label618);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label618", label618,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label618);
  gtk_table_attach (GTK_TABLE (table79), label618, 2, 3, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label618), 0, 0.5);

  frame101 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame101, "frame101");
  gtk_widget_ref (frame101);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame101", frame101,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame101);
  gtk_table_attach (GTK_TABLE (table79), frame101, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_frame_set_shadow_type (GTK_FRAME (frame101), GTK_SHADOW_IN);

  label_qrp_indexing_timestamp = gtk_label_new (_("[place holder]"));
  gtk_widget_set_name (label_qrp_indexing_timestamp, "label_qrp_indexing_timestamp");
  gtk_widget_ref (label_qrp_indexing_timestamp);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label_qrp_indexing_timestamp", label_qrp_indexing_timestamp,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_qrp_indexing_timestamp);
  gtk_container_add (GTK_CONTAINER (frame101), label_qrp_indexing_timestamp);
  gtk_misc_set_alignment (GTK_MISC (label_qrp_indexing_timestamp), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_qrp_indexing_timestamp), 5, 0);

  frame102 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame102, "frame102");
  gtk_widget_ref (frame102);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame102", frame102,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame102);
  gtk_table_attach (GTK_TABLE (table79), frame102, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_frame_set_shadow_type (GTK_FRAME (frame102), GTK_SHADOW_IN);

  label_qrp_timestamp = gtk_label_new (_("[place holder]"));
  gtk_widget_set_name (label_qrp_timestamp, "label_qrp_timestamp");
  gtk_widget_ref (label_qrp_timestamp);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label_qrp_timestamp", label_qrp_timestamp,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_qrp_timestamp);
  gtk_container_add (GTK_CONTAINER (frame102), label_qrp_timestamp);
  gtk_misc_set_alignment (GTK_MISC (label_qrp_timestamp), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_qrp_timestamp), 5, 0);

  frame103 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame103, "frame103");
  gtk_widget_ref (frame103);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame103", frame103,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame103);
  gtk_table_attach (GTK_TABLE (table79), frame103, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_frame_set_shadow_type (GTK_FRAME (frame103), GTK_SHADOW_IN);

  label_qrp_patch_timestamp = gtk_label_new (_("[place holder]"));
  gtk_widget_set_name (label_qrp_patch_timestamp, "label_qrp_patch_timestamp");
  gtk_widget_ref (label_qrp_patch_timestamp);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label_qrp_patch_timestamp", label_qrp_patch_timestamp,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_qrp_patch_timestamp);
  gtk_container_add (GTK_CONTAINER (frame103), label_qrp_patch_timestamp);
  gtk_misc_set_alignment (GTK_MISC (label_qrp_patch_timestamp), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_qrp_patch_timestamp), 5, 0);

  frame104 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame104, "frame104");
  gtk_widget_ref (frame104);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame104", frame104,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame104);
  gtk_table_attach (GTK_TABLE (table79), frame104, 3, 4, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_frame_set_shadow_type (GTK_FRAME (frame104), GTK_SHADOW_IN);

  label_qrp_indexing_time = gtk_label_new (_("[place holder]"));
  gtk_widget_set_name (label_qrp_indexing_time, "label_qrp_indexing_time");
  gtk_widget_ref (label_qrp_indexing_time);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label_qrp_indexing_time", label_qrp_indexing_time,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_qrp_indexing_time);
  gtk_container_add (GTK_CONTAINER (frame104), label_qrp_indexing_time);
  gtk_misc_set_alignment (GTK_MISC (label_qrp_indexing_time), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_qrp_indexing_time), 5, 0);

  frame105 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame105, "frame105");
  gtk_widget_ref (frame105);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame105", frame105,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame105);
  gtk_table_attach (GTK_TABLE (table79), frame105, 3, 4, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_frame_set_shadow_type (GTK_FRAME (frame105), GTK_SHADOW_IN);

  label_qrp_computation_time = gtk_label_new (_("[place holder]"));
  gtk_widget_set_name (label_qrp_computation_time, "label_qrp_computation_time");
  gtk_widget_ref (label_qrp_computation_time);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label_qrp_computation_time", label_qrp_computation_time,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_qrp_computation_time);
  gtk_container_add (GTK_CONTAINER (frame105), label_qrp_computation_time);
  gtk_misc_set_alignment (GTK_MISC (label_qrp_computation_time), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_qrp_computation_time), 5, 0);

  frame106 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame106, "frame106");
  gtk_widget_ref (frame106);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame106", frame106,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame106);
  gtk_table_attach (GTK_TABLE (table79), frame106, 3, 4, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_frame_set_shadow_type (GTK_FRAME (frame106), GTK_SHADOW_IN);

  label_qrp_patch_computation_time = gtk_label_new (_("[place holder]"));
  gtk_widget_set_name (label_qrp_patch_computation_time, "label_qrp_patch_computation_time");
  gtk_widget_ref (label_qrp_patch_computation_time);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label_qrp_patch_computation_time", label_qrp_patch_computation_time,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_qrp_patch_computation_time);
  gtk_container_add (GTK_CONTAINER (frame106), label_qrp_patch_computation_time);
  gtk_misc_set_alignment (GTK_MISC (label_qrp_patch_computation_time), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_qrp_patch_computation_time), 5, 0);

  alignment35 = gtk_alignment_new (0.5, 0.5, 0, 1);
  gtk_widget_set_name (alignment35, "alignment35");
  gtk_widget_ref (alignment35);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "alignment35", alignment35,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (alignment35);
  gtk_box_pack_start (GTK_BOX (vbox117), alignment35, FALSE, TRUE, 0);

  hbox191 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox191, "hbox191");
  gtk_widget_ref (hbox191);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "hbox191", hbox191,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox191);
  gtk_container_add (GTK_CONTAINER (alignment35), hbox191);

  frame_qrp_table_info = gtk_frame_new (_("Query routing table information:"));
  gtk_widget_set_name (frame_qrp_table_info, "frame_qrp_table_info");
  gtk_widget_ref (frame_qrp_table_info);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame_qrp_table_info", frame_qrp_table_info,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame_qrp_table_info);
  gtk_box_pack_start (GTK_BOX (hbox191), frame_qrp_table_info, FALSE, TRUE, 0);
  gtk_frame_set_shadow_type (GTK_FRAME (frame_qrp_table_info), GTK_SHADOW_OUT);

  table80 = gtk_table_new (3, 6, FALSE);
  gtk_widget_set_name (table80, "table80");
  gtk_widget_ref (table80);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "table80", table80,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table80);
  gtk_container_add (GTK_CONTAINER (frame_qrp_table_info), table80);
  gtk_container_set_border_width (GTK_CONTAINER (table80), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table80), 4);

  label621 = gtk_label_new (_("Keywords:"));
  gtk_widget_set_name (label621, "label621");
  gtk_widget_ref (label621);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label621", label621,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label621);
  gtk_table_attach (GTK_TABLE (table80), label621, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label621), 0, 0.5);

  label623 = gtk_label_new (_("Slots:"));
  gtk_widget_set_name (label623, "label623");
  gtk_widget_ref (label623);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label623", label623,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label623);
  gtk_table_attach (GTK_TABLE (table80), label623, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label623), 0, 0.5);

  label625 = gtk_label_new (_("Filled slots:"));
  gtk_widget_set_name (label625, "label625");
  gtk_widget_ref (label625);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label625", label625,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label625);
  gtk_table_attach (GTK_TABLE (table80), label625, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label625), 0, 0.5);

  label630 = gtk_label_new (_("Generation:"));
  gtk_widget_set_name (label630, "label630");
  gtk_widget_ref (label630);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label630", label630,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label630);
  gtk_table_attach (GTK_TABLE (table80), label630, 3, 4, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label630), 0, 0.5);

  label628 = gtk_label_new (_("Filled ratio:"));
  gtk_widget_set_name (label628, "label628");
  gtk_widget_ref (label628);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label628", label628,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label628);
  gtk_table_attach (GTK_TABLE (table80), label628, 3, 4, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label628), 0, 0.5);

  label629 = gtk_label_new (_("Conflict ratio:"));
  gtk_widget_set_name (label629, "label629");
  gtk_widget_ref (label629);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label629", label629,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label629);
  gtk_table_attach (GTK_TABLE (table80), label629, 3, 4, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label629), 0, 0.5);

  label633 = gtk_label_new (_("%"));
  gtk_widget_set_name (label633, "label633");
  gtk_widget_ref (label633);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label633", label633,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label633);
  gtk_table_attach (GTK_TABLE (table80), label633, 5, 6, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label633), 0, 0.5);

  label634 = gtk_label_new (_("%"));
  gtk_widget_set_name (label634, "label634");
  gtk_widget_ref (label634);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label634", label634,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label634);
  gtk_table_attach (GTK_TABLE (table80), label634, 5, 6, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label634), 0, 0.5);

  vseparator4 = gtk_vseparator_new ();
  gtk_widget_set_name (vseparator4, "vseparator4");
  gtk_widget_ref (vseparator4);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "vseparator4", vseparator4,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vseparator4);
  gtk_table_attach (GTK_TABLE (table80), vseparator4, 2, 3, 0, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  frame90 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame90, "frame90");
  gtk_widget_ref (frame90);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame90", frame90,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame90);
  gtk_table_attach (GTK_TABLE (table80), frame90, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_frame_set_shadow_type (GTK_FRAME (frame90), GTK_SHADOW_IN);

  label_qrp_hashed_keywords = gtk_label_new (_("[place holder]"));
  gtk_widget_set_name (label_qrp_hashed_keywords, "label_qrp_hashed_keywords");
  gtk_widget_ref (label_qrp_hashed_keywords);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label_qrp_hashed_keywords", label_qrp_hashed_keywords,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_qrp_hashed_keywords);
  gtk_container_add (GTK_CONTAINER (frame90), label_qrp_hashed_keywords);
  gtk_misc_set_alignment (GTK_MISC (label_qrp_hashed_keywords), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_qrp_hashed_keywords), 5, 0);

  frame91 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame91, "frame91");
  gtk_widget_ref (frame91);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame91", frame91,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame91);
  gtk_table_attach (GTK_TABLE (table80), frame91, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_frame_set_shadow_type (GTK_FRAME (frame91), GTK_SHADOW_IN);

  label_qrp_slots = gtk_label_new (_("[place holder]"));
  gtk_widget_set_name (label_qrp_slots, "label_qrp_slots");
  gtk_widget_ref (label_qrp_slots);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label_qrp_slots", label_qrp_slots,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_qrp_slots);
  gtk_container_add (GTK_CONTAINER (frame91), label_qrp_slots);
  gtk_misc_set_alignment (GTK_MISC (label_qrp_slots), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_qrp_slots), 5, 0);

  frame92 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame92, "frame92");
  gtk_widget_ref (frame92);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame92", frame92,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame92);
  gtk_table_attach (GTK_TABLE (table80), frame92, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_frame_set_shadow_type (GTK_FRAME (frame92), GTK_SHADOW_IN);

  label_qrp_slots_filled = gtk_label_new (_("[place holder]"));
  gtk_widget_set_name (label_qrp_slots_filled, "label_qrp_slots_filled");
  gtk_widget_ref (label_qrp_slots_filled);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label_qrp_slots_filled", label_qrp_slots_filled,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_qrp_slots_filled);
  gtk_container_add (GTK_CONTAINER (frame92), label_qrp_slots_filled);
  gtk_misc_set_alignment (GTK_MISC (label_qrp_slots_filled), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_qrp_slots_filled), 5, 0);

  frame93 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame93, "frame93");
  gtk_widget_ref (frame93);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame93", frame93,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame93);
  gtk_table_attach (GTK_TABLE (table80), frame93, 4, 5, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_frame_set_shadow_type (GTK_FRAME (frame93), GTK_SHADOW_IN);

  label_qrp_generation = gtk_label_new (_("[place holder]"));
  gtk_widget_set_name (label_qrp_generation, "label_qrp_generation");
  gtk_widget_ref (label_qrp_generation);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label_qrp_generation", label_qrp_generation,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_qrp_generation);
  gtk_container_add (GTK_CONTAINER (frame93), label_qrp_generation);
  gtk_misc_set_alignment (GTK_MISC (label_qrp_generation), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_qrp_generation), 5, 0);

  frame94 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame94, "frame94");
  gtk_widget_ref (frame94);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame94", frame94,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame94);
  gtk_table_attach (GTK_TABLE (table80), frame94, 4, 5, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_frame_set_shadow_type (GTK_FRAME (frame94), GTK_SHADOW_IN);

  label_qrp_fill_ratio = gtk_label_new (_("[place holder]"));
  gtk_widget_set_name (label_qrp_fill_ratio, "label_qrp_fill_ratio");
  gtk_widget_ref (label_qrp_fill_ratio);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label_qrp_fill_ratio", label_qrp_fill_ratio,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_qrp_fill_ratio);
  gtk_container_add (GTK_CONTAINER (frame94), label_qrp_fill_ratio);
  gtk_misc_set_alignment (GTK_MISC (label_qrp_fill_ratio), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_qrp_fill_ratio), 5, 0);

  frame95 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame95, "frame95");
  gtk_widget_ref (frame95);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame95", frame95,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame95);
  gtk_table_attach (GTK_TABLE (table80), frame95, 4, 5, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_frame_set_shadow_type (GTK_FRAME (frame95), GTK_SHADOW_IN);

  label_qrp_conflict_ratio = gtk_label_new (_("[place holder]"));
  gtk_widget_set_name (label_qrp_conflict_ratio, "label_qrp_conflict_ratio");
  gtk_widget_ref (label_qrp_conflict_ratio);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label_qrp_conflict_ratio", label_qrp_conflict_ratio,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_qrp_conflict_ratio);
  gtk_container_add (GTK_CONTAINER (frame95), label_qrp_conflict_ratio);
  gtk_misc_set_alignment (GTK_MISC (label_qrp_conflict_ratio), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_qrp_conflict_ratio), 5, 0);

  frame_qrp_patch_info = gtk_frame_new (_("Query routing patch information:"));
  gtk_widget_set_name (frame_qrp_patch_info, "frame_qrp_patch_info");
  gtk_widget_ref (frame_qrp_patch_info);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame_qrp_patch_info", frame_qrp_patch_info,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame_qrp_patch_info);
  gtk_box_pack_start (GTK_BOX (hbox191), frame_qrp_patch_info, FALSE, TRUE, 0);
  gtk_frame_set_shadow_type (GTK_FRAME (frame_qrp_patch_info), GTK_SHADOW_OUT);

  table81 = gtk_table_new (3, 3, FALSE);
  gtk_widget_set_name (table81, "table81");
  gtk_widget_ref (table81);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "table81", table81,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table81);
  gtk_container_add (GTK_CONTAINER (frame_qrp_patch_info), table81);
  gtk_container_set_border_width (GTK_CONTAINER (table81), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table81), 4);

  label635 = gtk_label_new (_("Raw length:"));
  gtk_widget_set_name (label635, "label635");
  gtk_widget_ref (label635);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label635", label635,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label635);
  gtk_table_attach (GTK_TABLE (table81), label635, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label635), 0, 0.5);

  label636 = gtk_label_new (_("Compressed length:"));
  gtk_widget_set_name (label636, "label636");
  gtk_widget_ref (label636);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label636", label636,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label636);
  gtk_table_attach (GTK_TABLE (table81), label636, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label636), 0, 0.5);

  label637 = gtk_label_new (_("Compression ratio:"));
  gtk_widget_set_name (label637, "label637");
  gtk_widget_ref (label637);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label637", label637,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label637);
  gtk_table_attach (GTK_TABLE (table81), label637, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label637), 0, 0.5);

  label638 = gtk_label_new (_("%"));
  gtk_widget_set_name (label638, "label638");
  gtk_widget_ref (label638);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label638", label638,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label638);
  gtk_table_attach (GTK_TABLE (table81), label638, 2, 3, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label638), 0, 0.5);

  frame96 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame96, "frame96");
  gtk_widget_ref (frame96);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame96", frame96,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame96);
  gtk_table_attach (GTK_TABLE (table81), frame96, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_frame_set_shadow_type (GTK_FRAME (frame96), GTK_SHADOW_IN);

  label_qrp_patch_raw_length = gtk_label_new (_("[place holder]"));
  gtk_widget_set_name (label_qrp_patch_raw_length, "label_qrp_patch_raw_length");
  gtk_widget_ref (label_qrp_patch_raw_length);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label_qrp_patch_raw_length", label_qrp_patch_raw_length,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_qrp_patch_raw_length);
  gtk_container_add (GTK_CONTAINER (frame96), label_qrp_patch_raw_length);
  gtk_misc_set_alignment (GTK_MISC (label_qrp_patch_raw_length), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_qrp_patch_raw_length), 5, 0);

  frame97 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame97, "frame97");
  gtk_widget_ref (frame97);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame97", frame97,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame97);
  gtk_table_attach (GTK_TABLE (table81), frame97, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_frame_set_shadow_type (GTK_FRAME (frame97), GTK_SHADOW_IN);

  label_qrp_patch_length = gtk_label_new (_("[place holder]"));
  gtk_widget_set_name (label_qrp_patch_length, "label_qrp_patch_length");
  gtk_widget_ref (label_qrp_patch_length);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label_qrp_patch_length", label_qrp_patch_length,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_qrp_patch_length);
  gtk_container_add (GTK_CONTAINER (frame97), label_qrp_patch_length);
  gtk_misc_set_alignment (GTK_MISC (label_qrp_patch_length), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_qrp_patch_length), 5, 0);

  frame98 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame98, "frame98");
  gtk_widget_ref (frame98);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame98", frame98,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame98);
  gtk_table_attach (GTK_TABLE (table81), frame98, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_frame_set_shadow_type (GTK_FRAME (frame98), GTK_SHADOW_IN);

  label_qrp_patch_comp_ratio = gtk_label_new (_("[place holder]"));
  gtk_widget_set_name (label_qrp_patch_comp_ratio, "label_qrp_patch_comp_ratio");
  gtk_widget_ref (label_qrp_patch_comp_ratio);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label_qrp_patch_comp_ratio", label_qrp_patch_comp_ratio,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_qrp_patch_comp_ratio);
  gtk_container_add (GTK_CONTAINER (frame98), label_qrp_patch_comp_ratio);
  gtk_misc_set_alignment (GTK_MISC (label_qrp_patch_comp_ratio), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_qrp_patch_comp_ratio), 5, 0);

  label686 = gtk_label_new (_("Uploads"));
  gtk_widget_set_name (label686, "label686");
  gtk_widget_ref (label686);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label686", label686,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label686);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_prefs), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_prefs), 4), label686);

  scrolledwindow36 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow36, "scrolledwindow36");
  gtk_widget_ref (scrolledwindow36);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "scrolledwindow36", scrolledwindow36,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (scrolledwindow36);
  gtk_container_add (GTK_CONTAINER (notebook_prefs), scrolledwindow36);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow36), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);

  viewport8 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport8, "viewport8");
  gtk_widget_ref (viewport8);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "viewport8", viewport8,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (viewport8);
  gtk_container_add (GTK_CONTAINER (scrolledwindow36), viewport8);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport8), GTK_SHADOW_NONE);

  vbox77 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox77, "vbox77");
  gtk_widget_ref (vbox77);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "vbox77", vbox77,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox77);
  gtk_container_add (GTK_CONTAINER (viewport8), vbox77);
  gtk_container_set_border_width (GTK_CONTAINER (vbox77), 4);

  frame52 = gtk_frame_new (_("Miscellaneous"));
  gtk_widget_set_name (frame52, "frame52");
  gtk_widget_ref (frame52);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame52", frame52,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame52);
  gtk_box_pack_start (GTK_BOX (vbox77), frame52, FALSE, TRUE, 0);

  table35 = gtk_table_new (7, 3, FALSE);
  gtk_widget_set_name (table35, "table35");
  gtk_widget_ref (table35);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "table35", table35,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table35);
  gtk_container_add (GTK_CONTAINER (frame52), table35);
  gtk_container_set_border_width (GTK_CONTAINER (table35), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table35), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table35), 4);

  checkbutton_config_confirm_quit = gtk_check_button_new_with_label ("");
  checkbutton_config_confirm_quit_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (checkbutton_config_confirm_quit)->child),
                                   _("Show _confirmation dialog when leaving gtk-gnutella"));
  gtk_widget_add_accelerator (checkbutton_config_confirm_quit, "clicked", accel_group,
                              checkbutton_config_confirm_quit_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (checkbutton_config_confirm_quit, "checkbutton_config_confirm_quit");
  gtk_widget_ref (checkbutton_config_confirm_quit);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_config_confirm_quit", checkbutton_config_confirm_quit,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_config_confirm_quit);
  gtk_table_attach (GTK_TABLE (table35), checkbutton_config_confirm_quit, 0, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_config_show_tooltips = gtk_check_button_new_with_label ("");
  checkbutton_config_show_tooltips_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (checkbutton_config_show_tooltips)->child),
                                   _("Show _tooltips (does not affect all tooltips yet)"));
  gtk_widget_add_accelerator (checkbutton_config_show_tooltips, "clicked", accel_group,
                              checkbutton_config_show_tooltips_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (checkbutton_config_show_tooltips, "checkbutton_config_show_tooltips");
  gtk_widget_ref (checkbutton_config_show_tooltips);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_config_show_tooltips", checkbutton_config_show_tooltips,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_config_show_tooltips);
  gtk_table_attach (GTK_TABLE (table35), checkbutton_config_show_tooltips, 0, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_config_metric = gtk_check_button_new_with_label ("");
  checkbutton_config_metric_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (checkbutton_config_metric)->child),
                                   _("Show _metric units"));
  gtk_widget_add_accelerator (checkbutton_config_metric, "clicked", accel_group,
                              checkbutton_config_metric_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (checkbutton_config_metric, "checkbutton_config_metric");
  gtk_widget_ref (checkbutton_config_metric);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_config_metric", checkbutton_config_metric,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_config_metric);
  gtk_table_attach (GTK_TABLE (table35), checkbutton_config_metric, 0, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_search_jump_to_created = gtk_check_button_new_with_label (_("Jump to newly created searches"));
  gtk_widget_set_name (checkbutton_search_jump_to_created, "checkbutton_search_jump_to_created");
  gtk_widget_ref (checkbutton_search_jump_to_created);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_search_jump_to_created", checkbutton_search_jump_to_created,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_search_jump_to_created);
  gtk_table_attach (GTK_TABLE (table35), checkbutton_search_jump_to_created, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label657 = gtk_label_new (_("Toolbar style"));
  gtk_widget_set_name (label657, "label657");
  gtk_widget_ref (label657);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label657", label657,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_table_attach (GTK_TABLE (table35), label657, 0, 1, 6, 7,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label657), 0, 0.5);

  option_menu_config_toolbar_style = gtk_option_menu_new ();
  gtk_widget_set_name (option_menu_config_toolbar_style, "option_menu_config_toolbar_style");
  gtk_widget_ref (option_menu_config_toolbar_style);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "option_menu_config_toolbar_style", option_menu_config_toolbar_style,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_table_attach (GTK_TABLE (table35), option_menu_config_toolbar_style, 1, 2, 6, 7,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  option_menu_config_toolbar_style_menu = gtk_menu_new ();
  gtk_option_menu_set_menu (GTK_OPTION_MENU (option_menu_config_toolbar_style), option_menu_config_toolbar_style_menu);

  label652 = gtk_label_new (_("Update search results pane every"));
  gtk_widget_set_name (label652, "label652");
  gtk_widget_ref (label652);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label652", label652,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label652);
  gtk_table_attach (GTK_TABLE (table35), label652, 0, 1, 5, 6,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label652), 0, 0.5);

  spinbutton_search_accumulation_period_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 10);
  spinbutton_search_accumulation_period = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_search_accumulation_period_adj), 1, 0);
  gtk_widget_set_name (spinbutton_search_accumulation_period, "spinbutton_search_accumulation_period");
  gtk_widget_ref (spinbutton_search_accumulation_period);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_search_accumulation_period", spinbutton_search_accumulation_period,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_search_accumulation_period);
  gtk_table_attach (GTK_TABLE (table35), spinbutton_search_accumulation_period, 1, 2, 5, 6,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label653 = gtk_label_new (_("seconds"));
  gtk_widget_set_name (label653, "label653");
  gtk_widget_ref (label653);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label653", label653,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label653);
  gtk_table_attach (GTK_TABLE (table35), label653, 2, 3, 5, 6,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label653), 0, 0.5);

  spinbutton_entry_removal_timeout_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 10);
  spinbutton_entry_removal_timeout = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_entry_removal_timeout_adj), 1, 0);
  gtk_widget_set_name (spinbutton_entry_removal_timeout, "spinbutton_entry_removal_timeout");
  gtk_widget_ref (spinbutton_entry_removal_timeout);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "spinbutton_entry_removal_timeout", spinbutton_entry_removal_timeout,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (spinbutton_entry_removal_timeout);
  gtk_table_attach (GTK_TABLE (table35), spinbutton_entry_removal_timeout, 1, 2, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label600 = gtk_label_new (_("seconds"));
  gtk_widget_set_name (label600, "label600");
  gtk_widget_ref (label600);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label600", label600,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label600);
  gtk_table_attach (GTK_TABLE (table35), label600, 2, 3, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label600), 0, 0.5);

  label599 = gtk_label_new (_("Try to keep 'dead' entries around for"));
  gtk_widget_set_name (label599, "label599");
  gtk_widget_ref (label599);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label599", label599,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label599);
  gtk_table_attach (GTK_TABLE (table35), label599, 0, 1, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label599), 0, 0.5);

  frame64 = gtk_frame_new (_("Expert mode"));
  gtk_widget_set_name (frame64, "frame64");
  gtk_widget_ref (frame64);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame64", frame64,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame64);
  gtk_box_pack_start (GTK_BOX (vbox77), frame64, FALSE, TRUE, 0);

  table45 = gtk_table_new (1, 1, FALSE);
  gtk_widget_set_name (table45, "table45");
  gtk_widget_ref (table45);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "table45", table45,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table45);
  gtk_container_add (GTK_CONTAINER (frame64), table45);

  checkbutton_expert_mode = gtk_check_button_new_with_label ("");
  checkbutton_expert_mode_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (checkbutton_expert_mode)->child),
                                   _("Show additional information and settings for advanced and _expert users"));
  gtk_widget_add_accelerator (checkbutton_expert_mode, "clicked", accel_group,
                              checkbutton_expert_mode_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_set_name (checkbutton_expert_mode, "checkbutton_expert_mode");
  gtk_widget_ref (checkbutton_expert_mode);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_expert_mode", checkbutton_expert_mode,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_expert_mode);
  gtk_table_attach (GTK_TABLE (table45), checkbutton_expert_mode, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  frame84 = gtk_frame_new (_("Gnutella display"));
  gtk_widget_set_name (frame84, "frame84");
  gtk_widget_ref (frame84);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame84", frame84,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame84);
  gtk_box_pack_start (GTK_BOX (vbox77), frame84, FALSE, TRUE, 0);

  hbox190 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox190, "hbox190");
  gtk_widget_ref (hbox190);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "hbox190", hbox190,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox190);
  gtk_container_add (GTK_CONTAINER (frame84), hbox190);
  gtk_container_set_border_width (GTK_CONTAINER (hbox190), 2);

  alignment33 = gtk_alignment_new (0, 0.5, 0, 1);
  gtk_widget_set_name (alignment33, "alignment33");
  gtk_widget_ref (alignment33);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "alignment33", alignment33,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (alignment33);
  gtk_box_pack_start (GTK_BOX (hbox190), alignment33, TRUE, TRUE, 0);

  vbox119 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox119, "vbox119");
  gtk_widget_ref (vbox119);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "vbox119", vbox119,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox119);
  gtk_container_add (GTK_CONTAINER (alignment33), vbox119);

  checkbutton_node_show_detailed_info = gtk_check_button_new_with_label (_("Display detailed traffic information"));
  gtk_widget_set_name (checkbutton_node_show_detailed_info, "checkbutton_node_show_detailed_info");
  gtk_widget_ref (checkbutton_node_show_detailed_info);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_node_show_detailed_info", checkbutton_node_show_detailed_info,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_node_show_detailed_info);
  gtk_box_pack_start (GTK_BOX (vbox119), checkbutton_node_show_detailed_info, FALSE, FALSE, 0);

  vbox123 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox123, "vbox123");
  gtk_widget_ref (vbox123);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "vbox123", vbox123,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox123);
  gtk_box_pack_start (GTK_BOX (hbox190), vbox123, FALSE, TRUE, 0);

  frame_gnet_detailed_traffic = gtk_frame_new (_("Detailed traffic information to display"));
  gtk_widget_set_name (frame_gnet_detailed_traffic, "frame_gnet_detailed_traffic");
  gtk_widget_ref (frame_gnet_detailed_traffic);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame_gnet_detailed_traffic", frame_gnet_detailed_traffic,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame_gnet_detailed_traffic);
  gtk_box_pack_start (GTK_BOX (vbox123), frame_gnet_detailed_traffic, FALSE, TRUE, 0);
  gtk_frame_set_shadow_type (GTK_FRAME (frame_gnet_detailed_traffic), GTK_SHADOW_OUT);

  table71 = gtk_table_new (7, 3, FALSE);
  gtk_widget_set_name (table71, "table71");
  gtk_widget_ref (table71);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "table71", table71,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table71);
  gtk_container_add (GTK_CONTAINER (frame_gnet_detailed_traffic), table71);
  gtk_container_set_border_width (GTK_CONTAINER (table71), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table71), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table71), 4);

  checkbutton_gnet_info_txc = gtk_check_button_new_with_label (_("TX compression"));
  gtk_widget_set_name (checkbutton_gnet_info_txc, "checkbutton_gnet_info_txc");
  gtk_widget_ref (checkbutton_gnet_info_txc);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_gnet_info_txc", checkbutton_gnet_info_txc,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_gnet_info_txc);
  gtk_table_attach (GTK_TABLE (table71), checkbutton_gnet_info_txc, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_gnet_info_rxc = gtk_check_button_new_with_label (_("RX compression"));
  gtk_widget_set_name (checkbutton_gnet_info_rxc, "checkbutton_gnet_info_rxc");
  gtk_widget_ref (checkbutton_gnet_info_rxc);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_gnet_info_rxc", checkbutton_gnet_info_rxc,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_gnet_info_rxc);
  gtk_table_attach (GTK_TABLE (table71), checkbutton_gnet_info_rxc, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_gnet_info_tx_speed = gtk_check_button_new_with_label (_("TX speed"));
  gtk_widget_set_name (checkbutton_gnet_info_tx_speed, "checkbutton_gnet_info_tx_speed");
  gtk_widget_ref (checkbutton_gnet_info_tx_speed);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_gnet_info_tx_speed", checkbutton_gnet_info_tx_speed,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_gnet_info_tx_speed);
  gtk_table_attach (GTK_TABLE (table71), checkbutton_gnet_info_tx_speed, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_gnet_info_rx_speed = gtk_check_button_new_with_label (_("RX speed"));
  gtk_widget_set_name (checkbutton_gnet_info_rx_speed, "checkbutton_gnet_info_rx_speed");
  gtk_widget_ref (checkbutton_gnet_info_rx_speed);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_gnet_info_rx_speed", checkbutton_gnet_info_rx_speed,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_gnet_info_rx_speed);
  gtk_table_attach (GTK_TABLE (table71), checkbutton_gnet_info_rx_speed, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_gnet_info_tx_queries = gtk_check_button_new_with_label (_("TX queries"));
  gtk_widget_set_name (checkbutton_gnet_info_tx_queries, "checkbutton_gnet_info_tx_queries");
  gtk_widget_ref (checkbutton_gnet_info_tx_queries);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_gnet_info_tx_queries", checkbutton_gnet_info_tx_queries,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_gnet_info_tx_queries);
  gtk_table_attach (GTK_TABLE (table71), checkbutton_gnet_info_tx_queries, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_gnet_info_rx_queries = gtk_check_button_new_with_label (_("RX queries"));
  gtk_widget_set_name (checkbutton_gnet_info_rx_queries, "checkbutton_gnet_info_rx_queries");
  gtk_widget_ref (checkbutton_gnet_info_rx_queries);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_gnet_info_rx_queries", checkbutton_gnet_info_rx_queries,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_gnet_info_rx_queries);
  gtk_table_attach (GTK_TABLE (table71), checkbutton_gnet_info_rx_queries, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_gnet_info_tx_hits = gtk_check_button_new_with_label (_("TX query hits"));
  gtk_widget_set_name (checkbutton_gnet_info_tx_hits, "checkbutton_gnet_info_tx_hits");
  gtk_widget_ref (checkbutton_gnet_info_tx_hits);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_gnet_info_tx_hits", checkbutton_gnet_info_tx_hits,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_gnet_info_tx_hits);
  gtk_table_attach (GTK_TABLE (table71), checkbutton_gnet_info_tx_hits, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_gnet_info_rx_hits = gtk_check_button_new_with_label (_("RX query hits"));
  gtk_widget_set_name (checkbutton_gnet_info_rx_hits, "checkbutton_gnet_info_rx_hits");
  gtk_widget_ref (checkbutton_gnet_info_rx_hits);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_gnet_info_rx_hits", checkbutton_gnet_info_rx_hits,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_gnet_info_rx_hits);
  gtk_table_attach (GTK_TABLE (table71), checkbutton_gnet_info_rx_hits, 1, 2, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_gnet_info_gen_queries = gtk_check_button_new_with_label (_("Generated queries"));
  gtk_widget_set_name (checkbutton_gnet_info_gen_queries, "checkbutton_gnet_info_gen_queries");
  gtk_widget_ref (checkbutton_gnet_info_gen_queries);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_gnet_info_gen_queries", checkbutton_gnet_info_gen_queries,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_gnet_info_gen_queries);
  gtk_table_attach (GTK_TABLE (table71), checkbutton_gnet_info_gen_queries, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_gnet_info_sq_queries = gtk_check_button_new_with_label (_("Pending local queries"));
  gtk_widget_set_name (checkbutton_gnet_info_sq_queries, "checkbutton_gnet_info_sq_queries");
  gtk_widget_ref (checkbutton_gnet_info_sq_queries);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_gnet_info_sq_queries", checkbutton_gnet_info_sq_queries,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_gnet_info_sq_queries);
  gtk_table_attach (GTK_TABLE (table71), checkbutton_gnet_info_sq_queries, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_gnet_info_tx_dropped = gtk_check_button_new_with_label (_("TX dropped"));
  gtk_widget_set_name (checkbutton_gnet_info_tx_dropped, "checkbutton_gnet_info_tx_dropped");
  gtk_widget_ref (checkbutton_gnet_info_tx_dropped);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_gnet_info_tx_dropped", checkbutton_gnet_info_tx_dropped,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_gnet_info_tx_dropped);
  gtk_table_attach (GTK_TABLE (table71), checkbutton_gnet_info_tx_dropped, 0, 1, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_gnet_info_rx_dropped = gtk_check_button_new_with_label (_("RX dropped"));
  gtk_widget_set_name (checkbutton_gnet_info_rx_dropped, "checkbutton_gnet_info_rx_dropped");
  gtk_widget_ref (checkbutton_gnet_info_rx_dropped);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_gnet_info_rx_dropped", checkbutton_gnet_info_rx_dropped,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_gnet_info_rx_dropped);
  gtk_table_attach (GTK_TABLE (table71), checkbutton_gnet_info_rx_dropped, 1, 2, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_gnet_info_qrp_stats = gtk_check_button_new_with_label (_("QRP stats"));
  gtk_widget_set_name (checkbutton_gnet_info_qrp_stats, "checkbutton_gnet_info_qrp_stats");
  gtk_widget_ref (checkbutton_gnet_info_qrp_stats);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_gnet_info_qrp_stats", checkbutton_gnet_info_qrp_stats,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_gnet_info_qrp_stats);
  gtk_table_attach (GTK_TABLE (table71), checkbutton_gnet_info_qrp_stats, 2, 3, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_gnet_info_dbw = gtk_check_button_new_with_label (_("Dup / Bad / Weird"));
  gtk_widget_set_name (checkbutton_gnet_info_dbw, "checkbutton_gnet_info_dbw");
  gtk_widget_ref (checkbutton_gnet_info_dbw);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_gnet_info_dbw", checkbutton_gnet_info_dbw,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_gnet_info_dbw);
  gtk_table_attach (GTK_TABLE (table71), checkbutton_gnet_info_dbw, 2, 3, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_gnet_info_rt = gtk_check_button_new_with_label (_("Ping / Pong round trip"));
  gtk_widget_set_name (checkbutton_gnet_info_rt, "checkbutton_gnet_info_rt");
  gtk_widget_ref (checkbutton_gnet_info_rt);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_gnet_info_rt", checkbutton_gnet_info_rt,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_gnet_info_rt);
  gtk_table_attach (GTK_TABLE (table71), checkbutton_gnet_info_rt, 2, 3, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_gnet_info_shared_size = gtk_check_button_new_with_label (_("Library size"));
  gtk_widget_set_name (checkbutton_gnet_info_shared_size, "checkbutton_gnet_info_shared_size");
  gtk_widget_ref (checkbutton_gnet_info_shared_size);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_gnet_info_shared_size", checkbutton_gnet_info_shared_size,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_gnet_info_shared_size);
  gtk_table_attach (GTK_TABLE (table71), checkbutton_gnet_info_shared_size, 0, 1, 6, 7,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_gnet_info_shared_files = gtk_check_button_new_with_label (_("Library # of files"));
  gtk_widget_set_name (checkbutton_gnet_info_shared_files, "checkbutton_gnet_info_shared_files");
  gtk_widget_ref (checkbutton_gnet_info_shared_files);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_gnet_info_shared_files", checkbutton_gnet_info_shared_files,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_gnet_info_shared_files);
  gtk_table_attach (GTK_TABLE (table71), checkbutton_gnet_info_shared_files, 1, 2, 6, 7,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_gnet_info_rx_wire = gtk_check_button_new_with_label (_("RX wire bytes"));
  gtk_widget_set_name (checkbutton_gnet_info_rx_wire, "checkbutton_gnet_info_rx_wire");
  gtk_widget_ref (checkbutton_gnet_info_rx_wire);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_gnet_info_rx_wire", checkbutton_gnet_info_rx_wire,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_gnet_info_rx_wire);
  gtk_table_attach (GTK_TABLE (table71), checkbutton_gnet_info_rx_wire, 1, 2, 5, 6,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_gnet_info_tx_wire = gtk_check_button_new_with_label (_("TX wire bytes"));
  gtk_widget_set_name (checkbutton_gnet_info_tx_wire, "checkbutton_gnet_info_tx_wire");
  gtk_widget_ref (checkbutton_gnet_info_tx_wire);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "checkbutton_gnet_info_tx_wire", checkbutton_gnet_info_tx_wire,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (checkbutton_gnet_info_tx_wire);
  gtk_table_attach (GTK_TABLE (table71), checkbutton_gnet_info_tx_wire, 0, 1, 5, 6,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label687 = gtk_label_new (_("User Interface"));
  gtk_widget_set_name (label687, "label687");
  gtk_widget_ref (label687);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label687", label687,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label687);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_prefs), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_prefs), 5), label687);

  scrolledwindow37 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow37, "scrolledwindow37");
  gtk_widget_ref (scrolledwindow37);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "scrolledwindow37", scrolledwindow37,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (scrolledwindow37);
  gtk_container_add (GTK_CONTAINER (notebook_prefs), scrolledwindow37);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow37), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);

  viewport9 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport9, "viewport9");
  gtk_widget_ref (viewport9);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "viewport9", viewport9,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (viewport9);
  gtk_container_add (GTK_CONTAINER (scrolledwindow37), viewport9);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport9), GTK_SHADOW_NONE);

  vbox75 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox75, "vbox75");
  gtk_widget_ref (vbox75);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "vbox75", vbox75,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox75);
  gtk_container_add (GTK_CONTAINER (viewport9), vbox75);
  gtk_container_set_border_width (GTK_CONTAINER (vbox75), 4);

  frame49 = gtk_frame_new (_("Property browser"));
  gtk_widget_set_name (frame49, "frame49");
  gtk_widget_ref (frame49);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame49", frame49,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame49);
  gtk_box_pack_start (GTK_BOX (vbox75), frame49, TRUE, TRUE, 0);

  vbox139 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox139, "vbox139");
  gtk_widget_ref (vbox139);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "vbox139", vbox139,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (vbox139);
  gtk_container_add (GTK_CONTAINER (frame49), vbox139);

  hbox2102 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox2102, "hbox2102");
  gtk_widget_ref (hbox2102);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "hbox2102", hbox2102,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox2102);
  gtk_box_pack_start (GTK_BOX (vbox139), hbox2102, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (hbox2102), 2);

  label765 = gtk_label_new (_("Property pattern:"));
  gtk_widget_set_name (label765, "label765");
  gtk_widget_ref (label765);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label765", label765,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label765);
  gtk_box_pack_start (GTK_BOX (hbox2102), label765, FALSE, FALSE, 0);

  entry_dbg_property_pattern = gtk_entry_new ();
  gtk_widget_set_name (entry_dbg_property_pattern, "entry_dbg_property_pattern");
  gtk_widget_ref (entry_dbg_property_pattern);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "entry_dbg_property_pattern", entry_dbg_property_pattern,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_dbg_property_pattern);
  gtk_box_pack_start (GTK_BOX (hbox2102), entry_dbg_property_pattern, TRUE, TRUE, 0);

  scrolledwindow492 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow492, "scrolledwindow492");
  gtk_widget_ref (scrolledwindow492);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "scrolledwindow492", scrolledwindow492,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (scrolledwindow492);
  gtk_box_pack_start (GTK_BOX (vbox139), scrolledwindow492, TRUE, TRUE, 0);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow492), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);

  clist_dbg_property = gtk_clist_new (4);
  gtk_widget_set_name (clist_dbg_property, "clist_dbg_property");
  gtk_widget_ref (clist_dbg_property);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "clist_dbg_property", clist_dbg_property,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (clist_dbg_property);
  gtk_container_add (GTK_CONTAINER (scrolledwindow492), clist_dbg_property);
  gtk_clist_set_column_width (GTK_CLIST (clist_dbg_property), 0, 80);
  gtk_clist_set_column_width (GTK_CLIST (clist_dbg_property), 1, 160);
  gtk_clist_set_column_width (GTK_CLIST (clist_dbg_property), 2, 160);
  gtk_clist_set_column_width (GTK_CLIST (clist_dbg_property), 3, 80);
  gtk_clist_set_selection_mode (GTK_CLIST (clist_dbg_property), GTK_SELECTION_BROWSE);
  gtk_clist_column_titles_show (GTK_CLIST (clist_dbg_property));

  label766 = gtk_label_new (_("Saved"));
  gtk_widget_set_name (label766, "label766");
  gtk_widget_ref (label766);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label766", label766,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label766);
  gtk_clist_set_column_widget (GTK_CLIST (clist_dbg_property), 0, label766);

  label767 = gtk_label_new (_("Type"));
  gtk_widget_set_name (label767, "label767");
  gtk_widget_ref (label767);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label767", label767,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label767);
  gtk_clist_set_column_widget (GTK_CLIST (clist_dbg_property), 1, label767);

  label_767 = gtk_label_new (_("Property"));
  gtk_widget_set_name (label_767, "label_767");
  gtk_widget_ref (label_767);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label_767", label_767,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_767);
  gtk_clist_set_column_widget (GTK_CLIST (clist_dbg_property), 2, label_767);

  label_768 = gtk_label_new (_("Value"));
  gtk_widget_set_name (label_768, "label_768");
  gtk_widget_ref (label_768);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label_768", label_768,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_768);
  gtk_clist_set_column_widget (GTK_CLIST (clist_dbg_property), 3, label_768);
  gtk_misc_set_alignment (GTK_MISC (label_768), 0, 0.5);

  hbox2103 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox2103, "hbox2103");
  gtk_widget_ref (hbox2103);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "hbox2103", hbox2103,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox2103);
  gtk_box_pack_start (GTK_BOX (vbox139), hbox2103, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (hbox2103), 2);

  label769 = gtk_label_new (_("Selected property:"));
  gtk_widget_set_name (label769, "label769");
  gtk_widget_ref (label769);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label769", label769,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label769);
  gtk_box_pack_start (GTK_BOX (hbox2103), label769, FALSE, TRUE, 0);

  label_dbg_property_name = gtk_label_new (_("<no property selected>"));
  gtk_widget_set_name (label_dbg_property_name, "label_dbg_property_name");
  gtk_widget_ref (label_dbg_property_name);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label_dbg_property_name", label_dbg_property_name,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_dbg_property_name);
  gtk_box_pack_start (GTK_BOX (hbox2103), label_dbg_property_name, FALSE, TRUE, 0);
  gtk_misc_set_alignment (GTK_MISC (label_dbg_property_name), 0, 0.5);

  label771 = gtk_label_new (_("Min/Max:"));
  gtk_widget_set_name (label771, "label771");
  gtk_widget_ref (label771);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label771", label771,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label771);
  gtk_box_pack_start (GTK_BOX (hbox2103), label771, TRUE, TRUE, 0);
  gtk_misc_set_alignment (GTK_MISC (label771), 1, 0.5);

  label_dbg_property_limits = gtk_label_new (_("<no property selected>"));
  gtk_widget_set_name (label_dbg_property_limits, "label_dbg_property_limits");
  gtk_widget_ref (label_dbg_property_limits);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label_dbg_property_limits", label_dbg_property_limits,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label_dbg_property_limits);
  gtk_box_pack_start (GTK_BOX (hbox2103), label_dbg_property_limits, FALSE, FALSE, 0);
  gtk_misc_set_alignment (GTK_MISC (label_dbg_property_limits), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_dbg_property_limits), 4, 0);

  hbox2104 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox2104, "hbox2104");
  gtk_widget_ref (hbox2104);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "hbox2104", hbox2104,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox2104);
  gtk_box_pack_start (GTK_BOX (vbox139), hbox2104, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (hbox2104), 2);

  label773 = gtk_label_new (_("Default value:"));
  gtk_widget_set_name (label773, "label773");
  gtk_widget_ref (label773);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label773", label773,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label773);
  gtk_box_pack_start (GTK_BOX (hbox2104), label773, FALSE, FALSE, 0);

  entry_dbg_property_default = gtk_entry_new ();
  gtk_widget_set_name (entry_dbg_property_default, "entry_dbg_property_default");
  gtk_widget_ref (entry_dbg_property_default);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "entry_dbg_property_default", entry_dbg_property_default,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_dbg_property_default);
  gtk_box_pack_start (GTK_BOX (hbox2104), entry_dbg_property_default, TRUE, TRUE, 0);
  gtk_entry_set_editable (GTK_ENTRY (entry_dbg_property_default), FALSE);
  gtk_entry_set_text (GTK_ENTRY (entry_dbg_property_default), _("<no property selected>"));

  hbox2105 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox2105, "hbox2105");
  gtk_widget_ref (hbox2105);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "hbox2105", hbox2105,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox2105);
  gtk_box_pack_start (GTK_BOX (vbox139), hbox2105, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (hbox2105), 2);

  label774 = gtk_label_new (_("Edit value:"));
  gtk_widget_set_name (label774, "label774");
  gtk_widget_ref (label774);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label774", label774,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label774);
  gtk_box_pack_start (GTK_BOX (hbox2105), label774, FALSE, FALSE, 0);

  entry_dbg_property_value = gtk_entry_new ();
  gtk_widget_set_name (entry_dbg_property_value, "entry_dbg_property_value");
  gtk_widget_ref (entry_dbg_property_value);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "entry_dbg_property_value", entry_dbg_property_value,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_dbg_property_value);
  gtk_box_pack_start (GTK_BOX (hbox2105), entry_dbg_property_value, TRUE, TRUE, 0);
  gtk_entry_set_text (GTK_ENTRY (entry_dbg_property_value), _("<no property selected>"));

  frame_expert_unmapped = gtk_frame_new (_("Diverse properties"));
  gtk_widget_set_name (frame_expert_unmapped, "frame_expert_unmapped");
  gtk_widget_ref (frame_expert_unmapped);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "frame_expert_unmapped", frame_expert_unmapped,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (frame_expert_unmapped);
  gtk_box_pack_start (GTK_BOX (vbox75), frame_expert_unmapped, FALSE, TRUE, 0);

  table57 = gtk_table_new (4, 2, FALSE);
  gtk_widget_set_name (table57, "table57");
  gtk_widget_ref (table57);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "table57", table57,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (table57);
  gtk_container_add (GTK_CONTAINER (frame_expert_unmapped), table57);
  gtk_container_set_border_width (GTK_CONTAINER (table57), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table57), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table57), 4);

  label466 = gtk_label_new (_("Avg. time between IP address changes:"));
  gtk_widget_set_name (label466, "label466");
  gtk_widget_ref (label466);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label466", label466,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label466);
  gtk_table_attach (GTK_TABLE (table57), label466, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label466), 0, 0.5);

  label468 = gtk_label_new (_("Avg. uptime of this servent:"));
  gtk_widget_set_name (label468, "label468");
  gtk_widget_ref (label468);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label468", label468,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label468);
  gtk_table_attach (GTK_TABLE (table57), label468, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label468), 0, 0.5);

  entry_average_ip_uptime = gtk_entry_new ();
  gtk_widget_set_name (entry_average_ip_uptime, "entry_average_ip_uptime");
  gtk_widget_ref (entry_average_ip_uptime);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "entry_average_ip_uptime", entry_average_ip_uptime,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_average_ip_uptime);
  gtk_table_attach (GTK_TABLE (table57), entry_average_ip_uptime, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_entry_set_editable (GTK_ENTRY (entry_average_ip_uptime), FALSE);

  entry_average_servent_uptime = gtk_entry_new ();
  gtk_widget_set_name (entry_average_servent_uptime, "entry_average_servent_uptime");
  gtk_widget_ref (entry_average_servent_uptime);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "entry_average_servent_uptime", entry_average_servent_uptime,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_average_servent_uptime);
  gtk_table_attach (GTK_TABLE (table57), entry_average_servent_uptime, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_entry_set_editable (GTK_ENTRY (entry_average_servent_uptime), FALSE);

  label480 = gtk_label_new (_("Available physical memory:"));
  gtk_widget_set_name (label480, "label480");
  gtk_widget_ref (label480);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label480", label480,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label480);
  gtk_table_attach (GTK_TABLE (table57), label480, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label480), 0, 0.5);

  entry_sys_physmem = gtk_entry_new ();
  gtk_widget_set_name (entry_sys_physmem, "entry_sys_physmem");
  gtk_widget_ref (entry_sys_physmem);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "entry_sys_physmem", entry_sys_physmem,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_sys_physmem);
  gtk_table_attach (GTK_TABLE (table57), entry_sys_physmem, 1, 2, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_entry_set_editable (GTK_ENTRY (entry_sys_physmem), FALSE);

  label8025 = gtk_label_new (_("Avg. downtime of this servent:"));
  gtk_widget_set_name (label8025, "label8025");
  gtk_widget_ref (label8025);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label8025", label8025,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label8025);
  gtk_table_attach (GTK_TABLE (table57), label8025, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label8025), 0, 0.5);

  entry_average_servent_downtime = gtk_entry_new ();
  gtk_widget_set_name (entry_average_servent_downtime, "entry_average_servent_downtime");
  gtk_widget_ref (entry_average_servent_downtime);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "entry_average_servent_downtime", entry_average_servent_downtime,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (entry_average_servent_downtime);
  gtk_table_attach (GTK_TABLE (table57), entry_average_servent_downtime, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_entry_set_editable (GTK_ENTRY (entry_average_servent_downtime), FALSE);

  label688 = gtk_label_new (_("Debugging"));
  gtk_widget_set_name (label688, "label688");
  gtk_widget_ref (label688);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "label688", label688,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (label688);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_prefs), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_prefs), 6), label688);

  dialog_action_area2 = GTK_DIALOG (dlg_prefs)->action_area;
  gtk_widget_set_name (dialog_action_area2, "dialog_action_area2");
  gtk_object_set_data (GTK_OBJECT (dlg_prefs), "dialog_action_area2", dialog_action_area2);
  gtk_widget_show (dialog_action_area2);
  gtk_container_set_border_width (GTK_CONTAINER (dialog_action_area2), 10);

  hbox205 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox205, "hbox205");
  gtk_widget_ref (hbox205);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "hbox205", hbox205,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (hbox205);
  gtk_box_pack_end (GTK_BOX (dialog_action_area2), hbox205, FALSE, TRUE, 0);

  button_prefs_close = gtk_button_new_with_label (_("Close"));
  gtk_widget_set_name (button_prefs_close, "button_prefs_close");
  gtk_widget_ref (button_prefs_close);
  gtk_object_set_data_full (GTK_OBJECT (dlg_prefs), "button_prefs_close", button_prefs_close,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (button_prefs_close);
  gtk_box_pack_end (GTK_BOX (hbox205), button_prefs_close, FALSE, FALSE, 0);
  gtk_widget_add_accelerator (button_prefs_close, "clicked", accel_group,
                              GDK_c, GDK_MOD1_MASK,
                              GTK_ACCEL_VISIBLE);

  gtk_signal_connect (GTK_OBJECT (dlg_prefs), "delete_event",
                      GTK_SIGNAL_FUNC (on_dlg_prefs_delete_event),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (entry_server_hostname), "changed",
                      GTK_SIGNAL_FUNC (on_entry_server_hostname_changed),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (entry_server_hostname), "activate",
                      GTK_SIGNAL_FUNC (on_entry_server_hostname_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (entry_server_hostname), "focus_out_event",
                      GTK_SIGNAL_FUNC (on_entry_server_hostname_focus_out_event),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (entry_config_force_ip), "changed",
                      GTK_SIGNAL_FUNC (on_entry_config_force_ip_changed),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (entry_config_force_ip), "activate",
                      GTK_SIGNAL_FUNC (on_entry_config_force_ip_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (entry_config_force_ip), "focus_out_event",
                      GTK_SIGNAL_FUNC (on_entry_config_force_ip_focus_out_event),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (entry_config_force_ipv6), "changed",
                      GTK_SIGNAL_FUNC (on_entry_config_force_ipv6_changed),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (entry_config_force_ipv6), "activate",
                      GTK_SIGNAL_FUNC (on_entry_config_force_ipv6_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (entry_config_force_ipv6), "focus_out_event",
                      GTK_SIGNAL_FUNC (on_entry_config_force_ipv6_focus_out_event),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (entry_config_ipv6_trt_prefix), "changed",
                      GTK_SIGNAL_FUNC (on_entry_config_ipv6_trt_prefix_changed),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (entry_config_ipv6_trt_prefix), "activate",
                      GTK_SIGNAL_FUNC (on_entry_config_ipv6_trt_prefix_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (entry_config_ipv6_trt_prefix), "focus_out_event",
                      GTK_SIGNAL_FUNC (on_entry_config_ipv6_trt_prefix_focus_out_event),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (entry_config_proxy_hostname), "activate",
                      GTK_SIGNAL_FUNC (on_entry_config_proxy_hostname_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (entry_config_proxy_hostname), "focus_out_event",
                      GTK_SIGNAL_FUNC (on_entry_config_proxy_hostname_focus_out_event),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (entry_config_socks_password), "activate",
                      GTK_SIGNAL_FUNC (on_entry_config_socks_password_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (entry_config_socks_password), "focus_out_event",
                      GTK_SIGNAL_FUNC (on_entry_config_socks_password_focus_out_event),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (entry_config_socks_username), "activate",
                      GTK_SIGNAL_FUNC (on_entry_config_socks_username_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (entry_config_socks_username), "focus_out_event",
                      GTK_SIGNAL_FUNC (on_entry_config_socks_username_focus_out_event),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (entry_config_netmasks), "focus_out_event",
                      GTK_SIGNAL_FUNC (on_entry_config_netmask_focus_out_event),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (entry_config_netmasks), "activate",
                      GTK_SIGNAL_FUNC (on_entry_config_netmask_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button_config_save_path), "clicked",
                      GTK_SIGNAL_FUNC (on_button_config_save_path_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button_config_move_path), "clicked",
                      GTK_SIGNAL_FUNC (on_button_config_move_path_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button_config_bad_path), "clicked",
                      GTK_SIGNAL_FUNC (on_button_config_bad_path_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (entry_config_path), "activate",
                      GTK_SIGNAL_FUNC (on_entry_config_path_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (entry_config_path), "focus_out_event",
                      GTK_SIGNAL_FUNC (on_entry_config_path_focus_out_event),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button_config_add_dir), "clicked",
                      GTK_SIGNAL_FUNC (on_button_config_add_dir_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button_config_rescan_dir), "clicked",
                      GTK_SIGNAL_FUNC (on_button_config_rescan_dir_clicked),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (entry_config_extensions), "activate",
                      GTK_SIGNAL_FUNC (on_entry_config_extensions_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (entry_config_extensions), "focus_out_event",
                      GTK_SIGNAL_FUNC (on_entry_config_extensions_focus_out_event),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (entry_dbg_property_pattern), "activate",
                      GTK_SIGNAL_FUNC (on_entry_dbg_property_pattern_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (clist_dbg_property), "select_row",
                      GTK_SIGNAL_FUNC (on_clist_dbg_property_select_row),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (clist_dbg_property), "click_column",
                      GTK_SIGNAL_FUNC (on_clist_dbg_property_click_column),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (entry_dbg_property_default), "activate",
                      GTK_SIGNAL_FUNC (on_entry_dbg_property_value_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (entry_dbg_property_value), "activate",
                      GTK_SIGNAL_FUNC (on_entry_dbg_property_value_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (button_prefs_close), "clicked",
                      GTK_SIGNAL_FUNC (on_button_prefs_close_clicked),
                      NULL);

  gtk_widget_add_accelerator (spinbutton_config_port, "grab_focus", accel_group,
                              label129_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_add_accelerator (entry_config_proxy_hostname, "grab_focus", accel_group,
                              label91_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_add_accelerator (spinbutton_config_proxy_port, "grab_focus", accel_group,
                              label92_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_add_accelerator (option_menu_config_proxy_protocol, "grab_focus", accel_group,
                              label90_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_add_accelerator (entry_config_socks_username, "grab_focus", accel_group,
                              label93_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_add_accelerator (entry_config_socks_password, "grab_focus", accel_group,
                              label94_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_add_accelerator (spinbutton_config_ban_max_fds, "grab_focus", accel_group,
                              label441_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_add_accelerator (spinbutton_config_ban_ratio_fds, "grab_focus", accel_group,
                              label442_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_add_accelerator (entry_config_max_banned_fd, "grab_focus", accel_group,
                              label502_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_add_accelerator (spinbutton_node_rx_size, "grab_focus", accel_group,
                              label553_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_add_accelerator (spinbutton_download_rx_size, "grab_focus", accel_group,
                              label552_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_add_accelerator (spinbutton_config_search_items, "grab_focus", accel_group,
                              label37_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_add_accelerator (spinbutton_config_search_reissue_timeout, "grab_focus", accel_group,
                              label567_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_add_accelerator (spinbutton_config_node_connecting_timeout, "grab_focus", accel_group,
                              label175_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_add_accelerator (spinbutton_config_node_connected_timeout, "grab_focus", accel_group,
                              label176_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_add_accelerator (spinbutton_config_node_tx_flowc_timeout, "grab_focus", accel_group,
                              label177_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_add_accelerator (spinbutton_config_maxttl, "grab_focus", accel_group,
                              label84_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_add_accelerator (spinbutton_config_myttl, "grab_focus", accel_group,
                              label85_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_add_accelerator (spinbutton_config_max_high_ttl_radius, "grab_focus", accel_group,
                              label158_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_add_accelerator (spinbutton_config_max_high_ttl_msg, "grab_focus", accel_group,
                              label157_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_add_accelerator (spinbutton_config_hard_ttl_limit, "grab_focus", accel_group,
                              label159_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_add_accelerator (spinbutton_config_min_dup_ratio, "grab_focus", accel_group,
                              label279_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_add_accelerator (spinbutton_config_min_dup_msg, "grab_focus", accel_group,
                              label278_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_add_accelerator (spinbutton_config_speed, "grab_focus", accel_group,
                              label156_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_add_accelerator (spinbutton_config_download_overlap_range, "grab_focus", accel_group,
                              label171_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_add_accelerator (spinbutton_config_download_max_retries, "grab_focus", accel_group,
                              label172_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_add_accelerator (spinbutton_config_download_connecting_timeout, "grab_focus", accel_group,
                              label168_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_add_accelerator (spinbutton_config_download_push_sent_timeout, "grab_focus", accel_group,
                              label169_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_add_accelerator (spinbutton_config_download_connected_timeout, "grab_focus", accel_group,
                              label170_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_add_accelerator (spinbutton_dl_minchunksize, "grab_focus", accel_group,
                              label283_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_add_accelerator (spinbutton_dl_maxchunksize, "grab_focus", accel_group,
                              label284_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_add_accelerator (entry_config_extensions, "grab_focus", accel_group,
                              label41_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_add_accelerator (spinbutton_config_upload_connecting_timeout, "grab_focus", accel_group,
                              label179_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_add_accelerator (spinbutton_config_upload_connected_timeout, "grab_focus", accel_group,
                              label180_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);
  gtk_widget_add_accelerator (spinbutton_pfsp_first_chunk, "grab_focus", accel_group,
                              label547_key, GDK_MOD1_MASK, (GtkAccelFlags) 0);

  gtk_object_set_data (GTK_OBJECT (dlg_prefs), "tooltips", tooltips);

  gtk_window_add_accel_group (GTK_WINDOW (dlg_prefs), accel_group);

  return dlg_prefs;
}

GtkWidget*
create_dlg_faq (void)
{
  GtkWidget *dlg_faq;
  GtkWidget *scrolledwindow493;
  GtkWidget *textview_faq;

  dlg_faq = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_widget_set_name (dlg_faq, "dlg_faq");
  gtk_object_set_data (GTK_OBJECT (dlg_faq), "dlg_faq", dlg_faq);
  gtk_window_set_position (GTK_WINDOW (dlg_faq), GTK_WIN_POS_MOUSE);
  gtk_window_set_default_size (GTK_WINDOW (dlg_faq), 600, 400);

  scrolledwindow493 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow493, "scrolledwindow493");
  gtk_widget_ref (scrolledwindow493);
  gtk_object_set_data_full (GTK_OBJECT (dlg_faq), "scrolledwindow493", scrolledwindow493,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (scrolledwindow493);
  gtk_container_add (GTK_CONTAINER (dlg_faq), scrolledwindow493);
  gtk_container_set_border_width (GTK_CONTAINER (scrolledwindow493), 2);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow493), GTK_POLICY_NEVER, GTK_POLICY_ALWAYS);

  textview_faq = gtk_text_new (NULL, NULL);
  gtk_widget_set_name (textview_faq, "textview_faq");
  gtk_widget_ref (textview_faq);
  gtk_object_set_data_full (GTK_OBJECT (dlg_faq), "textview_faq", textview_faq,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (textview_faq);
  gtk_container_add (GTK_CONTAINER (scrolledwindow493), textview_faq);
  gtk_widget_set_usize (textview_faq, 240, 100);

  gtk_signal_connect (GTK_OBJECT (dlg_faq), "delete_event",
                      GTK_SIGNAL_FUNC (on_dlg_faq_delete_event),
                      NULL);

  return dlg_faq;
}

GtkWidget*
create_popup_search_list (void)
{
  GtkWidget *popup_search_list;
  GtkAccelGroup *popup_search_list_accels;
  guint tmp_key;
  GtkWidget *popup_search_list_edit_filters;
  GtkWidget *separator25;
  GtkWidget *popup_search_list_stop;
  GtkWidget *popup_search_list_resume;
  GtkWidget *popup_search_list_restart;
  GtkWidget *popup_search_list_duplicate;
  GtkWidget *popup_search_list_close;

  popup_search_list = gtk_menu_new ();
  gtk_widget_set_name (popup_search_list, "popup_search_list");
  gtk_object_set_data (GTK_OBJECT (popup_search_list), "popup_search_list", popup_search_list);
  popup_search_list_accels = gtk_menu_ensure_uline_accel_group (GTK_MENU (popup_search_list));

  popup_search_list_edit_filters = gtk_menu_item_new_with_label ("");
  tmp_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (popup_search_list_edit_filters)->child),
                                   _("_Edit filters"));
  gtk_widget_add_accelerator (popup_search_list_edit_filters, "activate_item", popup_search_list_accels,
                              tmp_key, 0, 0);
  gtk_widget_set_name (popup_search_list_edit_filters, "popup_search_list_edit_filters");
  gtk_widget_ref (popup_search_list_edit_filters);
  gtk_object_set_data_full (GTK_OBJECT (popup_search_list), "popup_search_list_edit_filters", popup_search_list_edit_filters,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (popup_search_list_edit_filters);
  gtk_container_add (GTK_CONTAINER (popup_search_list), popup_search_list_edit_filters);

  separator25 = gtk_menu_item_new ();
  gtk_widget_set_name (separator25, "separator25");
  gtk_widget_ref (separator25);
  gtk_object_set_data_full (GTK_OBJECT (popup_search_list), "separator25", separator25,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (separator25);
  gtk_container_add (GTK_CONTAINER (popup_search_list), separator25);
  gtk_widget_set_sensitive (separator25, FALSE);

  popup_search_list_stop = gtk_menu_item_new_with_label ("");
  tmp_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (popup_search_list_stop)->child),
                                   _("_Stop"));
  gtk_widget_add_accelerator (popup_search_list_stop, "activate_item", popup_search_list_accels,
                              tmp_key, 0, 0);
  gtk_widget_set_name (popup_search_list_stop, "popup_search_list_stop");
  gtk_widget_ref (popup_search_list_stop);
  gtk_object_set_data_full (GTK_OBJECT (popup_search_list), "popup_search_list_stop", popup_search_list_stop,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (popup_search_list_stop);
  gtk_container_add (GTK_CONTAINER (popup_search_list), popup_search_list_stop);

  popup_search_list_resume = gtk_menu_item_new_with_label ("");
  tmp_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (popup_search_list_resume)->child),
                                   _("Resu_me"));
  gtk_widget_add_accelerator (popup_search_list_resume, "activate_item", popup_search_list_accels,
                              tmp_key, 0, 0);
  gtk_widget_set_name (popup_search_list_resume, "popup_search_list_resume");
  gtk_widget_ref (popup_search_list_resume);
  gtk_object_set_data_full (GTK_OBJECT (popup_search_list), "popup_search_list_resume", popup_search_list_resume,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (popup_search_list_resume);
  gtk_container_add (GTK_CONTAINER (popup_search_list), popup_search_list_resume);

  popup_search_list_restart = gtk_menu_item_new_with_label ("");
  tmp_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (popup_search_list_restart)->child),
                                   _("_Restart"));
  gtk_widget_add_accelerator (popup_search_list_restart, "activate_item", popup_search_list_accels,
                              tmp_key, 0, 0);
  gtk_widget_set_name (popup_search_list_restart, "popup_search_list_restart");
  gtk_widget_ref (popup_search_list_restart);
  gtk_object_set_data_full (GTK_OBJECT (popup_search_list), "popup_search_list_restart", popup_search_list_restart,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (popup_search_list_restart);
  gtk_container_add (GTK_CONTAINER (popup_search_list), popup_search_list_restart);

  popup_search_list_duplicate = gtk_menu_item_new_with_label ("");
  tmp_key = gtk_label_parse_uline (GTK_LABEL (GTK_BIN (popup_search_list_duplicate)->child),
                                   _("_Duplicate"));
  gtk_widget_add_accelerator (popup_search_list_duplicate, "activate_item", popup_search_list_accels,
                              tmp_key, 0, 0);
  gtk_widget_set_name (popup_search_list_duplicate, "popup_search_list_duplicate");
  gtk_widget_ref (popup_search_list_duplicate);
  gtk_object_set_data_full (GTK_OBJECT (popup_search_list), "popup_search_list_duplicate", popup_search_list_duplicate,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (popup_search_list_duplicate);
  gtk_container_add (GTK_CONTAINER (popup_search_list), popup_search_list_duplicate);

  popup_search_list_close = gtk_menu_item_new_with_label (_("Close"));
  gtk_widget_set_name (popup_search_list_close, "popup_search_list_close");
  gtk_widget_ref (popup_search_list_close);
  gtk_object_set_data_full (GTK_OBJECT (popup_search_list), "popup_search_list_close", popup_search_list_close,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (popup_search_list_close);
  gtk_container_add (GTK_CONTAINER (popup_search_list), popup_search_list_close);

  return popup_search_list;
}

GtkWidget*
create_dlg_ancient (void)
{
  GtkWidget *dlg_ancient;
  GtkWidget *scrolledwindow494;
  GtkWidget *textview_ancient;

  dlg_ancient = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_widget_set_name (dlg_ancient, "dlg_ancient");
  gtk_object_set_data (GTK_OBJECT (dlg_ancient), "dlg_ancient", dlg_ancient);
  gtk_window_set_position (GTK_WINDOW (dlg_ancient), GTK_WIN_POS_MOUSE);
  gtk_window_set_default_size (GTK_WINDOW (dlg_ancient), 320, 240);

  scrolledwindow494 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow494, "scrolledwindow494");
  gtk_widget_ref (scrolledwindow494);
  gtk_object_set_data_full (GTK_OBJECT (dlg_ancient), "scrolledwindow494", scrolledwindow494,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (scrolledwindow494);
  gtk_container_add (GTK_CONTAINER (dlg_ancient), scrolledwindow494);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow494), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);

  textview_ancient = gtk_text_new (NULL, NULL);
  gtk_widget_set_name (textview_ancient, "textview_ancient");
  gtk_widget_ref (textview_ancient);
  gtk_object_set_data_full (GTK_OBJECT (dlg_ancient), "textview_ancient", textview_ancient,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (textview_ancient);
  gtk_container_add (GTK_CONTAINER (scrolledwindow494), textview_ancient);
  gtk_widget_set_usize (textview_ancient, 240, 100);

  gtk_signal_connect (GTK_OBJECT (dlg_ancient), "delete_event",
                      GTK_SIGNAL_FUNC (on_dlg_ancient_delete_event),
                      NULL);

  return dlg_ancient;
}

GtkWidget*
create_popup_sources (void)
{
  GtkWidget *popup_sources;
  GtkAccelGroup *popup_sources_accels;
  GtkWidget *popup_sources_start_now;
  GtkWidget *popup_sources_pause;
  GtkWidget *popup_sources_resume;
  GtkWidget *popup_sources_queue;
  GtkWidget *popup_sources_forget;
  GtkWidget *separator28;
  GtkWidget *popup_sources_copy_url;
  GtkWidget *popup_sources_browse_host;
  GtkWidget *popup_sources_connect;
  GtkWidget *popup_sources_push;
  GtkWidget *separator26;
  GtkWidget *popup_sources_config_cols;

  popup_sources = gtk_menu_new ();
  gtk_widget_set_name (popup_sources, "popup_sources");
  gtk_object_set_data (GTK_OBJECT (popup_sources), "popup_sources", popup_sources);
  popup_sources_accels = gtk_menu_ensure_uline_accel_group (GTK_MENU (popup_sources));

  popup_sources_start_now = gtk_menu_item_new_with_label (_("Start now"));
  gtk_widget_set_name (popup_sources_start_now, "popup_sources_start_now");
  gtk_widget_ref (popup_sources_start_now);
  gtk_object_set_data_full (GTK_OBJECT (popup_sources), "popup_sources_start_now", popup_sources_start_now,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (popup_sources_start_now);
  gtk_container_add (GTK_CONTAINER (popup_sources), popup_sources_start_now);

  popup_sources_pause = gtk_menu_item_new_with_label (_("Pause"));
  gtk_widget_set_name (popup_sources_pause, "popup_sources_pause");
  gtk_widget_ref (popup_sources_pause);
  gtk_object_set_data_full (GTK_OBJECT (popup_sources), "popup_sources_pause", popup_sources_pause,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (popup_sources_pause);
  gtk_container_add (GTK_CONTAINER (popup_sources), popup_sources_pause);

  popup_sources_resume = gtk_menu_item_new_with_label (_("Resume"));
  gtk_widget_set_name (popup_sources_resume, "popup_sources_resume");
  gtk_widget_ref (popup_sources_resume);
  gtk_object_set_data_full (GTK_OBJECT (popup_sources), "popup_sources_resume", popup_sources_resume,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (popup_sources_resume);
  gtk_container_add (GTK_CONTAINER (popup_sources), popup_sources_resume);

  popup_sources_queue = gtk_menu_item_new_with_label (_("Move back to queue"));
  gtk_widget_set_name (popup_sources_queue, "popup_sources_queue");
  gtk_widget_ref (popup_sources_queue);
  gtk_object_set_data_full (GTK_OBJECT (popup_sources), "popup_sources_queue", popup_sources_queue,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (popup_sources_queue);
  gtk_container_add (GTK_CONTAINER (popup_sources), popup_sources_queue);

  popup_sources_forget = gtk_menu_item_new_with_label (_("Forget"));
  gtk_widget_set_name (popup_sources_forget, "popup_sources_forget");
  gtk_widget_ref (popup_sources_forget);
  gtk_object_set_data_full (GTK_OBJECT (popup_sources), "popup_sources_forget", popup_sources_forget,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (popup_sources_forget);
  gtk_container_add (GTK_CONTAINER (popup_sources), popup_sources_forget);

  separator28 = gtk_menu_item_new ();
  gtk_widget_set_name (separator28, "separator28");
  gtk_widget_ref (separator28);
  gtk_object_set_data_full (GTK_OBJECT (popup_sources), "separator28", separator28,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (separator28);
  gtk_container_add (GTK_CONTAINER (popup_sources), separator28);
  gtk_widget_set_sensitive (separator28, FALSE);

  popup_sources_copy_url = gtk_menu_item_new_with_label (_("Copy URL to clipboard"));
  gtk_widget_set_name (popup_sources_copy_url, "popup_sources_copy_url");
  gtk_widget_ref (popup_sources_copy_url);
  gtk_object_set_data_full (GTK_OBJECT (popup_sources), "popup_sources_copy_url", popup_sources_copy_url,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (popup_sources_copy_url);
  gtk_container_add (GTK_CONTAINER (popup_sources), popup_sources_copy_url);

  popup_sources_browse_host = gtk_menu_item_new_with_label (_("Browse host"));
  gtk_widget_set_name (popup_sources_browse_host, "popup_sources_browse_host");
  gtk_widget_ref (popup_sources_browse_host);
  gtk_object_set_data_full (GTK_OBJECT (popup_sources), "popup_sources_browse_host", popup_sources_browse_host,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (popup_sources_browse_host);
  gtk_container_add (GTK_CONTAINER (popup_sources), popup_sources_browse_host);

  popup_sources_connect = gtk_menu_item_new_with_label (_("Connect to host"));
  gtk_widget_set_name (popup_sources_connect, "popup_sources_connect");
  gtk_widget_ref (popup_sources_connect);
  gtk_object_set_data_full (GTK_OBJECT (popup_sources), "popup_sources_connect", popup_sources_connect,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (popup_sources_connect);
  gtk_container_add (GTK_CONTAINER (popup_sources), popup_sources_connect);

  popup_sources_push = gtk_menu_item_new_with_label (_("Force push mode"));
  gtk_widget_set_name (popup_sources_push, "popup_sources_push");
  gtk_widget_ref (popup_sources_push);
  gtk_object_set_data_full (GTK_OBJECT (popup_sources), "popup_sources_push", popup_sources_push,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (popup_sources_push);
  gtk_container_add (GTK_CONTAINER (popup_sources), popup_sources_push);

  separator26 = gtk_menu_item_new ();
  gtk_widget_set_name (separator26, "separator26");
  gtk_widget_ref (separator26);
  gtk_object_set_data_full (GTK_OBJECT (popup_sources), "separator26", separator26,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (separator26);
  gtk_container_add (GTK_CONTAINER (popup_sources), separator26);
  gtk_widget_set_sensitive (separator26, FALSE);

  popup_sources_config_cols = gtk_menu_item_new_with_label (_("Configure columns"));
  gtk_widget_set_name (popup_sources_config_cols, "popup_sources_config_cols");
  gtk_widget_ref (popup_sources_config_cols);
  gtk_object_set_data_full (GTK_OBJECT (popup_sources), "popup_sources_config_cols", popup_sources_config_cols,
                            (GtkDestroyNotify) gtk_widget_unref);
  gtk_widget_show (popup_sources_config_cols);
  gtk_container_add (GTK_CONTAINER (popup_sources), popup_sources_config_cols);

  gtk_signal_connect (GTK_OBJECT (popup_sources_start_now), "activate",
                      GTK_SIGNAL_FUNC (on_popup_sources_start_now_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (popup_sources_pause), "activate",
                      GTK_SIGNAL_FUNC (on_popup_sources_pause_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (popup_sources_resume), "activate",
                      GTK_SIGNAL_FUNC (on_popup_sources_resume_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (popup_sources_queue), "activate",
                      GTK_SIGNAL_FUNC (on_popup_sources_queue_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (popup_sources_forget), "activate",
                      GTK_SIGNAL_FUNC (on_popup_sources_forget_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (popup_sources_copy_url), "activate",
                      GTK_SIGNAL_FUNC (on_popup_sources_copy_url_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (popup_sources_browse_host), "activate",
                      GTK_SIGNAL_FUNC (on_popup_sources_browse_host_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (popup_sources_connect), "activate",
                      GTK_SIGNAL_FUNC (on_popup_sources_connect_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (popup_sources_push), "activate",
                      GTK_SIGNAL_FUNC (on_popup_sources_push_activate),
                      NULL);
  gtk_signal_connect (GTK_OBJECT (popup_sources_config_cols), "activate",
                      GTK_SIGNAL_FUNC (on_popup_sources_config_cols_activate),
                      NULL);

  return popup_sources;
}

