/*
 * DO NOT EDIT THIS FILE - it is generated by Glade.
 */

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <string.h>
#include <stdio.h>

#include <gdk/gdkkeysyms.h>
#include <gtk/gtk.h>

#include "callbacks.h"
#include "interface-glade.h"
#include "support-glade.h"

#define GLADE_HOOKUP_OBJECT(component,widget,name) \
  g_object_set_data_full (G_OBJECT (component), name, \
    gtk_widget_ref (widget), (GDestroyNotify) gtk_widget_unref)

#define GLADE_HOOKUP_OBJECT_NO_REF(component,widget,name) \
  g_object_set_data (G_OBJECT (component), name, widget)

GtkWidget*
create_popup_downloads (void)
{
  GtkWidget *popup_downloads;
  GtkWidget *popup_downloads_copy_magnet;
  GtkWidget *image2142;
  GtkWidget *popup_downloads_start_now;
  GtkWidget *image2143;
  GtkWidget *popup_downloads_pause;
  GtkWidget *popup_downloads_resume;
  GtkWidget *image2144;
  GtkWidget *popup_downloads_queue;
  GtkWidget *image2145;
  GtkWidget *separator32;
  GtkWidget *popup_downloads_abort;
  GtkWidget *image2146;
  GtkWidget *separator33;
  GtkWidget *popup_downloads_config_cols;
  GtkWidget *image2147;

  popup_downloads = gtk_menu_new ();
  gtk_widget_set_name (popup_downloads, "popup_downloads");

  popup_downloads_copy_magnet = gtk_image_menu_item_new_with_mnemonic (_("Copy magnet to clipboard"));
  gtk_widget_set_name (popup_downloads_copy_magnet, "popup_downloads_copy_magnet");
  gtk_widget_show (popup_downloads_copy_magnet);
  gtk_container_add (GTK_CONTAINER (popup_downloads), popup_downloads_copy_magnet);

  image2142 = create_pixmap (popup_downloads, "magnet.16x16.png");
  gtk_widget_set_name (image2142, "image2142");
  gtk_widget_show (image2142);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (popup_downloads_copy_magnet), image2142);

  popup_downloads_start_now = gtk_image_menu_item_new_with_mnemonic (_("Start now"));
  gtk_widget_set_name (popup_downloads_start_now, "popup_downloads_start_now");
  gtk_widget_show (popup_downloads_start_now);
  gtk_container_add (GTK_CONTAINER (popup_downloads), popup_downloads_start_now);

  image2143 = gtk_image_new_from_stock ("gtk-connect", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image2143, "image2143");
  gtk_widget_show (image2143);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (popup_downloads_start_now), image2143);

  popup_downloads_pause = gtk_menu_item_new_with_mnemonic (_("Pause"));
  gtk_widget_set_name (popup_downloads_pause, "popup_downloads_pause");
  gtk_widget_show (popup_downloads_pause);
  gtk_container_add (GTK_CONTAINER (popup_downloads), popup_downloads_pause);

  popup_downloads_resume = gtk_image_menu_item_new_with_mnemonic (_("Resume"));
  gtk_widget_set_name (popup_downloads_resume, "popup_downloads_resume");
  gtk_widget_show (popup_downloads_resume);
  gtk_container_add (GTK_CONTAINER (popup_downloads), popup_downloads_resume);

  image2144 = gtk_image_new_from_stock ("gtk-disconnect", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image2144, "image2144");
  gtk_widget_show (image2144);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (popup_downloads_resume), image2144);

  popup_downloads_queue = gtk_image_menu_item_new_with_mnemonic (_("Move back to queue"));
  gtk_widget_set_name (popup_downloads_queue, "popup_downloads_queue");
  gtk_widget_show (popup_downloads_queue);
  gtk_container_add (GTK_CONTAINER (popup_downloads), popup_downloads_queue);

  image2145 = gtk_image_new_from_stock ("gtk-redo", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image2145, "image2145");
  gtk_widget_show (image2145);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (popup_downloads_queue), image2145);

  separator32 = gtk_separator_menu_item_new ();
  gtk_widget_set_name (separator32, "separator32");
  gtk_widget_show (separator32);
  gtk_container_add (GTK_CONTAINER (popup_downloads), separator32);
  gtk_widget_set_sensitive (separator32, FALSE);

  popup_downloads_abort = gtk_image_menu_item_new_with_mnemonic (_("Abort"));
  gtk_widget_set_name (popup_downloads_abort, "popup_downloads_abort");
  gtk_widget_show (popup_downloads_abort);
  gtk_container_add (GTK_CONTAINER (popup_downloads), popup_downloads_abort);

  image2146 = gtk_image_new_from_stock ("gtk-stop", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image2146, "image2146");
  gtk_widget_show (image2146);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (popup_downloads_abort), image2146);

  separator33 = gtk_separator_menu_item_new ();
  gtk_widget_set_name (separator33, "separator33");
  gtk_widget_show (separator33);
  gtk_container_add (GTK_CONTAINER (popup_downloads), separator33);
  gtk_widget_set_sensitive (separator33, FALSE);

  popup_downloads_config_cols = gtk_image_menu_item_new_with_mnemonic (_("Configure columns"));
  gtk_widget_set_name (popup_downloads_config_cols, "popup_downloads_config_cols");
  gtk_widget_show (popup_downloads_config_cols);
  gtk_container_add (GTK_CONTAINER (popup_downloads), popup_downloads_config_cols);

  image2147 = gtk_image_new_from_stock ("gtk-preferences", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image2147, "image2147");
  gtk_widget_show (image2147);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (popup_downloads_config_cols), image2147);

  g_signal_connect ((gpointer) popup_downloads_copy_magnet, "activate",
                    G_CALLBACK (on_popup_downloads_copy_magnet_activate),
                    NULL);
  g_signal_connect ((gpointer) popup_downloads_start_now, "activate",
                    G_CALLBACK (on_popup_downloads_start_now_activate),
                    NULL);
  g_signal_connect ((gpointer) popup_downloads_pause, "activate",
                    G_CALLBACK (on_popup_downloads_pause_activate),
                    NULL);
  g_signal_connect ((gpointer) popup_downloads_resume, "activate",
                    G_CALLBACK (on_popup_downloads_resume_activate),
                    NULL);
  g_signal_connect ((gpointer) popup_downloads_queue, "activate",
                    G_CALLBACK (on_popup_downloads_queue_activate),
                    NULL);
  g_signal_connect ((gpointer) popup_downloads_abort, "activate",
                    G_CALLBACK (on_popup_downloads_abort_activate),
                    NULL);
  g_signal_connect ((gpointer) popup_downloads_config_cols, "activate",
                    G_CALLBACK (on_popup_downloads_config_cols_activate),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (popup_downloads, popup_downloads, "popup_downloads");
  GLADE_HOOKUP_OBJECT (popup_downloads, popup_downloads_copy_magnet, "popup_downloads_copy_magnet");
  GLADE_HOOKUP_OBJECT (popup_downloads, image2142, "image2142");
  GLADE_HOOKUP_OBJECT (popup_downloads, popup_downloads_start_now, "popup_downloads_start_now");
  GLADE_HOOKUP_OBJECT (popup_downloads, image2143, "image2143");
  GLADE_HOOKUP_OBJECT (popup_downloads, popup_downloads_pause, "popup_downloads_pause");
  GLADE_HOOKUP_OBJECT (popup_downloads, popup_downloads_resume, "popup_downloads_resume");
  GLADE_HOOKUP_OBJECT (popup_downloads, image2144, "image2144");
  GLADE_HOOKUP_OBJECT (popup_downloads, popup_downloads_queue, "popup_downloads_queue");
  GLADE_HOOKUP_OBJECT (popup_downloads, image2145, "image2145");
  GLADE_HOOKUP_OBJECT (popup_downloads, separator32, "separator32");
  GLADE_HOOKUP_OBJECT (popup_downloads, popup_downloads_abort, "popup_downloads_abort");
  GLADE_HOOKUP_OBJECT (popup_downloads, image2146, "image2146");
  GLADE_HOOKUP_OBJECT (popup_downloads, separator33, "separator33");
  GLADE_HOOKUP_OBJECT (popup_downloads, popup_downloads_config_cols, "popup_downloads_config_cols");
  GLADE_HOOKUP_OBJECT (popup_downloads, image2147, "image2147");

  return popup_downloads;
}

GtkWidget*
create_popup_search (void)
{
  GtkWidget *popup_search;
  GtkWidget *popup_search_download;
  GtkWidget *image2257;
  GtkWidget *popup_search_browse_host;
  GtkWidget *image2258;
  GtkWidget *popup_search_copy_magnet;
  GtkWidget *image2259;
  GtkWidget *separator14;
  GtkWidget *popup_search_stop;
  GtkWidget *image2260;
  GtkWidget *popup_search_resume;
  GtkWidget *image2261;
  GtkWidget *popup_search_restart;
  GtkWidget *image2262;
  GtkWidget *separator15;
  GtkWidget *popup_search_expand_all;
  GtkWidget *image2263;
  GtkWidget *popup_search_collapse_all;
  GtkWidget *image2264;
  GtkWidget *separator2;
  GtkWidget *item3;
  GtkWidget *image2265;
  GtkWidget *item3_menu;
  GtkWidget *popup_search_toggle_tabs;
  GtkWidget *image2266;
  GtkWidget *popup_search_config_cols;
  GtkWidget *image2267;
  GtkWidget *popup_search_sort_defaults;
  GtkWidget *image2268;

  popup_search = gtk_menu_new ();
  gtk_widget_set_name (popup_search, "popup_search");

  popup_search_download = gtk_image_menu_item_new_with_mnemonic (_("Download"));
  gtk_widget_set_name (popup_search_download, "popup_search_download");
  gtk_widget_show (popup_search_download);
  gtk_container_add (GTK_CONTAINER (popup_search), popup_search_download);

  image2257 = gtk_image_new_from_stock ("gtk-save", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image2257, "image2257");
  gtk_widget_show (image2257);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (popup_search_download), image2257);

  popup_search_browse_host = gtk_image_menu_item_new_with_mnemonic (_("Browse host"));
  gtk_widget_set_name (popup_search_browse_host, "popup_search_browse_host");
  gtk_widget_show (popup_search_browse_host);
  gtk_container_add (GTK_CONTAINER (popup_search), popup_search_browse_host);

  image2258 = gtk_image_new_from_stock ("gtk-zoom-in", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image2258, "image2258");
  gtk_widget_show (image2258);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (popup_search_browse_host), image2258);

  popup_search_copy_magnet = gtk_image_menu_item_new_with_mnemonic (_("Copy magnet to clipboard"));
  gtk_widget_set_name (popup_search_copy_magnet, "popup_search_copy_magnet");
  gtk_widget_show (popup_search_copy_magnet);
  gtk_container_add (GTK_CONTAINER (popup_search), popup_search_copy_magnet);

  image2259 = create_pixmap (popup_search, "magnet.16x16.png");
  gtk_widget_set_name (image2259, "image2259");
  gtk_widget_show (image2259);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (popup_search_copy_magnet), image2259);

  separator14 = gtk_separator_menu_item_new ();
  gtk_widget_set_name (separator14, "separator14");
  gtk_widget_show (separator14);
  gtk_container_add (GTK_CONTAINER (popup_search), separator14);
  gtk_widget_set_sensitive (separator14, FALSE);

  popup_search_stop = gtk_image_menu_item_new_with_mnemonic (_("Stop"));
  gtk_widget_set_name (popup_search_stop, "popup_search_stop");
  gtk_widget_show (popup_search_stop);
  gtk_container_add (GTK_CONTAINER (popup_search), popup_search_stop);

  image2260 = gtk_image_new_from_stock ("gtk-stop", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image2260, "image2260");
  gtk_widget_show (image2260);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (popup_search_stop), image2260);

  popup_search_resume = gtk_image_menu_item_new_with_mnemonic (_("Resume"));
  gtk_widget_set_name (popup_search_resume, "popup_search_resume");
  gtk_widget_show (popup_search_resume);
  gtk_container_add (GTK_CONTAINER (popup_search), popup_search_resume);

  image2261 = gtk_image_new_from_stock ("gtk-media-forward", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image2261, "image2261");
  gtk_widget_show (image2261);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (popup_search_resume), image2261);

  popup_search_restart = gtk_image_menu_item_new_with_mnemonic (_("Restart"));
  gtk_widget_set_name (popup_search_restart, "popup_search_restart");
  gtk_widget_show (popup_search_restart);
  gtk_container_add (GTK_CONTAINER (popup_search), popup_search_restart);

  image2262 = gtk_image_new_from_stock ("gtk-redo", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image2262, "image2262");
  gtk_widget_show (image2262);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (popup_search_restart), image2262);

  separator15 = gtk_separator_menu_item_new ();
  gtk_widget_set_name (separator15, "separator15");
  gtk_widget_show (separator15);
  gtk_container_add (GTK_CONTAINER (popup_search), separator15);
  gtk_widget_set_sensitive (separator15, FALSE);

  popup_search_expand_all = gtk_image_menu_item_new_with_mnemonic (_("Expand all"));
  gtk_widget_set_name (popup_search_expand_all, "popup_search_expand_all");
  gtk_widget_show (popup_search_expand_all);
  gtk_container_add (GTK_CONTAINER (popup_search), popup_search_expand_all);

  image2263 = gtk_image_new_from_stock ("gtk-add", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image2263, "image2263");
  gtk_widget_show (image2263);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (popup_search_expand_all), image2263);

  popup_search_collapse_all = gtk_image_menu_item_new_with_mnemonic (_("Collapse all"));
  gtk_widget_set_name (popup_search_collapse_all, "popup_search_collapse_all");
  gtk_widget_show (popup_search_collapse_all);
  gtk_container_add (GTK_CONTAINER (popup_search), popup_search_collapse_all);

  image2264 = gtk_image_new_from_stock ("gtk-remove", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image2264, "image2264");
  gtk_widget_show (image2264);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (popup_search_collapse_all), image2264);

  separator2 = gtk_separator_menu_item_new ();
  gtk_widget_set_name (separator2, "separator2");
  gtk_widget_show (separator2);
  gtk_container_add (GTK_CONTAINER (popup_search), separator2);
  gtk_widget_set_sensitive (separator2, FALSE);

  item3 = gtk_image_menu_item_new_with_mnemonic (_("Preferences"));
  gtk_widget_set_name (item3, "item3");
  gtk_widget_show (item3);
  gtk_container_add (GTK_CONTAINER (popup_search), item3);

  image2265 = gtk_image_new_from_stock ("gtk-properties", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image2265, "image2265");
  gtk_widget_show (image2265);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item3), image2265);

  item3_menu = gtk_menu_new ();
  gtk_widget_set_name (item3_menu, "item3_menu");
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (item3), item3_menu);

  popup_search_toggle_tabs = gtk_image_menu_item_new_with_mnemonic (_("Show tabs"));
  gtk_widget_set_name (popup_search_toggle_tabs, "popup_search_toggle_tabs");
  gtk_widget_show (popup_search_toggle_tabs);
  gtk_container_add (GTK_CONTAINER (item3_menu), popup_search_toggle_tabs);

  image2266 = gtk_image_new_from_stock ("gtk-index", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image2266, "image2266");
  gtk_widget_show (image2266);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (popup_search_toggle_tabs), image2266);

  popup_search_config_cols = gtk_image_menu_item_new_with_mnemonic (_("Configure columns"));
  gtk_widget_set_name (popup_search_config_cols, "popup_search_config_cols");
  gtk_widget_show (popup_search_config_cols);
  gtk_container_add (GTK_CONTAINER (item3_menu), popup_search_config_cols);

  image2267 = gtk_image_new_from_stock ("gtk-preferences", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image2267, "image2267");
  gtk_widget_show (image2267);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (popup_search_config_cols), image2267);

  popup_search_sort_defaults = gtk_image_menu_item_new_with_mnemonic (_("Make current sorting default"));
  gtk_widget_set_name (popup_search_sort_defaults, "popup_search_sort_defaults");
  gtk_widget_show (popup_search_sort_defaults);
  gtk_container_add (GTK_CONTAINER (item3_menu), popup_search_sort_defaults);

  image2268 = gtk_image_new_from_stock ("gtk-media-record", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image2268, "image2268");
  gtk_widget_show (image2268);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (popup_search_sort_defaults), image2268);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (popup_search, popup_search, "popup_search");
  GLADE_HOOKUP_OBJECT (popup_search, popup_search_download, "popup_search_download");
  GLADE_HOOKUP_OBJECT (popup_search, image2257, "image2257");
  GLADE_HOOKUP_OBJECT (popup_search, popup_search_browse_host, "popup_search_browse_host");
  GLADE_HOOKUP_OBJECT (popup_search, image2258, "image2258");
  GLADE_HOOKUP_OBJECT (popup_search, popup_search_copy_magnet, "popup_search_copy_magnet");
  GLADE_HOOKUP_OBJECT (popup_search, image2259, "image2259");
  GLADE_HOOKUP_OBJECT (popup_search, separator14, "separator14");
  GLADE_HOOKUP_OBJECT (popup_search, popup_search_stop, "popup_search_stop");
  GLADE_HOOKUP_OBJECT (popup_search, image2260, "image2260");
  GLADE_HOOKUP_OBJECT (popup_search, popup_search_resume, "popup_search_resume");
  GLADE_HOOKUP_OBJECT (popup_search, image2261, "image2261");
  GLADE_HOOKUP_OBJECT (popup_search, popup_search_restart, "popup_search_restart");
  GLADE_HOOKUP_OBJECT (popup_search, image2262, "image2262");
  GLADE_HOOKUP_OBJECT (popup_search, separator15, "separator15");
  GLADE_HOOKUP_OBJECT (popup_search, popup_search_expand_all, "popup_search_expand_all");
  GLADE_HOOKUP_OBJECT (popup_search, image2263, "image2263");
  GLADE_HOOKUP_OBJECT (popup_search, popup_search_collapse_all, "popup_search_collapse_all");
  GLADE_HOOKUP_OBJECT (popup_search, image2264, "image2264");
  GLADE_HOOKUP_OBJECT (popup_search, separator2, "separator2");
  GLADE_HOOKUP_OBJECT (popup_search, item3, "item3");
  GLADE_HOOKUP_OBJECT (popup_search, image2265, "image2265");
  GLADE_HOOKUP_OBJECT (popup_search, item3_menu, "item3_menu");
  GLADE_HOOKUP_OBJECT (popup_search, popup_search_toggle_tabs, "popup_search_toggle_tabs");
  GLADE_HOOKUP_OBJECT (popup_search, image2266, "image2266");
  GLADE_HOOKUP_OBJECT (popup_search, popup_search_config_cols, "popup_search_config_cols");
  GLADE_HOOKUP_OBJECT (popup_search, image2267, "image2267");
  GLADE_HOOKUP_OBJECT (popup_search, popup_search_sort_defaults, "popup_search_sort_defaults");
  GLADE_HOOKUP_OBJECT (popup_search, image2268, "image2268");

  return popup_search;
}

GtkWidget*
create_popup_monitor (void)
{
  GtkWidget *popup_monitor;
  GtkWidget *popup_monitor_add_search;
  GtkWidget *image758;
  GtkWidget *popup_monitor_copy_to_clipboard;
  GtkWidget *image759;

  popup_monitor = gtk_menu_new ();
  gtk_widget_set_name (popup_monitor, "popup_monitor");

  popup_monitor_add_search = gtk_image_menu_item_new_with_mnemonic (_("Add as search"));
  gtk_widget_set_name (popup_monitor_add_search, "popup_monitor_add_search");
  gtk_widget_show (popup_monitor_add_search);
  gtk_container_add (GTK_CONTAINER (popup_monitor), popup_monitor_add_search);

  image758 = gtk_image_new_from_stock ("gtk-find", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image758, "image758");
  gtk_widget_show (image758);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (popup_monitor_add_search), image758);

  popup_monitor_copy_to_clipboard = gtk_image_menu_item_new_with_mnemonic (_("Copy to clipboard"));
  gtk_widget_set_name (popup_monitor_copy_to_clipboard, "popup_monitor_copy_to_clipboard");
  gtk_widget_show (popup_monitor_copy_to_clipboard);
  gtk_container_add (GTK_CONTAINER (popup_monitor), popup_monitor_copy_to_clipboard);

  image759 = gtk_image_new_from_stock ("gtk-copy", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image759, "image759");
  gtk_widget_show (image759);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (popup_monitor_copy_to_clipboard), image759);

  g_signal_connect ((gpointer) popup_monitor_add_search, "activate",
                    G_CALLBACK (on_popup_monitor_add_search_activate),
                    NULL);
  g_signal_connect ((gpointer) popup_monitor_copy_to_clipboard, "activate",
                    G_CALLBACK (on_popup_monitor_copy_to_clipboard_activate),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (popup_monitor, popup_monitor, "popup_monitor");
  GLADE_HOOKUP_OBJECT (popup_monitor, popup_monitor_add_search, "popup_monitor_add_search");
  GLADE_HOOKUP_OBJECT (popup_monitor, image758, "image758");
  GLADE_HOOKUP_OBJECT (popup_monitor, popup_monitor_copy_to_clipboard, "popup_monitor_copy_to_clipboard");
  GLADE_HOOKUP_OBJECT (popup_monitor, image759, "image759");

  return popup_monitor;
}

GtkWidget*
create_popup_uploads (void)
{
  GtkWidget *popup_uploads;
  GtkWidget *popup_uploads_config_cols;
  GtkWidget *image1242;
  GtkWidget *popup_uploads_browse_host;
  GtkWidget *image1243;

  popup_uploads = gtk_menu_new ();
  gtk_widget_set_name (popup_uploads, "popup_uploads");

  popup_uploads_config_cols = gtk_image_menu_item_new_with_mnemonic (_("Configure columns"));
  gtk_widget_set_name (popup_uploads_config_cols, "popup_uploads_config_cols");
  gtk_widget_show (popup_uploads_config_cols);
  gtk_container_add (GTK_CONTAINER (popup_uploads), popup_uploads_config_cols);

  image1242 = gtk_image_new_from_stock ("gtk-preferences", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image1242, "image1242");
  gtk_widget_show (image1242);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (popup_uploads_config_cols), image1242);

  popup_uploads_browse_host = gtk_image_menu_item_new_with_mnemonic (_("Browse Host"));
  gtk_widget_set_name (popup_uploads_browse_host, "popup_uploads_browse_host");
  gtk_widget_show (popup_uploads_browse_host);
  gtk_container_add (GTK_CONTAINER (popup_uploads), popup_uploads_browse_host);

  image1243 = gtk_image_new_from_stock ("gtk-zoom-in", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image1243, "image1243");
  gtk_widget_show (image1243);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (popup_uploads_browse_host), image1243);

  g_signal_connect ((gpointer) popup_uploads_config_cols, "activate",
                    G_CALLBACK (on_popup_uploads_config_cols_activate),
                    NULL);
  g_signal_connect ((gpointer) popup_uploads_browse_host, "activate",
                    G_CALLBACK (on_popup_uploads_browse_host_activate),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (popup_uploads, popup_uploads, "popup_uploads");
  GLADE_HOOKUP_OBJECT (popup_uploads, popup_uploads_config_cols, "popup_uploads_config_cols");
  GLADE_HOOKUP_OBJECT (popup_uploads, image1242, "image1242");
  GLADE_HOOKUP_OBJECT (popup_uploads, popup_uploads_browse_host, "popup_uploads_browse_host");
  GLADE_HOOKUP_OBJECT (popup_uploads, image1243, "image1243");

  return popup_uploads;
}

GtkWidget*
create_dlg_filters (void)
{
  GtkWidget *dlg_filters;
  GdkPixbuf *dlg_filters_icon_pixbuf;
  GtkWidget *vbox_filter_main;
  GtkWidget *hpaned_filter_main;
  GtkWidget *vbox59;
  GtkWidget *hbox111;
  GtkWidget *entry_filter_new;
  GtkWidget *button_filter_create;
  GtkWidget *alignment113;
  GtkWidget *hbox9303;
  GtkWidget *image761;
  GtkWidget *label958;
  GtkWidget *scrolledwindow34;
  GtkWidget *treeview_filter_filters;
  GtkWidget *hseparator4;
  GtkWidget *vbox32;
  GtkWidget *hbox97;
  GtkWidget *label221;
  GtkWidget *entry_filter_name;
  GtkWidget *checkbutton_filter_enabled;
  GtkWidget *button_filter_remove;
  GtkWidget *alignment112;
  GtkWidget *hbox9302;
  GtkWidget *image760;
  GtkWidget *label957;
  GtkWidget *scrolledwindow35;
  GtkWidget *treeview_filter_rules;
  GtkWidget *hbox125;
  GtkWidget *button_filter_clear;
  GtkWidget *button_filter_reset_all_rules;
  GtkWidget *button_filter_reset;
  GtkWidget *button_filter_reset_all;
  GtkWidget *hseparator6;
  GtkWidget *notebook_filter_detail;
  GtkWidget *empty_notebook_page;
  GtkWidget *label591;
  GtkWidget *hseparator5;
  GtkWidget *hbox103;
  GtkWidget *button_filter_apply;
  GtkWidget *button_filter_revert;
  GtkWidget *alignment45;
  GtkWidget *hbox177;
  GtkWidget *image77;
  GtkWidget *label442;
  GtkWidget *button_filter_ok;
  GtkWidget *button_filter_cancel;
  GtkTooltips *tooltips;

  tooltips = gtk_tooltips_new ();

  dlg_filters = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_widget_set_name (dlg_filters, "dlg_filters");
  gtk_window_set_title (GTK_WINDOW (dlg_filters), _("Ruleset editor"));
  gtk_window_set_position (GTK_WINDOW (dlg_filters), GTK_WIN_POS_MOUSE);
  gtk_window_set_default_size (GTK_WINDOW (dlg_filters), 450, 300);
  dlg_filters_icon_pixbuf = create_pixbuf ("icon.48x48.xpm");
  if (dlg_filters_icon_pixbuf)
    {
      gtk_window_set_icon (GTK_WINDOW (dlg_filters), dlg_filters_icon_pixbuf);
      g_object_unref (dlg_filters_icon_pixbuf);
    }

  vbox_filter_main = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox_filter_main, "vbox_filter_main");
  gtk_widget_show (vbox_filter_main);
  gtk_container_add (GTK_CONTAINER (dlg_filters), vbox_filter_main);

  hpaned_filter_main = gtk_hpaned_new ();
  gtk_widget_set_name (hpaned_filter_main, "hpaned_filter_main");
  gtk_widget_show (hpaned_filter_main);
  gtk_box_pack_start (GTK_BOX (vbox_filter_main), hpaned_filter_main, TRUE, TRUE, 0);

  vbox59 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox59, "vbox59");
  gtk_widget_show (vbox59);
  gtk_paned_pack1 (GTK_PANED (hpaned_filter_main), vbox59, FALSE, TRUE);

  hbox111 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox111, "hbox111");
  gtk_widget_show (hbox111);
  gtk_box_pack_start (GTK_BOX (vbox59), hbox111, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (hbox111), 2);

  entry_filter_new = gtk_entry_new ();
  gtk_widget_set_name (entry_filter_new, "entry_filter_new");
  gtk_widget_show (entry_filter_new);
  gtk_box_pack_start (GTK_BOX (hbox111), entry_filter_new, TRUE, TRUE, 0);

  button_filter_create = gtk_button_new ();
  gtk_widget_set_name (button_filter_create, "button_filter_create");
  gtk_widget_show (button_filter_create);
  gtk_box_pack_start (GTK_BOX (hbox111), button_filter_create, FALSE, FALSE, 0);

  alignment113 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment113, "alignment113");
  gtk_widget_show (alignment113);
  gtk_container_add (GTK_CONTAINER (button_filter_create), alignment113);

  hbox9303 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox9303, "hbox9303");
  gtk_widget_show (hbox9303);
  gtk_container_add (GTK_CONTAINER (alignment113), hbox9303);

  image761 = gtk_image_new_from_stock ("gtk-new", GTK_ICON_SIZE_BUTTON);
  gtk_widget_set_name (image761, "image761");
  gtk_widget_show (image761);
  gtk_box_pack_start (GTK_BOX (hbox9303), image761, FALSE, FALSE, 0);

  label958 = gtk_label_new_with_mnemonic (_("_Create filter"));
  gtk_widget_set_name (label958, "label958");
  gtk_widget_show (label958);
  gtk_box_pack_start (GTK_BOX (hbox9303), label958, FALSE, FALSE, 0);

  scrolledwindow34 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow34, "scrolledwindow34");
  gtk_widget_show (scrolledwindow34);
  gtk_box_pack_start (GTK_BOX (vbox59), scrolledwindow34, TRUE, TRUE, 0);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow34), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolledwindow34), GTK_SHADOW_IN);

  treeview_filter_filters = gtk_tree_view_new ();
  gtk_widget_set_name (treeview_filter_filters, "treeview_filter_filters");
  gtk_widget_show (treeview_filter_filters);
  gtk_container_add (GTK_CONTAINER (scrolledwindow34), treeview_filter_filters);

  hseparator4 = gtk_hseparator_new ();
  gtk_widget_set_name (hseparator4, "hseparator4");
  gtk_widget_show (hseparator4);
  gtk_box_pack_start (GTK_BOX (vbox59), hseparator4, FALSE, TRUE, 0);

  vbox32 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox32, "vbox32");
  gtk_widget_show (vbox32);
  gtk_paned_pack2 (GTK_PANED (hpaned_filter_main), vbox32, TRUE, TRUE);

  hbox97 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox97, "hbox97");
  gtk_widget_show (hbox97);
  gtk_box_pack_start (GTK_BOX (vbox32), hbox97, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (hbox97), 2);

  label221 = gtk_label_new (_("Filter"));
  gtk_widget_set_name (label221, "label221");
  gtk_widget_show (label221);
  gtk_box_pack_start (GTK_BOX (hbox97), label221, FALSE, FALSE, 0);
  gtk_label_set_justify (GTK_LABEL (label221), GTK_JUSTIFY_CENTER);

  entry_filter_name = gtk_entry_new ();
  gtk_widget_set_name (entry_filter_name, "entry_filter_name");
  gtk_widget_show (entry_filter_name);
  gtk_box_pack_start (GTK_BOX (hbox97), entry_filter_name, TRUE, TRUE, 0);
  gtk_editable_set_editable (GTK_EDITABLE (entry_filter_name), FALSE);

  checkbutton_filter_enabled = gtk_check_button_new_with_mnemonic (_("enabled"));
  gtk_widget_set_name (checkbutton_filter_enabled, "checkbutton_filter_enabled");
  gtk_widget_show (checkbutton_filter_enabled);
  gtk_box_pack_start (GTK_BOX (hbox97), checkbutton_filter_enabled, FALSE, FALSE, 0);

  button_filter_remove = gtk_button_new ();
  gtk_widget_set_name (button_filter_remove, "button_filter_remove");
  gtk_widget_show (button_filter_remove);
  gtk_box_pack_start (GTK_BOX (hbox97), button_filter_remove, FALSE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, button_filter_remove, _("A filter cannot be removed if it is bound to a search or if it is in use (used as a target in a rule)."), NULL);

  alignment112 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment112, "alignment112");
  gtk_widget_show (alignment112);
  gtk_container_add (GTK_CONTAINER (button_filter_remove), alignment112);

  hbox9302 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox9302, "hbox9302");
  gtk_widget_show (hbox9302);
  gtk_container_add (GTK_CONTAINER (alignment112), hbox9302);

  image760 = gtk_image_new_from_stock ("gtk-delete", GTK_ICON_SIZE_BUTTON);
  gtk_widget_set_name (image760, "image760");
  gtk_widget_show (image760);
  gtk_box_pack_start (GTK_BOX (hbox9302), image760, FALSE, FALSE, 0);

  label957 = gtk_label_new_with_mnemonic (_("_Remove filter"));
  gtk_widget_set_name (label957, "label957");
  gtk_widget_show (label957);
  gtk_box_pack_start (GTK_BOX (hbox9302), label957, FALSE, FALSE, 0);

  scrolledwindow35 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow35, "scrolledwindow35");
  gtk_widget_show (scrolledwindow35);
  gtk_box_pack_start (GTK_BOX (vbox32), scrolledwindow35, TRUE, TRUE, 0);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow35), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolledwindow35), GTK_SHADOW_IN);

  treeview_filter_rules = gtk_tree_view_new ();
  gtk_widget_set_name (treeview_filter_rules, "treeview_filter_rules");
  gtk_widget_show (treeview_filter_rules);
  gtk_container_add (GTK_CONTAINER (scrolledwindow35), treeview_filter_rules);

  hbox125 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox125, "hbox125");
  gtk_widget_show (hbox125);
  gtk_box_pack_start (GTK_BOX (vbox32), hbox125, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (hbox125), 2);

  button_filter_clear = gtk_button_new_with_mnemonic (_("Remove all rules\nfrom this filter"));
  gtk_widget_set_name (button_filter_clear, "button_filter_clear");
  gtk_widget_show (button_filter_clear);
  gtk_box_pack_start (GTK_BOX (hbox125), button_filter_clear, FALSE, FALSE, 0);

  button_filter_reset_all_rules = gtk_button_new_with_mnemonic (_("Reset all rule stats\nin this filter"));
  gtk_widget_set_name (button_filter_reset_all_rules, "button_filter_reset_all_rules");
  gtk_widget_show (button_filter_reset_all_rules);
  gtk_box_pack_start (GTK_BOX (hbox125), button_filter_reset_all_rules, FALSE, FALSE, 0);

  button_filter_reset = gtk_button_new_with_mnemonic (_("Reset filter stats\nfor this filter"));
  gtk_widget_set_name (button_filter_reset, "button_filter_reset");
  gtk_widget_show (button_filter_reset);
  gtk_box_pack_start (GTK_BOX (hbox125), button_filter_reset, FALSE, FALSE, 0);

  button_filter_reset_all = gtk_button_new_with_mnemonic (_("Reset filter stats\nfor all filters"));
  gtk_widget_set_name (button_filter_reset_all, "button_filter_reset_all");
  gtk_widget_show (button_filter_reset_all);
  gtk_box_pack_start (GTK_BOX (hbox125), button_filter_reset_all, FALSE, FALSE, 0);

  hseparator6 = gtk_hseparator_new ();
  gtk_widget_set_name (hseparator6, "hseparator6");
  gtk_widget_show (hseparator6);
  gtk_box_pack_start (GTK_BOX (vbox32), hseparator6, FALSE, TRUE, 0);

  notebook_filter_detail = gtk_notebook_new ();
  gtk_widget_set_name (notebook_filter_detail, "notebook_filter_detail");
  gtk_widget_show (notebook_filter_detail);
  gtk_box_pack_start (GTK_BOX (vbox32), notebook_filter_detail, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (notebook_filter_detail), 2);
  gtk_notebook_set_show_border (GTK_NOTEBOOK (notebook_filter_detail), FALSE);

  empty_notebook_page = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (empty_notebook_page);
  gtk_container_add (GTK_CONTAINER (notebook_filter_detail), empty_notebook_page);

  label591 = gtk_label_new ("");
  gtk_widget_set_name (label591, "label591");
  gtk_widget_show (label591);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_filter_detail), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_filter_detail), 0), label591);

  hseparator5 = gtk_hseparator_new ();
  gtk_widget_set_name (hseparator5, "hseparator5");
  gtk_widget_show (hseparator5);
  gtk_box_pack_start (GTK_BOX (vbox_filter_main), hseparator5, FALSE, TRUE, 4);

  hbox103 = gtk_hbox_new (TRUE, 4);
  gtk_widget_set_name (hbox103, "hbox103");
  gtk_widget_show (hbox103);
  gtk_box_pack_start (GTK_BOX (vbox_filter_main), hbox103, FALSE, FALSE, 0);

  button_filter_apply = gtk_button_new_from_stock ("gtk-apply");
  gtk_widget_set_name (button_filter_apply, "button_filter_apply");
  gtk_widget_show (button_filter_apply);
  gtk_box_pack_start (GTK_BOX (hbox103), button_filter_apply, TRUE, TRUE, 0);
  GTK_WIDGET_SET_FLAGS (button_filter_apply, GTK_CAN_DEFAULT);

  button_filter_revert = gtk_button_new ();
  gtk_widget_set_name (button_filter_revert, "button_filter_revert");
  gtk_widget_show (button_filter_revert);
  gtk_box_pack_start (GTK_BOX (hbox103), button_filter_revert, TRUE, TRUE, 0);
  GTK_WIDGET_SET_FLAGS (button_filter_revert, GTK_CAN_DEFAULT);

  alignment45 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment45, "alignment45");
  gtk_widget_show (alignment45);
  gtk_container_add (GTK_CONTAINER (button_filter_revert), alignment45);

  hbox177 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox177, "hbox177");
  gtk_widget_show (hbox177);
  gtk_container_add (GTK_CONTAINER (alignment45), hbox177);

  image77 = gtk_image_new_from_stock ("gtk-undo", GTK_ICON_SIZE_BUTTON);
  gtk_widget_set_name (image77, "image77");
  gtk_widget_show (image77);
  gtk_box_pack_start (GTK_BOX (hbox177), image77, FALSE, FALSE, 0);

  label442 = gtk_label_new_with_mnemonic (_("Revert"));
  gtk_widget_set_name (label442, "label442");
  gtk_widget_show (label442);
  gtk_box_pack_start (GTK_BOX (hbox177), label442, FALSE, FALSE, 0);

  button_filter_ok = gtk_button_new_from_stock ("gtk-ok");
  gtk_widget_set_name (button_filter_ok, "button_filter_ok");
  gtk_widget_show (button_filter_ok);
  gtk_box_pack_start (GTK_BOX (hbox103), button_filter_ok, TRUE, TRUE, 0);
  GTK_WIDGET_SET_FLAGS (button_filter_ok, GTK_CAN_DEFAULT);

  button_filter_cancel = gtk_button_new_from_stock ("gtk-cancel");
  gtk_widget_set_name (button_filter_cancel, "button_filter_cancel");
  gtk_widget_show (button_filter_cancel);
  gtk_box_pack_start (GTK_BOX (hbox103), button_filter_cancel, TRUE, TRUE, 0);
  GTK_WIDGET_SET_FLAGS (button_filter_cancel, GTK_CAN_DEFAULT);

  g_signal_connect ((gpointer) dlg_filters, "delete_event",
                    G_CALLBACK (on_dlg_filters_delete_event),
                    NULL);
  g_signal_connect ((gpointer) entry_filter_new, "activate",
                    G_CALLBACK (on_entry_filter_new_activate),
                    NULL);
  g_signal_connect ((gpointer) button_filter_create, "clicked",
                    G_CALLBACK (on_button_filter_create_clicked),
                    NULL);
  g_signal_connect ((gpointer) checkbutton_filter_enabled, "toggled",
                    G_CALLBACK (on_checkbutton_filter_enabled_toggled),
                    NULL);
  g_signal_connect ((gpointer) button_filter_remove, "clicked",
                    G_CALLBACK (on_button_filter_remove_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_filter_clear, "clicked",
                    G_CALLBACK (on_button_filter_clear_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_filter_reset_all_rules, "clicked",
                    G_CALLBACK (on_button_filter_reset_all_rules_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_filter_reset, "clicked",
                    G_CALLBACK (on_button_filter_reset_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_filter_reset_all, "clicked",
                    G_CALLBACK (on_button_filter_reset_all_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_filter_apply, "clicked",
                    G_CALLBACK (on_button_filter_apply_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_filter_revert, "clicked",
                    G_CALLBACK (on_button_filter_revert_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_filter_ok, "clicked",
                    G_CALLBACK (on_button_filter_ok_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_filter_cancel, "clicked",
                    G_CALLBACK (on_button_filter_cancel_clicked),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (dlg_filters, dlg_filters, "dlg_filters");
  GLADE_HOOKUP_OBJECT (dlg_filters, vbox_filter_main, "vbox_filter_main");
  GLADE_HOOKUP_OBJECT (dlg_filters, hpaned_filter_main, "hpaned_filter_main");
  GLADE_HOOKUP_OBJECT (dlg_filters, vbox59, "vbox59");
  GLADE_HOOKUP_OBJECT (dlg_filters, hbox111, "hbox111");
  GLADE_HOOKUP_OBJECT (dlg_filters, entry_filter_new, "entry_filter_new");
  GLADE_HOOKUP_OBJECT (dlg_filters, button_filter_create, "button_filter_create");
  GLADE_HOOKUP_OBJECT (dlg_filters, alignment113, "alignment113");
  GLADE_HOOKUP_OBJECT (dlg_filters, hbox9303, "hbox9303");
  GLADE_HOOKUP_OBJECT (dlg_filters, image761, "image761");
  GLADE_HOOKUP_OBJECT (dlg_filters, label958, "label958");
  GLADE_HOOKUP_OBJECT (dlg_filters, scrolledwindow34, "scrolledwindow34");
  GLADE_HOOKUP_OBJECT (dlg_filters, treeview_filter_filters, "treeview_filter_filters");
  GLADE_HOOKUP_OBJECT (dlg_filters, hseparator4, "hseparator4");
  GLADE_HOOKUP_OBJECT (dlg_filters, vbox32, "vbox32");
  GLADE_HOOKUP_OBJECT (dlg_filters, hbox97, "hbox97");
  GLADE_HOOKUP_OBJECT (dlg_filters, label221, "label221");
  GLADE_HOOKUP_OBJECT (dlg_filters, entry_filter_name, "entry_filter_name");
  GLADE_HOOKUP_OBJECT (dlg_filters, checkbutton_filter_enabled, "checkbutton_filter_enabled");
  GLADE_HOOKUP_OBJECT (dlg_filters, button_filter_remove, "button_filter_remove");
  GLADE_HOOKUP_OBJECT (dlg_filters, alignment112, "alignment112");
  GLADE_HOOKUP_OBJECT (dlg_filters, hbox9302, "hbox9302");
  GLADE_HOOKUP_OBJECT (dlg_filters, image760, "image760");
  GLADE_HOOKUP_OBJECT (dlg_filters, label957, "label957");
  GLADE_HOOKUP_OBJECT (dlg_filters, scrolledwindow35, "scrolledwindow35");
  GLADE_HOOKUP_OBJECT (dlg_filters, treeview_filter_rules, "treeview_filter_rules");
  GLADE_HOOKUP_OBJECT (dlg_filters, hbox125, "hbox125");
  GLADE_HOOKUP_OBJECT (dlg_filters, button_filter_clear, "button_filter_clear");
  GLADE_HOOKUP_OBJECT (dlg_filters, button_filter_reset_all_rules, "button_filter_reset_all_rules");
  GLADE_HOOKUP_OBJECT (dlg_filters, button_filter_reset, "button_filter_reset");
  GLADE_HOOKUP_OBJECT (dlg_filters, button_filter_reset_all, "button_filter_reset_all");
  GLADE_HOOKUP_OBJECT (dlg_filters, hseparator6, "hseparator6");
  GLADE_HOOKUP_OBJECT (dlg_filters, notebook_filter_detail, "notebook_filter_detail");
  GLADE_HOOKUP_OBJECT (dlg_filters, label591, "label591");
  GLADE_HOOKUP_OBJECT (dlg_filters, hseparator5, "hseparator5");
  GLADE_HOOKUP_OBJECT (dlg_filters, hbox103, "hbox103");
  GLADE_HOOKUP_OBJECT (dlg_filters, button_filter_apply, "button_filter_apply");
  GLADE_HOOKUP_OBJECT (dlg_filters, button_filter_revert, "button_filter_revert");
  GLADE_HOOKUP_OBJECT (dlg_filters, alignment45, "alignment45");
  GLADE_HOOKUP_OBJECT (dlg_filters, hbox177, "hbox177");
  GLADE_HOOKUP_OBJECT (dlg_filters, image77, "image77");
  GLADE_HOOKUP_OBJECT (dlg_filters, label442, "label442");
  GLADE_HOOKUP_OBJECT (dlg_filters, button_filter_ok, "button_filter_ok");
  GLADE_HOOKUP_OBJECT (dlg_filters, button_filter_cancel, "button_filter_cancel");
  GLADE_HOOKUP_OBJECT_NO_REF (dlg_filters, tooltips, "tooltips");

  gtk_widget_grab_default (button_filter_ok);
  return dlg_filters;
}

GtkWidget*
create_shutdown_window (void)
{
  GtkWidget *shutdown_window;
  GdkPixbuf *shutdown_window_icon_pixbuf;
  GtkWidget *frame30;
  GtkWidget *vbox44;
  GtkWidget *label184;
  GtkWidget *label_shutdown_count;

  shutdown_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_widget_set_name (shutdown_window, "shutdown_window");
  gtk_window_set_title (GTK_WINDOW (shutdown_window), _("gtk-gnutella shutdown"));
  gtk_window_set_position (GTK_WINDOW (shutdown_window), GTK_WIN_POS_MOUSE);
  shutdown_window_icon_pixbuf = create_pixbuf ("icon.48x48.xpm");
  if (shutdown_window_icon_pixbuf)
    {
      gtk_window_set_icon (GTK_WINDOW (shutdown_window), shutdown_window_icon_pixbuf);
      g_object_unref (shutdown_window_icon_pixbuf);
    }

  frame30 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame30, "frame30");
  gtk_widget_show (frame30);
  gtk_container_add (GTK_CONTAINER (shutdown_window), frame30);
  gtk_container_set_border_width (GTK_CONTAINER (frame30), 6);

  vbox44 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox44, "vbox44");
  gtk_widget_show (vbox44);
  gtk_container_add (GTK_CONTAINER (frame30), vbox44);
  gtk_container_set_border_width (GTK_CONTAINER (vbox44), 30);

  label184 = gtk_label_new (_("gtk-gnutella is shutting down.\nSending bye messages to peers.\n\nGrace time remaining:"));
  gtk_widget_set_name (label184, "label184");
  gtk_widget_show (label184);
  gtk_box_pack_start (GTK_BOX (vbox44), label184, FALSE, FALSE, 0);
  gtk_label_set_justify (GTK_LABEL (label184), GTK_JUSTIFY_CENTER);

  label_shutdown_count = gtk_label_new ("[time]");
  gtk_widget_set_name (label_shutdown_count, "label_shutdown_count");
  gtk_widget_show (label_shutdown_count);
  gtk_box_pack_start (GTK_BOX (vbox44), label_shutdown_count, FALSE, FALSE, 0);
  gtk_label_set_justify (GTK_LABEL (label_shutdown_count), GTK_JUSTIFY_CENTER);

  g_signal_connect ((gpointer) shutdown_window, "delete_event",
                    G_CALLBACK (gtk_true),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (shutdown_window, shutdown_window, "shutdown_window");
  GLADE_HOOKUP_OBJECT (shutdown_window, frame30, "frame30");
  GLADE_HOOKUP_OBJECT (shutdown_window, vbox44, "vbox44");
  GLADE_HOOKUP_OBJECT (shutdown_window, label184, "label184");
  GLADE_HOOKUP_OBJECT (shutdown_window, label_shutdown_count, "label_shutdown_count");

  return shutdown_window;
}

GtkWidget*
create_popup_filter_rule (void)
{
  GtkWidget *popup_filter_rule;
  GtkWidget *popup_filter_rule_copy;
  GtkWidget *image11;
  GtkWidget *popup_filter_rule_paste;
  GtkWidget *image12;

  popup_filter_rule = gtk_menu_new ();
  gtk_widget_set_name (popup_filter_rule, "popup_filter_rule");

  popup_filter_rule_copy = gtk_image_menu_item_new_with_mnemonic (_("Copy rule"));
  gtk_widget_set_name (popup_filter_rule_copy, "popup_filter_rule_copy");
  gtk_widget_show (popup_filter_rule_copy);
  gtk_container_add (GTK_CONTAINER (popup_filter_rule), popup_filter_rule_copy);

  image11 = gtk_image_new_from_stock ("gtk-copy", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image11, "image11");
  gtk_widget_show (image11);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (popup_filter_rule_copy), image11);

  popup_filter_rule_paste = gtk_image_menu_item_new_with_mnemonic (_("Paste rule"));
  gtk_widget_set_name (popup_filter_rule_paste, "popup_filter_rule_paste");
  gtk_widget_show (popup_filter_rule_paste);
  gtk_container_add (GTK_CONTAINER (popup_filter_rule), popup_filter_rule_paste);

  image12 = gtk_image_new_from_stock ("gtk-paste", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image12, "image12");
  gtk_widget_show (image12);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (popup_filter_rule_paste), image12);

  g_signal_connect ((gpointer) popup_filter_rule_copy, "activate",
                    G_CALLBACK (on_popup_filter_rule_copy_activate),
                    NULL);
  g_signal_connect ((gpointer) popup_filter_rule_paste, "activate",
                    G_CALLBACK (on_popup_filter_rule_paste_activate),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (popup_filter_rule, popup_filter_rule, "popup_filter_rule");
  GLADE_HOOKUP_OBJECT (popup_filter_rule, popup_filter_rule_copy, "popup_filter_rule_copy");
  GLADE_HOOKUP_OBJECT (popup_filter_rule, image11, "image11");
  GLADE_HOOKUP_OBJECT (popup_filter_rule, popup_filter_rule_paste, "popup_filter_rule_paste");
  GLADE_HOOKUP_OBJECT (popup_filter_rule, image12, "image12");

  return popup_filter_rule;
}

GtkWidget*
create_dlg_about (void)
{
  GtkWidget *dlg_about;
  GdkPixbuf *dlg_about_icon_pixbuf;
  GtkWidget *vbox67;
  GtkWidget *frame44;
  GtkWidget *hbox231;
  GtkWidget *image222;
  GtkWidget *label_about_title;
  GtkWidget *table105;
  GtkWidget *label501;
  GtkWidget *label492;
  GtkWidget *label498;
  GtkWidget *label494;
  GtkWidget *label703;
  GtkWidget *label704;
  GtkWidget *label493;
  GtkWidget *label495;
  GtkWidget *label496;
  GtkWidget *label497;
  GtkWidget *label499;
  GtkWidget *label500;
  GtkWidget *vseparator6;
  GtkWidget *label_about_translation;
  GtkWidget *frame46;
  GtkWidget *scrolledwindow61;
  GtkWidget *viewport31;
  GtkWidget *textview_about_contributors;
  GtkWidget *label302;
  GtkWidget *label488;
  GtkWidget *label489;
  GtkWidget *label538;
  GtkWidget *label490;
  GtkWidget *label491;
  GtkWidget *hseparator14;
  GtkWidget *label892;
  GtkWidget *hbox137;
  GtkWidget *button_about_close;

  dlg_about = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_widget_set_name (dlg_about, "dlg_about");
  gtk_window_set_title (GTK_WINDOW (dlg_about), _("About gtk-gnutella"));
  gtk_window_set_position (GTK_WINDOW (dlg_about), GTK_WIN_POS_MOUSE);
  dlg_about_icon_pixbuf = create_pixbuf ("icon.48x48.xpm");
  if (dlg_about_icon_pixbuf)
    {
      gtk_window_set_icon (GTK_WINDOW (dlg_about), dlg_about_icon_pixbuf);
      g_object_unref (dlg_about_icon_pixbuf);
    }

  vbox67 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox67, "vbox67");
  gtk_widget_show (vbox67);
  gtk_container_add (GTK_CONTAINER (dlg_about), vbox67);

  frame44 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame44, "frame44");
  gtk_widget_show (frame44);
  gtk_box_pack_start (GTK_BOX (vbox67), frame44, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame44), 2);

  hbox231 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox231, "hbox231");
  gtk_widget_show (hbox231);
  gtk_container_add (GTK_CONTAINER (frame44), hbox231);

  image222 = create_pixmap (dlg_about, "icon.48x48.xpm");
  gtk_widget_set_name (image222, "image222");
  gtk_widget_show (image222);
  gtk_box_pack_start (GTK_BOX (hbox231), image222, FALSE, TRUE, 0);
  gtk_misc_set_padding (GTK_MISC (image222), 4, 2);

  label_about_title = gtk_label_new ("[name and version]");
  gtk_widget_set_name (label_about_title, "label_about_title");
  gtk_widget_show (label_about_title);
  gtk_box_pack_start (GTK_BOX (hbox231), label_about_title, TRUE, TRUE, 0);
  GTK_WIDGET_SET_FLAGS (label_about_title, GTK_CAN_FOCUS);
  gtk_label_set_justify (GTK_LABEL (label_about_title), GTK_JUSTIFY_CENTER);
  gtk_label_set_selectable (GTK_LABEL (label_about_title), TRUE);
  gtk_misc_set_padding (GTK_MISC (label_about_title), 10, 10);

  table105 = gtk_table_new (3, 5, FALSE);
  gtk_widget_set_name (table105, "table105");
  gtk_widget_show (table105);
  gtk_box_pack_start (GTK_BOX (vbox67), table105, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (table105), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table105), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table105), 4);

  label501 = gtk_label_new (_("Original author:"));
  gtk_widget_set_name (label501, "label501");
  gtk_widget_show (label501);
  gtk_table_attach (GTK_TABLE (table105), label501, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label501), GTK_JUSTIFY_RIGHT);
  gtk_misc_set_alignment (GTK_MISC (label501), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label501), 10, 0);

  label492 = gtk_label_new ("Yann Grossel");
  gtk_widget_set_name (label492, "label492");
  gtk_widget_show (label492);
  gtk_table_attach (GTK_TABLE (table105), label492, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label492), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label492), 4, 0);

  label498 = gtk_label_new (_("Core development:"));
  gtk_widget_set_name (label498, "label498");
  gtk_widget_show (label498);
  gtk_table_attach (GTK_TABLE (table105), label498, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label498), GTK_JUSTIFY_RIGHT);
  gtk_misc_set_alignment (GTK_MISC (label498), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label498), 10, 0);

  label494 = gtk_label_new ("Raphaël Manfredi");
  gtk_widget_set_name (label494, "label494");
  gtk_widget_show (label494);
  gtk_table_attach (GTK_TABLE (table105), label494, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label494), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label494), 4, 0);

  label703 = gtk_label_new (_("PARQ development:"));
  gtk_widget_set_name (label703, "label703");
  gtk_widget_show (label703);
  gtk_table_attach (GTK_TABLE (table105), label703, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label703), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label703), 10, 0);

  label704 = gtk_label_new ("Jeroen Asselman");
  gtk_widget_set_name (label704, "label704");
  gtk_widget_show (label704);
  gtk_table_attach (GTK_TABLE (table105), label704, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label704), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label704), 4, 0);

  label493 = gtk_label_new ("Raphaël Manfredi");
  gtk_widget_set_name (label493, "label493");
  gtk_widget_show (label493);
  gtk_table_attach (GTK_TABLE (table105), label493, 4, 5, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label493), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label493), 4, 0);

  label495 = gtk_label_new ("Richard Eckart");
  gtk_widget_set_name (label495, "label495");
  gtk_widget_show (label495);
  gtk_table_attach (GTK_TABLE (table105), label495, 4, 5, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label495), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label495), 4, 0);

  label496 = gtk_label_new ("Vidar Madsen");
  gtk_widget_set_name (label496, "label496");
  gtk_widget_show (label496);
  gtk_table_attach (GTK_TABLE (table105), label496, 4, 5, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label496), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label496), 4, 0);

  label497 = gtk_label_new (_("Project leader:"));
  gtk_widget_set_name (label497, "label497");
  gtk_widget_show (label497);
  gtk_table_attach (GTK_TABLE (table105), label497, 3, 4, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label497), GTK_JUSTIFY_RIGHT);
  gtk_misc_set_alignment (GTK_MISC (label497), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label497), 10, 0);

  label499 = gtk_label_new (_("GUI development:"));
  gtk_widget_set_name (label499, "label499");
  gtk_widget_show (label499);
  gtk_table_attach (GTK_TABLE (table105), label499, 3, 4, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label499), GTK_JUSTIFY_RIGHT);
  gtk_misc_set_alignment (GTK_MISC (label499), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label499), 10, 0);

  label500 = gtk_label_new (_("Swarming development:"));
  gtk_widget_set_name (label500, "label500");
  gtk_widget_show (label500);
  gtk_table_attach (GTK_TABLE (table105), label500, 3, 4, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label500), GTK_JUSTIFY_RIGHT);
  gtk_misc_set_alignment (GTK_MISC (label500), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label500), 10, 0);

  vseparator6 = gtk_vseparator_new ();
  gtk_widget_set_name (vseparator6, "vseparator6");
  gtk_widget_show (vseparator6);
  gtk_table_attach (GTK_TABLE (table105), vseparator6, 2, 3, 0, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 4, 0);

  label_about_translation = gtk_label_new ("[translator credit]");
  gtk_widget_set_name (label_about_translation, "label_about_translation");
  gtk_widget_show (label_about_translation);
  gtk_box_pack_start (GTK_BOX (vbox67), label_about_translation, FALSE, FALSE, 0);

  frame46 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame46, "frame46");
  gtk_widget_show (frame46);
  gtk_box_pack_start (GTK_BOX (vbox67), frame46, TRUE, TRUE, 0);
  gtk_widget_set_size_request (frame46, 100, 100);
  gtk_container_set_border_width (GTK_CONTAINER (frame46), 3);

  scrolledwindow61 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow61, "scrolledwindow61");
  gtk_widget_show (scrolledwindow61);
  gtk_container_add (GTK_CONTAINER (frame46), scrolledwindow61);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow61), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);

  viewport31 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport31, "viewport31");
  gtk_widget_show (viewport31);
  gtk_container_add (GTK_CONTAINER (scrolledwindow61), viewport31);

  textview_about_contributors = gtk_text_view_new ();
  gtk_widget_set_name (textview_about_contributors, "textview_about_contributors");
  gtk_widget_show (textview_about_contributors);
  gtk_container_add (GTK_CONTAINER (viewport31), textview_about_contributors);
  gtk_text_view_set_editable (GTK_TEXT_VIEW (textview_about_contributors), FALSE);
  gtk_text_view_set_justification (GTK_TEXT_VIEW (textview_about_contributors), GTK_JUSTIFY_CENTER);
  gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (textview_about_contributors), GTK_WRAP_WORD);
  gtk_text_view_set_cursor_visible (GTK_TEXT_VIEW (textview_about_contributors), FALSE);
  gtk_text_view_set_left_margin (GTK_TEXT_VIEW (textview_about_contributors), 4);
  gtk_text_view_set_right_margin (GTK_TEXT_VIEW (textview_about_contributors), 4);

  label302 = gtk_label_new (_("Contributors:"));
  gtk_widget_set_name (label302, "label302");
  gtk_widget_show (label302);
  gtk_frame_set_label_widget (GTK_FRAME (frame46), label302);

  label488 = gtk_label_new (_("==> We are looking for people who want to contribute to this fine tool. <=="));
  gtk_widget_set_name (label488, "label488");
  gtk_widget_show (label488);
  gtk_box_pack_start (GTK_BOX (vbox67), label488, FALSE, TRUE, 0);
  gtk_label_set_justify (GTK_LABEL (label488), GTK_JUSTIFY_CENTER);

  label489 = gtk_label_new (_("Visit http://gtk-gnutella.sourceforge.net/."));
  gtk_widget_set_name (label489, "label489");
  gtk_widget_show (label489);
  gtk_box_pack_start (GTK_BOX (vbox67), label489, FALSE, TRUE, 0);
  GTK_WIDGET_SET_FLAGS (label489, GTK_CAN_FOCUS);
  gtk_label_set_selectable (GTK_LABEL (label489), TRUE);

  label538 = gtk_label_new ("Translations are on https://www.transifex.com/projects/p/gtk-gnutella/");
  gtk_widget_set_name (label538, "label538");
  gtk_widget_show (label538);
  gtk_box_pack_start (GTK_BOX (vbox67), label538, FALSE, TRUE, 0);
  GTK_WIDGET_SET_FLAGS (label538, GTK_CAN_FOCUS);
  gtk_label_set_justify (GTK_LABEL (label538), GTK_JUSTIFY_CENTER);
  gtk_label_set_selectable (GTK_LABEL (label538), TRUE);

  label490 = gtk_label_new (_("Join the users or developers mailing lists."));
  gtk_widget_set_name (label490, "label490");
  gtk_widget_show (label490);
  gtk_box_pack_start (GTK_BOX (vbox67), label490, FALSE, TRUE, 0);

  label491 = gtk_label_new (_("Meet us on #gtk-gnutella at irc.freenode.net."));
  gtk_widget_set_name (label491, "label491");
  gtk_widget_show (label491);
  gtk_box_pack_start (GTK_BOX (vbox67), label491, FALSE, TRUE, 0);
  GTK_WIDGET_SET_FLAGS (label491, GTK_CAN_FOCUS);
  gtk_label_set_justify (GTK_LABEL (label491), GTK_JUSTIFY_CENTER);
  gtk_label_set_selectable (GTK_LABEL (label491), TRUE);

  hseparator14 = gtk_hseparator_new ();
  gtk_widget_set_name (hseparator14, "hseparator14");
  gtk_widget_show (hseparator14);
  gtk_box_pack_start (GTK_BOX (vbox67), hseparator14, FALSE, TRUE, 2);

  label892 = gtk_label_new (_("This product includes GeoIP data created by MaxMind, available from\nhttp://maxmind.com/"));
  gtk_widget_set_name (label892, "label892");
  gtk_widget_show (label892);
  gtk_box_pack_start (GTK_BOX (vbox67), label892, FALSE, TRUE, 2);
  GTK_WIDGET_SET_FLAGS (label892, GTK_CAN_FOCUS);
  gtk_label_set_justify (GTK_LABEL (label892), GTK_JUSTIFY_CENTER);
  gtk_label_set_selectable (GTK_LABEL (label892), TRUE);

  hbox137 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox137, "hbox137");
  gtk_widget_show (hbox137);
  gtk_box_pack_start (GTK_BOX (vbox67), hbox137, FALSE, TRUE, 0);

  button_about_close = gtk_button_new_with_mnemonic (_("_Close"));
  gtk_widget_set_name (button_about_close, "button_about_close");
  gtk_widget_show (button_about_close);
  gtk_box_pack_start (GTK_BOX (hbox137), button_about_close, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (button_about_close), 6);
  GTK_WIDGET_SET_FLAGS (button_about_close, GTK_CAN_DEFAULT);

  g_signal_connect ((gpointer) dlg_about, "delete_event",
                    G_CALLBACK (on_dlg_about_delete_event),
                    NULL);
  g_signal_connect ((gpointer) button_about_close, "clicked",
                    G_CALLBACK (on_button_about_close_clicked),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (dlg_about, dlg_about, "dlg_about");
  GLADE_HOOKUP_OBJECT (dlg_about, vbox67, "vbox67");
  GLADE_HOOKUP_OBJECT (dlg_about, frame44, "frame44");
  GLADE_HOOKUP_OBJECT (dlg_about, hbox231, "hbox231");
  GLADE_HOOKUP_OBJECT (dlg_about, image222, "image222");
  GLADE_HOOKUP_OBJECT (dlg_about, label_about_title, "label_about_title");
  GLADE_HOOKUP_OBJECT (dlg_about, table105, "table105");
  GLADE_HOOKUP_OBJECT (dlg_about, label501, "label501");
  GLADE_HOOKUP_OBJECT (dlg_about, label492, "label492");
  GLADE_HOOKUP_OBJECT (dlg_about, label498, "label498");
  GLADE_HOOKUP_OBJECT (dlg_about, label494, "label494");
  GLADE_HOOKUP_OBJECT (dlg_about, label703, "label703");
  GLADE_HOOKUP_OBJECT (dlg_about, label704, "label704");
  GLADE_HOOKUP_OBJECT (dlg_about, label493, "label493");
  GLADE_HOOKUP_OBJECT (dlg_about, label495, "label495");
  GLADE_HOOKUP_OBJECT (dlg_about, label496, "label496");
  GLADE_HOOKUP_OBJECT (dlg_about, label497, "label497");
  GLADE_HOOKUP_OBJECT (dlg_about, label499, "label499");
  GLADE_HOOKUP_OBJECT (dlg_about, label500, "label500");
  GLADE_HOOKUP_OBJECT (dlg_about, vseparator6, "vseparator6");
  GLADE_HOOKUP_OBJECT (dlg_about, label_about_translation, "label_about_translation");
  GLADE_HOOKUP_OBJECT (dlg_about, frame46, "frame46");
  GLADE_HOOKUP_OBJECT (dlg_about, scrolledwindow61, "scrolledwindow61");
  GLADE_HOOKUP_OBJECT (dlg_about, viewport31, "viewport31");
  GLADE_HOOKUP_OBJECT (dlg_about, textview_about_contributors, "textview_about_contributors");
  GLADE_HOOKUP_OBJECT (dlg_about, label302, "label302");
  GLADE_HOOKUP_OBJECT (dlg_about, label488, "label488");
  GLADE_HOOKUP_OBJECT (dlg_about, label489, "label489");
  GLADE_HOOKUP_OBJECT (dlg_about, label538, "label538");
  GLADE_HOOKUP_OBJECT (dlg_about, label490, "label490");
  GLADE_HOOKUP_OBJECT (dlg_about, label491, "label491");
  GLADE_HOOKUP_OBJECT (dlg_about, hseparator14, "hseparator14");
  GLADE_HOOKUP_OBJECT (dlg_about, label892, "label892");
  GLADE_HOOKUP_OBJECT (dlg_about, hbox137, "hbox137");
  GLADE_HOOKUP_OBJECT (dlg_about, button_about_close, "button_about_close");

  gtk_widget_grab_focus (textview_about_contributors);
  gtk_widget_grab_default (button_about_close);
  return dlg_about;
}

GtkWidget*
create_main_window (void)
{
  GtkWidget *main_window;
  GdkPixbuf *main_window_icon_pixbuf;
  GtkWidget *vbox12;
  GtkWidget *menubar_main;
  GtkWidget *menu_file;
  GtkWidget *menu_file_menu;
  GtkWidget *menu_prefs;
  GtkWidget *image2291;
  GtkWidget *separator27;
  GtkWidget *quit;
  GtkWidget *image2292;
  GtkWidget *menu_view;
  GtkWidget *menu_view_menu;
  GtkWidget *menu_searchbar_visible;
  GtkWidget *menu_sidebar_visible;
  GtkWidget *menu_menubar_visible;
  GtkWidget *menu_statusbar_visible;
  GtkWidget *separator29;
  GtkWidget *connection_counters1;
  GtkWidget *connection_counters1_menu;
  GtkWidget *menu_downloads_visible;
  GtkWidget *menu_uploads_visible;
  GtkWidget *menu_connections_visible;
  GtkWidget *menu_http_stats_visible;
  GtkWidget *menu_http_stats_visible_menu;
  GtkWidget *menu_bws_in_visible;
  GtkWidget *menu_bws_out_visible;
  GtkWidget *menu_gnet_stats_visible;
  GtkWidget *menu_gnet_stats_visible_menu;
  GtkWidget *menu_bws_gin_visible;
  GtkWidget *menu_bws_gout_visible;
  GtkWidget *menu_gnet_leaf_stats_visible;
  GtkWidget *menu_gnet_leaf_stats_visible_menu;
  GtkWidget *menu_autohide_bws_gleaf;
  GtkWidget *menu_bws_glin_visible;
  GtkWidget *menu_bws_glout_visible;
  GtkWidget *menu_dht_traffic_stats_visible;
  GtkWidget *menu_dht_traffic_stats_visible_menu;
  GtkWidget *menu_autohide_bws_dht;
  GtkWidget *menu_bws_dht_in_visible;
  GtkWidget *menu_bws_dht_out_visible;
  GtkWidget *menu_help;
  GtkWidget *menu_help_menu;
  GtkWidget *menu_faq;
  GtkWidget *image2293;
  GtkWidget *menu_glossary;
  GtkWidget *menu_about;
  GtkWidget *image2294;
  GtkWidget *viewport_searchbar;
  GtkWidget *vbox160;
  GtkWidget *hbox9350;
  GtkWidget *button_search;
  GtkWidget *alignment106;
  GtkWidget *hbox288;
  GtkWidget *image401;
  GtkWidget *label903;
  GtkWidget *frame129;
  GtkWidget *combo_search;
  GtkWidget *entry_search;
  GtkWidget *button_search_whats_new;
  GtkWidget *alignment147;
  GtkWidget *hbox9349;
  GtkWidget *image2245;
  GtkWidget *label1067;
  GtkWidget *button_search_passive;
  GtkWidget *alignment110;
  GtkWidget *hbox9292;
  GtkWidget *image404;
  GtkWidget *label911;
  GtkWidget *hbox9351;
  GtkWidget *frame_search_media_type;
  GtkWidget *alignment144;
  GtkWidget *hbox9346;
  GtkWidget *button_search_media_type_any;
  GtkWidget *alignment145;
  GtkWidget *hbox9347;
  GtkWidget *image2244;
  GtkWidget *label1065;
  GtkWidget *checkbutton_config_search_media_type_audio;
  GtkWidget *checkbutton_config_search_media_type_video;
  GtkWidget *checkbutton_config_search_media_type_document;
  GtkWidget *checkbutton_config_search_media_type_image;
  GtkWidget *checkbutton_config_search_media_type_archive;
  GtkWidget *label1064;
  GtkWidget *frame152;
  GtkWidget *alignment146;
  GtkWidget *hbox9348;
  GtkWidget *option_menu_search_lifetime;
  GtkWidget *menu1;
  GtkWidget *optionmenu_search_filter;
  GtkWidget *convertwidget20;
  GtkWidget *label1066;
  GtkWidget *hpaned_main;
  GtkWidget *vbox_sidebar;
  GtkWidget *sw_searches;
  GtkWidget *tree_view_search;
  GtkWidget *vbox_sidebar_stats;
  GtkWidget *frame71;
  GtkWidget *vbox105;
  GtkWidget *hbox_stats_connections;
  GtkWidget *eventbox8;
  GtkWidget *image131;
  GtkWidget *progressbar_connections;
  GtkWidget *hbox_stats_uploads;
  GtkWidget *eventbox7;
  GtkWidget *image130;
  GtkWidget *progressbar_uploads;
  GtkWidget *hbox_stats_downloads;
  GtkWidget *eventbox10;
  GtkWidget *image132;
  GtkWidget *progressbar_downloads;
  GtkWidget *frame_bws_inout;
  GtkWidget *vbox42;
  GtkWidget *progressbar_bws_in;
  GtkWidget *progressbar_bws_out;
  GtkWidget *label277;
  GtkWidget *frame_bws_ginout;
  GtkWidget *vbox43;
  GtkWidget *progressbar_bws_gin;
  GtkWidget *progressbar_bws_gout;
  GtkWidget *label278;
  GtkWidget *frame_bws_glinout;
  GtkWidget *vbox104;
  GtkWidget *progressbar_bws_lin;
  GtkWidget *progressbar_bws_lout;
  GtkWidget *label605;
  GtkWidget *frame_bws_dht_inout;
  GtkWidget *vbox155;
  GtkWidget *progressbar_bws_dht_in;
  GtkWidget *progressbar_bws_dht_out;
  GtkWidget *label1031;
  GtkWidget *vbox_right;
  GtkWidget *notebook_main;
  GtkWidget *empty_notebook_page;
  GtkWidget *label590;
  GtkWidget *hbox_statusbar;
  GtkWidget *togglebutton_online;
  GtkWidget *hbox170;
  GtkWidget *eventbox9;
  GtkWidget *image_offline;
  GtkWidget *image_online;
  GtkWidget *hbox_port_mapping;
  GtkWidget *eventbox_port_mapping_possible;
  GtkWidget *image_port_mapping_possible;
  GtkWidget *eventbox_upnp_port_mapping_successful;
  GtkWidget *image_upnp_successful;
  GtkWidget *eventbox_natpmp_port_mapping_successful;
  GtkWidget *image_natpmp_successful;
  GtkWidget *statusbar;
  GtkWidget *hbox211;
  GtkWidget *eventbox_image_download_queue_frozen;
  GtkWidget *image_download_queue_frozen;
  GtkWidget *eventbox_image_chip;
  GtkWidget *image_chip;
  GtkWidget *eventbox_net_buffer_shortage;
  GtkWidget *image_net_buffer_shortage;
  GtkWidget *eventbox_tcp_no_listening;
  GtkWidget *image_tcp_no_listening;
  GtkWidget *eventbox_image_warning;
  GtkWidget *image_warning;
  GtkWidget *hbox9345;
  GtkWidget *eventbox_early_stall_1;
  GtkWidget *image_early_stall_1;
  GtkWidget *eventbox_early_stall_2;
  GtkWidget *image_early_stall_2;
  GtkWidget *eventbox_early_stall_3;
  GtkWidget *image_early_stall_3;
  GtkWidget *eventbox_image_fd_shortage;
  GtkWidget *image_fd_shortage;
  GtkWidget *eventbox_image_fd_runout;
  GtkWidget *image_fd_runout;
  GtkWidget *eventbox_image_ancient;
  GtkWidget *image_ancient;
  GtkWidget *eventbox_image_save;
  GtkWidget *image_save;
  GtkWidget *eventbox_image_sha;
  GtkWidget *image_sha;
  GtkWidget *eventbox_image_shav;
  GtkWidget *image_shav;
  GtkWidget *eventbox_image_tth;
  GtkWidget *image_tth;
  GtkWidget *eventbox_image_tthv;
  GtkWidget *image_tthv;
  GtkWidget *eventbox_image_lib;
  GtkWidget *image_lib;
  GtkWidget *hbox147;
  GtkWidget *eventbox_image_firewall;
  GtkWidget *image_firewall;
  GtkWidget *eventbox_image_firewall_punchable;
  GtkWidget *image_firewall_punchable;
  GtkWidget *eventbox_image_tcp_firewall;
  GtkWidget *image_tcp_firewall;
  GtkWidget *eventbox_image_udp_firewall;
  GtkWidget *image_udp_firewall;
  GtkWidget *eventbox_image_firewall_udp_punchable;
  GtkWidget *image_firewall_udp_punchable;
  GtkWidget *eventbox_image_no_firewall;
  GtkWidget *image_no_firewall;
  GtkWidget *hbox228;
  GtkWidget *eventbox_image_ultra;
  GtkWidget *image_ultra;
  GtkWidget *eventbox_image_leaf;
  GtkWidget *image_leaf;
  GtkWidget *eventbox_image_legacy;
  GtkWidget *image_legacy;
  GtkWidget *hbox9344;
  GtkWidget *eventbox_image_dht_none;
  GtkWidget *image_dht_none;
  GtkWidget *eventbox_image_dht_seeded;
  GtkWidget *image_dht_seeded;
  GtkWidget *eventbox_image_dht_own_kuid;
  GtkWidget *image_dht_own_kuid;
  GtkWidget *eventbox_image_dht_completing;
  GtkWidget *image_dht_completing;
  GtkWidget *eventbox_image_dht_active;
  GtkWidget *image_dht_active;
  GtkWidget *eventbox_image_dht_passive;
  GtkWidget *image_dht_passive;
  GtkWidget *frame_statusbar_uptime;
  GtkWidget *alignment102;
  GtkWidget *label_statusbar_uptime;
  GtkWidget *statusbar1;
  GtkAccelGroup *accel_group;
  GtkTooltips *tooltips;

  tooltips = gtk_tooltips_new ();

  accel_group = gtk_accel_group_new ();

  main_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_widget_set_name (main_window, "main_window");
  main_window_icon_pixbuf = create_pixbuf ("icon.48x48.xpm");
  if (main_window_icon_pixbuf)
    {
      gtk_window_set_icon (GTK_WINDOW (main_window), main_window_icon_pixbuf);
      g_object_unref (main_window_icon_pixbuf);
    }

  vbox12 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox12, "vbox12");
  gtk_widget_show (vbox12);
  gtk_container_add (GTK_CONTAINER (main_window), vbox12);

  menubar_main = gtk_menu_bar_new ();
  gtk_widget_set_name (menubar_main, "menubar_main");
  gtk_widget_show (menubar_main);
  gtk_box_pack_start (GTK_BOX (vbox12), menubar_main, FALSE, FALSE, 0);

  menu_file = gtk_menu_item_new_with_mnemonic (_("_File"));
  gtk_widget_set_name (menu_file, "menu_file");
  gtk_widget_show (menu_file);
  gtk_container_add (GTK_CONTAINER (menubar_main), menu_file);

  menu_file_menu = gtk_menu_new ();
  gtk_widget_set_name (menu_file_menu, "menu_file_menu");
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_file), menu_file_menu);

  menu_prefs = gtk_image_menu_item_new_with_mnemonic (_("_Preferences"));
  gtk_widget_set_name (menu_prefs, "menu_prefs");
  gtk_widget_show (menu_prefs);
  gtk_container_add (GTK_CONTAINER (menu_file_menu), menu_prefs);
  gtk_widget_add_accelerator (menu_prefs, "activate", accel_group,
                              GDK_p, (GdkModifierType) GDK_CONTROL_MASK,
                              GTK_ACCEL_VISIBLE);

  image2291 = gtk_image_new_from_stock ("gtk-preferences", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image2291, "image2291");
  gtk_widget_show (image2291);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_prefs), image2291);

  separator27 = gtk_separator_menu_item_new ();
  gtk_widget_set_name (separator27, "separator27");
  gtk_widget_show (separator27);
  gtk_container_add (GTK_CONTAINER (menu_file_menu), separator27);
  gtk_widget_set_sensitive (separator27, FALSE);

  quit = gtk_image_menu_item_new_with_mnemonic (_("_Quit"));
  gtk_widget_set_name (quit, "quit");
  gtk_widget_show (quit);
  gtk_container_add (GTK_CONTAINER (menu_file_menu), quit);
  gtk_widget_add_accelerator (quit, "activate", accel_group,
                              GDK_q, (GdkModifierType) GDK_CONTROL_MASK,
                              GTK_ACCEL_VISIBLE);

  image2292 = gtk_image_new_from_stock ("gtk-quit", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image2292, "image2292");
  gtk_widget_show (image2292);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (quit), image2292);

  menu_view = gtk_menu_item_new_with_mnemonic (_("_View"));
  gtk_widget_set_name (menu_view, "menu_view");
  gtk_widget_show (menu_view);
  gtk_container_add (GTK_CONTAINER (menubar_main), menu_view);

  menu_view_menu = gtk_menu_new ();
  gtk_widget_set_name (menu_view_menu, "menu_view_menu");
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_view), menu_view_menu);

  menu_searchbar_visible = gtk_check_menu_item_new_with_mnemonic (_("Show Search_bar"));
  gtk_widget_set_name (menu_searchbar_visible, "menu_searchbar_visible");
  gtk_widget_show (menu_searchbar_visible);
  gtk_container_add (GTK_CONTAINER (menu_view_menu), menu_searchbar_visible);
  gtk_widget_add_accelerator (menu_searchbar_visible, "activate", accel_group,
                              GDK_F2, (GdkModifierType) 0,
                              GTK_ACCEL_VISIBLE);

  menu_sidebar_visible = gtk_check_menu_item_new_with_mnemonic (_("Show _Sidebar"));
  gtk_widget_set_name (menu_sidebar_visible, "menu_sidebar_visible");
  gtk_widget_show (menu_sidebar_visible);
  gtk_container_add (GTK_CONTAINER (menu_view_menu), menu_sidebar_visible);
  gtk_widget_add_accelerator (menu_sidebar_visible, "activate", accel_group,
                              GDK_F8, (GdkModifierType) 0,
                              GTK_ACCEL_VISIBLE);

  menu_menubar_visible = gtk_check_menu_item_new_with_mnemonic (_("Show _Menubar"));
  gtk_widget_set_name (menu_menubar_visible, "menu_menubar_visible");
  gtk_widget_show (menu_menubar_visible);
  gtk_container_add (GTK_CONTAINER (menu_view_menu), menu_menubar_visible);
  gtk_widget_add_accelerator (menu_menubar_visible, "activate", accel_group,
                              GDK_F9, (GdkModifierType) 0,
                              GTK_ACCEL_VISIBLE);

  menu_statusbar_visible = gtk_check_menu_item_new_with_mnemonic (_("Show _Statusbar"));
  gtk_widget_set_name (menu_statusbar_visible, "menu_statusbar_visible");
  gtk_widget_show (menu_statusbar_visible);
  gtk_container_add (GTK_CONTAINER (menu_view_menu), menu_statusbar_visible);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu_statusbar_visible), TRUE);

  separator29 = gtk_separator_menu_item_new ();
  gtk_widget_set_name (separator29, "separator29");
  gtk_widget_show (separator29);
  gtk_container_add (GTK_CONTAINER (menu_view_menu), separator29);
  gtk_widget_set_sensitive (separator29, FALSE);

  connection_counters1 = gtk_menu_item_new_with_mnemonic (_("Connection counters"));
  gtk_widget_set_name (connection_counters1, "connection_counters1");
  gtk_widget_show (connection_counters1);
  gtk_container_add (GTK_CONTAINER (menu_view_menu), connection_counters1);

  connection_counters1_menu = gtk_menu_new ();
  gtk_widget_set_name (connection_counters1_menu, "connection_counters1_menu");
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (connection_counters1), connection_counters1_menu);

  menu_downloads_visible = gtk_check_menu_item_new_with_mnemonic (_("Show _Downloads"));
  gtk_widget_set_name (menu_downloads_visible, "menu_downloads_visible");
  gtk_widget_show (menu_downloads_visible);
  gtk_container_add (GTK_CONTAINER (connection_counters1_menu), menu_downloads_visible);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu_downloads_visible), TRUE);

  menu_uploads_visible = gtk_check_menu_item_new_with_mnemonic (_("Show _Uploads"));
  gtk_widget_set_name (menu_uploads_visible, "menu_uploads_visible");
  gtk_widget_show (menu_uploads_visible);
  gtk_container_add (GTK_CONTAINER (connection_counters1_menu), menu_uploads_visible);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu_uploads_visible), TRUE);

  menu_connections_visible = gtk_check_menu_item_new_with_mnemonic (_("Show _Peers"));
  gtk_widget_set_name (menu_connections_visible, "menu_connections_visible");
  gtk_widget_show (menu_connections_visible);
  gtk_container_add (GTK_CONTAINER (connection_counters1_menu), menu_connections_visible);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu_connections_visible), TRUE);

  menu_http_stats_visible = gtk_menu_item_new_with_mnemonic (_("_HTTP traffic stats"));
  gtk_widget_set_name (menu_http_stats_visible, "menu_http_stats_visible");
  gtk_widget_show (menu_http_stats_visible);
  gtk_container_add (GTK_CONTAINER (menu_view_menu), menu_http_stats_visible);

  menu_http_stats_visible_menu = gtk_menu_new ();
  gtk_widget_set_name (menu_http_stats_visible_menu, "menu_http_stats_visible_menu");
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_http_stats_visible), menu_http_stats_visible_menu);

  menu_bws_in_visible = gtk_check_menu_item_new_with_mnemonic (_("Show _inbound HTTP traffic"));
  gtk_widget_set_name (menu_bws_in_visible, "menu_bws_in_visible");
  gtk_widget_show (menu_bws_in_visible);
  gtk_container_add (GTK_CONTAINER (menu_http_stats_visible_menu), menu_bws_in_visible);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu_bws_in_visible), TRUE);

  menu_bws_out_visible = gtk_check_menu_item_new_with_mnemonic (_("Show _outbound HTTP traffic"));
  gtk_widget_set_name (menu_bws_out_visible, "menu_bws_out_visible");
  gtk_widget_show (menu_bws_out_visible);
  gtk_container_add (GTK_CONTAINER (menu_http_stats_visible_menu), menu_bws_out_visible);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu_bws_out_visible), TRUE);

  menu_gnet_stats_visible = gtk_menu_item_new_with_mnemonic (_("Gnutella _traffic stats"));
  gtk_widget_set_name (menu_gnet_stats_visible, "menu_gnet_stats_visible");
  gtk_widget_show (menu_gnet_stats_visible);
  gtk_container_add (GTK_CONTAINER (menu_view_menu), menu_gnet_stats_visible);

  menu_gnet_stats_visible_menu = gtk_menu_new ();
  gtk_widget_set_name (menu_gnet_stats_visible_menu, "menu_gnet_stats_visible_menu");
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_gnet_stats_visible), menu_gnet_stats_visible_menu);

  menu_bws_gin_visible = gtk_check_menu_item_new_with_mnemonic (_("Show _inbound Gnutella traffic"));
  gtk_widget_set_name (menu_bws_gin_visible, "menu_bws_gin_visible");
  gtk_widget_show (menu_bws_gin_visible);
  gtk_container_add (GTK_CONTAINER (menu_gnet_stats_visible_menu), menu_bws_gin_visible);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu_bws_gin_visible), TRUE);

  menu_bws_gout_visible = gtk_check_menu_item_new_with_mnemonic (_("Show _outbound Gnutella traffic"));
  gtk_widget_set_name (menu_bws_gout_visible, "menu_bws_gout_visible");
  gtk_widget_show (menu_bws_gout_visible);
  gtk_container_add (GTK_CONTAINER (menu_gnet_stats_visible_menu), menu_bws_gout_visible);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu_bws_gout_visible), TRUE);

  menu_gnet_leaf_stats_visible = gtk_menu_item_new_with_mnemonic (_("Gnutella _leaf traffic stats"));
  gtk_widget_set_name (menu_gnet_leaf_stats_visible, "menu_gnet_leaf_stats_visible");
  gtk_widget_show (menu_gnet_leaf_stats_visible);
  gtk_container_add (GTK_CONTAINER (menu_view_menu), menu_gnet_leaf_stats_visible);

  menu_gnet_leaf_stats_visible_menu = gtk_menu_new ();
  gtk_widget_set_name (menu_gnet_leaf_stats_visible_menu, "menu_gnet_leaf_stats_visible_menu");
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_gnet_leaf_stats_visible), menu_gnet_leaf_stats_visible_menu);

  menu_autohide_bws_gleaf = gtk_check_menu_item_new_with_mnemonic (_("_Auto-hide leaf traffic stats"));
  gtk_widget_set_name (menu_autohide_bws_gleaf, "menu_autohide_bws_gleaf");
  gtk_widget_show (menu_autohide_bws_gleaf);
  gtk_container_add (GTK_CONTAINER (menu_gnet_leaf_stats_visible_menu), menu_autohide_bws_gleaf);

  menu_bws_glin_visible = gtk_check_menu_item_new_with_mnemonic (_("Show _inbound leaf traffic"));
  gtk_widget_set_name (menu_bws_glin_visible, "menu_bws_glin_visible");
  gtk_widget_show (menu_bws_glin_visible);
  gtk_container_add (GTK_CONTAINER (menu_gnet_leaf_stats_visible_menu), menu_bws_glin_visible);

  menu_bws_glout_visible = gtk_check_menu_item_new_with_mnemonic (_("Show _outbound leaf traffic"));
  gtk_widget_set_name (menu_bws_glout_visible, "menu_bws_glout_visible");
  gtk_widget_show (menu_bws_glout_visible);
  gtk_container_add (GTK_CONTAINER (menu_gnet_leaf_stats_visible_menu), menu_bws_glout_visible);

  menu_dht_traffic_stats_visible = gtk_menu_item_new_with_mnemonic (_("DHT traffic stats"));
  gtk_widget_set_name (menu_dht_traffic_stats_visible, "menu_dht_traffic_stats_visible");
  gtk_widget_show (menu_dht_traffic_stats_visible);
  gtk_container_add (GTK_CONTAINER (menu_view_menu), menu_dht_traffic_stats_visible);

  menu_dht_traffic_stats_visible_menu = gtk_menu_new ();
  gtk_widget_set_name (menu_dht_traffic_stats_visible_menu, "menu_dht_traffic_stats_visible_menu");
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_dht_traffic_stats_visible), menu_dht_traffic_stats_visible_menu);

  menu_autohide_bws_dht = gtk_check_menu_item_new_with_mnemonic (_("auto-hide DHT traffic stats"));
  gtk_widget_set_name (menu_autohide_bws_dht, "menu_autohide_bws_dht");
  gtk_widget_show (menu_autohide_bws_dht);
  gtk_container_add (GTK_CONTAINER (menu_dht_traffic_stats_visible_menu), menu_autohide_bws_dht);

  menu_bws_dht_in_visible = gtk_check_menu_item_new_with_mnemonic (_("Show inbound DHT traffic"));
  gtk_widget_set_name (menu_bws_dht_in_visible, "menu_bws_dht_in_visible");
  gtk_widget_show (menu_bws_dht_in_visible);
  gtk_container_add (GTK_CONTAINER (menu_dht_traffic_stats_visible_menu), menu_bws_dht_in_visible);

  menu_bws_dht_out_visible = gtk_check_menu_item_new_with_mnemonic (_("Show outbound DHT traffic"));
  gtk_widget_set_name (menu_bws_dht_out_visible, "menu_bws_dht_out_visible");
  gtk_widget_show (menu_bws_dht_out_visible);
  gtk_container_add (GTK_CONTAINER (menu_dht_traffic_stats_visible_menu), menu_bws_dht_out_visible);

  menu_help = gtk_menu_item_new_with_mnemonic (_("_Help"));
  gtk_widget_set_name (menu_help, "menu_help");
  gtk_widget_show (menu_help);
  gtk_container_add (GTK_CONTAINER (menubar_main), menu_help);

  menu_help_menu = gtk_menu_new ();
  gtk_widget_set_name (menu_help_menu, "menu_help_menu");
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menu_help), menu_help_menu);

  menu_faq = gtk_image_menu_item_new_with_mnemonic (_("_FAQ"));
  gtk_widget_set_name (menu_faq, "menu_faq");
  gtk_widget_show (menu_faq);
  gtk_container_add (GTK_CONTAINER (menu_help_menu), menu_faq);
  gtk_tooltips_set_tip (tooltips, menu_faq, _("Frequently Asked Questions"), NULL);

  image2293 = gtk_image_new_from_stock ("gtk-info", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image2293, "image2293");
  gtk_widget_show (image2293);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_faq), image2293);

  menu_glossary = gtk_menu_item_new_with_mnemonic (_("Glossary"));
  gtk_widget_set_name (menu_glossary, "menu_glossary");
  gtk_widget_show (menu_glossary);
  gtk_container_add (GTK_CONTAINER (menu_help_menu), menu_glossary);
  gtk_tooltips_set_tip (tooltips, menu_glossary, _("Glossary"), NULL);

  menu_about = gtk_image_menu_item_new_with_mnemonic (_("_About"));
  gtk_widget_set_name (menu_about, "menu_about");
  gtk_widget_show (menu_about);
  gtk_container_add (GTK_CONTAINER (menu_help_menu), menu_about);

  image2294 = gtk_image_new_from_stock ("gtk-about", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image2294, "image2294");
  gtk_widget_show (image2294);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menu_about), image2294);

  viewport_searchbar = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport_searchbar, "viewport_searchbar");
  gtk_widget_show (viewport_searchbar);
  gtk_box_pack_start (GTK_BOX (vbox12), viewport_searchbar, FALSE, TRUE, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport_searchbar), GTK_SHADOW_OUT);

  vbox160 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox160, "vbox160");
  gtk_widget_show (vbox160);
  gtk_container_add (GTK_CONTAINER (viewport_searchbar), vbox160);

  hbox9350 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox9350, "hbox9350");
  gtk_widget_show (hbox9350);
  gtk_box_pack_start (GTK_BOX (vbox160), hbox9350, TRUE, TRUE, 0);

  button_search = gtk_button_new ();
  gtk_widget_set_name (button_search, "button_search");
  gtk_widget_show (button_search);
  gtk_box_pack_start (GTK_BOX (hbox9350), button_search, FALSE, FALSE, 0);
  gtk_widget_set_sensitive (button_search, FALSE);
  gtk_button_set_relief (GTK_BUTTON (button_search), GTK_RELIEF_NONE);

  alignment106 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment106, "alignment106");
  gtk_widget_show (alignment106);
  gtk_container_add (GTK_CONTAINER (button_search), alignment106);

  hbox288 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox288, "hbox288");
  gtk_widget_show (hbox288);
  gtk_container_add (GTK_CONTAINER (alignment106), hbox288);

  image401 = gtk_image_new_from_stock ("gtk-find", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image401, "image401");
  gtk_widget_show (image401);
  gtk_box_pack_start (GTK_BOX (hbox288), image401, FALSE, FALSE, 0);

  label903 = gtk_label_new_with_mnemonic (_("_Search"));
  gtk_widget_set_name (label903, "label903");
  gtk_widget_show (label903);
  gtk_box_pack_start (GTK_BOX (hbox288), label903, FALSE, FALSE, 0);

  frame129 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame129, "frame129");
  gtk_widget_show (frame129);
  gtk_box_pack_start (GTK_BOX (hbox9350), frame129, TRUE, TRUE, 0);
  gtk_frame_set_shadow_type (GTK_FRAME (frame129), GTK_SHADOW_NONE);

  combo_search = gtk_combo_new ();
  g_object_set_data (G_OBJECT (GTK_COMBO (combo_search)->popwin),
                     "GladeParentKey", combo_search);
  gtk_widget_set_name (combo_search, "combo_search");
  gtk_widget_show (combo_search);
  gtk_container_add (GTK_CONTAINER (frame129), combo_search);

  entry_search = GTK_COMBO (combo_search)->entry;
  gtk_widget_set_name (entry_search, "entry_search");
  gtk_widget_show (entry_search);

  button_search_whats_new = gtk_button_new ();
  gtk_widget_set_name (button_search_whats_new, "button_search_whats_new");
  gtk_widget_show (button_search_whats_new);
  gtk_box_pack_start (GTK_BOX (hbox9350), button_search_whats_new, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, button_search_whats_new, _("Look for newest files shared by nodes in the network vicinity"), NULL);
  gtk_widget_add_accelerator (button_search_whats_new, "clicked", accel_group,
                              GDK_p, (GdkModifierType) GDK_CONTROL_MASK,
                              GTK_ACCEL_VISIBLE);
  gtk_button_set_relief (GTK_BUTTON (button_search_whats_new), GTK_RELIEF_NONE);

  alignment147 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment147, "alignment147");
  gtk_widget_show (alignment147);
  gtk_container_add (GTK_CONTAINER (button_search_whats_new), alignment147);

  hbox9349 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox9349, "hbox9349");
  gtk_widget_show (hbox9349);
  gtk_container_add (GTK_CONTAINER (alignment147), hbox9349);

  image2245 = gtk_image_new_from_stock ("gtk-dialog-question", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image2245, "image2245");
  gtk_widget_show (image2245);
  gtk_box_pack_start (GTK_BOX (hbox9349), image2245, FALSE, FALSE, 0);

  label1067 = gtk_label_new_with_mnemonic (_("What's New?"));
  gtk_widget_set_name (label1067, "label1067");
  gtk_widget_show (label1067);
  gtk_box_pack_start (GTK_BOX (hbox9349), label1067, FALSE, FALSE, 0);

  button_search_passive = gtk_button_new ();
  gtk_widget_set_name (button_search_passive, "button_search_passive");
  gtk_widget_show (button_search_passive);
  gtk_box_pack_start (GTK_BOX (hbox9350), button_search_passive, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, button_search_passive, _("A passive search matches any search results routed through this node"), NULL);
  gtk_widget_add_accelerator (button_search_passive, "clicked", accel_group,
                              GDK_p, (GdkModifierType) GDK_CONTROL_MASK,
                              GTK_ACCEL_VISIBLE);
  gtk_button_set_relief (GTK_BUTTON (button_search_passive), GTK_RELIEF_NONE);

  alignment110 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment110, "alignment110");
  gtk_widget_show (alignment110);
  gtk_container_add (GTK_CONTAINER (button_search_passive), alignment110);

  hbox9292 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox9292, "hbox9292");
  gtk_widget_show (hbox9292);
  gtk_container_add (GTK_CONTAINER (alignment110), hbox9292);

  image404 = gtk_image_new_from_stock ("gtk-index", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image404, "image404");
  gtk_widget_show (image404);
  gtk_box_pack_start (GTK_BOX (hbox9292), image404, FALSE, FALSE, 0);

  label911 = gtk_label_new_with_mnemonic (_("_Passive"));
  gtk_widget_set_name (label911, "label911");
  gtk_widget_show (label911);
  gtk_box_pack_start (GTK_BOX (hbox9292), label911, FALSE, FALSE, 0);

  hbox9351 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox9351, "hbox9351");
  gtk_widget_show (hbox9351);
  gtk_box_pack_start (GTK_BOX (vbox160), hbox9351, TRUE, TRUE, 0);

  frame_search_media_type = gtk_frame_new (NULL);
  gtk_widget_set_name (frame_search_media_type, "frame_search_media_type");
  gtk_widget_show (frame_search_media_type);
  gtk_box_pack_start (GTK_BOX (hbox9351), frame_search_media_type, FALSE, TRUE, 0);

  alignment144 = gtk_alignment_new (0.5, 0.5, 1, 1);
  gtk_widget_set_name (alignment144, "alignment144");
  gtk_widget_show (alignment144);
  gtk_container_add (GTK_CONTAINER (frame_search_media_type), alignment144);
  gtk_alignment_set_padding (GTK_ALIGNMENT (alignment144), 0, 0, 2, 0);

  hbox9346 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox9346, "hbox9346");
  gtk_widget_show (hbox9346);
  gtk_container_add (GTK_CONTAINER (alignment144), hbox9346);

  button_search_media_type_any = gtk_button_new ();
  gtk_widget_set_name (button_search_media_type_any, "button_search_media_type_any");
  gtk_widget_show (button_search_media_type_any);
  gtk_box_pack_start (GTK_BOX (hbox9346), button_search_media_type_any, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, button_search_media_type_any, _("Do not specify any media type (will match any kind of files remotely)"), NULL);
  gtk_widget_add_accelerator (button_search_media_type_any, "clicked", accel_group,
                              GDK_p, (GdkModifierType) GDK_CONTROL_MASK,
                              GTK_ACCEL_VISIBLE);
  gtk_button_set_relief (GTK_BUTTON (button_search_media_type_any), GTK_RELIEF_NONE);

  alignment145 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment145, "alignment145");
  gtk_widget_show (alignment145);
  gtk_container_add (GTK_CONTAINER (button_search_media_type_any), alignment145);

  hbox9347 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox9347, "hbox9347");
  gtk_widget_show (hbox9347);
  gtk_container_add (GTK_CONTAINER (alignment145), hbox9347);

  image2244 = gtk_image_new_from_stock ("gtk-remove", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image2244, "image2244");
  gtk_widget_show (image2244);
  gtk_box_pack_start (GTK_BOX (hbox9347), image2244, FALSE, FALSE, 0);

  label1065 = gtk_label_new_with_mnemonic (_("Unspecified"));
  gtk_widget_set_name (label1065, "label1065");
  gtk_widget_show (label1065);
  gtk_box_pack_start (GTK_BOX (hbox9347), label1065, FALSE, FALSE, 0);

  checkbutton_config_search_media_type_audio = gtk_check_button_new_with_mnemonic (_("Audio"));
  gtk_widget_set_name (checkbutton_config_search_media_type_audio, "checkbutton_config_search_media_type_audio");
  gtk_widget_show (checkbutton_config_search_media_type_audio);
  gtk_box_pack_start (GTK_BOX (hbox9346), checkbutton_config_search_media_type_audio, FALSE, FALSE, 0);

  checkbutton_config_search_media_type_video = gtk_check_button_new_with_mnemonic (_("Video"));
  gtk_widget_set_name (checkbutton_config_search_media_type_video, "checkbutton_config_search_media_type_video");
  gtk_widget_show (checkbutton_config_search_media_type_video);
  gtk_box_pack_start (GTK_BOX (hbox9346), checkbutton_config_search_media_type_video, FALSE, FALSE, 0);

  checkbutton_config_search_media_type_document = gtk_check_button_new_with_mnemonic (_("Document"));
  gtk_widget_set_name (checkbutton_config_search_media_type_document, "checkbutton_config_search_media_type_document");
  gtk_widget_show (checkbutton_config_search_media_type_document);
  gtk_box_pack_start (GTK_BOX (hbox9346), checkbutton_config_search_media_type_document, FALSE, FALSE, 0);

  checkbutton_config_search_media_type_image = gtk_check_button_new_with_mnemonic (_("Image"));
  gtk_widget_set_name (checkbutton_config_search_media_type_image, "checkbutton_config_search_media_type_image");
  gtk_widget_show (checkbutton_config_search_media_type_image);
  gtk_box_pack_start (GTK_BOX (hbox9346), checkbutton_config_search_media_type_image, FALSE, FALSE, 0);

  checkbutton_config_search_media_type_archive = gtk_check_button_new_with_mnemonic (_("Archive"));
  gtk_widget_set_name (checkbutton_config_search_media_type_archive, "checkbutton_config_search_media_type_archive");
  gtk_widget_show (checkbutton_config_search_media_type_archive);
  gtk_box_pack_start (GTK_BOX (hbox9346), checkbutton_config_search_media_type_archive, FALSE, FALSE, 0);

  label1064 = gtk_label_new (_("Search Media Type"));
  gtk_widget_set_name (label1064, "label1064");
  gtk_widget_show (label1064);
  gtk_frame_set_label_widget (GTK_FRAME (frame_search_media_type), label1064);
  gtk_label_set_use_markup (GTK_LABEL (label1064), TRUE);

  frame152 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame152, "frame152");
  gtk_widget_show (frame152);
  gtk_box_pack_start (GTK_BOX (hbox9351), frame152, FALSE, TRUE, 2);

  alignment146 = gtk_alignment_new (0.5, 0.5, 1, 1);
  gtk_widget_set_name (alignment146, "alignment146");
  gtk_widget_show (alignment146);
  gtk_container_add (GTK_CONTAINER (frame152), alignment146);
  gtk_alignment_set_padding (GTK_ALIGNMENT (alignment146), 0, 0, 2, 0);

  hbox9348 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox9348, "hbox9348");
  gtk_widget_show (hbox9348);
  gtk_container_add (GTK_CONTAINER (alignment146), hbox9348);

  option_menu_search_lifetime = gtk_option_menu_new ();
  gtk_widget_set_name (option_menu_search_lifetime, "option_menu_search_lifetime");
  gtk_widget_show (option_menu_search_lifetime);
  gtk_box_pack_start (GTK_BOX (hbox9348), option_menu_search_lifetime, FALSE, FALSE, 0);

  menu1 = gtk_menu_new ();
  gtk_widget_set_name (menu1, "menu1");

  gtk_option_menu_set_menu (GTK_OPTION_MENU (option_menu_search_lifetime), menu1);

  optionmenu_search_filter = gtk_option_menu_new ();
  gtk_widget_set_name (optionmenu_search_filter, "optionmenu_search_filter");
  gtk_widget_show (optionmenu_search_filter);
  gtk_box_pack_start (GTK_BOX (hbox9348), optionmenu_search_filter, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, optionmenu_search_filter, _("Search filters to apply locally on newly created searches."), NULL);

  convertwidget20 = gtk_menu_new ();
  gtk_widget_set_name (convertwidget20, "convertwidget20");

  gtk_option_menu_set_menu (GTK_OPTION_MENU (optionmenu_search_filter), convertwidget20);

  label1066 = gtk_label_new (_("Search Configuration"));
  gtk_widget_set_name (label1066, "label1066");
  gtk_widget_show (label1066);
  gtk_frame_set_label_widget (GTK_FRAME (frame152), label1066);
  gtk_label_set_use_markup (GTK_LABEL (label1066), TRUE);

  hpaned_main = gtk_hpaned_new ();
  gtk_widget_set_name (hpaned_main, "hpaned_main");
  gtk_widget_show (hpaned_main);
  gtk_box_pack_start (GTK_BOX (vbox12), hpaned_main, TRUE, TRUE, 0);
  gtk_paned_set_position (GTK_PANED (hpaned_main), 200);

  vbox_sidebar = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox_sidebar, "vbox_sidebar");
  gtk_widget_show (vbox_sidebar);
  gtk_paned_pack1 (GTK_PANED (hpaned_main), vbox_sidebar, FALSE, FALSE);

  sw_searches = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (sw_searches, "sw_searches");
  gtk_widget_show (sw_searches);
  gtk_box_pack_start (GTK_BOX (vbox_sidebar), sw_searches, TRUE, TRUE, 0);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw_searches), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw_searches), GTK_SHADOW_IN);

  tree_view_search = gtk_tree_view_new ();
  gtk_widget_set_name (tree_view_search, "tree_view_search");
  gtk_widget_show (tree_view_search);
  gtk_container_add (GTK_CONTAINER (sw_searches), tree_view_search);

  vbox_sidebar_stats = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox_sidebar_stats, "vbox_sidebar_stats");
  gtk_widget_show (vbox_sidebar_stats);
  gtk_box_pack_start (GTK_BOX (vbox_sidebar), vbox_sidebar_stats, FALSE, TRUE, 0);

  frame71 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame71, "frame71");
  gtk_widget_show (frame71);
  gtk_box_pack_start (GTK_BOX (vbox_sidebar_stats), frame71, FALSE, TRUE, 0);
  gtk_frame_set_shadow_type (GTK_FRAME (frame71), GTK_SHADOW_NONE);

  vbox105 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox105, "vbox105");
  gtk_widget_show (vbox105);
  gtk_container_add (GTK_CONTAINER (frame71), vbox105);

  hbox_stats_connections = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox_stats_connections, "hbox_stats_connections");
  gtk_widget_show (hbox_stats_connections);
  gtk_box_pack_start (GTK_BOX (vbox105), hbox_stats_connections, FALSE, TRUE, 0);

  eventbox8 = gtk_event_box_new ();
  gtk_widget_set_name (eventbox8, "eventbox8");
  gtk_widget_show (eventbox8);
  gtk_box_pack_start (GTK_BOX (hbox_stats_connections), eventbox8, FALSE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox8, _("Gnutella peers"), NULL);

  image131 = create_pixmap (main_window, "smallserver.xpm");
  gtk_widget_set_name (image131, "image131");
  gtk_widget_show (image131);
  gtk_container_add (GTK_CONTAINER (eventbox8), image131);
  gtk_misc_set_alignment (GTK_MISC (image131), 0, 0.5);

  progressbar_connections = gtk_progress_bar_new ();
  gtk_widget_set_name (progressbar_connections, "progressbar_connections");
  gtk_widget_show (progressbar_connections);
  gtk_box_pack_start (GTK_BOX (hbox_stats_connections), progressbar_connections, TRUE, TRUE, 0);

  hbox_stats_uploads = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox_stats_uploads, "hbox_stats_uploads");
  gtk_widget_show (hbox_stats_uploads);
  gtk_box_pack_start (GTK_BOX (vbox105), hbox_stats_uploads, FALSE, TRUE, 0);

  eventbox7 = gtk_event_box_new ();
  gtk_widget_set_name (eventbox7, "eventbox7");
  gtk_widget_show (eventbox7);
  gtk_box_pack_start (GTK_BOX (hbox_stats_uploads), eventbox7, FALSE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox7, _("Uploads"), NULL);

  image130 = create_pixmap (main_window, "upload.xpm");
  gtk_widget_set_name (image130, "image130");
  gtk_widget_show (image130);
  gtk_container_add (GTK_CONTAINER (eventbox7), image130);
  gtk_misc_set_alignment (GTK_MISC (image130), 0, 0.5);

  progressbar_uploads = gtk_progress_bar_new ();
  gtk_widget_set_name (progressbar_uploads, "progressbar_uploads");
  gtk_widget_show (progressbar_uploads);
  gtk_box_pack_start (GTK_BOX (hbox_stats_uploads), progressbar_uploads, TRUE, TRUE, 0);

  hbox_stats_downloads = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox_stats_downloads, "hbox_stats_downloads");
  gtk_widget_show (hbox_stats_downloads);
  gtk_box_pack_start (GTK_BOX (vbox105), hbox_stats_downloads, FALSE, TRUE, 0);

  eventbox10 = gtk_event_box_new ();
  gtk_widget_set_name (eventbox10, "eventbox10");
  gtk_widget_show (eventbox10);
  gtk_box_pack_start (GTK_BOX (hbox_stats_downloads), eventbox10, FALSE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox10, _("Downloads"), NULL);

  image132 = create_pixmap (main_window, "download.xpm");
  gtk_widget_set_name (image132, "image132");
  gtk_widget_show (image132);
  gtk_container_add (GTK_CONTAINER (eventbox10), image132);
  gtk_misc_set_alignment (GTK_MISC (image132), 0, 0.5);

  progressbar_downloads = gtk_progress_bar_new ();
  gtk_widget_set_name (progressbar_downloads, "progressbar_downloads");
  gtk_widget_show (progressbar_downloads);
  gtk_box_pack_start (GTK_BOX (hbox_stats_downloads), progressbar_downloads, TRUE, TRUE, 0);

  frame_bws_inout = gtk_frame_new (NULL);
  gtk_widget_set_name (frame_bws_inout, "frame_bws_inout");
  gtk_widget_show (frame_bws_inout);
  gtk_box_pack_start (GTK_BOX (vbox_sidebar_stats), frame_bws_inout, FALSE, TRUE, 0);
  gtk_frame_set_label_align (GTK_FRAME (frame_bws_inout), 0.5, 0.5);
  gtk_frame_set_shadow_type (GTK_FRAME (frame_bws_inout), GTK_SHADOW_NONE);

  vbox42 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox42, "vbox42");
  gtk_widget_show (vbox42);
  gtk_container_add (GTK_CONTAINER (frame_bws_inout), vbox42);

  progressbar_bws_in = gtk_progress_bar_new ();
  gtk_widget_set_name (progressbar_bws_in, "progressbar_bws_in");
  gtk_widget_show (progressbar_bws_in);
  gtk_box_pack_start (GTK_BOX (vbox42), progressbar_bws_in, FALSE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, progressbar_bws_in, _("Click to toggle display."), NULL);
  gtk_widget_set_events (progressbar_bws_in, GDK_BUTTON_PRESS_MASK);

  progressbar_bws_out = gtk_progress_bar_new ();
  gtk_widget_set_name (progressbar_bws_out, "progressbar_bws_out");
  gtk_widget_show (progressbar_bws_out);
  gtk_box_pack_start (GTK_BOX (vbox42), progressbar_bws_out, FALSE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, progressbar_bws_out, _("Click to toggle display."), NULL);
  gtk_widget_set_events (progressbar_bws_out, GDK_BUTTON_PRESS_MASK);

  label277 = gtk_label_new (_("HTTP traffic"));
  gtk_widget_set_name (label277, "label277");
  gtk_widget_show (label277);
  gtk_frame_set_label_widget (GTK_FRAME (frame_bws_inout), label277);

  frame_bws_ginout = gtk_frame_new (NULL);
  gtk_widget_set_name (frame_bws_ginout, "frame_bws_ginout");
  gtk_widget_show (frame_bws_ginout);
  gtk_box_pack_start (GTK_BOX (vbox_sidebar_stats), frame_bws_ginout, FALSE, TRUE, 0);
  gtk_frame_set_label_align (GTK_FRAME (frame_bws_ginout), 0.5, 0.5);
  gtk_frame_set_shadow_type (GTK_FRAME (frame_bws_ginout), GTK_SHADOW_NONE);

  vbox43 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox43, "vbox43");
  gtk_widget_show (vbox43);
  gtk_container_add (GTK_CONTAINER (frame_bws_ginout), vbox43);

  progressbar_bws_gin = gtk_progress_bar_new ();
  gtk_widget_set_name (progressbar_bws_gin, "progressbar_bws_gin");
  gtk_widget_show (progressbar_bws_gin);
  gtk_box_pack_start (GTK_BOX (vbox43), progressbar_bws_gin, FALSE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, progressbar_bws_gin, _("Click to toggle display."), NULL);
  gtk_widget_set_events (progressbar_bws_gin, GDK_BUTTON_PRESS_MASK);

  progressbar_bws_gout = gtk_progress_bar_new ();
  gtk_widget_set_name (progressbar_bws_gout, "progressbar_bws_gout");
  gtk_widget_show (progressbar_bws_gout);
  gtk_box_pack_start (GTK_BOX (vbox43), progressbar_bws_gout, FALSE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, progressbar_bws_gout, _("Click to toggle display."), NULL);
  gtk_widget_set_events (progressbar_bws_gout, GDK_BUTTON_PRESS_MASK);

  label278 = gtk_label_new (_("Gnutella traffic"));
  gtk_widget_set_name (label278, "label278");
  gtk_widget_show (label278);
  gtk_frame_set_label_widget (GTK_FRAME (frame_bws_ginout), label278);

  frame_bws_glinout = gtk_frame_new (NULL);
  gtk_widget_set_name (frame_bws_glinout, "frame_bws_glinout");
  gtk_widget_show (frame_bws_glinout);
  gtk_box_pack_start (GTK_BOX (vbox_sidebar_stats), frame_bws_glinout, FALSE, TRUE, 0);
  gtk_frame_set_label_align (GTK_FRAME (frame_bws_glinout), 0.5, 0.5);
  gtk_frame_set_shadow_type (GTK_FRAME (frame_bws_glinout), GTK_SHADOW_NONE);

  vbox104 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox104, "vbox104");
  gtk_widget_show (vbox104);
  gtk_container_add (GTK_CONTAINER (frame_bws_glinout), vbox104);

  progressbar_bws_lin = gtk_progress_bar_new ();
  gtk_widget_set_name (progressbar_bws_lin, "progressbar_bws_lin");
  gtk_widget_show (progressbar_bws_lin);
  gtk_box_pack_start (GTK_BOX (vbox104), progressbar_bws_lin, FALSE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, progressbar_bws_lin, _("Click to toggle display."), NULL);
  gtk_widget_set_events (progressbar_bws_lin, GDK_BUTTON_PRESS_MASK);

  progressbar_bws_lout = gtk_progress_bar_new ();
  gtk_widget_set_name (progressbar_bws_lout, "progressbar_bws_lout");
  gtk_widget_show (progressbar_bws_lout);
  gtk_box_pack_start (GTK_BOX (vbox104), progressbar_bws_lout, FALSE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, progressbar_bws_lout, _("Click to toggle display."), NULL);
  gtk_widget_set_events (progressbar_bws_lout, GDK_BUTTON_PRESS_MASK);

  label605 = gtk_label_new (_("Leaf traffic"));
  gtk_widget_set_name (label605, "label605");
  gtk_widget_show (label605);
  gtk_frame_set_label_widget (GTK_FRAME (frame_bws_glinout), label605);

  frame_bws_dht_inout = gtk_frame_new (NULL);
  gtk_widget_set_name (frame_bws_dht_inout, "frame_bws_dht_inout");
  gtk_widget_show (frame_bws_dht_inout);
  gtk_box_pack_start (GTK_BOX (vbox_sidebar_stats), frame_bws_dht_inout, FALSE, TRUE, 0);
  gtk_frame_set_label_align (GTK_FRAME (frame_bws_dht_inout), 0.5, 0.5);
  gtk_frame_set_shadow_type (GTK_FRAME (frame_bws_dht_inout), GTK_SHADOW_NONE);

  vbox155 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox155, "vbox155");
  gtk_widget_show (vbox155);
  gtk_container_add (GTK_CONTAINER (frame_bws_dht_inout), vbox155);

  progressbar_bws_dht_in = gtk_progress_bar_new ();
  gtk_widget_set_name (progressbar_bws_dht_in, "progressbar_bws_dht_in");
  gtk_widget_show (progressbar_bws_dht_in);
  gtk_box_pack_start (GTK_BOX (vbox155), progressbar_bws_dht_in, FALSE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, progressbar_bws_dht_in, _("Click to toggle display."), NULL);
  gtk_widget_set_events (progressbar_bws_dht_in, GDK_BUTTON_PRESS_MASK);

  progressbar_bws_dht_out = gtk_progress_bar_new ();
  gtk_widget_set_name (progressbar_bws_dht_out, "progressbar_bws_dht_out");
  gtk_widget_show (progressbar_bws_dht_out);
  gtk_box_pack_start (GTK_BOX (vbox155), progressbar_bws_dht_out, FALSE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, progressbar_bws_dht_out, _("Click to toggle display."), NULL);
  gtk_widget_set_events (progressbar_bws_dht_out, GDK_BUTTON_PRESS_MASK);

  label1031 = gtk_label_new (_("DHT traffic"));
  gtk_widget_set_name (label1031, "label1031");
  gtk_widget_show (label1031);
  gtk_frame_set_label_widget (GTK_FRAME (frame_bws_dht_inout), label1031);

  vbox_right = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox_right, "vbox_right");
  gtk_widget_show (vbox_right);
  gtk_paned_pack2 (GTK_PANED (hpaned_main), vbox_right, TRUE, TRUE);

  notebook_main = gtk_notebook_new ();
  gtk_widget_set_name (notebook_main, "notebook_main");
  gtk_widget_show (notebook_main);
  gtk_box_pack_start (GTK_BOX (vbox_right), notebook_main, TRUE, TRUE, 0);
  gtk_notebook_set_scrollable (GTK_NOTEBOOK (notebook_main), TRUE);

  empty_notebook_page = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (empty_notebook_page);
  gtk_container_add (GTK_CONTAINER (notebook_main), empty_notebook_page);

  label590 = gtk_label_new ("");
  gtk_widget_set_name (label590, "label590");
  gtk_widget_show (label590);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_main), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_main), 0), label590);

  hbox_statusbar = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox_statusbar, "hbox_statusbar");
  gtk_widget_show (hbox_statusbar);
  gtk_box_pack_start (GTK_BOX (vbox12), hbox_statusbar, FALSE, TRUE, 0);

  togglebutton_online = gtk_toggle_button_new ();
  gtk_widget_set_name (togglebutton_online, "togglebutton_online");
  gtk_widget_show (togglebutton_online);
  gtk_box_pack_start (GTK_BOX (hbox_statusbar), togglebutton_online, FALSE, TRUE, 0);
  GTK_WIDGET_UNSET_FLAGS (togglebutton_online, GTK_CAN_FOCUS);
  gtk_button_set_relief (GTK_BUTTON (togglebutton_online), GTK_RELIEF_NONE);

  hbox170 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox170, "hbox170");
  gtk_widget_show (hbox170);
  gtk_container_add (GTK_CONTAINER (togglebutton_online), hbox170);
  gtk_widget_set_size_request (hbox170, 28, 6);

  eventbox9 = gtk_event_box_new ();
  gtk_widget_set_name (eventbox9, "eventbox9");
  gtk_widget_show (eventbox9);
  gtk_box_pack_start (GTK_BOX (hbox170), eventbox9, FALSE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox9, _("You seem to be offline."), NULL);

  image_offline = create_pixmap (main_window, "offline.xpm");
  gtk_widget_set_name (image_offline, "image_offline");
  gtk_widget_show (image_offline);
  gtk_container_add (GTK_CONTAINER (eventbox9), image_offline);

  image_online = create_pixmap (main_window, "online.xpm");
  gtk_widget_set_name (image_online, "image_online");
  gtk_widget_show (image_online);
  gtk_box_pack_start (GTK_BOX (hbox170), image_online, FALSE, TRUE, 0);

  hbox_port_mapping = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox_port_mapping, "hbox_port_mapping");
  gtk_widget_show (hbox_port_mapping);
  gtk_box_pack_start (GTK_BOX (hbox_statusbar), hbox_port_mapping, FALSE, TRUE, 0);

  eventbox_port_mapping_possible = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_port_mapping_possible, "eventbox_port_mapping_possible");
  gtk_widget_show (eventbox_port_mapping_possible);
  gtk_box_pack_start (GTK_BOX (hbox_port_mapping), eventbox_port_mapping_possible, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox_port_mapping_possible, _("Port mapping possible through UPnP or NAT-PMP."), NULL);

  image_port_mapping_possible = create_pixmap (main_window, "upnp-unusable.xpm");
  gtk_widget_set_name (image_port_mapping_possible, "image_port_mapping_possible");
  gtk_widget_show (image_port_mapping_possible);
  gtk_container_add (GTK_CONTAINER (eventbox_port_mapping_possible), image_port_mapping_possible);

  eventbox_upnp_port_mapping_successful = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_upnp_port_mapping_successful, "eventbox_upnp_port_mapping_successful");
  gtk_widget_show (eventbox_upnp_port_mapping_successful);
  gtk_box_pack_start (GTK_BOX (hbox_port_mapping), eventbox_upnp_port_mapping_successful, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox_upnp_port_mapping_successful, _("Port mapping configured through UPnP."), NULL);

  image_upnp_successful = create_pixmap (main_window, "upnp.xpm");
  gtk_widget_set_name (image_upnp_successful, "image_upnp_successful");
  gtk_widget_show (image_upnp_successful);
  gtk_container_add (GTK_CONTAINER (eventbox_upnp_port_mapping_successful), image_upnp_successful);

  eventbox_natpmp_port_mapping_successful = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_natpmp_port_mapping_successful, "eventbox_natpmp_port_mapping_successful");
  gtk_widget_show (eventbox_natpmp_port_mapping_successful);
  gtk_box_pack_start (GTK_BOX (hbox_port_mapping), eventbox_natpmp_port_mapping_successful, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox_natpmp_port_mapping_successful, _("Port mapping configured through NAT-PMP."), NULL);

  image_natpmp_successful = create_pixmap (main_window, "natpmp.xpm");
  gtk_widget_set_name (image_natpmp_successful, "image_natpmp_successful");
  gtk_widget_show (image_natpmp_successful);
  gtk_container_add (GTK_CONTAINER (eventbox_natpmp_port_mapping_successful), image_natpmp_successful);

  statusbar = gtk_statusbar_new ();
  gtk_widget_set_name (statusbar, "statusbar");
  gtk_widget_show (statusbar);
  gtk_box_pack_start (GTK_BOX (hbox_statusbar), statusbar, TRUE, TRUE, 0);
  gtk_statusbar_set_has_resize_grip (GTK_STATUSBAR (statusbar), FALSE);

  hbox211 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox211, "hbox211");
  gtk_widget_show (hbox211);
  gtk_box_pack_start (GTK_BOX (hbox_statusbar), hbox211, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (hbox211), 2);

  eventbox_image_download_queue_frozen = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_download_queue_frozen, "eventbox_image_download_queue_frozen");
  gtk_widget_show (eventbox_image_download_queue_frozen);
  gtk_box_pack_start (GTK_BOX (hbox211), eventbox_image_download_queue_frozen, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox_image_download_queue_frozen, _("Download queue is frozen."), NULL);

  image_download_queue_frozen = create_pixmap (main_window, "pause.xpm");
  gtk_widget_set_name (image_download_queue_frozen, "image_download_queue_frozen");
  gtk_widget_show (image_download_queue_frozen);
  gtk_container_add (GTK_CONTAINER (eventbox_image_download_queue_frozen), image_download_queue_frozen);
  gtk_misc_set_padding (GTK_MISC (image_download_queue_frozen), 1, 0);

  eventbox_image_chip = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_chip, "eventbox_image_chip");
  gtk_widget_show (eventbox_image_chip);
  gtk_box_pack_start (GTK_BOX (hbox211), eventbox_image_chip, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox_image_chip, _("CPU overloaded"), NULL);

  image_chip = create_pixmap (main_window, "chip.xpm");
  gtk_widget_set_name (image_chip, "image_chip");
  gtk_widget_show (image_chip);
  gtk_container_add (GTK_CONTAINER (eventbox_image_chip), image_chip);
  gtk_misc_set_padding (GTK_MISC (image_chip), 1, 0);

  eventbox_net_buffer_shortage = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_net_buffer_shortage, "eventbox_net_buffer_shortage");
  gtk_widget_show (eventbox_net_buffer_shortage);
  gtk_box_pack_start (GTK_BOX (hbox211), eventbox_net_buffer_shortage, TRUE, TRUE, 0);

  image_net_buffer_shortage = create_pixmap (main_window, "hungup.xpm");
  gtk_widget_set_name (image_net_buffer_shortage, "image_net_buffer_shortage");
  gtk_widget_show (image_net_buffer_shortage);
  gtk_container_add (GTK_CONTAINER (eventbox_net_buffer_shortage), image_net_buffer_shortage);
  gtk_misc_set_padding (GTK_MISC (image_net_buffer_shortage), 1, 0);

  eventbox_tcp_no_listening = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_tcp_no_listening, "eventbox_tcp_no_listening");
  gtk_widget_show (eventbox_tcp_no_listening);
  gtk_box_pack_start (GTK_BOX (hbox211), eventbox_tcp_no_listening, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox_tcp_no_listening, _("Download queue is frozen."), NULL);

  image_tcp_no_listening = create_pixmap (main_window, "no_listening.xpm");
  gtk_widget_set_name (image_tcp_no_listening, "image_tcp_no_listening");
  gtk_widget_show (image_tcp_no_listening);
  gtk_container_add (GTK_CONTAINER (eventbox_tcp_no_listening), image_tcp_no_listening);
  gtk_misc_set_padding (GTK_MISC (image_tcp_no_listening), 1, 0);

  eventbox_image_warning = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_warning, "eventbox_image_warning");
  gtk_widget_show (eventbox_image_warning);
  gtk_box_pack_start (GTK_BOX (hbox211), eventbox_image_warning, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox_image_warning, _("Your uploads are stalling at an abnormal rate, indicating that your bandwidth is probably saturated. You should not run as an ultra node, and try to reduce the allocated bandwidth to gtk-gnutella to avoid saturating both your incoming and outgoing paths."), NULL);

  image_warning = create_pixmap (main_window, "warning.xpm");
  gtk_widget_set_name (image_warning, "image_warning");
  gtk_widget_show (image_warning);
  gtk_container_add (GTK_CONTAINER (eventbox_image_warning), image_warning);

  hbox9345 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox9345, "hbox9345");
  gtk_widget_show (hbox9345);
  gtk_box_pack_start (GTK_BOX (hbox211), hbox9345, TRUE, TRUE, 0);

  eventbox_early_stall_1 = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_early_stall_1, "eventbox_early_stall_1");
  gtk_widget_show (eventbox_early_stall_1);
  gtk_box_pack_start (GTK_BOX (hbox9345), eventbox_early_stall_1, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox_early_stall_1, _("Capping HTTP outgoing bandwidth."), NULL);

  image_early_stall_1 = create_pixmap (main_window, "upload.xpm");
  gtk_widget_set_name (image_early_stall_1, "image_early_stall_1");
  gtk_widget_show (image_early_stall_1);
  gtk_container_add (GTK_CONTAINER (eventbox_early_stall_1), image_early_stall_1);

  eventbox_early_stall_2 = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_early_stall_2, "eventbox_early_stall_2");
  gtk_widget_show (eventbox_early_stall_2);
  gtk_box_pack_start (GTK_BOX (hbox9345), eventbox_early_stall_2, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox_early_stall_2, _("Disabled stealing of outgoing HTTP bandwidth."), NULL);

  image_early_stall_2 = create_pixmap (main_window, "upload-yellow.xpm");
  gtk_widget_set_name (image_early_stall_2, "image_early_stall_2");
  gtk_widget_show (image_early_stall_2);
  gtk_container_add (GTK_CONTAINER (eventbox_early_stall_2), image_early_stall_2);

  eventbox_early_stall_3 = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_early_stall_3, "eventbox_early_stall_3");
  gtk_widget_show (eventbox_early_stall_3);
  gtk_box_pack_start (GTK_BOX (hbox9345), eventbox_early_stall_3, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox_early_stall_3, _("Splitting outgoing HTTP bandwidth evenly."), NULL);

  image_early_stall_3 = create_pixmap (main_window, "upload-red.xpm");
  gtk_widget_set_name (image_early_stall_3, "image_early_stall_3");
  gtk_widget_show (image_early_stall_3);
  gtk_container_add (GTK_CONTAINER (eventbox_early_stall_3), image_early_stall_3);

  eventbox_image_fd_shortage = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_fd_shortage, "eventbox_image_fd_shortage");
  gtk_widget_show (eventbox_image_fd_shortage);
  gtk_box_pack_start (GTK_BOX (hbox211), eventbox_image_fd_shortage, TRUE, TRUE, 0);

  image_fd_shortage = create_pixmap (main_window, "clanbomber_yellow.xpm");
  gtk_widget_set_name (image_fd_shortage, "image_fd_shortage");
  gtk_widget_show (image_fd_shortage);
  gtk_container_add (GTK_CONTAINER (eventbox_image_fd_shortage), image_fd_shortage);

  eventbox_image_fd_runout = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_fd_runout, "eventbox_image_fd_runout");
  gtk_widget_show (eventbox_image_fd_runout);
  gtk_box_pack_start (GTK_BOX (hbox211), eventbox_image_fd_runout, TRUE, TRUE, 0);

  image_fd_runout = create_pixmap (main_window, "clanbomber_red.xpm");
  gtk_widget_set_name (image_fd_runout, "image_fd_runout");
  gtk_widget_show (image_fd_runout);
  gtk_container_add (GTK_CONTAINER (eventbox_image_fd_runout), image_fd_runout);

  eventbox_image_ancient = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_ancient, "eventbox_image_ancient");
  gtk_widget_show (eventbox_image_ancient);
  gtk_box_pack_start (GTK_BOX (hbox211), eventbox_image_ancient, TRUE, TRUE, 0);

  image_ancient = create_pixmap (main_window, "stock_form-time-field-16.xpm");
  gtk_widget_set_name (image_ancient, "image_ancient");
  gtk_widget_show (image_ancient);
  gtk_container_add (GTK_CONTAINER (eventbox_image_ancient), image_ancient);

  eventbox_image_save = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_save, "eventbox_image_save");
  gtk_widget_show (eventbox_image_save);
  gtk_box_pack_start (GTK_BOX (hbox211), eventbox_image_save, TRUE, TRUE, 0);

  image_save = create_pixmap (main_window, "save.xpm");
  gtk_widget_set_name (image_save, "image_save");
  gtk_widget_show (image_save);
  gtk_container_add (GTK_CONTAINER (eventbox_image_save), image_save);
  gtk_misc_set_padding (GTK_MISC (image_save), 1, 0);

  eventbox_image_sha = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_sha, "eventbox_image_sha");
  gtk_widget_show (eventbox_image_sha);
  gtk_box_pack_start (GTK_BOX (hbox211), eventbox_image_sha, TRUE, TRUE, 0);

  image_sha = create_pixmap (main_window, "booksha.xpm");
  gtk_widget_set_name (image_sha, "image_sha");
  gtk_widget_show (image_sha);
  gtk_container_add (GTK_CONTAINER (eventbox_image_sha), image_sha);

  eventbox_image_shav = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_shav, "eventbox_image_shav");
  gtk_widget_show (eventbox_image_shav);
  gtk_box_pack_start (GTK_BOX (hbox211), eventbox_image_shav, TRUE, TRUE, 0);

  image_shav = create_pixmap (main_window, "bookshav.xpm");
  gtk_widget_set_name (image_shav, "image_shav");
  gtk_widget_show (image_shav);
  gtk_container_add (GTK_CONTAINER (eventbox_image_shav), image_shav);
  gtk_misc_set_padding (GTK_MISC (image_shav), 1, 0);

  eventbox_image_tth = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_tth, "eventbox_image_tth");
  gtk_widget_show (eventbox_image_tth);
  gtk_box_pack_start (GTK_BOX (hbox211), eventbox_image_tth, TRUE, TRUE, 0);

  image_tth = create_pixmap (main_window, "booktth.xpm");
  gtk_widget_set_name (image_tth, "image_tth");
  gtk_widget_show (image_tth);
  gtk_container_add (GTK_CONTAINER (eventbox_image_tth), image_tth);

  eventbox_image_tthv = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_tthv, "eventbox_image_tthv");
  gtk_widget_show (eventbox_image_tthv);
  gtk_box_pack_start (GTK_BOX (hbox211), eventbox_image_tthv, TRUE, TRUE, 0);

  image_tthv = create_pixmap (main_window, "booktthv.xpm");
  gtk_widget_set_name (image_tthv, "image_tthv");
  gtk_widget_show (image_tthv);
  gtk_container_add (GTK_CONTAINER (eventbox_image_tthv), image_tthv);
  gtk_misc_set_padding (GTK_MISC (image_tthv), 1, 0);

  eventbox_image_lib = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_lib, "eventbox_image_lib");
  gtk_widget_show (eventbox_image_lib);
  gtk_box_pack_start (GTK_BOX (hbox211), eventbox_image_lib, TRUE, TRUE, 0);

  image_lib = create_pixmap (main_window, "booklib.xpm");
  gtk_widget_set_name (image_lib, "image_lib");
  gtk_widget_show (image_lib);
  gtk_container_add (GTK_CONTAINER (eventbox_image_lib), image_lib);

  hbox147 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox147, "hbox147");
  gtk_widget_show (hbox147);
  gtk_box_pack_start (GTK_BOX (hbox211), hbox147, TRUE, TRUE, 0);

  eventbox_image_firewall = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_firewall, "eventbox_image_firewall");
  gtk_widget_show (eventbox_image_firewall);
  gtk_box_pack_start (GTK_BOX (hbox147), eventbox_image_firewall, FALSE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox_image_firewall, _("You appear to be firewalled, both TCP-wise and UDP-wise. You will not see any push results, which may prevent you from seeing a large amount of results. You will not be able to send queries requesting out-of-band delivery of query hits."), NULL);

  image_firewall = create_pixmap (main_window, "firewall.xpm");
  gtk_widget_set_name (image_firewall, "image_firewall");
  gtk_widget_show (image_firewall);
  gtk_container_add (GTK_CONTAINER (eventbox_image_firewall), image_firewall);
  gtk_widget_set_size_request (image_firewall, 16, 16);
  gtk_misc_set_padding (GTK_MISC (image_firewall), 1, 0);

  eventbox_image_firewall_punchable = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_firewall_punchable, "eventbox_image_firewall_punchable");
  gtk_widget_show (eventbox_image_firewall_punchable);
  gtk_box_pack_start (GTK_BOX (hbox147), eventbox_image_firewall_punchable, TRUE, TRUE, 0);
  gtk_widget_set_size_request (eventbox_image_firewall_punchable, 16, 16);
  gtk_tooltips_set_tip (tooltips, eventbox_image_firewall_punchable, _("You appear to be firewalled, both TCP-wise and UDP-wise. You will not see any push results, which may prevent you from seeing a large amount of results. You will not be able to send queries requesting out-of-band delivery of query hits. However, it is possible to punch a hole into the UDP firewall, so you will be able to send out-of-band query hits."), NULL);

  image_firewall_punchable = create_pixmap (main_window, "firewall_punchable.xpm");
  gtk_widget_set_name (image_firewall_punchable, "image_firewall_punchable");
  gtk_widget_show (image_firewall_punchable);
  gtk_container_add (GTK_CONTAINER (eventbox_image_firewall_punchable), image_firewall_punchable);
  gtk_widget_set_size_request (image_firewall_punchable, 16, 16);
  gtk_misc_set_padding (GTK_MISC (image_firewall_punchable), 1, 0);

  eventbox_image_tcp_firewall = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_tcp_firewall, "eventbox_image_tcp_firewall");
  gtk_widget_show (eventbox_image_tcp_firewall);
  gtk_box_pack_start (GTK_BOX (hbox147), eventbox_image_tcp_firewall, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox_image_tcp_firewall, _("You appear to be TCP-firewalled, i.e. others cannot connect to you to download files. You will not see push results, which may prevent you from seeing a large amount of results."), NULL);

  image_tcp_firewall = create_pixmap (main_window, "firewall_tcp.xpm");
  gtk_widget_set_name (image_tcp_firewall, "image_tcp_firewall");
  gtk_widget_show (image_tcp_firewall);
  gtk_container_add (GTK_CONTAINER (eventbox_image_tcp_firewall), image_tcp_firewall);
  gtk_widget_set_size_request (image_tcp_firewall, 16, 16);
  gtk_misc_set_padding (GTK_MISC (image_tcp_firewall), 1, 0);

  eventbox_image_udp_firewall = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_udp_firewall, "eventbox_image_udp_firewall");
  gtk_widget_show (eventbox_image_udp_firewall);
  gtk_box_pack_start (GTK_BOX (hbox147), eventbox_image_udp_firewall, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox_image_udp_firewall, _("You appear to be UDP-firewalled, i.e. you cannot receive unsolicited traffic via UDP. You will not be able to send queries requesting out-of-band delivery of query hits."), NULL);

  image_udp_firewall = create_pixmap (main_window, "firewall_udp.xpm");
  gtk_widget_set_name (image_udp_firewall, "image_udp_firewall");
  gtk_widget_show (image_udp_firewall);
  gtk_container_add (GTK_CONTAINER (eventbox_image_udp_firewall), image_udp_firewall);
  gtk_widget_set_size_request (image_udp_firewall, 16, 16);
  gtk_misc_set_padding (GTK_MISC (image_udp_firewall), 1, 0);

  eventbox_image_firewall_udp_punchable = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_firewall_udp_punchable, "eventbox_image_firewall_udp_punchable");
  gtk_widget_show (eventbox_image_firewall_udp_punchable);
  gtk_box_pack_start (GTK_BOX (hbox147), eventbox_image_firewall_udp_punchable, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox_image_firewall_udp_punchable, _("People can connect to you via TCP, but you are UDP-firewalled.  However, you can punch a hole into that firewall, allowing reception of replies to your UDP packets.  You will be able to send out-of-band query hits, but you won't be able to receive any."), NULL);

  image_firewall_udp_punchable = create_pixmap (main_window, "firewall_udp_punchable.xpm");
  gtk_widget_set_name (image_firewall_udp_punchable, "image_firewall_udp_punchable");
  gtk_widget_show (image_firewall_udp_punchable);
  gtk_container_add (GTK_CONTAINER (eventbox_image_firewall_udp_punchable), image_firewall_udp_punchable);
  gtk_widget_set_size_request (image_firewall_udp_punchable, 16, 16);
  gtk_misc_set_padding (GTK_MISC (image_firewall_udp_punchable), 1, 0);

  eventbox_image_no_firewall = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_no_firewall, "eventbox_image_no_firewall");
  gtk_widget_show (eventbox_image_no_firewall);
  gtk_box_pack_start (GTK_BOX (hbox147), eventbox_image_no_firewall, FALSE, TRUE, 0);
  gtk_widget_set_size_request (eventbox_image_no_firewall, 16, 16);
  gtk_tooltips_set_tip (tooltips, eventbox_image_no_firewall, _("People can connect to you, using both TCP and UDP. Push should work and you will be able to receive out-of-band results for your queries."), NULL);

  image_no_firewall = create_pixmap (main_window, "no_firewall.xpm");
  gtk_widget_set_name (image_no_firewall, "image_no_firewall");
  gtk_widget_show (image_no_firewall);
  gtk_container_add (GTK_CONTAINER (eventbox_image_no_firewall), image_no_firewall);
  gtk_widget_set_size_request (image_no_firewall, 16, 16);
  gtk_misc_set_padding (GTK_MISC (image_no_firewall), 1, 0);

  hbox228 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox228, "hbox228");
  gtk_widget_show (hbox228);
  gtk_box_pack_start (GTK_BOX (hbox211), hbox228, TRUE, TRUE, 0);

  eventbox_image_ultra = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_ultra, "eventbox_image_ultra");
  gtk_widget_show (eventbox_image_ultra);
  gtk_box_pack_start (GTK_BOX (hbox228), eventbox_image_ultra, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox_image_ultra, _("Running in ultrapeer mode."), NULL);

  image_ultra = create_pixmap (main_window, "ultra.xpm");
  gtk_widget_set_name (image_ultra, "image_ultra");
  gtk_widget_show (image_ultra);
  gtk_container_add (GTK_CONTAINER (eventbox_image_ultra), image_ultra);

  eventbox_image_leaf = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_leaf, "eventbox_image_leaf");
  gtk_widget_show (eventbox_image_leaf);
  gtk_box_pack_start (GTK_BOX (hbox228), eventbox_image_leaf, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox_image_leaf, _("Running in leaf mode."), NULL);

  image_leaf = create_pixmap (main_window, "leaf.xpm");
  gtk_widget_set_name (image_leaf, "image_leaf");
  gtk_widget_show (image_leaf);
  gtk_container_add (GTK_CONTAINER (eventbox_image_leaf), image_leaf);

  eventbox_image_legacy = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_legacy, "eventbox_image_legacy");
  gtk_widget_show (eventbox_image_legacy);
  gtk_box_pack_start (GTK_BOX (hbox228), eventbox_image_legacy, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox_image_legacy, _("Running in legacy mode. Consider switching to auto mode."), NULL);

  image_legacy = create_pixmap (main_window, "legacy.xpm");
  gtk_widget_set_name (image_legacy, "image_legacy");
  gtk_widget_show (image_legacy);
  gtk_container_add (GTK_CONTAINER (eventbox_image_legacy), image_legacy);

  hbox9344 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox9344, "hbox9344");
  gtk_widget_show (hbox9344);
  gtk_box_pack_start (GTK_BOX (hbox211), hbox9344, TRUE, TRUE, 0);

  eventbox_image_dht_none = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_dht_none, "eventbox_image_dht_none");
  gtk_widget_show (eventbox_image_dht_none);
  gtk_box_pack_start (GTK_BOX (hbox9344), eventbox_image_dht_none, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox_image_dht_none, _("DHT inactive."), NULL);

  image_dht_none = create_pixmap (main_window, "star-black.xpm");
  gtk_widget_set_name (image_dht_none, "image_dht_none");
  gtk_widget_show (image_dht_none);
  gtk_container_add (GTK_CONTAINER (eventbox_image_dht_none), image_dht_none);

  eventbox_image_dht_seeded = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_dht_seeded, "eventbox_image_dht_seeded");
  gtk_widget_show (eventbox_image_dht_seeded);
  gtk_box_pack_start (GTK_BOX (hbox9344), eventbox_image_dht_seeded, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox_image_dht_seeded, _("DHT seeded."), NULL);

  image_dht_seeded = create_pixmap (main_window, "star-violet.xpm");
  gtk_widget_set_name (image_dht_seeded, "image_dht_seeded");
  gtk_widget_show (image_dht_seeded);
  gtk_container_add (GTK_CONTAINER (eventbox_image_dht_seeded), image_dht_seeded);

  eventbox_image_dht_own_kuid = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_dht_own_kuid, "eventbox_image_dht_own_kuid");
  gtk_widget_show (eventbox_image_dht_own_kuid);
  gtk_box_pack_start (GTK_BOX (hbox9344), eventbox_image_dht_own_kuid, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox_image_dht_own_kuid, _("DHT looking up own KUID."), NULL);

  image_dht_own_kuid = create_pixmap (main_window, "star-blue.xpm");
  gtk_widget_set_name (image_dht_own_kuid, "image_dht_own_kuid");
  gtk_widget_show (image_dht_own_kuid);
  gtk_container_add (GTK_CONTAINER (eventbox_image_dht_own_kuid), image_dht_own_kuid);

  eventbox_image_dht_completing = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_dht_completing, "eventbox_image_dht_completing");
  gtk_widget_show (eventbox_image_dht_completing);
  gtk_box_pack_start (GTK_BOX (hbox9344), eventbox_image_dht_completing, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox_image_dht_completing, _("DHT bootstrapping."), NULL);

  image_dht_completing = create_pixmap (main_window, "star-green.xpm");
  gtk_widget_set_name (image_dht_completing, "image_dht_completing");
  gtk_widget_show (image_dht_completing);
  gtk_container_add (GTK_CONTAINER (eventbox_image_dht_completing), image_dht_completing);

  eventbox_image_dht_active = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_dht_active, "eventbox_image_dht_active");
  gtk_widget_show (eventbox_image_dht_active);
  gtk_box_pack_start (GTK_BOX (hbox9344), eventbox_image_dht_active, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox_image_dht_active, _("DHT up, active mode."), NULL);

  image_dht_active = create_pixmap (main_window, "star-yellow.xpm");
  gtk_widget_set_name (image_dht_active, "image_dht_active");
  gtk_widget_show (image_dht_active);
  gtk_container_add (GTK_CONTAINER (eventbox_image_dht_active), image_dht_active);

  eventbox_image_dht_passive = gtk_event_box_new ();
  gtk_widget_set_name (eventbox_image_dht_passive, "eventbox_image_dht_passive");
  gtk_widget_show (eventbox_image_dht_passive);
  gtk_box_pack_start (GTK_BOX (hbox9344), eventbox_image_dht_passive, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox_image_dht_passive, _("DHT up, passive mode."), NULL);

  image_dht_passive = create_pixmap (main_window, "star-red.xpm");
  gtk_widget_set_name (image_dht_passive, "image_dht_passive");
  gtk_widget_show (image_dht_passive);
  gtk_container_add (GTK_CONTAINER (eventbox_image_dht_passive), image_dht_passive);

  frame_statusbar_uptime = gtk_frame_new (NULL);
  gtk_widget_set_name (frame_statusbar_uptime, "frame_statusbar_uptime");
  gtk_widget_show (frame_statusbar_uptime);
  gtk_box_pack_start (GTK_BOX (hbox_statusbar), frame_statusbar_uptime, FALSE, TRUE, 0);

  alignment102 = gtk_alignment_new (0.5, 0.5, 1, 1);
  gtk_widget_set_name (alignment102, "alignment102");
  gtk_widget_show (alignment102);
  gtk_container_add (GTK_CONTAINER (frame_statusbar_uptime), alignment102);

  label_statusbar_uptime = gtk_label_new ("[uptime]");
  gtk_widget_set_name (label_statusbar_uptime, "label_statusbar_uptime");
  gtk_widget_show (label_statusbar_uptime);
  gtk_container_add (GTK_CONTAINER (alignment102), label_statusbar_uptime);

  statusbar1 = gtk_statusbar_new ();
  gtk_widget_set_name (statusbar1, "statusbar1");
  gtk_widget_show (statusbar1);
  gtk_box_pack_start (GTK_BOX (hbox_statusbar), statusbar1, FALSE, TRUE, 0);
  gtk_widget_set_size_request (statusbar1, 23, -1);

  g_signal_connect ((gpointer) main_window, "delete_event",
                    G_CALLBACK (on_main_window_delete_event),
                    NULL);
  g_signal_connect ((gpointer) menu_prefs, "activate",
                    G_CALLBACK (on_menu_prefs_activate),
                    NULL);
  g_signal_connect ((gpointer) quit, "activate",
                    G_CALLBACK (on_button_quit_clicked),
                    NULL);
  g_signal_connect ((gpointer) menu_searchbar_visible, "activate",
                    G_CALLBACK (on_menu_searchbar_visible_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_sidebar_visible, "activate",
                    G_CALLBACK (on_menu_sidebar_visible_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_menubar_visible, "activate",
                    G_CALLBACK (on_menu_menubar_visible_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_statusbar_visible, "activate",
                    G_CALLBACK (on_menu_statusbar_visible_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_downloads_visible, "activate",
                    G_CALLBACK (on_menu_downloads_visible_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_uploads_visible, "activate",
                    G_CALLBACK (on_menu_uploads_visible_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_connections_visible, "activate",
                    G_CALLBACK (on_menu_connections_visible_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_bws_in_visible, "activate",
                    G_CALLBACK (on_menu_bws_in_visible_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_bws_out_visible, "activate",
                    G_CALLBACK (on_menu_bws_out_visible_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_bws_gin_visible, "activate",
                    G_CALLBACK (on_menu_bws_gin_visible_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_bws_gout_visible, "activate",
                    G_CALLBACK (on_menu_bws_gout_visible_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_autohide_bws_gleaf, "activate",
                    G_CALLBACK (on_menu_autohide_bws_gleaf_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_bws_glin_visible, "activate",
                    G_CALLBACK (on_menu_bws_glin_visible_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_bws_glout_visible, "activate",
                    G_CALLBACK (on_menu_bws_glout_visible_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_autohide_bws_dht, "activate",
                    G_CALLBACK (on_menu_autohide_bws_dht_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_bws_dht_in_visible, "activate",
                    G_CALLBACK (on_menu_bws_dht_in_visible_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_bws_dht_out_visible, "activate",
                    G_CALLBACK (on_menu_bws_dht_out_visible_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_faq, "activate",
                    G_CALLBACK (on_menu_faq_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_glossary, "activate",
                    G_CALLBACK (on_menu_glossary_activate),
                    NULL);
  g_signal_connect ((gpointer) menu_about, "activate",
                    G_CALLBACK (on_menu_about_activate),
                    NULL);
  g_signal_connect ((gpointer) progressbar_bws_in, "button_press_event",
                    G_CALLBACK (on_progressbar_bws_in_button_press_event),
                    NULL);
  g_signal_connect ((gpointer) progressbar_bws_out, "button_press_event",
                    G_CALLBACK (on_progressbar_bws_out_button_press_event),
                    NULL);
  g_signal_connect ((gpointer) progressbar_bws_gin, "button_press_event",
                    G_CALLBACK (on_progressbar_bws_gin_button_press_event),
                    NULL);
  g_signal_connect ((gpointer) progressbar_bws_gout, "button_press_event",
                    G_CALLBACK (on_progressbar_bws_gout_button_press_event),
                    NULL);
  g_signal_connect ((gpointer) progressbar_bws_lin, "button_press_event",
                    G_CALLBACK (on_progressbar_bws_lin_button_press_event),
                    NULL);
  g_signal_connect ((gpointer) progressbar_bws_lout, "button_press_event",
                    G_CALLBACK (on_progressbar_bws_lout_button_press_event),
                    NULL);
  g_signal_connect ((gpointer) progressbar_bws_dht_in, "button_press_event",
                    G_CALLBACK (on_progressbar_bws_dht_in_button_press_event),
                    NULL);
  g_signal_connect ((gpointer) progressbar_bws_dht_out, "button_press_event",
                    G_CALLBACK (on_progressbar_bws_dht_out_button_press_event),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (main_window, main_window, "main_window");
  GLADE_HOOKUP_OBJECT (main_window, vbox12, "vbox12");
  GLADE_HOOKUP_OBJECT (main_window, menubar_main, "menubar_main");
  GLADE_HOOKUP_OBJECT (main_window, menu_file, "menu_file");
  GLADE_HOOKUP_OBJECT (main_window, menu_file_menu, "menu_file_menu");
  GLADE_HOOKUP_OBJECT (main_window, menu_prefs, "menu_prefs");
  GLADE_HOOKUP_OBJECT (main_window, image2291, "image2291");
  GLADE_HOOKUP_OBJECT (main_window, separator27, "separator27");
  GLADE_HOOKUP_OBJECT (main_window, quit, "quit");
  GLADE_HOOKUP_OBJECT (main_window, image2292, "image2292");
  GLADE_HOOKUP_OBJECT (main_window, menu_view, "menu_view");
  GLADE_HOOKUP_OBJECT (main_window, menu_view_menu, "menu_view_menu");
  GLADE_HOOKUP_OBJECT (main_window, menu_searchbar_visible, "menu_searchbar_visible");
  GLADE_HOOKUP_OBJECT (main_window, menu_sidebar_visible, "menu_sidebar_visible");
  GLADE_HOOKUP_OBJECT (main_window, menu_menubar_visible, "menu_menubar_visible");
  GLADE_HOOKUP_OBJECT (main_window, menu_statusbar_visible, "menu_statusbar_visible");
  GLADE_HOOKUP_OBJECT (main_window, separator29, "separator29");
  GLADE_HOOKUP_OBJECT (main_window, connection_counters1, "connection_counters1");
  GLADE_HOOKUP_OBJECT (main_window, connection_counters1_menu, "connection_counters1_menu");
  GLADE_HOOKUP_OBJECT (main_window, menu_downloads_visible, "menu_downloads_visible");
  GLADE_HOOKUP_OBJECT (main_window, menu_uploads_visible, "menu_uploads_visible");
  GLADE_HOOKUP_OBJECT (main_window, menu_connections_visible, "menu_connections_visible");
  GLADE_HOOKUP_OBJECT (main_window, menu_http_stats_visible, "menu_http_stats_visible");
  GLADE_HOOKUP_OBJECT (main_window, menu_http_stats_visible_menu, "menu_http_stats_visible_menu");
  GLADE_HOOKUP_OBJECT (main_window, menu_bws_in_visible, "menu_bws_in_visible");
  GLADE_HOOKUP_OBJECT (main_window, menu_bws_out_visible, "menu_bws_out_visible");
  GLADE_HOOKUP_OBJECT (main_window, menu_gnet_stats_visible, "menu_gnet_stats_visible");
  GLADE_HOOKUP_OBJECT (main_window, menu_gnet_stats_visible_menu, "menu_gnet_stats_visible_menu");
  GLADE_HOOKUP_OBJECT (main_window, menu_bws_gin_visible, "menu_bws_gin_visible");
  GLADE_HOOKUP_OBJECT (main_window, menu_bws_gout_visible, "menu_bws_gout_visible");
  GLADE_HOOKUP_OBJECT (main_window, menu_gnet_leaf_stats_visible, "menu_gnet_leaf_stats_visible");
  GLADE_HOOKUP_OBJECT (main_window, menu_gnet_leaf_stats_visible_menu, "menu_gnet_leaf_stats_visible_menu");
  GLADE_HOOKUP_OBJECT (main_window, menu_autohide_bws_gleaf, "menu_autohide_bws_gleaf");
  GLADE_HOOKUP_OBJECT (main_window, menu_bws_glin_visible, "menu_bws_glin_visible");
  GLADE_HOOKUP_OBJECT (main_window, menu_bws_glout_visible, "menu_bws_glout_visible");
  GLADE_HOOKUP_OBJECT (main_window, menu_dht_traffic_stats_visible, "menu_dht_traffic_stats_visible");
  GLADE_HOOKUP_OBJECT (main_window, menu_dht_traffic_stats_visible_menu, "menu_dht_traffic_stats_visible_menu");
  GLADE_HOOKUP_OBJECT (main_window, menu_autohide_bws_dht, "menu_autohide_bws_dht");
  GLADE_HOOKUP_OBJECT (main_window, menu_bws_dht_in_visible, "menu_bws_dht_in_visible");
  GLADE_HOOKUP_OBJECT (main_window, menu_bws_dht_out_visible, "menu_bws_dht_out_visible");
  GLADE_HOOKUP_OBJECT (main_window, menu_help, "menu_help");
  GLADE_HOOKUP_OBJECT (main_window, menu_help_menu, "menu_help_menu");
  GLADE_HOOKUP_OBJECT (main_window, menu_faq, "menu_faq");
  GLADE_HOOKUP_OBJECT (main_window, image2293, "image2293");
  GLADE_HOOKUP_OBJECT (main_window, menu_glossary, "menu_glossary");
  GLADE_HOOKUP_OBJECT (main_window, menu_about, "menu_about");
  GLADE_HOOKUP_OBJECT (main_window, image2294, "image2294");
  GLADE_HOOKUP_OBJECT (main_window, viewport_searchbar, "viewport_searchbar");
  GLADE_HOOKUP_OBJECT (main_window, vbox160, "vbox160");
  GLADE_HOOKUP_OBJECT (main_window, hbox9350, "hbox9350");
  GLADE_HOOKUP_OBJECT (main_window, button_search, "button_search");
  GLADE_HOOKUP_OBJECT (main_window, alignment106, "alignment106");
  GLADE_HOOKUP_OBJECT (main_window, hbox288, "hbox288");
  GLADE_HOOKUP_OBJECT (main_window, image401, "image401");
  GLADE_HOOKUP_OBJECT (main_window, label903, "label903");
  GLADE_HOOKUP_OBJECT (main_window, frame129, "frame129");
  GLADE_HOOKUP_OBJECT (main_window, combo_search, "combo_search");
  GLADE_HOOKUP_OBJECT (main_window, entry_search, "entry_search");
  GLADE_HOOKUP_OBJECT (main_window, button_search_whats_new, "button_search_whats_new");
  GLADE_HOOKUP_OBJECT (main_window, alignment147, "alignment147");
  GLADE_HOOKUP_OBJECT (main_window, hbox9349, "hbox9349");
  GLADE_HOOKUP_OBJECT (main_window, image2245, "image2245");
  GLADE_HOOKUP_OBJECT (main_window, label1067, "label1067");
  GLADE_HOOKUP_OBJECT (main_window, button_search_passive, "button_search_passive");
  GLADE_HOOKUP_OBJECT (main_window, alignment110, "alignment110");
  GLADE_HOOKUP_OBJECT (main_window, hbox9292, "hbox9292");
  GLADE_HOOKUP_OBJECT (main_window, image404, "image404");
  GLADE_HOOKUP_OBJECT (main_window, label911, "label911");
  GLADE_HOOKUP_OBJECT (main_window, hbox9351, "hbox9351");
  GLADE_HOOKUP_OBJECT (main_window, frame_search_media_type, "frame_search_media_type");
  GLADE_HOOKUP_OBJECT (main_window, alignment144, "alignment144");
  GLADE_HOOKUP_OBJECT (main_window, hbox9346, "hbox9346");
  GLADE_HOOKUP_OBJECT (main_window, button_search_media_type_any, "button_search_media_type_any");
  GLADE_HOOKUP_OBJECT (main_window, alignment145, "alignment145");
  GLADE_HOOKUP_OBJECT (main_window, hbox9347, "hbox9347");
  GLADE_HOOKUP_OBJECT (main_window, image2244, "image2244");
  GLADE_HOOKUP_OBJECT (main_window, label1065, "label1065");
  GLADE_HOOKUP_OBJECT (main_window, checkbutton_config_search_media_type_audio, "checkbutton_config_search_media_type_audio");
  GLADE_HOOKUP_OBJECT (main_window, checkbutton_config_search_media_type_video, "checkbutton_config_search_media_type_video");
  GLADE_HOOKUP_OBJECT (main_window, checkbutton_config_search_media_type_document, "checkbutton_config_search_media_type_document");
  GLADE_HOOKUP_OBJECT (main_window, checkbutton_config_search_media_type_image, "checkbutton_config_search_media_type_image");
  GLADE_HOOKUP_OBJECT (main_window, checkbutton_config_search_media_type_archive, "checkbutton_config_search_media_type_archive");
  GLADE_HOOKUP_OBJECT (main_window, label1064, "label1064");
  GLADE_HOOKUP_OBJECT (main_window, frame152, "frame152");
  GLADE_HOOKUP_OBJECT (main_window, alignment146, "alignment146");
  GLADE_HOOKUP_OBJECT (main_window, hbox9348, "hbox9348");
  GLADE_HOOKUP_OBJECT (main_window, option_menu_search_lifetime, "option_menu_search_lifetime");
  GLADE_HOOKUP_OBJECT (main_window, menu1, "menu1");
  GLADE_HOOKUP_OBJECT (main_window, optionmenu_search_filter, "optionmenu_search_filter");
  GLADE_HOOKUP_OBJECT (main_window, convertwidget20, "convertwidget20");
  GLADE_HOOKUP_OBJECT (main_window, label1066, "label1066");
  GLADE_HOOKUP_OBJECT (main_window, hpaned_main, "hpaned_main");
  GLADE_HOOKUP_OBJECT (main_window, vbox_sidebar, "vbox_sidebar");
  GLADE_HOOKUP_OBJECT (main_window, sw_searches, "sw_searches");
  GLADE_HOOKUP_OBJECT (main_window, tree_view_search, "tree_view_search");
  GLADE_HOOKUP_OBJECT (main_window, vbox_sidebar_stats, "vbox_sidebar_stats");
  GLADE_HOOKUP_OBJECT (main_window, frame71, "frame71");
  GLADE_HOOKUP_OBJECT (main_window, vbox105, "vbox105");
  GLADE_HOOKUP_OBJECT (main_window, hbox_stats_connections, "hbox_stats_connections");
  GLADE_HOOKUP_OBJECT (main_window, eventbox8, "eventbox8");
  GLADE_HOOKUP_OBJECT (main_window, image131, "image131");
  GLADE_HOOKUP_OBJECT (main_window, progressbar_connections, "progressbar_connections");
  GLADE_HOOKUP_OBJECT (main_window, hbox_stats_uploads, "hbox_stats_uploads");
  GLADE_HOOKUP_OBJECT (main_window, eventbox7, "eventbox7");
  GLADE_HOOKUP_OBJECT (main_window, image130, "image130");
  GLADE_HOOKUP_OBJECT (main_window, progressbar_uploads, "progressbar_uploads");
  GLADE_HOOKUP_OBJECT (main_window, hbox_stats_downloads, "hbox_stats_downloads");
  GLADE_HOOKUP_OBJECT (main_window, eventbox10, "eventbox10");
  GLADE_HOOKUP_OBJECT (main_window, image132, "image132");
  GLADE_HOOKUP_OBJECT (main_window, progressbar_downloads, "progressbar_downloads");
  GLADE_HOOKUP_OBJECT (main_window, frame_bws_inout, "frame_bws_inout");
  GLADE_HOOKUP_OBJECT (main_window, vbox42, "vbox42");
  GLADE_HOOKUP_OBJECT (main_window, progressbar_bws_in, "progressbar_bws_in");
  GLADE_HOOKUP_OBJECT (main_window, progressbar_bws_out, "progressbar_bws_out");
  GLADE_HOOKUP_OBJECT (main_window, label277, "label277");
  GLADE_HOOKUP_OBJECT (main_window, frame_bws_ginout, "frame_bws_ginout");
  GLADE_HOOKUP_OBJECT (main_window, vbox43, "vbox43");
  GLADE_HOOKUP_OBJECT (main_window, progressbar_bws_gin, "progressbar_bws_gin");
  GLADE_HOOKUP_OBJECT (main_window, progressbar_bws_gout, "progressbar_bws_gout");
  GLADE_HOOKUP_OBJECT (main_window, label278, "label278");
  GLADE_HOOKUP_OBJECT (main_window, frame_bws_glinout, "frame_bws_glinout");
  GLADE_HOOKUP_OBJECT (main_window, vbox104, "vbox104");
  GLADE_HOOKUP_OBJECT (main_window, progressbar_bws_lin, "progressbar_bws_lin");
  GLADE_HOOKUP_OBJECT (main_window, progressbar_bws_lout, "progressbar_bws_lout");
  GLADE_HOOKUP_OBJECT (main_window, label605, "label605");
  GLADE_HOOKUP_OBJECT (main_window, frame_bws_dht_inout, "frame_bws_dht_inout");
  GLADE_HOOKUP_OBJECT (main_window, vbox155, "vbox155");
  GLADE_HOOKUP_OBJECT (main_window, progressbar_bws_dht_in, "progressbar_bws_dht_in");
  GLADE_HOOKUP_OBJECT (main_window, progressbar_bws_dht_out, "progressbar_bws_dht_out");
  GLADE_HOOKUP_OBJECT (main_window, label1031, "label1031");
  GLADE_HOOKUP_OBJECT (main_window, vbox_right, "vbox_right");
  GLADE_HOOKUP_OBJECT (main_window, notebook_main, "notebook_main");
  GLADE_HOOKUP_OBJECT (main_window, label590, "label590");
  GLADE_HOOKUP_OBJECT (main_window, hbox_statusbar, "hbox_statusbar");
  GLADE_HOOKUP_OBJECT (main_window, togglebutton_online, "togglebutton_online");
  GLADE_HOOKUP_OBJECT (main_window, hbox170, "hbox170");
  GLADE_HOOKUP_OBJECT (main_window, eventbox9, "eventbox9");
  GLADE_HOOKUP_OBJECT (main_window, image_offline, "image_offline");
  GLADE_HOOKUP_OBJECT (main_window, image_online, "image_online");
  GLADE_HOOKUP_OBJECT (main_window, hbox_port_mapping, "hbox_port_mapping");
  GLADE_HOOKUP_OBJECT (main_window, eventbox_port_mapping_possible, "eventbox_port_mapping_possible");
  GLADE_HOOKUP_OBJECT (main_window, image_port_mapping_possible, "image_port_mapping_possible");
  GLADE_HOOKUP_OBJECT (main_window, eventbox_upnp_port_mapping_successful, "eventbox_upnp_port_mapping_successful");
  GLADE_HOOKUP_OBJECT (main_window, image_upnp_successful, "image_upnp_successful");
  GLADE_HOOKUP_OBJECT (main_window, eventbox_natpmp_port_mapping_successful, "eventbox_natpmp_port_mapping_successful");
  GLADE_HOOKUP_OBJECT (main_window, image_natpmp_successful, "image_natpmp_successful");
  GLADE_HOOKUP_OBJECT (main_window, statusbar, "statusbar");
  GLADE_HOOKUP_OBJECT (main_window, hbox211, "hbox211");
  GLADE_HOOKUP_OBJECT (main_window, eventbox_image_download_queue_frozen, "eventbox_image_download_queue_frozen");
  GLADE_HOOKUP_OBJECT (main_window, image_download_queue_frozen, "image_download_queue_frozen");
  GLADE_HOOKUP_OBJECT (main_window, eventbox_image_chip, "eventbox_image_chip");
  GLADE_HOOKUP_OBJECT (main_window, image_chip, "image_chip");
  GLADE_HOOKUP_OBJECT (main_window, eventbox_net_buffer_shortage, "eventbox_net_buffer_shortage");
  GLADE_HOOKUP_OBJECT (main_window, image_net_buffer_shortage, "image_net_buffer_shortage");
  GLADE_HOOKUP_OBJECT (main_window, eventbox_tcp_no_listening, "eventbox_tcp_no_listening");
  GLADE_HOOKUP_OBJECT (main_window, image_tcp_no_listening, "image_tcp_no_listening");
  GLADE_HOOKUP_OBJECT (main_window, eventbox_image_warning, "eventbox_image_warning");
  GLADE_HOOKUP_OBJECT (main_window, image_warning, "image_warning");
  GLADE_HOOKUP_OBJECT (main_window, hbox9345, "hbox9345");
  GLADE_HOOKUP_OBJECT (main_window, eventbox_early_stall_1, "eventbox_early_stall_1");
  GLADE_HOOKUP_OBJECT (main_window, image_early_stall_1, "image_early_stall_1");
  GLADE_HOOKUP_OBJECT (main_window, eventbox_early_stall_2, "eventbox_early_stall_2");
  GLADE_HOOKUP_OBJECT (main_window, image_early_stall_2, "image_early_stall_2");
  GLADE_HOOKUP_OBJECT (main_window, eventbox_early_stall_3, "eventbox_early_stall_3");
  GLADE_HOOKUP_OBJECT (main_window, image_early_stall_3, "image_early_stall_3");
  GLADE_HOOKUP_OBJECT (main_window, eventbox_image_fd_shortage, "eventbox_image_fd_shortage");
  GLADE_HOOKUP_OBJECT (main_window, image_fd_shortage, "image_fd_shortage");
  GLADE_HOOKUP_OBJECT (main_window, eventbox_image_fd_runout, "eventbox_image_fd_runout");
  GLADE_HOOKUP_OBJECT (main_window, image_fd_runout, "image_fd_runout");
  GLADE_HOOKUP_OBJECT (main_window, eventbox_image_ancient, "eventbox_image_ancient");
  GLADE_HOOKUP_OBJECT (main_window, image_ancient, "image_ancient");
  GLADE_HOOKUP_OBJECT (main_window, eventbox_image_save, "eventbox_image_save");
  GLADE_HOOKUP_OBJECT (main_window, image_save, "image_save");
  GLADE_HOOKUP_OBJECT (main_window, eventbox_image_sha, "eventbox_image_sha");
  GLADE_HOOKUP_OBJECT (main_window, image_sha, "image_sha");
  GLADE_HOOKUP_OBJECT (main_window, eventbox_image_shav, "eventbox_image_shav");
  GLADE_HOOKUP_OBJECT (main_window, image_shav, "image_shav");
  GLADE_HOOKUP_OBJECT (main_window, eventbox_image_tth, "eventbox_image_tth");
  GLADE_HOOKUP_OBJECT (main_window, image_tth, "image_tth");
  GLADE_HOOKUP_OBJECT (main_window, eventbox_image_tthv, "eventbox_image_tthv");
  GLADE_HOOKUP_OBJECT (main_window, image_tthv, "image_tthv");
  GLADE_HOOKUP_OBJECT (main_window, eventbox_image_lib, "eventbox_image_lib");
  GLADE_HOOKUP_OBJECT (main_window, image_lib, "image_lib");
  GLADE_HOOKUP_OBJECT (main_window, hbox147, "hbox147");
  GLADE_HOOKUP_OBJECT (main_window, eventbox_image_firewall, "eventbox_image_firewall");
  GLADE_HOOKUP_OBJECT (main_window, image_firewall, "image_firewall");
  GLADE_HOOKUP_OBJECT (main_window, eventbox_image_firewall_punchable, "eventbox_image_firewall_punchable");
  GLADE_HOOKUP_OBJECT (main_window, image_firewall_punchable, "image_firewall_punchable");
  GLADE_HOOKUP_OBJECT (main_window, eventbox_image_tcp_firewall, "eventbox_image_tcp_firewall");
  GLADE_HOOKUP_OBJECT (main_window, image_tcp_firewall, "image_tcp_firewall");
  GLADE_HOOKUP_OBJECT (main_window, eventbox_image_udp_firewall, "eventbox_image_udp_firewall");
  GLADE_HOOKUP_OBJECT (main_window, image_udp_firewall, "image_udp_firewall");
  GLADE_HOOKUP_OBJECT (main_window, eventbox_image_firewall_udp_punchable, "eventbox_image_firewall_udp_punchable");
  GLADE_HOOKUP_OBJECT (main_window, image_firewall_udp_punchable, "image_firewall_udp_punchable");
  GLADE_HOOKUP_OBJECT (main_window, eventbox_image_no_firewall, "eventbox_image_no_firewall");
  GLADE_HOOKUP_OBJECT (main_window, image_no_firewall, "image_no_firewall");
  GLADE_HOOKUP_OBJECT (main_window, hbox228, "hbox228");
  GLADE_HOOKUP_OBJECT (main_window, eventbox_image_ultra, "eventbox_image_ultra");
  GLADE_HOOKUP_OBJECT (main_window, image_ultra, "image_ultra");
  GLADE_HOOKUP_OBJECT (main_window, eventbox_image_leaf, "eventbox_image_leaf");
  GLADE_HOOKUP_OBJECT (main_window, image_leaf, "image_leaf");
  GLADE_HOOKUP_OBJECT (main_window, eventbox_image_legacy, "eventbox_image_legacy");
  GLADE_HOOKUP_OBJECT (main_window, image_legacy, "image_legacy");
  GLADE_HOOKUP_OBJECT (main_window, hbox9344, "hbox9344");
  GLADE_HOOKUP_OBJECT (main_window, eventbox_image_dht_none, "eventbox_image_dht_none");
  GLADE_HOOKUP_OBJECT (main_window, image_dht_none, "image_dht_none");
  GLADE_HOOKUP_OBJECT (main_window, eventbox_image_dht_seeded, "eventbox_image_dht_seeded");
  GLADE_HOOKUP_OBJECT (main_window, image_dht_seeded, "image_dht_seeded");
  GLADE_HOOKUP_OBJECT (main_window, eventbox_image_dht_own_kuid, "eventbox_image_dht_own_kuid");
  GLADE_HOOKUP_OBJECT (main_window, image_dht_own_kuid, "image_dht_own_kuid");
  GLADE_HOOKUP_OBJECT (main_window, eventbox_image_dht_completing, "eventbox_image_dht_completing");
  GLADE_HOOKUP_OBJECT (main_window, image_dht_completing, "image_dht_completing");
  GLADE_HOOKUP_OBJECT (main_window, eventbox_image_dht_active, "eventbox_image_dht_active");
  GLADE_HOOKUP_OBJECT (main_window, image_dht_active, "image_dht_active");
  GLADE_HOOKUP_OBJECT (main_window, eventbox_image_dht_passive, "eventbox_image_dht_passive");
  GLADE_HOOKUP_OBJECT (main_window, image_dht_passive, "image_dht_passive");
  GLADE_HOOKUP_OBJECT (main_window, frame_statusbar_uptime, "frame_statusbar_uptime");
  GLADE_HOOKUP_OBJECT (main_window, alignment102, "alignment102");
  GLADE_HOOKUP_OBJECT (main_window, label_statusbar_uptime, "label_statusbar_uptime");
  GLADE_HOOKUP_OBJECT (main_window, statusbar1, "statusbar1");
  GLADE_HOOKUP_OBJECT_NO_REF (main_window, tooltips, "tooltips");

  gtk_window_add_accel_group (GTK_WINDOW (main_window), accel_group);

  return main_window;
}

GtkWidget*
create_dlg_quit (void)
{
  GtkWidget *dlg_quit;
  GdkPixbuf *dlg_quit_icon_pixbuf;
  GtkWidget *dialog_vbox1;
  GtkWidget *frame59;
  GtkWidget *label405;
  GtkWidget *label404;
  GtkWidget *dialog_action_area1;
  GtkWidget *button_abort_quit;
  GtkWidget *button_really_quit;

  dlg_quit = gtk_dialog_new ();
  gtk_widget_set_name (dlg_quit, "dlg_quit");
  gtk_window_set_title (GTK_WINDOW (dlg_quit), _("gtk-gnutella: Quit?"));
  gtk_window_set_position (GTK_WINDOW (dlg_quit), GTK_WIN_POS_MOUSE);
  gtk_window_set_resizable (GTK_WINDOW (dlg_quit), FALSE);
  dlg_quit_icon_pixbuf = create_pixbuf ("icon.48x48.xpm");
  if (dlg_quit_icon_pixbuf)
    {
      gtk_window_set_icon (GTK_WINDOW (dlg_quit), dlg_quit_icon_pixbuf);
      g_object_unref (dlg_quit_icon_pixbuf);
    }
  gtk_window_set_type_hint (GTK_WINDOW (dlg_quit), GDK_WINDOW_TYPE_HINT_DIALOG);

  dialog_vbox1 = GTK_DIALOG (dlg_quit)->vbox;
  gtk_widget_set_name (dialog_vbox1, "dialog_vbox1");
  gtk_widget_show (dialog_vbox1);

  frame59 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame59, "frame59");
  gtk_widget_show (frame59);
  gtk_box_pack_start (GTK_BOX (dialog_vbox1), frame59, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame59), 10);

  label405 = gtk_label_new (_("Do you really want to quit?"));
  gtk_widget_set_name (label405, "label405");
  gtk_widget_show (label405);
  gtk_container_add (GTK_CONTAINER (frame59), label405);
  gtk_misc_set_padding (GTK_MISC (label405), 10, 10);

  label404 = gtk_label_new (_("Please confirm:"));
  gtk_widget_set_name (label404, "label404");
  gtk_widget_show (label404);
  gtk_frame_set_label_widget (GTK_FRAME (frame59), label404);

  dialog_action_area1 = GTK_DIALOG (dlg_quit)->action_area;
  gtk_widget_set_name (dialog_action_area1, "dialog_action_area1");
  gtk_widget_show (dialog_action_area1);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area1), GTK_BUTTONBOX_END);

  button_abort_quit = gtk_button_new_from_stock ("gtk-cancel");
  gtk_widget_set_name (button_abort_quit, "button_abort_quit");
  gtk_widget_show (button_abort_quit);
  gtk_dialog_add_action_widget (GTK_DIALOG (dlg_quit), button_abort_quit, GTK_RESPONSE_CANCEL);
  GTK_WIDGET_SET_FLAGS (button_abort_quit, GTK_CAN_DEFAULT);

  button_really_quit = gtk_button_new_from_stock ("gtk-quit");
  gtk_widget_set_name (button_really_quit, "button_really_quit");
  gtk_widget_show (button_really_quit);
  gtk_dialog_add_action_widget (GTK_DIALOG (dlg_quit), button_really_quit, GTK_RESPONSE_OK);
  GTK_WIDGET_SET_FLAGS (button_really_quit, GTK_CAN_DEFAULT);

  g_signal_connect ((gpointer) dlg_quit, "delete_event",
                    G_CALLBACK (on_dlg_quit_delete_event),
                    NULL);
  g_signal_connect ((gpointer) button_abort_quit, "clicked",
                    G_CALLBACK (on_button_abort_quit_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_really_quit, "clicked",
                    G_CALLBACK (on_button_really_quit_clicked),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (dlg_quit, dlg_quit, "dlg_quit");
  GLADE_HOOKUP_OBJECT_NO_REF (dlg_quit, dialog_vbox1, "dialog_vbox1");
  GLADE_HOOKUP_OBJECT (dlg_quit, frame59, "frame59");
  GLADE_HOOKUP_OBJECT (dlg_quit, label405, "label405");
  GLADE_HOOKUP_OBJECT (dlg_quit, label404, "label404");
  GLADE_HOOKUP_OBJECT_NO_REF (dlg_quit, dialog_action_area1, "dialog_action_area1");
  GLADE_HOOKUP_OBJECT (dlg_quit, button_abort_quit, "button_abort_quit");
  GLADE_HOOKUP_OBJECT (dlg_quit, button_really_quit, "button_really_quit");

  return dlg_quit;
}

GtkWidget*
create_main_window_gnet_tab (void)
{
  GtkWidget *main_window_gnet_tab;
  GtkWidget *vbox_gnutellanet;
  GtkWidget *vbox17;
  GtkWidget *scrolledwindow37;
  GtkWidget *treeview_nodes;
  GtkWidget *table56;
  GtkWidget *button_nodes_add;
  GtkWidget *alignment33;
  GtkWidget *hbox164;
  GtkWidget *image34;
  GtkWidget *label415;
  GtkWidget *entry_host;
  GtkWidget *button_nodes_disconnect;
  GtkWidget *alignment135;
  GtkWidget *hbox9331;
  GtkWidget *image1258;
  GtkWidget *label987;
  GtkWidget *hbox_leaf;
  GtkWidget *label519;
  GtkObject *spinbutton_max_ultrapeers_adj;
  GtkWidget *spinbutton_max_ultrapeers;
  GtkWidget *label520;
  GtkWidget *hbox9354;
  GtkWidget *label1079;
  GtkObject *spinbutton_max_g2_hubs_adj;
  GtkWidget *spinbutton_max_g2_hubs;
  GtkWidget *hbox_normal_or_ultrapeer;
  GtkWidget *label2;
  GtkObject *spinbutton_up_connections_adj;
  GtkWidget *spinbutton_up_connections;
  GtkWidget *label3;
  GtkObject *spinbutton_max_connections_adj;
  GtkWidget *spinbutton_max_connections;
  GtkWidget *label83;
  GtkWidget *hbox265;
  GtkWidget *label851;
  GtkObject *spinbutton_quick_connect_pool_size_adj;
  GtkWidget *spinbutton_quick_connect_pool_size;
  GtkWidget *label852;
  GtkWidget *vbox33;
  GtkWidget *frame_expert_node_info;
  GtkWidget *vbox34;
  GtkWidget *hbox151;
  GtkWidget *label150;
  GtkWidget *eventbox11;
  GtkWidget *label_nodes_guid;
  GtkWidget *label1046;
  GtkWidget *eventbox15;
  GtkWidget *label_nodes_kuid;
  GtkWidget *label151;
  GtkWidget *eventbox12;
  GtkWidget *label_nodes_ip;
  GtkWidget *label282;
  GtkTooltips *tooltips;

  tooltips = gtk_tooltips_new ();

  main_window_gnet_tab = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_widget_set_name (main_window_gnet_tab, "main_window_gnet_tab");
  gtk_widget_set_size_request (main_window_gnet_tab, 587, 359);

  vbox_gnutellanet = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox_gnutellanet, "vbox_gnutellanet");
  gtk_widget_show (vbox_gnutellanet);
  gtk_container_add (GTK_CONTAINER (main_window_gnet_tab), vbox_gnutellanet);

  vbox17 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox17, "vbox17");
  gtk_widget_show (vbox17);
  gtk_box_pack_start (GTK_BOX (vbox_gnutellanet), vbox17, TRUE, TRUE, 0);

  scrolledwindow37 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow37, "scrolledwindow37");
  gtk_widget_show (scrolledwindow37);
  gtk_box_pack_start (GTK_BOX (vbox17), scrolledwindow37, TRUE, TRUE, 0);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow37), GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS);
  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolledwindow37), GTK_SHADOW_IN);

  treeview_nodes = gtk_tree_view_new ();
  gtk_widget_set_name (treeview_nodes, "treeview_nodes");
  gtk_widget_show (treeview_nodes);
  gtk_container_add (GTK_CONTAINER (scrolledwindow37), treeview_nodes);
  gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (treeview_nodes), TRUE);
  gtk_tree_view_set_enable_search (GTK_TREE_VIEW (treeview_nodes), FALSE);

  table56 = gtk_table_new (1, 5, FALSE);
  gtk_widget_set_name (table56, "table56");
  gtk_widget_show (table56);
  gtk_box_pack_start (GTK_BOX (vbox17), table56, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (table56), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table56), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table56), 4);

  button_nodes_add = gtk_button_new ();
  gtk_widget_set_name (button_nodes_add, "button_nodes_add");
  gtk_widget_show (button_nodes_add);
  gtk_table_attach (GTK_TABLE (table56), button_nodes_add, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_widget_set_sensitive (button_nodes_add, FALSE);
  gtk_tooltips_set_tip (tooltips, button_nodes_add, _("Try to connect to specified address"), NULL);

  alignment33 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment33, "alignment33");
  gtk_widget_show (alignment33);
  gtk_container_add (GTK_CONTAINER (button_nodes_add), alignment33);

  hbox164 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox164, "hbox164");
  gtk_widget_show (hbox164);
  gtk_container_add (GTK_CONTAINER (alignment33), hbox164);

  image34 = gtk_image_new_from_stock ("gtk-jump-to", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image34, "image34");
  gtk_widget_show (image34);
  gtk_box_pack_start (GTK_BOX (hbox164), image34, FALSE, FALSE, 0);

  label415 = gtk_label_new_with_mnemonic (_("Add"));
  gtk_widget_set_name (label415, "label415");
  gtk_widget_show (label415);
  gtk_box_pack_start (GTK_BOX (hbox164), label415, FALSE, FALSE, 0);

  entry_host = gtk_entry_new ();
  gtk_widget_set_name (entry_host, "entry_host");
  gtk_widget_show (entry_host);
  gtk_table_attach (GTK_TABLE (table56), entry_host, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  button_nodes_disconnect = gtk_button_new ();
  gtk_widget_set_name (button_nodes_disconnect, "button_nodes_disconnect");
  gtk_widget_show (button_nodes_disconnect);
  gtk_table_attach (GTK_TABLE (table56), button_nodes_disconnect, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_tooltips_set_tip (tooltips, button_nodes_disconnect, _("Disconnect from selected nodes"), NULL);

  alignment135 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment135, "alignment135");
  gtk_widget_show (alignment135);
  gtk_container_add (GTK_CONTAINER (button_nodes_disconnect), alignment135);

  hbox9331 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox9331, "hbox9331");
  gtk_widget_show (hbox9331);
  gtk_container_add (GTK_CONTAINER (alignment135), hbox9331);

  image1258 = gtk_image_new_from_stock ("gtk-cancel", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image1258, "image1258");
  gtk_widget_show (image1258);
  gtk_box_pack_start (GTK_BOX (hbox9331), image1258, FALSE, FALSE, 0);

  label987 = gtk_label_new_with_mnemonic (_("Disconnect"));
  gtk_widget_set_name (label987, "label987");
  gtk_widget_show (label987);
  gtk_box_pack_start (GTK_BOX (hbox9331), label987, FALSE, FALSE, 0);

  hbox_leaf = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox_leaf, "hbox_leaf");
  gtk_widget_show (hbox_leaf);
  gtk_table_attach (GTK_TABLE (table56), hbox_leaf, 3, 4, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  label519 = gtk_label_new (_("Connect to"));
  gtk_widget_set_name (label519, "label519");
  gtk_widget_show (label519);
  gtk_box_pack_start (GTK_BOX (hbox_leaf), label519, FALSE, TRUE, 0);
  gtk_misc_set_padding (GTK_MISC (label519), 5, 0);

  spinbutton_max_ultrapeers_adj = gtk_adjustment_new (0, 0, 100, 1, 10, 0);
  spinbutton_max_ultrapeers = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_max_ultrapeers_adj), 1, 0);
  gtk_widget_set_name (spinbutton_max_ultrapeers, "spinbutton_max_ultrapeers");
  gtk_widget_show (spinbutton_max_ultrapeers);
  gtk_box_pack_start (GTK_BOX (hbox_leaf), spinbutton_max_ultrapeers, FALSE, TRUE, 0);

  label520 = gtk_label_new (_("ultrapeers"));
  gtk_widget_set_name (label520, "label520");
  gtk_widget_show (label520);
  gtk_box_pack_start (GTK_BOX (hbox_leaf), label520, FALSE, TRUE, 0);
  gtk_misc_set_padding (GTK_MISC (label520), 5, 0);

  hbox9354 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox9354, "hbox9354");
  gtk_widget_show (hbox9354);
  gtk_table_attach (GTK_TABLE (table56), hbox9354, 4, 5, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  label1079 = gtk_label_new (_("G2 hubs"));
  gtk_widget_set_name (label1079, "label1079");
  gtk_widget_show (label1079);
  gtk_box_pack_start (GTK_BOX (hbox9354), label1079, FALSE, TRUE, 0);

  spinbutton_max_g2_hubs_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 0);
  spinbutton_max_g2_hubs = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_max_g2_hubs_adj), 1, 0);
  gtk_widget_set_name (spinbutton_max_g2_hubs, "spinbutton_max_g2_hubs");
  gtk_widget_show (spinbutton_max_g2_hubs);
  gtk_box_pack_start (GTK_BOX (hbox9354), spinbutton_max_g2_hubs, FALSE, TRUE, 0);

  hbox_normal_or_ultrapeer = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox_normal_or_ultrapeer, "hbox_normal_or_ultrapeer");
  gtk_widget_show (hbox_normal_or_ultrapeer);
  gtk_box_pack_start (GTK_BOX (vbox17), hbox_normal_or_ultrapeer, FALSE, TRUE, 0);

  label2 = gtk_label_new (_("Try to keep at least"));
  gtk_widget_set_name (label2, "label2");
  gtk_widget_show (label2);
  gtk_box_pack_start (GTK_BOX (hbox_normal_or_ultrapeer), label2, FALSE, TRUE, 0);
  gtk_label_set_justify (GTK_LABEL (label2), GTK_JUSTIFY_CENTER);
  gtk_misc_set_padding (GTK_MISC (label2), 5, 0);

  spinbutton_up_connections_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 0);
  spinbutton_up_connections = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_up_connections_adj), 1, 0);
  gtk_widget_set_name (spinbutton_up_connections, "spinbutton_up_connections");
  gtk_widget_show (spinbutton_up_connections);
  gtk_box_pack_start (GTK_BOX (hbox_normal_or_ultrapeer), spinbutton_up_connections, FALSE, TRUE, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_up_connections), TRUE);

  label3 = gtk_label_new (_("and allow at most"));
  gtk_widget_set_name (label3, "label3");
  gtk_widget_show (label3);
  gtk_box_pack_start (GTK_BOX (hbox_normal_or_ultrapeer), label3, FALSE, TRUE, 0);
  gtk_label_set_justify (GTK_LABEL (label3), GTK_JUSTIFY_CENTER);

  spinbutton_max_connections_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 0);
  spinbutton_max_connections = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_max_connections_adj), 1, 0);
  gtk_widget_set_name (spinbutton_max_connections, "spinbutton_max_connections");
  gtk_widget_show (spinbutton_max_connections);
  gtk_box_pack_start (GTK_BOX (hbox_normal_or_ultrapeer), spinbutton_max_connections, FALSE, TRUE, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_max_connections), TRUE);

  label83 = gtk_label_new (_("total connections up."));
  gtk_widget_set_name (label83, "label83");
  gtk_widget_show (label83);
  gtk_box_pack_start (GTK_BOX (hbox_normal_or_ultrapeer), label83, FALSE, TRUE, 0);
  gtk_label_set_justify (GTK_LABEL (label83), GTK_JUSTIFY_CENTER);

  hbox265 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox265, "hbox265");
  gtk_widget_show (hbox265);
  gtk_box_pack_start (GTK_BOX (vbox17), hbox265, FALSE, TRUE, 0);

  label851 = gtk_label_new (_("Use up to "));
  gtk_widget_set_name (label851, "label851");
  gtk_widget_show (label851);
  gtk_box_pack_start (GTK_BOX (hbox265), label851, FALSE, FALSE, 0);
  gtk_misc_set_padding (GTK_MISC (label851), 5, 0);

  spinbutton_quick_connect_pool_size_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 0);
  spinbutton_quick_connect_pool_size = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_quick_connect_pool_size_adj), 1, 0);
  gtk_widget_set_name (spinbutton_quick_connect_pool_size, "spinbutton_quick_connect_pool_size");
  gtk_widget_show (spinbutton_quick_connect_pool_size);
  gtk_box_pack_start (GTK_BOX (hbox265), spinbutton_quick_connect_pool_size, FALSE, TRUE, 0);

  label852 = gtk_label_new (_("connections to connect more quickly while not all slots are used."));
  gtk_widget_set_name (label852, "label852");
  gtk_widget_show (label852);
  gtk_box_pack_start (GTK_BOX (hbox265), label852, FALSE, FALSE, 0);
  gtk_misc_set_padding (GTK_MISC (label852), 5, 0);

  vbox33 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox33, "vbox33");
  gtk_widget_show (vbox33);
  gtk_box_pack_start (GTK_BOX (vbox_gnutellanet), vbox33, FALSE, TRUE, 0);

  frame_expert_node_info = gtk_frame_new (NULL);
  gtk_widget_set_name (frame_expert_node_info, "frame_expert_node_info");
  gtk_widget_show (frame_expert_node_info);
  gtk_box_pack_start (GTK_BOX (vbox33), frame_expert_node_info, FALSE, FALSE, 0);

  vbox34 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox34, "vbox34");
  gtk_widget_show (vbox34);
  gtk_container_add (GTK_CONTAINER (frame_expert_node_info), vbox34);

  hbox151 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox151, "hbox151");
  gtk_widget_show (hbox151);
  gtk_box_pack_start (GTK_BOX (vbox34), hbox151, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (hbox151), 2);

  label150 = gtk_label_new (_("GUID:"));
  gtk_widget_set_name (label150, "label150");
  gtk_widget_show (label150);
  gtk_box_pack_start (GTK_BOX (hbox151), label150, FALSE, TRUE, 0);
  gtk_label_set_justify (GTK_LABEL (label150), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label150), 7.45058e-09, 0.5);

  eventbox11 = gtk_event_box_new ();
  gtk_widget_set_name (eventbox11, "eventbox11");
  gtk_widget_show (eventbox11);
  gtk_box_pack_start (GTK_BOX (hbox151), eventbox11, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox11, _("The Global Unique IDentifier associated with this node. It's used for routing packets in the Gnutella network."), NULL);

  label_nodes_guid = gtk_label_new (_("[GUID placeholder]"));
  gtk_widget_set_name (label_nodes_guid, "label_nodes_guid");
  gtk_widget_show (label_nodes_guid);
  gtk_container_add (GTK_CONTAINER (eventbox11), label_nodes_guid);
  GTK_WIDGET_SET_FLAGS (label_nodes_guid, GTK_CAN_FOCUS);
  gtk_label_set_selectable (GTK_LABEL (label_nodes_guid), TRUE);
  gtk_misc_set_alignment (GTK_MISC (label_nodes_guid), 0, 0.5);

  label1046 = gtk_label_new (_("KUID:"));
  gtk_widget_set_name (label1046, "label1046");
  gtk_widget_show (label1046);
  gtk_box_pack_start (GTK_BOX (hbox151), label1046, FALSE, FALSE, 0);

  eventbox15 = gtk_event_box_new ();
  gtk_widget_set_name (eventbox15, "eventbox15");
  gtk_widget_show (eventbox15);
  gtk_box_pack_start (GTK_BOX (hbox151), eventbox15, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox15, _("The Global Unique IDentifier associated with this node. It's used for routing packets in the Gnutella network."), NULL);

  label_nodes_kuid = gtk_label_new (_("[KUID placeholder]"));
  gtk_widget_set_name (label_nodes_kuid, "label_nodes_kuid");
  gtk_widget_show (label_nodes_kuid);
  gtk_container_add (GTK_CONTAINER (eventbox15), label_nodes_kuid);
  GTK_WIDGET_SET_FLAGS (label_nodes_kuid, GTK_CAN_FOCUS);
  gtk_label_set_selectable (GTK_LABEL (label_nodes_kuid), TRUE);
  gtk_misc_set_alignment (GTK_MISC (label_nodes_kuid), 0, 0.5);

  label151 = gtk_label_new (_("Address/Port:"));
  gtk_widget_set_name (label151, "label151");
  gtk_widget_show (label151);
  gtk_box_pack_start (GTK_BOX (hbox151), label151, FALSE, TRUE, 0);
  gtk_label_set_justify (GTK_LABEL (label151), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label151), 0, 0.5);

  eventbox12 = gtk_event_box_new ();
  gtk_widget_set_name (eventbox12, "eventbox12");
  gtk_widget_show (eventbox12);
  gtk_box_pack_start (GTK_BOX (hbox151), eventbox12, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, eventbox12, _("The current IP address and listening port for this node. To change these go to File->Preferences->Network."), NULL);

  label_nodes_ip = gtk_label_new (_("[IP:port placeholder]"));
  gtk_widget_set_name (label_nodes_ip, "label_nodes_ip");
  gtk_widget_show (label_nodes_ip);
  gtk_container_add (GTK_CONTAINER (eventbox12), label_nodes_ip);
  GTK_WIDGET_SET_FLAGS (label_nodes_ip, GTK_CAN_FOCUS);
  gtk_label_set_selectable (GTK_LABEL (label_nodes_ip), TRUE);
  gtk_misc_set_alignment (GTK_MISC (label_nodes_ip), 0, 0.5);

  label282 = gtk_label_new (_("Local node"));
  gtk_widget_set_name (label282, "label282");
  gtk_widget_show (label282);
  gtk_frame_set_label_widget (GTK_FRAME (frame_expert_node_info), label282);

  g_signal_connect ((gpointer) button_nodes_add, "clicked",
                    G_CALLBACK (on_button_nodes_add_clicked),
                    NULL);
  g_signal_connect ((gpointer) entry_host, "changed",
                    G_CALLBACK (on_entry_host_changed),
                    NULL);
  g_signal_connect ((gpointer) entry_host, "activate",
                    G_CALLBACK (on_entry_host_activate),
                    NULL);
  g_signal_connect ((gpointer) button_nodes_disconnect, "clicked",
                    G_CALLBACK (on_button_nodes_disconnect_clicked),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (main_window_gnet_tab, main_window_gnet_tab, "main_window_gnet_tab");
  GLADE_HOOKUP_OBJECT (main_window_gnet_tab, vbox_gnutellanet, "vbox_gnutellanet");
  GLADE_HOOKUP_OBJECT (main_window_gnet_tab, vbox17, "vbox17");
  GLADE_HOOKUP_OBJECT (main_window_gnet_tab, scrolledwindow37, "scrolledwindow37");
  GLADE_HOOKUP_OBJECT (main_window_gnet_tab, treeview_nodes, "treeview_nodes");
  GLADE_HOOKUP_OBJECT (main_window_gnet_tab, table56, "table56");
  GLADE_HOOKUP_OBJECT (main_window_gnet_tab, button_nodes_add, "button_nodes_add");
  GLADE_HOOKUP_OBJECT (main_window_gnet_tab, alignment33, "alignment33");
  GLADE_HOOKUP_OBJECT (main_window_gnet_tab, hbox164, "hbox164");
  GLADE_HOOKUP_OBJECT (main_window_gnet_tab, image34, "image34");
  GLADE_HOOKUP_OBJECT (main_window_gnet_tab, label415, "label415");
  GLADE_HOOKUP_OBJECT (main_window_gnet_tab, entry_host, "entry_host");
  GLADE_HOOKUP_OBJECT (main_window_gnet_tab, button_nodes_disconnect, "button_nodes_disconnect");
  GLADE_HOOKUP_OBJECT (main_window_gnet_tab, alignment135, "alignment135");
  GLADE_HOOKUP_OBJECT (main_window_gnet_tab, hbox9331, "hbox9331");
  GLADE_HOOKUP_OBJECT (main_window_gnet_tab, image1258, "image1258");
  GLADE_HOOKUP_OBJECT (main_window_gnet_tab, label987, "label987");
  GLADE_HOOKUP_OBJECT (main_window_gnet_tab, hbox_leaf, "hbox_leaf");
  GLADE_HOOKUP_OBJECT (main_window_gnet_tab, label519, "label519");
  GLADE_HOOKUP_OBJECT (main_window_gnet_tab, spinbutton_max_ultrapeers, "spinbutton_max_ultrapeers");
  GLADE_HOOKUP_OBJECT (main_window_gnet_tab, label520, "label520");
  GLADE_HOOKUP_OBJECT (main_window_gnet_tab, hbox9354, "hbox9354");
  GLADE_HOOKUP_OBJECT (main_window_gnet_tab, label1079, "label1079");
  GLADE_HOOKUP_OBJECT (main_window_gnet_tab, spinbutton_max_g2_hubs, "spinbutton_max_g2_hubs");
  GLADE_HOOKUP_OBJECT (main_window_gnet_tab, hbox_normal_or_ultrapeer, "hbox_normal_or_ultrapeer");
  GLADE_HOOKUP_OBJECT (main_window_gnet_tab, label2, "label2");
  GLADE_HOOKUP_OBJECT (main_window_gnet_tab, spinbutton_up_connections, "spinbutton_up_connections");
  GLADE_HOOKUP_OBJECT (main_window_gnet_tab, label3, "label3");
  GLADE_HOOKUP_OBJECT (main_window_gnet_tab, spinbutton_max_connections, "spinbutton_max_connections");
  GLADE_HOOKUP_OBJECT (main_window_gnet_tab, label83, "label83");
  GLADE_HOOKUP_OBJECT (main_window_gnet_tab, hbox265, "hbox265");
  GLADE_HOOKUP_OBJECT (main_window_gnet_tab, label851, "label851");
  GLADE_HOOKUP_OBJECT (main_window_gnet_tab, spinbutton_quick_connect_pool_size, "spinbutton_quick_connect_pool_size");
  GLADE_HOOKUP_OBJECT (main_window_gnet_tab, label852, "label852");
  GLADE_HOOKUP_OBJECT (main_window_gnet_tab, vbox33, "vbox33");
  GLADE_HOOKUP_OBJECT (main_window_gnet_tab, frame_expert_node_info, "frame_expert_node_info");
  GLADE_HOOKUP_OBJECT (main_window_gnet_tab, vbox34, "vbox34");
  GLADE_HOOKUP_OBJECT (main_window_gnet_tab, hbox151, "hbox151");
  GLADE_HOOKUP_OBJECT (main_window_gnet_tab, label150, "label150");
  GLADE_HOOKUP_OBJECT (main_window_gnet_tab, eventbox11, "eventbox11");
  GLADE_HOOKUP_OBJECT (main_window_gnet_tab, label_nodes_guid, "label_nodes_guid");
  GLADE_HOOKUP_OBJECT (main_window_gnet_tab, label1046, "label1046");
  GLADE_HOOKUP_OBJECT (main_window_gnet_tab, eventbox15, "eventbox15");
  GLADE_HOOKUP_OBJECT (main_window_gnet_tab, label_nodes_kuid, "label_nodes_kuid");
  GLADE_HOOKUP_OBJECT (main_window_gnet_tab, label151, "label151");
  GLADE_HOOKUP_OBJECT (main_window_gnet_tab, eventbox12, "eventbox12");
  GLADE_HOOKUP_OBJECT (main_window_gnet_tab, label_nodes_ip, "label_nodes_ip");
  GLADE_HOOKUP_OBJECT (main_window_gnet_tab, label282, "label282");
  GLADE_HOOKUP_OBJECT_NO_REF (main_window_gnet_tab, tooltips, "tooltips");

  return main_window_gnet_tab;
}

GtkWidget*
create_main_window_uploads_tab (void)
{
  GtkWidget *main_window_uploads_tab;
  GtkWidget *vbox18;
  GtkWidget *scrolledwindow20;
  GtkWidget *treeview_uploads;
  GtkWidget *hbox72;
  GtkWidget *button_uploads_kill;
  GtkWidget *alignment35;
  GtkWidget *hbox166;
  GtkWidget *image36;
  GtkWidget *label417;
  GtkWidget *button_uploads_clear_completed;
  GtkWidget *alignment36;
  GtkWidget *hbox167;
  GtkWidget *image37;
  GtkWidget *label418;
  GtkWidget *table69;
  GtkWidget *checkbutton_uploads_auto_clear_complete;
  GtkWidget *checkbutton_uploads_auto_clear_failed;
  GtkWidget *label130;
  GtkWidget *label81;
  GtkObject *spinbutton_max_uploads_adj;
  GtkWidget *spinbutton_max_uploads;
  GtkObject *spinbutton_max_uploads_ip_adj;
  GtkWidget *spinbutton_max_uploads_ip;
  GtkTooltips *tooltips;

  tooltips = gtk_tooltips_new ();

  main_window_uploads_tab = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_widget_set_name (main_window_uploads_tab, "main_window_uploads_tab");

  vbox18 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox18, "vbox18");
  gtk_widget_show (vbox18);
  gtk_container_add (GTK_CONTAINER (main_window_uploads_tab), vbox18);

  scrolledwindow20 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow20, "scrolledwindow20");
  gtk_widget_show (scrolledwindow20);
  gtk_box_pack_start (GTK_BOX (vbox18), scrolledwindow20, TRUE, TRUE, 0);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow20), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolledwindow20), GTK_SHADOW_IN);

  treeview_uploads = gtk_tree_view_new ();
  gtk_widget_set_name (treeview_uploads, "treeview_uploads");
  gtk_widget_show (treeview_uploads);
  gtk_container_add (GTK_CONTAINER (scrolledwindow20), treeview_uploads);
  gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (treeview_uploads), TRUE);
  gtk_tree_view_set_enable_search (GTK_TREE_VIEW (treeview_uploads), FALSE);

  hbox72 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox72, "hbox72");
  gtk_widget_show (hbox72);
  gtk_box_pack_start (GTK_BOX (vbox18), hbox72, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (hbox72), 2);

  button_uploads_kill = gtk_button_new ();
  gtk_widget_set_name (button_uploads_kill, "button_uploads_kill");
  gtk_widget_show (button_uploads_kill);
  gtk_box_pack_start (GTK_BOX (hbox72), button_uploads_kill, FALSE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, button_uploads_kill, _("Abort and remove all selected uploads"), NULL);

  alignment35 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment35, "alignment35");
  gtk_widget_show (alignment35);
  gtk_container_add (GTK_CONTAINER (button_uploads_kill), alignment35);

  hbox166 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox166, "hbox166");
  gtk_widget_show (hbox166);
  gtk_container_add (GTK_CONTAINER (alignment35), hbox166);

  image36 = gtk_image_new_from_stock ("gtk-delete", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image36, "image36");
  gtk_widget_show (image36);
  gtk_box_pack_start (GTK_BOX (hbox166), image36, FALSE, FALSE, 0);

  label417 = gtk_label_new_with_mnemonic (_(" Kill selected "));
  gtk_widget_set_name (label417, "label417");
  gtk_widget_show (label417);
  gtk_box_pack_start (GTK_BOX (hbox166), label417, FALSE, FALSE, 0);

  button_uploads_clear_completed = gtk_button_new ();
  gtk_widget_set_name (button_uploads_clear_completed, "button_uploads_clear_completed");
  gtk_widget_show (button_uploads_clear_completed);
  gtk_box_pack_start (GTK_BOX (hbox72), button_uploads_clear_completed, FALSE, FALSE, 0);
  gtk_widget_set_sensitive (button_uploads_clear_completed, FALSE);
  gtk_tooltips_set_tip (tooltips, button_uploads_clear_completed, _("Clear already completed uploads from list"), NULL);

  alignment36 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment36, "alignment36");
  gtk_widget_show (alignment36);
  gtk_container_add (GTK_CONTAINER (button_uploads_clear_completed), alignment36);

  hbox167 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox167, "hbox167");
  gtk_widget_show (hbox167);
  gtk_container_add (GTK_CONTAINER (alignment36), hbox167);

  image37 = gtk_image_new_from_stock ("gtk-clear", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image37, "image37");
  gtk_widget_show (image37);
  gtk_box_pack_start (GTK_BOX (hbox167), image37, FALSE, FALSE, 0);

  label418 = gtk_label_new_with_mnemonic (_(" Clear completed "));
  gtk_widget_set_name (label418, "label418");
  gtk_widget_show (label418);
  gtk_box_pack_start (GTK_BOX (hbox167), label418, FALSE, FALSE, 0);

  table69 = gtk_table_new (2, 3, FALSE);
  gtk_widget_set_name (table69, "table69");
  gtk_widget_show (table69);
  gtk_box_pack_start (GTK_BOX (vbox18), table69, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (table69), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table69), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table69), 4);

  checkbutton_uploads_auto_clear_complete = gtk_check_button_new_with_mnemonic (_("Auto clear completed uploads"));
  gtk_widget_set_name (checkbutton_uploads_auto_clear_complete, "checkbutton_uploads_auto_clear_complete");
  gtk_widget_show (checkbutton_uploads_auto_clear_complete);
  gtk_table_attach (GTK_TABLE (table69), checkbutton_uploads_auto_clear_complete, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  checkbutton_uploads_auto_clear_failed = gtk_check_button_new_with_mnemonic (_("Auto clear failed uploads"));
  gtk_widget_set_name (checkbutton_uploads_auto_clear_failed, "checkbutton_uploads_auto_clear_failed");
  gtk_widget_show (checkbutton_uploads_auto_clear_failed);
  gtk_table_attach (GTK_TABLE (table69), checkbutton_uploads_auto_clear_failed, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  label130 = gtk_label_new (_("Max. uploads to a single host"));
  gtk_widget_set_name (label130, "label130");
  gtk_widget_show (label130);
  gtk_table_attach (GTK_TABLE (table69), label130, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label130), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label130), 0, 0.5);

  label81 = gtk_label_new (_("Max. simultaneous uploads"));
  gtk_widget_set_name (label81, "label81");
  gtk_widget_show (label81);
  gtk_table_attach (GTK_TABLE (table69), label81, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label81), 0, 0.5);

  spinbutton_max_uploads_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 0);
  spinbutton_max_uploads = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_max_uploads_adj), 1, 0);
  gtk_widget_set_name (spinbutton_max_uploads, "spinbutton_max_uploads");
  gtk_widget_show (spinbutton_max_uploads);
  gtk_table_attach (GTK_TABLE (table69), spinbutton_max_uploads, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_max_uploads), TRUE);

  spinbutton_max_uploads_ip_adj = gtk_adjustment_new (1, 1, 100, 1, 10, 0);
  spinbutton_max_uploads_ip = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_max_uploads_ip_adj), 1, 0);
  gtk_widget_set_name (spinbutton_max_uploads_ip, "spinbutton_max_uploads_ip");
  gtk_widget_show (spinbutton_max_uploads_ip);
  gtk_table_attach (GTK_TABLE (table69), spinbutton_max_uploads_ip, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_max_uploads_ip), TRUE);

  g_signal_connect ((gpointer) button_uploads_kill, "clicked",
                    G_CALLBACK (on_button_uploads_kill_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_uploads_clear_completed, "clicked",
                    G_CALLBACK (on_button_uploads_clear_completed_clicked),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (main_window_uploads_tab, main_window_uploads_tab, "main_window_uploads_tab");
  GLADE_HOOKUP_OBJECT (main_window_uploads_tab, vbox18, "vbox18");
  GLADE_HOOKUP_OBJECT (main_window_uploads_tab, scrolledwindow20, "scrolledwindow20");
  GLADE_HOOKUP_OBJECT (main_window_uploads_tab, treeview_uploads, "treeview_uploads");
  GLADE_HOOKUP_OBJECT (main_window_uploads_tab, hbox72, "hbox72");
  GLADE_HOOKUP_OBJECT (main_window_uploads_tab, button_uploads_kill, "button_uploads_kill");
  GLADE_HOOKUP_OBJECT (main_window_uploads_tab, alignment35, "alignment35");
  GLADE_HOOKUP_OBJECT (main_window_uploads_tab, hbox166, "hbox166");
  GLADE_HOOKUP_OBJECT (main_window_uploads_tab, image36, "image36");
  GLADE_HOOKUP_OBJECT (main_window_uploads_tab, label417, "label417");
  GLADE_HOOKUP_OBJECT (main_window_uploads_tab, button_uploads_clear_completed, "button_uploads_clear_completed");
  GLADE_HOOKUP_OBJECT (main_window_uploads_tab, alignment36, "alignment36");
  GLADE_HOOKUP_OBJECT (main_window_uploads_tab, hbox167, "hbox167");
  GLADE_HOOKUP_OBJECT (main_window_uploads_tab, image37, "image37");
  GLADE_HOOKUP_OBJECT (main_window_uploads_tab, label418, "label418");
  GLADE_HOOKUP_OBJECT (main_window_uploads_tab, table69, "table69");
  GLADE_HOOKUP_OBJECT (main_window_uploads_tab, checkbutton_uploads_auto_clear_complete, "checkbutton_uploads_auto_clear_complete");
  GLADE_HOOKUP_OBJECT (main_window_uploads_tab, checkbutton_uploads_auto_clear_failed, "checkbutton_uploads_auto_clear_failed");
  GLADE_HOOKUP_OBJECT (main_window_uploads_tab, label130, "label130");
  GLADE_HOOKUP_OBJECT (main_window_uploads_tab, label81, "label81");
  GLADE_HOOKUP_OBJECT (main_window_uploads_tab, spinbutton_max_uploads, "spinbutton_max_uploads");
  GLADE_HOOKUP_OBJECT (main_window_uploads_tab, spinbutton_max_uploads_ip, "spinbutton_max_uploads_ip");
  GLADE_HOOKUP_OBJECT_NO_REF (main_window_uploads_tab, tooltips, "tooltips");

  return main_window_uploads_tab;
}

GtkWidget*
create_main_window_upload_stats_tab (void)
{
  GtkWidget *main_window_upload_stats_tab;
  GtkWidget *vbox19;
  GtkWidget *scrolledwindow63;
  GtkWidget *treeview_ul_stats;
  GtkWidget *ul_stats_hbox2;
  GtkWidget *button_ul_stats_clear_deleted;
  GtkWidget *alignment38;
  GtkWidget *hbox169;
  GtkWidget *image39;
  GtkWidget *label420;
  GtkWidget *button_ul_stats_clear_all;
  GtkWidget *alignment37;
  GtkWidget *hbox168;
  GtkWidget *image38;
  GtkWidget *label419;
  GtkWidget *hbox9296;
  GtkWidget *label923;
  GtkWidget *label_g2_browse_served;
  GtkWidget *label1081;
  GtkWidget *label_g2_browse_count;
  GtkWidget *label1083;
  GtkWidget *label_html_browse_served;
  GtkWidget *label991;
  GtkWidget *label_html_browse_count;
  GtkWidget *label925;
  GtkWidget *label_qhits_browse_served;
  GtkWidget *label988;
  GtkWidget *label_qhits_browse_count;
  GtkWidget *label927;
  GtkTooltips *tooltips;

  tooltips = gtk_tooltips_new ();

  main_window_upload_stats_tab = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_widget_set_name (main_window_upload_stats_tab, "main_window_upload_stats_tab");

  vbox19 = gtk_vbox_new (FALSE, 4);
  gtk_widget_set_name (vbox19, "vbox19");
  gtk_widget_show (vbox19);
  gtk_container_add (GTK_CONTAINER (main_window_upload_stats_tab), vbox19);

  scrolledwindow63 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow63, "scrolledwindow63");
  gtk_widget_show (scrolledwindow63);
  gtk_box_pack_start (GTK_BOX (vbox19), scrolledwindow63, TRUE, TRUE, 0);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow63), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolledwindow63), GTK_SHADOW_IN);

  treeview_ul_stats = gtk_tree_view_new ();
  gtk_widget_set_name (treeview_ul_stats, "treeview_ul_stats");
  gtk_widget_show (treeview_ul_stats);
  gtk_container_add (GTK_CONTAINER (scrolledwindow63), treeview_ul_stats);
  gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (treeview_ul_stats), TRUE);
  gtk_tree_view_set_enable_search (GTK_TREE_VIEW (treeview_ul_stats), FALSE);

  ul_stats_hbox2 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (ul_stats_hbox2, "ul_stats_hbox2");
  gtk_widget_show (ul_stats_hbox2);
  gtk_box_pack_start (GTK_BOX (vbox19), ul_stats_hbox2, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (ul_stats_hbox2), 2);

  button_ul_stats_clear_deleted = gtk_button_new ();
  gtk_widget_set_name (button_ul_stats_clear_deleted, "button_ul_stats_clear_deleted");
  gtk_widget_show (button_ul_stats_clear_deleted);
  gtk_box_pack_start (GTK_BOX (ul_stats_hbox2), button_ul_stats_clear_deleted, FALSE, FALSE, 0);
  gtk_widget_set_sensitive (button_ul_stats_clear_deleted, FALSE);
  gtk_tooltips_set_tip (tooltips, button_ul_stats_clear_deleted, _("Somebody tell me a sensible tooltip for this."), NULL);

  alignment38 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment38, "alignment38");
  gtk_widget_show (alignment38);
  gtk_container_add (GTK_CONTAINER (button_ul_stats_clear_deleted), alignment38);

  hbox169 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox169, "hbox169");
  gtk_widget_show (hbox169);
  gtk_container_add (GTK_CONTAINER (alignment38), hbox169);

  image39 = gtk_image_new_from_stock ("gtk-clear", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image39, "image39");
  gtk_widget_show (image39);
  gtk_box_pack_start (GTK_BOX (hbox169), image39, FALSE, FALSE, 0);

  label420 = gtk_label_new_with_mnemonic (_("Clear non-existent files"));
  gtk_widget_set_name (label420, "label420");
  gtk_widget_show (label420);
  gtk_box_pack_start (GTK_BOX (hbox169), label420, FALSE, FALSE, 0);

  button_ul_stats_clear_all = gtk_button_new ();
  gtk_widget_set_name (button_ul_stats_clear_all, "button_ul_stats_clear_all");
  gtk_widget_show (button_ul_stats_clear_all);
  gtk_box_pack_start (GTK_BOX (ul_stats_hbox2), button_ul_stats_clear_all, FALSE, FALSE, 0);

  alignment37 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment37, "alignment37");
  gtk_widget_show (alignment37);
  gtk_container_add (GTK_CONTAINER (button_ul_stats_clear_all), alignment37);

  hbox168 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox168, "hbox168");
  gtk_widget_show (hbox168);
  gtk_container_add (GTK_CONTAINER (alignment37), hbox168);

  image38 = gtk_image_new_from_stock ("gtk-clear", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image38, "image38");
  gtk_widget_show (image38);
  gtk_box_pack_start (GTK_BOX (hbox168), image38, FALSE, FALSE, 0);

  label419 = gtk_label_new_with_mnemonic (_("Clear all"));
  gtk_widget_set_name (label419, "label419");
  gtk_widget_show (label419);
  gtk_box_pack_start (GTK_BOX (hbox168), label419, FALSE, FALSE, 0);

  hbox9296 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox9296, "hbox9296");
  gtk_widget_show (hbox9296);
  gtk_box_pack_start (GTK_BOX (ul_stats_hbox2), hbox9296, TRUE, TRUE, 0);

  label923 = gtk_label_new (_("Served "));
  gtk_widget_set_name (label923, "label923");
  gtk_widget_show (label923);
  gtk_box_pack_start (GTK_BOX (hbox9296), label923, TRUE, TRUE, 0);
  gtk_misc_set_alignment (GTK_MISC (label923), 1, 0.5);

  label_g2_browse_served = gtk_label_new (_("[G2 served]"));
  gtk_widget_set_name (label_g2_browse_served, "label_g2_browse_served");
  gtk_widget_show (label_g2_browse_served);
  gtk_box_pack_start (GTK_BOX (hbox9296), label_g2_browse_served, FALSE, FALSE, 0);

  label1081 = gtk_label_new (_(" / "));
  gtk_widget_set_name (label1081, "label1081");
  gtk_widget_show (label1081);
  gtk_box_pack_start (GTK_BOX (hbox9296), label1081, FALSE, FALSE, 0);

  label_g2_browse_count = gtk_label_new (_("[G2]"));
  gtk_widget_set_name (label_g2_browse_count, "label_g2_browse_count");
  gtk_widget_show (label_g2_browse_count);
  gtk_box_pack_start (GTK_BOX (hbox9296), label_g2_browse_count, FALSE, FALSE, 0);

  label1083 = gtk_label_new (_(" G2, "));
  gtk_widget_set_name (label1083, "label1083");
  gtk_widget_show (label1083);
  gtk_box_pack_start (GTK_BOX (hbox9296), label1083, FALSE, FALSE, 0);

  label_html_browse_served = gtk_label_new (_("[BH HTML served]"));
  gtk_widget_set_name (label_html_browse_served, "label_html_browse_served");
  gtk_widget_show (label_html_browse_served);
  gtk_box_pack_start (GTK_BOX (hbox9296), label_html_browse_served, FALSE, FALSE, 0);

  label991 = gtk_label_new (_(" / "));
  gtk_widget_set_name (label991, "label991");
  gtk_widget_show (label991);
  gtk_box_pack_start (GTK_BOX (hbox9296), label991, FALSE, FALSE, 0);

  label_html_browse_count = gtk_label_new (_("[BH HTML]"));
  gtk_widget_set_name (label_html_browse_count, "label_html_browse_count");
  gtk_widget_show (label_html_browse_count);
  gtk_box_pack_start (GTK_BOX (hbox9296), label_html_browse_count, FALSE, FALSE, 0);

  label925 = gtk_label_new (_(" HTML and "));
  gtk_widget_set_name (label925, "label925");
  gtk_widget_show (label925);
  gtk_box_pack_start (GTK_BOX (hbox9296), label925, FALSE, FALSE, 0);

  label_qhits_browse_served = gtk_label_new (_("[BH qhits]"));
  gtk_widget_set_name (label_qhits_browse_served, "label_qhits_browse_served");
  gtk_widget_show (label_qhits_browse_served);
  gtk_box_pack_start (GTK_BOX (hbox9296), label_qhits_browse_served, FALSE, FALSE, 0);

  label988 = gtk_label_new (_(" / "));
  gtk_widget_set_name (label988, "label988");
  gtk_widget_show (label988);
  gtk_box_pack_start (GTK_BOX (hbox9296), label988, FALSE, FALSE, 0);

  label_qhits_browse_count = gtk_label_new (_("[BH qhits]"));
  gtk_widget_set_name (label_qhits_browse_count, "label_qhits_browse_count");
  gtk_widget_show (label_qhits_browse_count);
  gtk_box_pack_start (GTK_BOX (hbox9296), label_qhits_browse_count, FALSE, FALSE, 0);

  label927 = gtk_label_new (_(" Gnutella browse requests"));
  gtk_widget_set_name (label927, "label927");
  gtk_widget_show (label927);
  gtk_box_pack_start (GTK_BOX (hbox9296), label927, FALSE, FALSE, 0);

  g_signal_connect ((gpointer) button_ul_stats_clear_deleted, "clicked",
                    G_CALLBACK (on_button_ul_stats_clear_deleted_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_ul_stats_clear_all, "clicked",
                    G_CALLBACK (on_button_ul_stats_clear_all_clicked),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (main_window_upload_stats_tab, main_window_upload_stats_tab, "main_window_upload_stats_tab");
  GLADE_HOOKUP_OBJECT (main_window_upload_stats_tab, vbox19, "vbox19");
  GLADE_HOOKUP_OBJECT (main_window_upload_stats_tab, scrolledwindow63, "scrolledwindow63");
  GLADE_HOOKUP_OBJECT (main_window_upload_stats_tab, treeview_ul_stats, "treeview_ul_stats");
  GLADE_HOOKUP_OBJECT (main_window_upload_stats_tab, ul_stats_hbox2, "ul_stats_hbox2");
  GLADE_HOOKUP_OBJECT (main_window_upload_stats_tab, button_ul_stats_clear_deleted, "button_ul_stats_clear_deleted");
  GLADE_HOOKUP_OBJECT (main_window_upload_stats_tab, alignment38, "alignment38");
  GLADE_HOOKUP_OBJECT (main_window_upload_stats_tab, hbox169, "hbox169");
  GLADE_HOOKUP_OBJECT (main_window_upload_stats_tab, image39, "image39");
  GLADE_HOOKUP_OBJECT (main_window_upload_stats_tab, label420, "label420");
  GLADE_HOOKUP_OBJECT (main_window_upload_stats_tab, button_ul_stats_clear_all, "button_ul_stats_clear_all");
  GLADE_HOOKUP_OBJECT (main_window_upload_stats_tab, alignment37, "alignment37");
  GLADE_HOOKUP_OBJECT (main_window_upload_stats_tab, hbox168, "hbox168");
  GLADE_HOOKUP_OBJECT (main_window_upload_stats_tab, image38, "image38");
  GLADE_HOOKUP_OBJECT (main_window_upload_stats_tab, label419, "label419");
  GLADE_HOOKUP_OBJECT (main_window_upload_stats_tab, hbox9296, "hbox9296");
  GLADE_HOOKUP_OBJECT (main_window_upload_stats_tab, label923, "label923");
  GLADE_HOOKUP_OBJECT (main_window_upload_stats_tab, label_g2_browse_served, "label_g2_browse_served");
  GLADE_HOOKUP_OBJECT (main_window_upload_stats_tab, label1081, "label1081");
  GLADE_HOOKUP_OBJECT (main_window_upload_stats_tab, label_g2_browse_count, "label_g2_browse_count");
  GLADE_HOOKUP_OBJECT (main_window_upload_stats_tab, label1083, "label1083");
  GLADE_HOOKUP_OBJECT (main_window_upload_stats_tab, label_html_browse_served, "label_html_browse_served");
  GLADE_HOOKUP_OBJECT (main_window_upload_stats_tab, label991, "label991");
  GLADE_HOOKUP_OBJECT (main_window_upload_stats_tab, label_html_browse_count, "label_html_browse_count");
  GLADE_HOOKUP_OBJECT (main_window_upload_stats_tab, label925, "label925");
  GLADE_HOOKUP_OBJECT (main_window_upload_stats_tab, label_qhits_browse_served, "label_qhits_browse_served");
  GLADE_HOOKUP_OBJECT (main_window_upload_stats_tab, label988, "label988");
  GLADE_HOOKUP_OBJECT (main_window_upload_stats_tab, label_qhits_browse_count, "label_qhits_browse_count");
  GLADE_HOOKUP_OBJECT (main_window_upload_stats_tab, label927, "label927");
  GLADE_HOOKUP_OBJECT_NO_REF (main_window_upload_stats_tab, tooltips, "tooltips");

  return main_window_upload_stats_tab;
}

GtkWidget*
create_main_window_search_tab (void)
{
  GtkWidget *main_window_search_tab;
  GtkWidget *vbox79;
  GtkWidget *table96;
  GtkWidget *label832;
  GtkWidget *option_menu_searches;
  GtkWidget *button_search_close;
  GtkWidget *alignment76;
  GtkWidget *hbox214;
  GtkWidget *image137;
  GtkWidget *label670;
  GtkWidget *viewport474;
  GtkWidget *label_search_expiry;
  GtkWidget *vpaned_results;
  GtkWidget *viewport16;
  GtkWidget *notebook_search_results;
  GtkWidget *empty_notebook_page;
  GtkWidget *label190;
  GtkWidget *viewport477;
  GtkWidget *notebook1;
  GtkWidget *viewport106;
  GtkWidget *scrolledwindow67;
  GtkWidget *viewport57;
  GtkWidget *scrolledwindow82;
  GtkWidget *treeview_search_details;
  GtkWidget *label1010;
  GtkWidget *scrolledwindow83;
  GtkWidget *textview_result_info_xml;
  GtkWidget *label1015;
  GtkWidget *table78;
  GtkWidget *label993;
  GtkWidget *alignment136;
  GtkObject *spinbutton_browse_host_max_results_adj;
  GtkWidget *spinbutton_browse_host_max_results;
  GtkWidget *checkbutton_search_hide_downloaded;
  GtkWidget *checkbutton_search_remove_downloaded;
  GtkWidget *checkbutton_browse_copied_to_passive;
  GtkWidget *checkbutton_search_discard_hashless;
  GtkWidget *checkbutton_search_discard_spam;
  GtkWidget *label707;
  GtkWidget *frame137;
  GtkWidget *option_menu_search_handle_ignored_files;
  GtkWidget *label1068;
  GtkWidget *alignment148;
  GtkObject *spinbutton_passive_search_max_results_adj;
  GtkWidget *spinbutton_passive_search_max_results;
  GtkWidget *checkbutton_search_sort_casesense;
  GtkWidget *alignment90;
  GtkObject *spinbutton_search_max_results_adj;
  GtkWidget *spinbutton_search_max_results;
  GtkWidget *label557;
  GtkWidget *label1069;
  GtkWidget *alignment149;
  GtkObject *spinbutton_whats_new_search_max_results_adj;
  GtkWidget *spinbutton_whats_new_search_max_results;
  GtkWidget *checkbutton_search_discard_alien_ip;
  GtkWidget *checkbutton_search_discard_banned_guid;
  GtkWidget *checkbutton_search_display_guess_stats;
  GtkWidget *label1011;
  GtkWidget *guess_stats_line;
  GtkWidget *viewport482;
  GtkWidget *label_guess_stats;
  GtkWidget *checkbutton_guess_stats_show_total;
  GtkWidget *hbox215;
  GtkWidget *viewport56;
  GtkWidget *label_items_found;
  GtkWidget *hbox_expert_search_timeout;
  GtkWidget *label655;
  GtkObject *spinbutton_search_reissue_timeout_adj;
  GtkWidget *spinbutton_search_reissue_timeout;
  GtkWidget *label_search_reissue;
  GtkWidget *hbox154;
  GtkWidget *button_search_download;
  GtkWidget *alignment89;
  GtkWidget *hbox233;
  GtkWidget *image223;
  GtkWidget *label705;
  GtkWidget *button_search_filter;
  GtkWidget *alignment75;
  GtkWidget *hbox213;
  GtkWidget *image121;
  GtkWidget *label589;
  GtkWidget *label835;
  GtkWidget *button_search_clear;
  GtkWidget *alignment25;
  GtkWidget *hbox156;
  GtkWidget *image26;
  GtkWidget *label407;
  GtkAccelGroup *accel_group;

  accel_group = gtk_accel_group_new ();

  main_window_search_tab = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_widget_set_name (main_window_search_tab, "main_window_search_tab");
  gtk_window_set_default_size (GTK_WINDOW (main_window_search_tab), 300, 200);

  vbox79 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox79, "vbox79");
  gtk_widget_show (vbox79);
  gtk_container_add (GTK_CONTAINER (main_window_search_tab), vbox79);

  table96 = gtk_table_new (1, 4, FALSE);
  gtk_widget_set_name (table96, "table96");
  gtk_widget_show (table96);
  gtk_box_pack_start (GTK_BOX (vbox79), table96, FALSE, FALSE, 0);
  gtk_table_set_col_spacings (GTK_TABLE (table96), 4);

  label832 = gtk_label_new_with_mnemonic (_("Current _search:"));
  gtk_widget_set_name (label832, "label832");
  gtk_widget_show (label832);
  gtk_table_attach (GTK_TABLE (table96), label832, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 4, 0);

  option_menu_searches = gtk_option_menu_new ();
  gtk_widget_set_name (option_menu_searches, "option_menu_searches");
  gtk_widget_show (option_menu_searches);
  gtk_table_attach (GTK_TABLE (table96), option_menu_searches, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (GTK_SHRINK), 0, 0);

  button_search_close = gtk_button_new ();
  gtk_widget_set_name (button_search_close, "button_search_close");
  gtk_widget_show (button_search_close);
  gtk_table_attach (GTK_TABLE (table96), button_search_close, 3, 4, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 4, 0);
  gtk_widget_set_sensitive (button_search_close, FALSE);

  alignment76 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment76, "alignment76");
  gtk_widget_show (alignment76);
  gtk_container_add (GTK_CONTAINER (button_search_close), alignment76);

  hbox214 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox214, "hbox214");
  gtk_widget_show (hbox214);
  gtk_container_add (GTK_CONTAINER (alignment76), hbox214);

  image137 = gtk_image_new_from_stock ("gtk-close", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image137, "image137");
  gtk_widget_show (image137);
  gtk_box_pack_start (GTK_BOX (hbox214), image137, FALSE, FALSE, 0);

  label670 = gtk_label_new_with_mnemonic (_("Cl_ose search"));
  gtk_widget_set_name (label670, "label670");
  gtk_widget_show (label670);
  gtk_box_pack_start (GTK_BOX (hbox214), label670, FALSE, FALSE, 0);

  viewport474 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport474, "viewport474");
  gtk_widget_show (viewport474);
  gtk_table_attach (GTK_TABLE (table96), viewport474, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport474), GTK_SHADOW_ETCHED_IN);

  label_search_expiry = gtk_label_new ("                                                   ");
  gtk_widget_set_name (label_search_expiry, "label_search_expiry");
  gtk_widget_show (label_search_expiry);
  gtk_container_add (GTK_CONTAINER (viewport474), label_search_expiry);
  gtk_label_set_justify (GTK_LABEL (label_search_expiry), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label_search_expiry), 7.45058e-09, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_search_expiry), 5, 0);

  vpaned_results = gtk_vpaned_new ();
  gtk_widget_set_name (vpaned_results, "vpaned_results");
  gtk_widget_show (vpaned_results);
  gtk_box_pack_start (GTK_BOX (vbox79), vpaned_results, TRUE, TRUE, 0);
  gtk_paned_set_position (GTK_PANED (vpaned_results), 400);

  viewport16 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport16, "viewport16");
  gtk_widget_show (viewport16);
  gtk_paned_pack1 (GTK_PANED (vpaned_results), viewport16, FALSE, TRUE);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport16), GTK_SHADOW_NONE);

  notebook_search_results = gtk_notebook_new ();
  gtk_widget_set_name (notebook_search_results, "notebook_search_results");
  gtk_widget_show (notebook_search_results);
  gtk_container_add (GTK_CONTAINER (viewport16), notebook_search_results);
  gtk_notebook_set_scrollable (GTK_NOTEBOOK (notebook_search_results), TRUE);

  empty_notebook_page = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (empty_notebook_page);
  gtk_container_add (GTK_CONTAINER (notebook_search_results), empty_notebook_page);

  label190 = gtk_label_new (_("(no search)"));
  gtk_widget_set_name (label190, "label190");
  gtk_widget_show (label190);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_search_results), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_search_results), 0), label190);
  gtk_label_set_justify (GTK_LABEL (label190), GTK_JUSTIFY_CENTER);

  viewport477 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport477, "viewport477");
  gtk_widget_show (viewport477);
  gtk_paned_pack2 (GTK_PANED (vpaned_results), viewport477, TRUE, TRUE);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport477), GTK_SHADOW_NONE);

  notebook1 = gtk_notebook_new ();
  gtk_widget_set_name (notebook1, "notebook1");
  gtk_widget_show (notebook1);
  gtk_container_add (GTK_CONTAINER (viewport477), notebook1);
  gtk_notebook_set_scrollable (GTK_NOTEBOOK (notebook1), TRUE);

  viewport106 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport106, "viewport106");
  gtk_widget_show (viewport106);
  gtk_container_add (GTK_CONTAINER (notebook1), viewport106);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport106), GTK_SHADOW_NONE);

  scrolledwindow67 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow67, "scrolledwindow67");
  gtk_widget_show (scrolledwindow67);
  gtk_container_add (GTK_CONTAINER (viewport106), scrolledwindow67);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow67), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);

  viewport57 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport57, "viewport57");
  gtk_widget_show (viewport57);
  gtk_container_add (GTK_CONTAINER (scrolledwindow67), viewport57);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport57), GTK_SHADOW_NONE);

  scrolledwindow82 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow82, "scrolledwindow82");
  gtk_widget_show (scrolledwindow82);
  gtk_container_add (GTK_CONTAINER (viewport57), scrolledwindow82);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow82), GTK_POLICY_NEVER, GTK_POLICY_ALWAYS);
  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolledwindow82), GTK_SHADOW_ETCHED_IN);

  treeview_search_details = gtk_tree_view_new ();
  gtk_widget_set_name (treeview_search_details, "treeview_search_details");
  gtk_widget_show (treeview_search_details);
  gtk_container_add (GTK_CONTAINER (scrolledwindow82), treeview_search_details);
  gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (treeview_search_details), FALSE);
  gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (treeview_search_details), TRUE);
  gtk_tree_view_set_enable_search (GTK_TREE_VIEW (treeview_search_details), FALSE);

  label1010 = gtk_label_new (_("Details"));
  gtk_widget_set_name (label1010, "label1010");
  gtk_widget_show (label1010);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook1), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook1), 0), label1010);

  scrolledwindow83 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow83, "scrolledwindow83");
  gtk_widget_show (scrolledwindow83);
  gtk_container_add (GTK_CONTAINER (notebook1), scrolledwindow83);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow83), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolledwindow83), GTK_SHADOW_ETCHED_IN);

  textview_result_info_xml = gtk_text_view_new ();
  gtk_widget_set_name (textview_result_info_xml, "textview_result_info_xml");
  gtk_widget_show (textview_result_info_xml);
  gtk_container_add (GTK_CONTAINER (scrolledwindow83), textview_result_info_xml);
  gtk_text_view_set_editable (GTK_TEXT_VIEW (textview_result_info_xml), FALSE);
  gtk_text_view_set_cursor_visible (GTK_TEXT_VIEW (textview_result_info_xml), FALSE);

  label1015 = gtk_label_new (_("XML Metadata"));
  gtk_widget_set_name (label1015, "label1015");
  gtk_widget_show (label1015);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook1), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook1), 1), label1015);

  table78 = gtk_table_new (7, 4, FALSE);
  gtk_widget_set_name (table78, "table78");
  gtk_widget_show (table78);
  gtk_container_add (GTK_CONTAINER (notebook1), table78);
  gtk_container_set_border_width (GTK_CONTAINER (table78), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table78), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table78), 4);

  label993 = gtk_label_new (_("Max. number of browse host results"));
  gtk_widget_set_name (label993, "label993");
  gtk_widget_show (label993);
  gtk_table_attach (GTK_TABLE (table78), label993, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label993), 0, 0.5);

  alignment136 = gtk_alignment_new (0, 0.5, 0.15, 1);
  gtk_widget_set_name (alignment136, "alignment136");
  gtk_widget_show (alignment136);
  gtk_table_attach (GTK_TABLE (table78), alignment136, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  spinbutton_browse_host_max_results_adj = gtk_adjustment_new (1000, 1, 50000, 1, 10, 0);
  spinbutton_browse_host_max_results = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_browse_host_max_results_adj), 1, 0);
  gtk_widget_set_name (spinbutton_browse_host_max_results, "spinbutton_browse_host_max_results");
  gtk_widget_show (spinbutton_browse_host_max_results);
  gtk_container_add (GTK_CONTAINER (alignment136), spinbutton_browse_host_max_results);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_browse_host_max_results), TRUE);

  checkbutton_search_hide_downloaded = gtk_check_button_new_with_mnemonic (_("_Hide downloaded files"));
  gtk_widget_set_name (checkbutton_search_hide_downloaded, "checkbutton_search_hide_downloaded");
  gtk_widget_show (checkbutton_search_hide_downloaded);
  gtk_table_attach (GTK_TABLE (table78), checkbutton_search_hide_downloaded, 2, 4, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_search_remove_downloaded = gtk_check_button_new_with_mnemonic (_("_Remove manually downloaded files"));
  gtk_widget_set_name (checkbutton_search_remove_downloaded, "checkbutton_search_remove_downloaded");
  gtk_widget_show (checkbutton_search_remove_downloaded);
  gtk_table_attach (GTK_TABLE (table78), checkbutton_search_remove_downloaded, 2, 4, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_browse_copied_to_passive = gtk_check_button_new_with_mnemonic (_("Copy browse-host results to passive searches"));
  gtk_widget_set_name (checkbutton_browse_copied_to_passive, "checkbutton_browse_copied_to_passive");
  gtk_widget_show (checkbutton_browse_copied_to_passive);
  gtk_table_attach (GTK_TABLE (table78), checkbutton_browse_copied_to_passive, 2, 4, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_search_discard_hashless = gtk_check_button_new_with_mnemonic (_("Discard results without SHA-1 hashes"));
  gtk_widget_set_name (checkbutton_search_discard_hashless, "checkbutton_search_discard_hashless");
  gtk_widget_show (checkbutton_search_discard_hashless);
  gtk_table_attach (GTK_TABLE (table78), checkbutton_search_discard_hashless, 2, 4, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_search_discard_spam = gtk_check_button_new_with_mnemonic (_("Discard spam"));
  gtk_widget_set_name (checkbutton_search_discard_spam, "checkbutton_search_discard_spam");
  gtk_widget_show (checkbutton_search_discard_spam);
  gtk_table_attach (GTK_TABLE (table78), checkbutton_search_discard_spam, 2, 4, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label707 = gtk_label_new (_("Ignored files are"));
  gtk_widget_set_name (label707, "label707");
  gtk_widget_show (label707);
  gtk_table_attach (GTK_TABLE (table78), label707, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label707), 0, 0.5);

  frame137 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame137, "frame137");
  gtk_widget_show (frame137);
  gtk_table_attach (GTK_TABLE (table78), frame137, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  option_menu_search_handle_ignored_files = gtk_option_menu_new ();
  gtk_widget_set_name (option_menu_search_handle_ignored_files, "option_menu_search_handle_ignored_files");
  gtk_widget_show (option_menu_search_handle_ignored_files);
  gtk_container_add (GTK_CONTAINER (frame137), option_menu_search_handle_ignored_files);

  label1068 = gtk_label_new (_("Max. number of passive results"));
  gtk_widget_set_name (label1068, "label1068");
  gtk_widget_show (label1068);
  gtk_table_attach (GTK_TABLE (table78), label1068, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label1068), 0, 0.5);

  alignment148 = gtk_alignment_new (0, 0.5, 0.15, 1);
  gtk_widget_set_name (alignment148, "alignment148");
  gtk_widget_show (alignment148);
  gtk_table_attach (GTK_TABLE (table78), alignment148, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  spinbutton_passive_search_max_results_adj = gtk_adjustment_new (1000, 1, 50000, 1, 10, 0);
  spinbutton_passive_search_max_results = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_passive_search_max_results_adj), 1, 0);
  gtk_widget_set_name (spinbutton_passive_search_max_results, "spinbutton_passive_search_max_results");
  gtk_widget_show (spinbutton_passive_search_max_results);
  gtk_container_add (GTK_CONTAINER (alignment148), spinbutton_passive_search_max_results);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_passive_search_max_results), TRUE);

  checkbutton_search_sort_casesense = gtk_check_button_new_with_mnemonic (_("Case-sensitive sorting"));
  gtk_widget_set_name (checkbutton_search_sort_casesense, "checkbutton_search_sort_casesense");
  gtk_widget_show (checkbutton_search_sort_casesense);
  gtk_table_attach (GTK_TABLE (table78), checkbutton_search_sort_casesense, 0, 1, 5, 6,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  alignment90 = gtk_alignment_new (0, 0.5, 0.15, 1);
  gtk_widget_set_name (alignment90, "alignment90");
  gtk_widget_show (alignment90);
  gtk_table_attach (GTK_TABLE (table78), alignment90, 1, 2, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  spinbutton_search_max_results_adj = gtk_adjustment_new (1000, 1, 50000, 1, 10, 0);
  spinbutton_search_max_results = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_search_max_results_adj), 1, 0);
  gtk_widget_set_name (spinbutton_search_max_results, "spinbutton_search_max_results");
  gtk_widget_show (spinbutton_search_max_results);
  gtk_container_add (GTK_CONTAINER (alignment90), spinbutton_search_max_results);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_search_max_results), TRUE);

  label557 = gtk_label_new_with_mnemonic (_("Max. _number of results"));
  gtk_widget_set_name (label557, "label557");
  gtk_widget_show (label557);
  gtk_table_attach (GTK_TABLE (table78), label557, 0, 1, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label557), 0, 0.5);

  label1069 = gtk_label_new_with_mnemonic (_("Max. number of What's New? results"));
  gtk_widget_set_name (label1069, "label1069");
  gtk_widget_show (label1069);
  gtk_table_attach (GTK_TABLE (table78), label1069, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label1069), 0, 0.5);

  alignment149 = gtk_alignment_new (0, 0.5, 0.15, 1);
  gtk_widget_set_name (alignment149, "alignment149");
  gtk_widget_show (alignment149);
  gtk_table_attach (GTK_TABLE (table78), alignment149, 1, 2, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  spinbutton_whats_new_search_max_results_adj = gtk_adjustment_new (1000, 1, 50000, 1, 10, 0);
  spinbutton_whats_new_search_max_results = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_whats_new_search_max_results_adj), 1, 0);
  gtk_widget_set_name (spinbutton_whats_new_search_max_results, "spinbutton_whats_new_search_max_results");
  gtk_widget_show (spinbutton_whats_new_search_max_results);
  gtk_container_add (GTK_CONTAINER (alignment149), spinbutton_whats_new_search_max_results);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_whats_new_search_max_results), TRUE);

  checkbutton_search_discard_alien_ip = gtk_check_button_new_with_mnemonic (_("Discard results bearing an alien IP address"));
  gtk_widget_set_name (checkbutton_search_discard_alien_ip, "checkbutton_search_discard_alien_ip");
  gtk_widget_show (checkbutton_search_discard_alien_ip);
  gtk_table_attach (GTK_TABLE (table78), checkbutton_search_discard_alien_ip, 2, 3, 5, 6,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_search_discard_banned_guid = gtk_check_button_new_with_mnemonic (_("Discard results bearing a banned GUID"));
  gtk_widget_set_name (checkbutton_search_discard_banned_guid, "checkbutton_search_discard_banned_guid");
  gtk_widget_show (checkbutton_search_discard_banned_guid);
  gtk_table_attach (GTK_TABLE (table78), checkbutton_search_discard_banned_guid, 2, 3, 6, 7,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_search_display_guess_stats = gtk_check_button_new_with_mnemonic (_("Display GUESS statistics"));
  gtk_widget_set_name (checkbutton_search_display_guess_stats, "checkbutton_search_display_guess_stats");
  gtk_widget_show (checkbutton_search_display_guess_stats);
  gtk_table_attach (GTK_TABLE (table78), checkbutton_search_display_guess_stats, 0, 1, 6, 7,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label1011 = gtk_label_new (_("General search settings (affect all searches)"));
  gtk_widget_set_name (label1011, "label1011");
  gtk_widget_show (label1011);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook1), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook1), 2), label1011);

  guess_stats_line = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (guess_stats_line, "guess_stats_line");
  gtk_widget_show (guess_stats_line);
  gtk_box_pack_start (GTK_BOX (vbox79), guess_stats_line, FALSE, TRUE, 0);

  viewport482 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport482, "viewport482");
  gtk_widget_show (viewport482);
  gtk_box_pack_start (GTK_BOX (guess_stats_line), viewport482, TRUE, TRUE, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport482), GTK_SHADOW_ETCHED_IN);

  label_guess_stats = gtk_label_new ("                                                                     ");
  gtk_widget_set_name (label_guess_stats, "label_guess_stats");
  gtk_widget_show (label_guess_stats);
  gtk_container_add (GTK_CONTAINER (viewport482), label_guess_stats);
  gtk_label_set_justify (GTK_LABEL (label_guess_stats), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label_guess_stats), 7.45058e-09, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_guess_stats), 5, 0);

  checkbutton_guess_stats_show_total = gtk_check_button_new_with_mnemonic (_("Total"));
  gtk_widget_set_name (checkbutton_guess_stats_show_total, "checkbutton_guess_stats_show_total");
  gtk_widget_show (checkbutton_guess_stats_show_total);
  gtk_box_pack_start (GTK_BOX (guess_stats_line), checkbutton_guess_stats_show_total, FALSE, TRUE, 0);

  hbox215 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox215, "hbox215");
  gtk_widget_show (hbox215);
  gtk_box_pack_start (GTK_BOX (vbox79), hbox215, FALSE, TRUE, 0);

  viewport56 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport56, "viewport56");
  gtk_widget_show (viewport56);
  gtk_box_pack_start (GTK_BOX (hbox215), viewport56, TRUE, TRUE, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport56), GTK_SHADOW_ETCHED_IN);

  label_items_found = gtk_label_new ("                                                                     ");
  gtk_widget_set_name (label_items_found, "label_items_found");
  gtk_widget_show (label_items_found);
  gtk_container_add (GTK_CONTAINER (viewport56), label_items_found);
  gtk_label_set_justify (GTK_LABEL (label_items_found), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label_items_found), 7.45058e-09, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_items_found), 5, 0);

  hbox_expert_search_timeout = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox_expert_search_timeout, "hbox_expert_search_timeout");
  gtk_widget_show (hbox_expert_search_timeout);
  gtk_box_pack_start (GTK_BOX (hbox215), hbox_expert_search_timeout, FALSE, FALSE, 0);

  label655 = gtk_label_new_with_mnemonic (_("Re_try search every"));
  gtk_widget_set_name (label655, "label655");
  gtk_widget_show (label655);
  gtk_box_pack_start (GTK_BOX (hbox_expert_search_timeout), label655, FALSE, FALSE, 0);
  gtk_label_set_justify (GTK_LABEL (label655), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label655), 1, 0.5);

  spinbutton_search_reissue_timeout_adj = gtk_adjustment_new (600, 0, 100000, 60, 600, 0);
  spinbutton_search_reissue_timeout = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_search_reissue_timeout_adj), 1, 0);
  gtk_widget_set_name (spinbutton_search_reissue_timeout, "spinbutton_search_reissue_timeout");
  gtk_widget_show (spinbutton_search_reissue_timeout);
  gtk_box_pack_start (GTK_BOX (hbox_expert_search_timeout), spinbutton_search_reissue_timeout, TRUE, TRUE, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_search_reissue_timeout), TRUE);

  label_search_reissue = gtk_label_new (_("secs   "));
  gtk_widget_set_name (label_search_reissue, "label_search_reissue");
  gtk_widget_show (label_search_reissue);
  gtk_box_pack_start (GTK_BOX (hbox_expert_search_timeout), label_search_reissue, FALSE, FALSE, 0);

  hbox154 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox154, "hbox154");
  gtk_widget_show (hbox154);
  gtk_box_pack_start (GTK_BOX (vbox79), hbox154, FALSE, TRUE, 0);

  button_search_download = gtk_button_new ();
  gtk_widget_set_name (button_search_download, "button_search_download");
  gtk_widget_show (button_search_download);
  gtk_box_pack_start (GTK_BOX (hbox154), button_search_download, FALSE, TRUE, 0);
  gtk_widget_set_sensitive (button_search_download, FALSE);

  alignment89 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment89, "alignment89");
  gtk_widget_show (alignment89);
  gtk_container_add (GTK_CONTAINER (button_search_download), alignment89);

  hbox233 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox233, "hbox233");
  gtk_widget_show (hbox233);
  gtk_container_add (GTK_CONTAINER (alignment89), hbox233);

  image223 = gtk_image_new_from_stock ("gtk-save", GTK_ICON_SIZE_BUTTON);
  gtk_widget_set_name (image223, "image223");
  gtk_widget_show (image223);
  gtk_box_pack_start (GTK_BOX (hbox233), image223, FALSE, FALSE, 0);

  label705 = gtk_label_new_with_mnemonic (_("_Download selected"));
  gtk_widget_set_name (label705, "label705");
  gtk_widget_show (label705);
  gtk_box_pack_start (GTK_BOX (hbox233), label705, FALSE, FALSE, 0);

  button_search_filter = gtk_button_new ();
  gtk_widget_set_name (button_search_filter, "button_search_filter");
  gtk_widget_show (button_search_filter);
  gtk_box_pack_start (GTK_BOX (hbox154), button_search_filter, FALSE, FALSE, 0);

  alignment75 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment75, "alignment75");
  gtk_widget_show (alignment75);
  gtk_container_add (GTK_CONTAINER (button_search_filter), alignment75);

  hbox213 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox213, "hbox213");
  gtk_widget_show (hbox213);
  gtk_container_add (GTK_CONTAINER (alignment75), hbox213);

  image121 = create_pixmap (main_window_search_tab, "filter.xpm");
  gtk_widget_set_name (image121, "image121");
  gtk_widget_show (image121);
  gtk_box_pack_start (GTK_BOX (hbox213), image121, FALSE, FALSE, 0);

  label589 = gtk_label_new_with_mnemonic (_("_Edit filters"));
  gtk_widget_set_name (label589, "label589");
  gtk_widget_show (label589);
  gtk_box_pack_start (GTK_BOX (hbox213), label589, FALSE, TRUE, 0);

  label835 = gtk_label_new ("");
  gtk_widget_set_name (label835, "label835");
  gtk_widget_show (label835);
  gtk_box_pack_start (GTK_BOX (hbox154), label835, TRUE, TRUE, 0);

  button_search_clear = gtk_button_new ();
  gtk_widget_set_name (button_search_clear, "button_search_clear");
  gtk_widget_show (button_search_clear);
  gtk_box_pack_start (GTK_BOX (hbox154), button_search_clear, FALSE, FALSE, 0);
  gtk_widget_set_sensitive (button_search_clear, FALSE);
  gtk_widget_add_accelerator (button_search_clear, "clicked", accel_group,
                              GDK_c, (GdkModifierType) GDK_CONTROL_MASK,
                              GTK_ACCEL_VISIBLE);

  alignment25 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment25, "alignment25");
  gtk_widget_show (alignment25);
  gtk_container_add (GTK_CONTAINER (button_search_clear), alignment25);

  hbox156 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox156, "hbox156");
  gtk_widget_show (hbox156);
  gtk_container_add (GTK_CONTAINER (alignment25), hbox156);

  image26 = gtk_image_new_from_stock ("gtk-clear", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image26, "image26");
  gtk_widget_show (image26);
  gtk_box_pack_start (GTK_BOX (hbox156), image26, FALSE, FALSE, 0);

  label407 = gtk_label_new_with_mnemonic (_("_Clear results"));
  gtk_widget_set_name (label407, "label407");
  gtk_widget_show (label407);
  gtk_box_pack_start (GTK_BOX (hbox156), label407, FALSE, FALSE, 0);

  gtk_label_set_mnemonic_widget (GTK_LABEL (label832), option_menu_searches);
  gtk_label_set_mnemonic_widget (GTK_LABEL (label557), spinbutton_search_max_results);
  gtk_label_set_mnemonic_widget (GTK_LABEL (label1069), spinbutton_search_max_results);
  gtk_label_set_mnemonic_widget (GTK_LABEL (label655), spinbutton_search_reissue_timeout);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (main_window_search_tab, main_window_search_tab, "main_window_search_tab");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, vbox79, "vbox79");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, table96, "table96");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, label832, "label832");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, option_menu_searches, "option_menu_searches");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, button_search_close, "button_search_close");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, alignment76, "alignment76");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, hbox214, "hbox214");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, image137, "image137");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, label670, "label670");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, viewport474, "viewport474");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, label_search_expiry, "label_search_expiry");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, vpaned_results, "vpaned_results");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, viewport16, "viewport16");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, notebook_search_results, "notebook_search_results");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, label190, "label190");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, viewport477, "viewport477");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, notebook1, "notebook1");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, viewport106, "viewport106");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, scrolledwindow67, "scrolledwindow67");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, viewport57, "viewport57");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, scrolledwindow82, "scrolledwindow82");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, treeview_search_details, "treeview_search_details");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, label1010, "label1010");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, scrolledwindow83, "scrolledwindow83");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, textview_result_info_xml, "textview_result_info_xml");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, label1015, "label1015");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, table78, "table78");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, label993, "label993");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, alignment136, "alignment136");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, spinbutton_browse_host_max_results, "spinbutton_browse_host_max_results");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, checkbutton_search_hide_downloaded, "checkbutton_search_hide_downloaded");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, checkbutton_search_remove_downloaded, "checkbutton_search_remove_downloaded");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, checkbutton_browse_copied_to_passive, "checkbutton_browse_copied_to_passive");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, checkbutton_search_discard_hashless, "checkbutton_search_discard_hashless");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, checkbutton_search_discard_spam, "checkbutton_search_discard_spam");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, label707, "label707");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, frame137, "frame137");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, option_menu_search_handle_ignored_files, "option_menu_search_handle_ignored_files");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, label1068, "label1068");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, alignment148, "alignment148");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, spinbutton_passive_search_max_results, "spinbutton_passive_search_max_results");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, checkbutton_search_sort_casesense, "checkbutton_search_sort_casesense");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, alignment90, "alignment90");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, spinbutton_search_max_results, "spinbutton_search_max_results");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, label557, "label557");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, label1069, "label1069");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, alignment149, "alignment149");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, spinbutton_whats_new_search_max_results, "spinbutton_whats_new_search_max_results");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, checkbutton_search_discard_alien_ip, "checkbutton_search_discard_alien_ip");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, checkbutton_search_discard_banned_guid, "checkbutton_search_discard_banned_guid");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, checkbutton_search_display_guess_stats, "checkbutton_search_display_guess_stats");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, label1011, "label1011");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, guess_stats_line, "guess_stats_line");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, viewport482, "viewport482");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, label_guess_stats, "label_guess_stats");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, checkbutton_guess_stats_show_total, "checkbutton_guess_stats_show_total");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, hbox215, "hbox215");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, viewport56, "viewport56");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, label_items_found, "label_items_found");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, hbox_expert_search_timeout, "hbox_expert_search_timeout");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, label655, "label655");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, spinbutton_search_reissue_timeout, "spinbutton_search_reissue_timeout");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, label_search_reissue, "label_search_reissue");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, hbox154, "hbox154");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, button_search_download, "button_search_download");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, alignment89, "alignment89");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, hbox233, "hbox233");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, image223, "image223");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, label705, "label705");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, button_search_filter, "button_search_filter");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, alignment75, "alignment75");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, hbox213, "hbox213");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, image121, "image121");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, label589, "label589");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, label835, "label835");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, button_search_clear, "button_search_clear");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, alignment25, "alignment25");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, hbox156, "hbox156");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, image26, "image26");
  GLADE_HOOKUP_OBJECT (main_window_search_tab, label407, "label407");

  gtk_window_add_accel_group (GTK_WINDOW (main_window_search_tab), accel_group);

  return main_window_search_tab;
}

GtkWidget*
create_main_window_monitor_tab (void)
{
  GtkWidget *main_window_monitor_tab;
  GtkWidget *vbox_monitor;
  GtkWidget *hbox45;
  GtkWidget *button_monitor_clear;
  GtkWidget *checkbutton_monitor_enable;
  GtkWidget *label75;
  GtkWidget *label68;
  GtkObject *spinbutton_monitor_items_adj;
  GtkWidget *spinbutton_monitor_items;
  GtkWidget *label69;
  GtkWidget *scrolledwindow26;
  GtkWidget *viewport10;
  GtkWidget *treeview_monitor;

  main_window_monitor_tab = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_widget_set_name (main_window_monitor_tab, "main_window_monitor_tab");
  gtk_window_set_default_size (GTK_WINDOW (main_window_monitor_tab), 300, 200);

  vbox_monitor = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox_monitor, "vbox_monitor");
  gtk_widget_show (vbox_monitor);
  gtk_container_add (GTK_CONTAINER (main_window_monitor_tab), vbox_monitor);

  hbox45 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox45, "hbox45");
  gtk_widget_show (hbox45);
  gtk_box_pack_start (GTK_BOX (vbox_monitor), hbox45, FALSE, TRUE, 0);

  button_monitor_clear = gtk_button_new_from_stock ("gtk-clear");
  gtk_widget_set_name (button_monitor_clear, "button_monitor_clear");
  gtk_widget_show (button_monitor_clear);
  gtk_box_pack_start (GTK_BOX (hbox45), button_monitor_clear, FALSE, TRUE, 0);

  checkbutton_monitor_enable = gtk_check_button_new_with_mnemonic (_("Search _monitor enabled"));
  gtk_widget_set_name (checkbutton_monitor_enable, "checkbutton_monitor_enable");
  gtk_widget_show (checkbutton_monitor_enable);
  gtk_box_pack_start (GTK_BOX (hbox45), checkbutton_monitor_enable, FALSE, FALSE, 0);

  label75 = gtk_label_new ("");
  gtk_widget_set_name (label75, "label75");
  gtk_widget_show (label75);
  gtk_box_pack_start (GTK_BOX (hbox45), label75, TRUE, FALSE, 0);
  gtk_label_set_justify (GTK_LABEL (label75), GTK_JUSTIFY_CENTER);

  label68 = gtk_label_new_with_mnemonic (_("Show _last"));
  gtk_widget_set_name (label68, "label68");
  gtk_widget_show (label68);
  gtk_box_pack_start (GTK_BOX (hbox45), label68, FALSE, FALSE, 0);
  gtk_label_set_justify (GTK_LABEL (label68), GTK_JUSTIFY_CENTER);

  spinbutton_monitor_items_adj = gtk_adjustment_new (1, 0, 1000, 1, 10, 0);
  spinbutton_monitor_items = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_monitor_items_adj), 1, 0);
  gtk_widget_set_name (spinbutton_monitor_items, "spinbutton_monitor_items");
  gtk_widget_show (spinbutton_monitor_items);
  gtk_box_pack_start (GTK_BOX (hbox45), spinbutton_monitor_items, FALSE, TRUE, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_monitor_items), TRUE);

  label69 = gtk_label_new (_("searches"));
  gtk_widget_set_name (label69, "label69");
  gtk_widget_show (label69);
  gtk_box_pack_start (GTK_BOX (hbox45), label69, FALSE, TRUE, 0);
  gtk_label_set_justify (GTK_LABEL (label69), GTK_JUSTIFY_CENTER);
  gtk_misc_set_padding (GTK_MISC (label69), 4, 0);

  scrolledwindow26 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow26, "scrolledwindow26");
  gtk_widget_show (scrolledwindow26);
  gtk_box_pack_start (GTK_BOX (vbox_monitor), scrolledwindow26, TRUE, TRUE, 0);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow26), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);

  viewport10 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport10, "viewport10");
  gtk_widget_show (viewport10);
  gtk_container_add (GTK_CONTAINER (scrolledwindow26), viewport10);

  treeview_monitor = gtk_tree_view_new ();
  gtk_widget_set_name (treeview_monitor, "treeview_monitor");
  gtk_widget_show (treeview_monitor);
  gtk_container_add (GTK_CONTAINER (viewport10), treeview_monitor);
  gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (treeview_monitor), FALSE);

  g_signal_connect ((gpointer) button_monitor_clear, "clicked",
                    G_CALLBACK (on_button_monitor_clear_clicked),
                    NULL);

  gtk_label_set_mnemonic_widget (GTK_LABEL (label68), spinbutton_monitor_items);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (main_window_monitor_tab, main_window_monitor_tab, "main_window_monitor_tab");
  GLADE_HOOKUP_OBJECT (main_window_monitor_tab, vbox_monitor, "vbox_monitor");
  GLADE_HOOKUP_OBJECT (main_window_monitor_tab, hbox45, "hbox45");
  GLADE_HOOKUP_OBJECT (main_window_monitor_tab, button_monitor_clear, "button_monitor_clear");
  GLADE_HOOKUP_OBJECT (main_window_monitor_tab, checkbutton_monitor_enable, "checkbutton_monitor_enable");
  GLADE_HOOKUP_OBJECT (main_window_monitor_tab, label75, "label75");
  GLADE_HOOKUP_OBJECT (main_window_monitor_tab, label68, "label68");
  GLADE_HOOKUP_OBJECT (main_window_monitor_tab, spinbutton_monitor_items, "spinbutton_monitor_items");
  GLADE_HOOKUP_OBJECT (main_window_monitor_tab, label69, "label69");
  GLADE_HOOKUP_OBJECT (main_window_monitor_tab, scrolledwindow26, "scrolledwindow26");
  GLADE_HOOKUP_OBJECT (main_window_monitor_tab, viewport10, "viewport10");
  GLADE_HOOKUP_OBJECT (main_window_monitor_tab, treeview_monitor, "treeview_monitor");

  return main_window_monitor_tab;
}

GtkWidget*
create_main_window_search_stats_tab (void)
{
  GtkWidget *main_window_search_stats_tab;
  GtkWidget *vbox12a;
  GtkWidget *hbox67;
  GtkWidget *option_menu_search_stats_type;
  GtkWidget *label101;
  GtkObject *spinbutton_search_stats_update_interval_adj;
  GtkWidget *spinbutton_search_stats_update_interval;
  GtkWidget *label102;
  GtkObject *spinbutton_search_stats_delcoef_adj;
  GtkWidget *spinbutton_search_stats_delcoef;
  GtkWidget *scrolledwindow66;
  GtkWidget *treeview_search_stats;
  GtkWidget *hbox66;
  GtkWidget *button_search_stats_reset;
  GtkWidget *alignment88;
  GtkWidget *hbox227;
  GtkWidget *image221;
  GtkWidget *label694;
  GtkWidget *viewport_fix_flashing_2;
  GtkWidget *label_search_stats_count;

  main_window_search_stats_tab = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_widget_set_name (main_window_search_stats_tab, "main_window_search_stats_tab");

  vbox12a = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox12a, "vbox12a");
  gtk_widget_show (vbox12a);
  gtk_container_add (GTK_CONTAINER (main_window_search_stats_tab), vbox12a);

  hbox67 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox67, "hbox67");
  gtk_widget_show (hbox67);
  gtk_box_pack_start (GTK_BOX (vbox12a), hbox67, FALSE, TRUE, 0);

  option_menu_search_stats_type = gtk_option_menu_new ();
  gtk_widget_set_name (option_menu_search_stats_type, "option_menu_search_stats_type");
  gtk_widget_show (option_menu_search_stats_type);
  gtk_box_pack_start (GTK_BOX (hbox67), option_menu_search_stats_type, FALSE, TRUE, 0);

  label101 = gtk_label_new_with_mnemonic (_("_Update interval (sec)"));
  gtk_widget_set_name (label101, "label101");
  gtk_widget_show (label101);
  gtk_box_pack_start (GTK_BOX (hbox67), label101, FALSE, FALSE, 0);
  gtk_label_set_justify (GTK_LABEL (label101), GTK_JUSTIFY_RIGHT);

  spinbutton_search_stats_update_interval_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 0);
  spinbutton_search_stats_update_interval = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_search_stats_update_interval_adj), 1, 0);
  gtk_widget_set_name (spinbutton_search_stats_update_interval, "spinbutton_search_stats_update_interval");
  gtk_widget_show (spinbutton_search_stats_update_interval);
  gtk_box_pack_start (GTK_BOX (hbox67), spinbutton_search_stats_update_interval, FALSE, FALSE, 0);

  label102 = gtk_label_new_with_mnemonic (_("_Deletion coeff. (0-100)"));
  gtk_widget_set_name (label102, "label102");
  gtk_widget_show (label102);
  gtk_box_pack_start (GTK_BOX (hbox67), label102, FALSE, FALSE, 0);
  gtk_label_set_justify (GTK_LABEL (label102), GTK_JUSTIFY_RIGHT);

  spinbutton_search_stats_delcoef_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 0);
  spinbutton_search_stats_delcoef = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_search_stats_delcoef_adj), 1, 0);
  gtk_widget_set_name (spinbutton_search_stats_delcoef, "spinbutton_search_stats_delcoef");
  gtk_widget_show (spinbutton_search_stats_delcoef);
  gtk_box_pack_end (GTK_BOX (hbox67), spinbutton_search_stats_delcoef, FALSE, FALSE, 0);

  scrolledwindow66 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow66, "scrolledwindow66");
  gtk_widget_show (scrolledwindow66);
  gtk_box_pack_start (GTK_BOX (vbox12a), scrolledwindow66, TRUE, TRUE, 0);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow66), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolledwindow66), GTK_SHADOW_IN);

  treeview_search_stats = gtk_tree_view_new ();
  gtk_widget_set_name (treeview_search_stats, "treeview_search_stats");
  gtk_widget_show (treeview_search_stats);
  gtk_container_add (GTK_CONTAINER (scrolledwindow66), treeview_search_stats);
  gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (treeview_search_stats), TRUE);
  gtk_tree_view_set_enable_search (GTK_TREE_VIEW (treeview_search_stats), FALSE);

  hbox66 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox66, "hbox66");
  gtk_widget_show (hbox66);
  gtk_box_pack_start (GTK_BOX (vbox12a), hbox66, FALSE, TRUE, 0);

  button_search_stats_reset = gtk_button_new ();
  gtk_widget_set_name (button_search_stats_reset, "button_search_stats_reset");
  gtk_widget_show (button_search_stats_reset);
  gtk_box_pack_start (GTK_BOX (hbox66), button_search_stats_reset, FALSE, FALSE, 0);

  alignment88 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment88, "alignment88");
  gtk_widget_show (alignment88);
  gtk_container_add (GTK_CONTAINER (button_search_stats_reset), alignment88);

  hbox227 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox227, "hbox227");
  gtk_widget_show (hbox227);
  gtk_container_add (GTK_CONTAINER (alignment88), hbox227);

  image221 = gtk_image_new_from_stock ("gtk-undo", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image221, "image221");
  gtk_widget_show (image221);
  gtk_box_pack_start (GTK_BOX (hbox227), image221, FALSE, FALSE, 0);

  label694 = gtk_label_new_with_mnemonic (_("_Reset stats"));
  gtk_widget_set_name (label694, "label694");
  gtk_widget_show (label694);
  gtk_box_pack_start (GTK_BOX (hbox227), label694, FALSE, FALSE, 0);

  viewport_fix_flashing_2 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport_fix_flashing_2, "viewport_fix_flashing_2");
  gtk_widget_show (viewport_fix_flashing_2);
  gtk_box_pack_end (GTK_BOX (hbox66), viewport_fix_flashing_2, TRUE, TRUE, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport_fix_flashing_2), GTK_SHADOW_ETCHED_IN);

  label_search_stats_count = gtk_label_new (_("0 terms counted"));
  gtk_widget_set_name (label_search_stats_count, "label_search_stats_count");
  gtk_widget_show (label_search_stats_count);
  gtk_container_add (GTK_CONTAINER (viewport_fix_flashing_2), label_search_stats_count);
  gtk_label_set_justify (GTK_LABEL (label_search_stats_count), GTK_JUSTIFY_RIGHT);
  gtk_misc_set_alignment (GTK_MISC (label_search_stats_count), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_search_stats_count), 5, 0);

  g_signal_connect ((gpointer) button_search_stats_reset, "clicked",
                    G_CALLBACK (on_button_search_stats_reset_clicked),
                    NULL);

  gtk_label_set_mnemonic_widget (GTK_LABEL (label101), spinbutton_search_stats_update_interval);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (main_window_search_stats_tab, main_window_search_stats_tab, "main_window_search_stats_tab");
  GLADE_HOOKUP_OBJECT (main_window_search_stats_tab, vbox12a, "vbox12a");
  GLADE_HOOKUP_OBJECT (main_window_search_stats_tab, hbox67, "hbox67");
  GLADE_HOOKUP_OBJECT (main_window_search_stats_tab, option_menu_search_stats_type, "option_menu_search_stats_type");
  GLADE_HOOKUP_OBJECT (main_window_search_stats_tab, label101, "label101");
  GLADE_HOOKUP_OBJECT (main_window_search_stats_tab, spinbutton_search_stats_update_interval, "spinbutton_search_stats_update_interval");
  GLADE_HOOKUP_OBJECT (main_window_search_stats_tab, label102, "label102");
  GLADE_HOOKUP_OBJECT (main_window_search_stats_tab, spinbutton_search_stats_delcoef, "spinbutton_search_stats_delcoef");
  GLADE_HOOKUP_OBJECT (main_window_search_stats_tab, scrolledwindow66, "scrolledwindow66");
  GLADE_HOOKUP_OBJECT (main_window_search_stats_tab, treeview_search_stats, "treeview_search_stats");
  GLADE_HOOKUP_OBJECT (main_window_search_stats_tab, hbox66, "hbox66");
  GLADE_HOOKUP_OBJECT (main_window_search_stats_tab, button_search_stats_reset, "button_search_stats_reset");
  GLADE_HOOKUP_OBJECT (main_window_search_stats_tab, alignment88, "alignment88");
  GLADE_HOOKUP_OBJECT (main_window_search_stats_tab, hbox227, "hbox227");
  GLADE_HOOKUP_OBJECT (main_window_search_stats_tab, image221, "image221");
  GLADE_HOOKUP_OBJECT (main_window_search_stats_tab, label694, "label694");
  GLADE_HOOKUP_OBJECT (main_window_search_stats_tab, viewport_fix_flashing_2, "viewport_fix_flashing_2");
  GLADE_HOOKUP_OBJECT (main_window_search_stats_tab, label_search_stats_count, "label_search_stats_count");

  return main_window_search_stats_tab;
}

GtkWidget*
create_main_window_gnet_stats_tab (void)
{
  GtkWidget *main_window_gnet_stats_tab;
  GtkWidget *vbox101;
  GtkWidget *gnet_stats_notebook;
  GtkWidget *hbox9304;
  GtkWidget *scrolledwindow32;
  GtkWidget *treeview_gnet_stats_general;
  GtkWidget *scrolledwindow45;
  GtkWidget *treeview_gnet_stats_drop_reasons;
  GtkWidget *label960;
  GtkWidget *scrolledwindow65;
  GtkWidget *treeview_gnet_stats_messages;
  GtkWidget *label478;
  GtkWidget *scrolledwindow52;
  GtkWidget *treeview_gnet_stats_flowc;
  GtkWidget *label502;
  GtkWidget *scrolledwindow56;
  GtkWidget *treeview_gnet_stats_recv;
  GtkWidget *label509;
  GtkWidget *vbox152;
  GtkWidget *scrolledwindow74;
  GtkWidget *treeview_gnet_stats_horizon;
  GtkWidget *hbox9342;
  GtkWidget *frame116;
  GtkWidget *alignment99;
  GtkWidget *label_statusbar_horizon_node_count;
  GtkWidget *frame117;
  GtkWidget *alignment100;
  GtkWidget *label_statusbar_horizon_file_count;
  GtkWidget *frame118;
  GtkWidget *alignment101;
  GtkWidget *label_statusbar_horizon_kb_count;
  GtkWidget *label959;
  GtkWidget *viewport463;
  GtkWidget *hbox9341;
  GtkWidget *vbox150;
  GtkWidget *frame115;
  GtkWidget *table55;
  GtkWidget *viewport467;
  GtkWidget *entry_dl_byte_count;
  GtkWidget *viewport468;
  GtkWidget *entry_count_downloads;
  GtkWidget *label551;
  GtkWidget *label552;
  GtkWidget *label844;
  GtkWidget *frame131;
  GtkWidget *table106;
  GtkWidget *label908;
  GtkWidget *label907;
  GtkWidget *viewport465;
  GtkWidget *entry_count_uploads;
  GtkWidget *viewport466;
  GtkWidget *entry_ul_byte_count;
  GtkWidget *label906;
  GtkWidget *label1016;
  GtkWidget *table49;
  GtkWidget *checkbutton_gnet_stats_hops;
  GtkWidget *checkbutton_gnet_stats_with_headers;
  GtkWidget *checkbutton_gnet_stats_bytes;
  GtkWidget *checkbutton_gnet_stats_perc;
  GtkWidget *label889;
  GtkWidget *label893;
  GtkWidget *label406;
  GtkWidget *option_menu_gnet_stats_type;
  GtkWidget *option_menu_gnet_stats_source;

  main_window_gnet_stats_tab = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_widget_set_name (main_window_gnet_stats_tab, "main_window_gnet_stats_tab");

  vbox101 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox101, "vbox101");
  gtk_widget_show (vbox101);
  gtk_container_add (GTK_CONTAINER (main_window_gnet_stats_tab), vbox101);

  gnet_stats_notebook = gtk_notebook_new ();
  gtk_widget_set_name (gnet_stats_notebook, "gnet_stats_notebook");
  gtk_widget_show (gnet_stats_notebook);
  gtk_box_pack_start (GTK_BOX (vbox101), gnet_stats_notebook, TRUE, TRUE, 0);
  gtk_notebook_set_show_border (GTK_NOTEBOOK (gnet_stats_notebook), FALSE);
  gtk_notebook_set_tab_pos (GTK_NOTEBOOK (gnet_stats_notebook), GTK_POS_BOTTOM);
  gtk_notebook_set_scrollable (GTK_NOTEBOOK (gnet_stats_notebook), TRUE);

  hbox9304 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox9304, "hbox9304");
  gtk_widget_show (hbox9304);
  gtk_container_add (GTK_CONTAINER (gnet_stats_notebook), hbox9304);

  scrolledwindow32 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow32, "scrolledwindow32");
  gtk_widget_show (scrolledwindow32);
  gtk_box_pack_start (GTK_BOX (hbox9304), scrolledwindow32, TRUE, TRUE, 0);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow32), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolledwindow32), GTK_SHADOW_IN);

  treeview_gnet_stats_general = gtk_tree_view_new ();
  gtk_widget_set_name (treeview_gnet_stats_general, "treeview_gnet_stats_general");
  gtk_widget_show (treeview_gnet_stats_general);
  gtk_container_add (GTK_CONTAINER (scrolledwindow32), treeview_gnet_stats_general);
  gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (treeview_gnet_stats_general), TRUE);
  gtk_tree_view_set_enable_search (GTK_TREE_VIEW (treeview_gnet_stats_general), FALSE);

  scrolledwindow45 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow45, "scrolledwindow45");
  gtk_widget_show (scrolledwindow45);
  gtk_box_pack_start (GTK_BOX (hbox9304), scrolledwindow45, TRUE, TRUE, 0);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow45), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolledwindow45), GTK_SHADOW_IN);

  treeview_gnet_stats_drop_reasons = gtk_tree_view_new ();
  gtk_widget_set_name (treeview_gnet_stats_drop_reasons, "treeview_gnet_stats_drop_reasons");
  gtk_widget_show (treeview_gnet_stats_drop_reasons);
  gtk_container_add (GTK_CONTAINER (scrolledwindow45), treeview_gnet_stats_drop_reasons);
  gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (treeview_gnet_stats_drop_reasons), TRUE);
  gtk_tree_view_set_enable_search (GTK_TREE_VIEW (treeview_gnet_stats_drop_reasons), FALSE);

  label960 = gtk_label_new_with_mnemonic (_("_General"));
  gtk_widget_set_name (label960, "label960");
  gtk_widget_show (label960);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (gnet_stats_notebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK (gnet_stats_notebook), 0), label960);

  scrolledwindow65 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow65, "scrolledwindow65");
  gtk_widget_show (scrolledwindow65);
  gtk_container_add (GTK_CONTAINER (gnet_stats_notebook), scrolledwindow65);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow65), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolledwindow65), GTK_SHADOW_IN);

  treeview_gnet_stats_messages = gtk_tree_view_new ();
  gtk_widget_set_name (treeview_gnet_stats_messages, "treeview_gnet_stats_messages");
  gtk_widget_show (treeview_gnet_stats_messages);
  gtk_container_add (GTK_CONTAINER (scrolledwindow65), treeview_gnet_stats_messages);
  gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (treeview_gnet_stats_messages), TRUE);
  gtk_tree_view_set_enable_search (GTK_TREE_VIEW (treeview_gnet_stats_messages), FALSE);

  label478 = gtk_label_new_with_mnemonic (_("_Messages"));
  gtk_widget_set_name (label478, "label478");
  gtk_widget_show (label478);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (gnet_stats_notebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK (gnet_stats_notebook), 1), label478);

  scrolledwindow52 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow52, "scrolledwindow52");
  gtk_widget_show (scrolledwindow52);
  gtk_container_add (GTK_CONTAINER (gnet_stats_notebook), scrolledwindow52);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow52), GTK_POLICY_AUTOMATIC, GTK_POLICY_NEVER);
  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolledwindow52), GTK_SHADOW_IN);

  treeview_gnet_stats_flowc = gtk_tree_view_new ();
  gtk_widget_set_name (treeview_gnet_stats_flowc, "treeview_gnet_stats_flowc");
  gtk_widget_show (treeview_gnet_stats_flowc);
  gtk_container_add (GTK_CONTAINER (scrolledwindow52), treeview_gnet_stats_flowc);
  gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (treeview_gnet_stats_flowc), TRUE);
  gtk_tree_view_set_enable_search (GTK_TREE_VIEW (treeview_gnet_stats_flowc), FALSE);

  label502 = gtk_label_new_with_mnemonic (_("Flow _control"));
  gtk_widget_set_name (label502, "label502");
  gtk_widget_show (label502);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (gnet_stats_notebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK (gnet_stats_notebook), 2), label502);

  scrolledwindow56 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow56, "scrolledwindow56");
  gtk_widget_show (scrolledwindow56);
  gtk_container_add (GTK_CONTAINER (gnet_stats_notebook), scrolledwindow56);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow56), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolledwindow56), GTK_SHADOW_IN);

  treeview_gnet_stats_recv = gtk_tree_view_new ();
  gtk_widget_set_name (treeview_gnet_stats_recv, "treeview_gnet_stats_recv");
  gtk_widget_show (treeview_gnet_stats_recv);
  gtk_container_add (GTK_CONTAINER (scrolledwindow56), treeview_gnet_stats_recv);
  gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (treeview_gnet_stats_recv), TRUE);
  gtk_tree_view_set_enable_search (GTK_TREE_VIEW (treeview_gnet_stats_recv), FALSE);

  label509 = gtk_label_new_with_mnemonic (_("_Received"));
  gtk_widget_set_name (label509, "label509");
  gtk_widget_show (label509);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (gnet_stats_notebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK (gnet_stats_notebook), 3), label509);

  vbox152 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox152, "vbox152");
  gtk_widget_show (vbox152);
  gtk_container_add (GTK_CONTAINER (gnet_stats_notebook), vbox152);

  scrolledwindow74 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow74, "scrolledwindow74");
  gtk_widget_show (scrolledwindow74);
  gtk_box_pack_start (GTK_BOX (vbox152), scrolledwindow74, TRUE, TRUE, 0);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow74), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolledwindow74), GTK_SHADOW_IN);

  treeview_gnet_stats_horizon = gtk_tree_view_new ();
  gtk_widget_set_name (treeview_gnet_stats_horizon, "treeview_gnet_stats_horizon");
  gtk_widget_show (treeview_gnet_stats_horizon);
  gtk_container_add (GTK_CONTAINER (scrolledwindow74), treeview_gnet_stats_horizon);
  gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (treeview_gnet_stats_horizon), TRUE);
  gtk_tree_view_set_enable_search (GTK_TREE_VIEW (treeview_gnet_stats_horizon), FALSE);

  hbox9342 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox9342, "hbox9342");
  gtk_widget_show (hbox9342);
  gtk_box_pack_start (GTK_BOX (vbox152), hbox9342, FALSE, TRUE, 0);

  frame116 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame116, "frame116");
  gtk_widget_show (frame116);
  gtk_box_pack_start (GTK_BOX (hbox9342), frame116, TRUE, TRUE, 0);

  alignment99 = gtk_alignment_new (0.5, 0.5, 1, 1);
  gtk_widget_set_name (alignment99, "alignment99");
  gtk_widget_show (alignment99);
  gtk_container_add (GTK_CONTAINER (frame116), alignment99);

  label_statusbar_horizon_node_count = gtk_label_new ("[Nodes]");
  gtk_widget_set_name (label_statusbar_horizon_node_count, "label_statusbar_horizon_node_count");
  gtk_widget_show (label_statusbar_horizon_node_count);
  gtk_container_add (GTK_CONTAINER (alignment99), label_statusbar_horizon_node_count);
  gtk_misc_set_padding (GTK_MISC (label_statusbar_horizon_node_count), 5, 0);

  frame117 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame117, "frame117");
  gtk_widget_show (frame117);
  gtk_box_pack_start (GTK_BOX (hbox9342), frame117, TRUE, TRUE, 0);

  alignment100 = gtk_alignment_new (0.5, 0.5, 1, 1);
  gtk_widget_set_name (alignment100, "alignment100");
  gtk_widget_show (alignment100);
  gtk_container_add (GTK_CONTAINER (frame117), alignment100);

  label_statusbar_horizon_file_count = gtk_label_new ("[Files]");
  gtk_widget_set_name (label_statusbar_horizon_file_count, "label_statusbar_horizon_file_count");
  gtk_widget_show (label_statusbar_horizon_file_count);
  gtk_container_add (GTK_CONTAINER (alignment100), label_statusbar_horizon_file_count);
  gtk_misc_set_padding (GTK_MISC (label_statusbar_horizon_file_count), 5, 0);

  frame118 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame118, "frame118");
  gtk_widget_show (frame118);
  gtk_box_pack_start (GTK_BOX (hbox9342), frame118, TRUE, TRUE, 0);

  alignment101 = gtk_alignment_new (0.5, 0.5, 1, 1);
  gtk_widget_set_name (alignment101, "alignment101");
  gtk_widget_show (alignment101);
  gtk_container_add (GTK_CONTAINER (frame118), alignment101);

  label_statusbar_horizon_kb_count = gtk_label_new ("[KB]");
  gtk_widget_set_name (label_statusbar_horizon_kb_count, "label_statusbar_horizon_kb_count");
  gtk_widget_show (label_statusbar_horizon_kb_count);
  gtk_container_add (GTK_CONTAINER (alignment101), label_statusbar_horizon_kb_count);
  gtk_misc_set_padding (GTK_MISC (label_statusbar_horizon_kb_count), 5, 0);

  label959 = gtk_label_new_with_mnemonic (_("_Horizon"));
  gtk_widget_set_name (label959, "label959");
  gtk_widget_show (label959);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (gnet_stats_notebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK (gnet_stats_notebook), 4), label959);

  viewport463 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport463, "viewport463");
  gtk_widget_show (viewport463);
  gtk_container_add (GTK_CONTAINER (gnet_stats_notebook), viewport463);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport463), GTK_SHADOW_NONE);

  hbox9341 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox9341, "hbox9341");
  gtk_widget_show (hbox9341);
  gtk_container_add (GTK_CONTAINER (viewport463), hbox9341);

  vbox150 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox150, "vbox150");
  gtk_widget_show (vbox150);
  gtk_box_pack_start (GTK_BOX (hbox9341), vbox150, TRUE, TRUE, 0);

  frame115 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame115, "frame115");
  gtk_widget_show (frame115);
  gtk_box_pack_start (GTK_BOX (vbox150), frame115, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame115), 8);
  gtk_frame_set_shadow_type (GTK_FRAME (frame115), GTK_SHADOW_NONE);

  table55 = gtk_table_new (1, 4, FALSE);
  gtk_widget_set_name (table55, "table55");
  gtk_widget_show (table55);
  gtk_container_add (GTK_CONTAINER (frame115), table55);
  gtk_container_set_border_width (GTK_CONTAINER (table55), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table55), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table55), 4);

  viewport467 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport467, "viewport467");
  gtk_widget_show (viewport467);
  gtk_table_attach (GTK_TABLE (table55), viewport467, 3, 4, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport467), GTK_SHADOW_ETCHED_IN);

  entry_dl_byte_count = gtk_entry_new ();
  gtk_widget_set_name (entry_dl_byte_count, "entry_dl_byte_count");
  gtk_widget_show (entry_dl_byte_count);
  gtk_container_add (GTK_CONTAINER (viewport467), entry_dl_byte_count);
  GTK_WIDGET_UNSET_FLAGS (entry_dl_byte_count, GTK_CAN_FOCUS);
  gtk_editable_set_editable (GTK_EDITABLE (entry_dl_byte_count), FALSE);
  gtk_entry_set_has_frame (GTK_ENTRY (entry_dl_byte_count), FALSE);

  viewport468 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport468, "viewport468");
  gtk_widget_show (viewport468);
  gtk_table_attach (GTK_TABLE (table55), viewport468, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport468), GTK_SHADOW_ETCHED_IN);

  entry_count_downloads = gtk_entry_new ();
  gtk_widget_set_name (entry_count_downloads, "entry_count_downloads");
  gtk_widget_show (entry_count_downloads);
  gtk_container_add (GTK_CONTAINER (viewport468), entry_count_downloads);
  GTK_WIDGET_UNSET_FLAGS (entry_count_downloads, GTK_CAN_FOCUS);
  gtk_editable_set_editable (GTK_EDITABLE (entry_count_downloads), FALSE);
  gtk_entry_set_has_frame (GTK_ENTRY (entry_count_downloads), FALSE);

  label551 = gtk_label_new (_("Chunks/Files:"));
  gtk_widget_set_name (label551, "label551");
  gtk_widget_show (label551);
  gtk_table_attach (GTK_TABLE (table55), label551, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label551), GTK_JUSTIFY_CENTER);
  gtk_misc_set_padding (GTK_MISC (label551), 4, 0);

  label552 = gtk_label_new (_("Volume:"));
  gtk_widget_set_name (label552, "label552");
  gtk_widget_show (label552);
  gtk_table_attach (GTK_TABLE (table55), label552, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label552), GTK_JUSTIFY_CENTER);
  gtk_misc_set_padding (GTK_MISC (label552), 4, 0);

  label844 = gtk_label_new (_("Downloaded data:"));
  gtk_widget_set_name (label844, "label844");
  gtk_widget_show (label844);
  gtk_frame_set_label_widget (GTK_FRAME (frame115), label844);

  frame131 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame131, "frame131");
  gtk_widget_show (frame131);
  gtk_box_pack_start (GTK_BOX (vbox150), frame131, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame131), 8);
  gtk_frame_set_shadow_type (GTK_FRAME (frame131), GTK_SHADOW_NONE);

  table106 = gtk_table_new (1, 4, FALSE);
  gtk_widget_set_name (table106, "table106");
  gtk_widget_show (table106);
  gtk_container_add (GTK_CONTAINER (frame131), table106);
  gtk_container_set_border_width (GTK_CONTAINER (table106), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table106), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table106), 4);

  label908 = gtk_label_new (_("Volume:"));
  gtk_widget_set_name (label908, "label908");
  gtk_widget_show (label908);
  gtk_table_attach (GTK_TABLE (table106), label908, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 4, 0);
  gtk_label_set_justify (GTK_LABEL (label908), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label908), 0, 0.5);

  label907 = gtk_label_new (_("Chunks/Files:"));
  gtk_widget_set_name (label907, "label907");
  gtk_widget_show (label907);
  gtk_table_attach (GTK_TABLE (table106), label907, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 4, 0);
  gtk_label_set_justify (GTK_LABEL (label907), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label907), 0, 0.5);

  viewport465 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport465, "viewport465");
  gtk_widget_show (viewport465);
  gtk_table_attach (GTK_TABLE (table106), viewport465, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport465), GTK_SHADOW_ETCHED_IN);

  entry_count_uploads = gtk_entry_new ();
  gtk_widget_set_name (entry_count_uploads, "entry_count_uploads");
  gtk_widget_show (entry_count_uploads);
  gtk_container_add (GTK_CONTAINER (viewport465), entry_count_uploads);
  GTK_WIDGET_UNSET_FLAGS (entry_count_uploads, GTK_CAN_FOCUS);
  gtk_editable_set_editable (GTK_EDITABLE (entry_count_uploads), FALSE);
  gtk_entry_set_has_frame (GTK_ENTRY (entry_count_uploads), FALSE);

  viewport466 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport466, "viewport466");
  gtk_widget_show (viewport466);
  gtk_table_attach (GTK_TABLE (table106), viewport466, 3, 4, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport466), GTK_SHADOW_ETCHED_IN);

  entry_ul_byte_count = gtk_entry_new ();
  gtk_widget_set_name (entry_ul_byte_count, "entry_ul_byte_count");
  gtk_widget_show (entry_ul_byte_count);
  gtk_container_add (GTK_CONTAINER (viewport466), entry_ul_byte_count);
  GTK_WIDGET_UNSET_FLAGS (entry_ul_byte_count, GTK_CAN_FOCUS);
  gtk_editable_set_editable (GTK_EDITABLE (entry_ul_byte_count), FALSE);
  gtk_entry_set_has_frame (GTK_ENTRY (entry_ul_byte_count), FALSE);

  label906 = gtk_label_new (_("Uploaded data:"));
  gtk_widget_set_name (label906, "label906");
  gtk_widget_show (label906);
  gtk_frame_set_label_widget (GTK_FRAME (frame131), label906);

  label1016 = gtk_label_new (_("File transfers"));
  gtk_widget_set_name (label1016, "label1016");
  gtk_widget_show (label1016);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (gnet_stats_notebook), gtk_notebook_get_nth_page (GTK_NOTEBOOK (gnet_stats_notebook), 5), label1016);

  table49 = gtk_table_new (2, 5, FALSE);
  gtk_widget_set_name (table49, "table49");
  gtk_widget_show (table49);
  gtk_box_pack_start (GTK_BOX (vbox101), table49, FALSE, FALSE, 0);
  gtk_table_set_row_spacings (GTK_TABLE (table49), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table49), 4);

  checkbutton_gnet_stats_hops = gtk_check_button_new_with_mnemonic (_("_Columns show hops"));
  gtk_widget_set_name (checkbutton_gnet_stats_hops, "checkbutton_gnet_stats_hops");
  gtk_widget_show (checkbutton_gnet_stats_hops);
  gtk_table_attach (GTK_TABLE (table49), checkbutton_gnet_stats_hops, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 5, 0);

  checkbutton_gnet_stats_with_headers = gtk_check_button_new_with_mnemonic (_("_Include headers"));
  gtk_widget_set_name (checkbutton_gnet_stats_with_headers, "checkbutton_gnet_stats_with_headers");
  gtk_widget_show (checkbutton_gnet_stats_with_headers);
  gtk_table_attach (GTK_TABLE (table49), checkbutton_gnet_stats_with_headers, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 5, 0);

  checkbutton_gnet_stats_bytes = gtk_check_button_new_with_mnemonic (_("Show _bytes"));
  gtk_widget_set_name (checkbutton_gnet_stats_bytes, "checkbutton_gnet_stats_bytes");
  gtk_widget_show (checkbutton_gnet_stats_bytes);
  gtk_table_attach (GTK_TABLE (table49), checkbutton_gnet_stats_bytes, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 0);

  checkbutton_gnet_stats_perc = gtk_check_button_new_with_mnemonic (_("Show _percentages"));
  gtk_widget_set_name (checkbutton_gnet_stats_perc, "checkbutton_gnet_stats_perc");
  gtk_widget_show (checkbutton_gnet_stats_perc);
  gtk_table_attach (GTK_TABLE (table49), checkbutton_gnet_stats_perc, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 5, 0);

  label889 = gtk_label_new_with_mnemonic (_("Show pr_otocol:"));
  gtk_widget_set_name (label889, "label889");
  gtk_widget_show (label889);
  gtk_table_attach (GTK_TABLE (table49), label889, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label889), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label889), 5, 0);

  label893 = gtk_label_new (_(" "));
  gtk_widget_set_name (label893, "label893");
  gtk_widget_show (label893);
  gtk_table_attach (GTK_TABLE (table49), label893, 4, 5, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label893), 0, 0.5);

  label406 = gtk_label_new_with_mnemonic (_("Show reasons _for"));
  gtk_widget_set_name (label406, "label406");
  gtk_widget_show (label406);
  gtk_table_attach (GTK_TABLE (table49), label406, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label406), 0, 0.5);

  option_menu_gnet_stats_type = gtk_option_menu_new ();
  gtk_widget_set_name (option_menu_gnet_stats_type, "option_menu_gnet_stats_type");
  gtk_widget_show (option_menu_gnet_stats_type);
  gtk_table_attach (GTK_TABLE (table49), option_menu_gnet_stats_type, 3, 4, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  option_menu_gnet_stats_source = gtk_option_menu_new ();
  gtk_widget_set_name (option_menu_gnet_stats_source, "option_menu_gnet_stats_source");
  gtk_widget_show (option_menu_gnet_stats_source);
  gtk_table_attach (GTK_TABLE (table49), option_menu_gnet_stats_source, 3, 4, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  gtk_label_set_mnemonic_widget (GTK_LABEL (label889), option_menu_gnet_stats_source);
  gtk_label_set_mnemonic_widget (GTK_LABEL (label406), option_menu_gnet_stats_type);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (main_window_gnet_stats_tab, main_window_gnet_stats_tab, "main_window_gnet_stats_tab");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, vbox101, "vbox101");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, gnet_stats_notebook, "gnet_stats_notebook");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, hbox9304, "hbox9304");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, scrolledwindow32, "scrolledwindow32");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, treeview_gnet_stats_general, "treeview_gnet_stats_general");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, scrolledwindow45, "scrolledwindow45");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, treeview_gnet_stats_drop_reasons, "treeview_gnet_stats_drop_reasons");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, label960, "label960");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, scrolledwindow65, "scrolledwindow65");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, treeview_gnet_stats_messages, "treeview_gnet_stats_messages");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, label478, "label478");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, scrolledwindow52, "scrolledwindow52");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, treeview_gnet_stats_flowc, "treeview_gnet_stats_flowc");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, label502, "label502");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, scrolledwindow56, "scrolledwindow56");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, treeview_gnet_stats_recv, "treeview_gnet_stats_recv");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, label509, "label509");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, vbox152, "vbox152");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, scrolledwindow74, "scrolledwindow74");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, treeview_gnet_stats_horizon, "treeview_gnet_stats_horizon");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, hbox9342, "hbox9342");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, frame116, "frame116");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, alignment99, "alignment99");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, label_statusbar_horizon_node_count, "label_statusbar_horizon_node_count");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, frame117, "frame117");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, alignment100, "alignment100");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, label_statusbar_horizon_file_count, "label_statusbar_horizon_file_count");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, frame118, "frame118");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, alignment101, "alignment101");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, label_statusbar_horizon_kb_count, "label_statusbar_horizon_kb_count");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, label959, "label959");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, viewport463, "viewport463");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, hbox9341, "hbox9341");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, vbox150, "vbox150");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, frame115, "frame115");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, table55, "table55");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, viewport467, "viewport467");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, entry_dl_byte_count, "entry_dl_byte_count");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, viewport468, "viewport468");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, entry_count_downloads, "entry_count_downloads");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, label551, "label551");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, label552, "label552");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, label844, "label844");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, frame131, "frame131");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, table106, "table106");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, label908, "label908");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, label907, "label907");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, viewport465, "viewport465");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, entry_count_uploads, "entry_count_uploads");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, viewport466, "viewport466");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, entry_ul_byte_count, "entry_ul_byte_count");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, label906, "label906");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, label1016, "label1016");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, table49, "table49");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, checkbutton_gnet_stats_hops, "checkbutton_gnet_stats_hops");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, checkbutton_gnet_stats_with_headers, "checkbutton_gnet_stats_with_headers");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, checkbutton_gnet_stats_bytes, "checkbutton_gnet_stats_bytes");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, checkbutton_gnet_stats_perc, "checkbutton_gnet_stats_perc");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, label889, "label889");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, label893, "label893");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, label406, "label406");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, option_menu_gnet_stats_type, "option_menu_gnet_stats_type");
  GLADE_HOOKUP_OBJECT (main_window_gnet_stats_tab, option_menu_gnet_stats_source, "option_menu_gnet_stats_source");

  return main_window_gnet_stats_tab;
}

GtkWidget*
create_dlg_filters_add_tab (void)
{
  GtkWidget *dlg_filters_add_tab;
  GtkWidget *vbox48;
  GtkWidget *hbox112;
  GtkWidget *table21;
  GtkWidget *button_filter_add_rule_jump;
  GtkWidget *button_filter_add_rule_size;
  GtkWidget *button_filter_add_rule_ip;
  GtkWidget *button_filter_add_rule_text;
  GtkWidget *button_filter_add_rule_flag;
  GtkWidget *button_filter_add_rule_state;

  dlg_filters_add_tab = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_widget_set_name (dlg_filters_add_tab, "dlg_filters_add_tab");

  vbox48 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox48, "vbox48");
  gtk_widget_show (vbox48);
  gtk_container_add (GTK_CONTAINER (dlg_filters_add_tab), vbox48);

  hbox112 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox112, "hbox112");
  gtk_widget_show (hbox112);
  gtk_box_pack_start (GTK_BOX (vbox48), hbox112, FALSE, FALSE, 0);

  table21 = gtk_table_new (3, 2, FALSE);
  gtk_widget_set_name (table21, "table21");
  gtk_widget_show (table21);
  gtk_box_pack_start (GTK_BOX (hbox112), table21, TRUE, TRUE, 0);
  gtk_table_set_row_spacings (GTK_TABLE (table21), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table21), 4);

  button_filter_add_rule_jump = gtk_button_new_with_mnemonic (_("Add jump rule"));
  gtk_widget_set_name (button_filter_add_rule_jump, "button_filter_add_rule_jump");
  gtk_widget_show (button_filter_add_rule_jump);
  gtk_table_attach (GTK_TABLE (table21), button_filter_add_rule_jump, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  button_filter_add_rule_size = gtk_button_new_with_mnemonic (_("Add size rule"));
  gtk_widget_set_name (button_filter_add_rule_size, "button_filter_add_rule_size");
  gtk_widget_show (button_filter_add_rule_size);
  gtk_table_attach (GTK_TABLE (table21), button_filter_add_rule_size, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  button_filter_add_rule_ip = gtk_button_new_with_mnemonic (_("Add IP rule"));
  gtk_widget_set_name (button_filter_add_rule_ip, "button_filter_add_rule_ip");
  gtk_widget_show (button_filter_add_rule_ip);
  gtk_table_attach (GTK_TABLE (table21), button_filter_add_rule_ip, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  button_filter_add_rule_text = gtk_button_new_with_mnemonic (_("Add name rule"));
  gtk_widget_set_name (button_filter_add_rule_text, "button_filter_add_rule_text");
  gtk_widget_show (button_filter_add_rule_text);
  gtk_table_attach (GTK_TABLE (table21), button_filter_add_rule_text, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  button_filter_add_rule_flag = gtk_button_new_with_mnemonic (_("Add flag rule"));
  gtk_widget_set_name (button_filter_add_rule_flag, "button_filter_add_rule_flag");
  gtk_widget_show (button_filter_add_rule_flag);
  gtk_table_attach (GTK_TABLE (table21), button_filter_add_rule_flag, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  button_filter_add_rule_state = gtk_button_new_with_mnemonic (_("Add state rule"));
  gtk_widget_set_name (button_filter_add_rule_state, "button_filter_add_rule_state");
  gtk_widget_show (button_filter_add_rule_state);
  gtk_table_attach (GTK_TABLE (table21), button_filter_add_rule_state, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  g_signal_connect ((gpointer) button_filter_add_rule_jump, "clicked",
                    G_CALLBACK (on_button_filter_add_rule_jump_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_filter_add_rule_size, "clicked",
                    G_CALLBACK (on_button_filter_add_rule_size_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_filter_add_rule_ip, "clicked",
                    G_CALLBACK (on_button_filter_add_rule_ip_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_filter_add_rule_text, "clicked",
                    G_CALLBACK (on_button_filter_add_rule_text_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_filter_add_rule_flag, "clicked",
                    G_CALLBACK (on_button_filter_add_rule_flag_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_filter_add_rule_state, "clicked",
                    G_CALLBACK (on_button_filter_add_rule_state_clicked),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (dlg_filters_add_tab, dlg_filters_add_tab, "dlg_filters_add_tab");
  GLADE_HOOKUP_OBJECT (dlg_filters_add_tab, vbox48, "vbox48");
  GLADE_HOOKUP_OBJECT (dlg_filters_add_tab, hbox112, "hbox112");
  GLADE_HOOKUP_OBJECT (dlg_filters_add_tab, table21, "table21");
  GLADE_HOOKUP_OBJECT (dlg_filters_add_tab, button_filter_add_rule_jump, "button_filter_add_rule_jump");
  GLADE_HOOKUP_OBJECT (dlg_filters_add_tab, button_filter_add_rule_size, "button_filter_add_rule_size");
  GLADE_HOOKUP_OBJECT (dlg_filters_add_tab, button_filter_add_rule_ip, "button_filter_add_rule_ip");
  GLADE_HOOKUP_OBJECT (dlg_filters_add_tab, button_filter_add_rule_text, "button_filter_add_rule_text");
  GLADE_HOOKUP_OBJECT (dlg_filters_add_tab, button_filter_add_rule_flag, "button_filter_add_rule_flag");
  GLADE_HOOKUP_OBJECT (dlg_filters_add_tab, button_filter_add_rule_state, "button_filter_add_rule_state");

  return dlg_filters_add_tab;
}

GtkWidget*
create_dlg_filters_text_tab (void)
{
  GtkWidget *dlg_filters_text_tab;
  GtkWidget *vbox52;
  GtkWidget *alignment12;
  GtkWidget *hbox120;
  GtkWidget *frame31;
  GtkWidget *vbox55;
  GtkWidget *checkbutton_filter_text_invert_cond;
  GtkWidget *checkbutton_filter_text_active;
  GtkWidget *checkbutton_filter_text_soft;
  GtkWidget *label222;
  GtkWidget *frame25;
  GtkWidget *hbox117;
  GtkWidget *table22;
  GtkWidget *optionmenu_filter_text_type;
  GtkWidget *convertwidget33;
  GtkWidget *entry_filter_text_pattern;
  GtkWidget *checkbutton_filter_text_case;
  GtkWidget *label223;
  GtkWidget *hbox110;
  GtkWidget *frame26;
  GtkWidget *optionmenu_filter_text_target;
  GtkWidget *convertwidget34;
  GtkWidget *label224;
  GtkWidget *vbox60;
  GtkWidget *button_filter_text_reset;
  GtkWidget *alignment121;
  GtkWidget *hbox9314;
  GtkWidget *image1160;
  GtkWidget *label968;
  GtkWidget *hbox138;
  GtkWidget *button_filter_text_add;
  GtkWidget *alignment61;
  GtkWidget *hbox193;
  GtkWidget *image93;
  GtkWidget *label465;
  GtkWidget *button_filter_text_remove;
  GtkWidget *alignment66;
  GtkWidget *hbox198;
  GtkWidget *image98;
  GtkWidget *label470;
  GtkWidget *button16;
  GtkWidget *alignment67;
  GtkWidget *hbox199;
  GtkWidget *image99;
  GtkWidget *label471;

  dlg_filters_text_tab = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_widget_set_name (dlg_filters_text_tab, "dlg_filters_text_tab");

  vbox52 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox52, "vbox52");
  gtk_widget_show (vbox52);
  gtk_container_add (GTK_CONTAINER (dlg_filters_text_tab), vbox52);

  alignment12 = gtk_alignment_new (0.5, 0, 1, 1);
  gtk_widget_set_name (alignment12, "alignment12");
  gtk_widget_show (alignment12);
  gtk_box_pack_start (GTK_BOX (vbox52), alignment12, TRUE, TRUE, 0);

  hbox120 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox120, "hbox120");
  gtk_widget_show (hbox120);
  gtk_container_add (GTK_CONTAINER (alignment12), hbox120);

  frame31 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame31, "frame31");
  gtk_widget_show (frame31);
  gtk_box_pack_start (GTK_BOX (hbox120), frame31, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame31), 2);

  vbox55 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox55, "vbox55");
  gtk_widget_show (vbox55);
  gtk_container_add (GTK_CONTAINER (frame31), vbox55);

  checkbutton_filter_text_invert_cond = gtk_check_button_new_with_mnemonic (_("invert condition"));
  gtk_widget_set_name (checkbutton_filter_text_invert_cond, "checkbutton_filter_text_invert_cond");
  gtk_widget_show (checkbutton_filter_text_invert_cond);
  gtk_box_pack_start (GTK_BOX (vbox55), checkbutton_filter_text_invert_cond, FALSE, FALSE, 0);

  checkbutton_filter_text_active = gtk_check_button_new_with_mnemonic (_("active"));
  gtk_widget_set_name (checkbutton_filter_text_active, "checkbutton_filter_text_active");
  gtk_widget_show (checkbutton_filter_text_active);
  gtk_box_pack_start (GTK_BOX (vbox55), checkbutton_filter_text_active, FALSE, FALSE, 0);

  checkbutton_filter_text_soft = gtk_check_button_new_with_mnemonic (_("mark only"));
  gtk_widget_set_name (checkbutton_filter_text_soft, "checkbutton_filter_text_soft");
  gtk_widget_show (checkbutton_filter_text_soft);
  gtk_box_pack_start (GTK_BOX (vbox55), checkbutton_filter_text_soft, FALSE, FALSE, 0);

  label222 = gtk_label_new (_("Flags"));
  gtk_widget_set_name (label222, "label222");
  gtk_widget_show (label222);
  gtk_frame_set_label_widget (GTK_FRAME (frame31), label222);

  frame25 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame25, "frame25");
  gtk_widget_show (frame25);
  gtk_box_pack_start (GTK_BOX (hbox120), frame25, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame25), 2);

  hbox117 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox117, "hbox117");
  gtk_widget_show (hbox117);
  gtk_container_add (GTK_CONTAINER (frame25), hbox117);

  table22 = gtk_table_new (2, 2, FALSE);
  gtk_widget_set_name (table22, "table22");
  gtk_widget_show (table22);
  gtk_box_pack_start (GTK_BOX (hbox117), table22, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (table22), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table22), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table22), 4);

  optionmenu_filter_text_type = gtk_option_menu_new ();
  gtk_widget_set_name (optionmenu_filter_text_type, "optionmenu_filter_text_type");
  gtk_widget_show (optionmenu_filter_text_type);
  gtk_table_attach (GTK_TABLE (table22), optionmenu_filter_text_type, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  convertwidget33 = gtk_menu_new ();
  gtk_widget_set_name (convertwidget33, "convertwidget33");

  gtk_option_menu_set_menu (GTK_OPTION_MENU (optionmenu_filter_text_type), convertwidget33);

  entry_filter_text_pattern = gtk_entry_new ();
  gtk_widget_set_name (entry_filter_text_pattern, "entry_filter_text_pattern");
  gtk_widget_show (entry_filter_text_pattern);
  gtk_table_attach (GTK_TABLE (table22), entry_filter_text_pattern, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_filter_text_case = gtk_check_button_new_with_mnemonic (_("case sensitive"));
  gtk_widget_set_name (checkbutton_filter_text_case, "checkbutton_filter_text_case");
  gtk_widget_show (checkbutton_filter_text_case);
  gtk_table_attach (GTK_TABLE (table22), checkbutton_filter_text_case, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label223 = gtk_label_new (_("Condition: If filename matches"));
  gtk_widget_set_name (label223, "label223");
  gtk_widget_show (label223);
  gtk_frame_set_label_widget (GTK_FRAME (frame25), label223);

  hbox110 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox110, "hbox110");
  gtk_widget_show (hbox110);
  gtk_box_pack_start (GTK_BOX (vbox52), hbox110, FALSE, FALSE, 0);

  frame26 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame26, "frame26");
  gtk_widget_show (frame26);
  gtk_box_pack_start (GTK_BOX (hbox110), frame26, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame26), 2);

  optionmenu_filter_text_target = gtk_option_menu_new ();
  gtk_widget_set_name (optionmenu_filter_text_target, "optionmenu_filter_text_target");
  gtk_widget_show (optionmenu_filter_text_target);
  gtk_container_add (GTK_CONTAINER (frame26), optionmenu_filter_text_target);

  convertwidget34 = gtk_menu_new ();
  gtk_widget_set_name (convertwidget34, "convertwidget34");

  gtk_option_menu_set_menu (GTK_OPTION_MENU (optionmenu_filter_text_target), convertwidget34);

  label224 = gtk_label_new (_("Target"));
  gtk_widget_set_name (label224, "label224");
  gtk_widget_show (label224);
  gtk_frame_set_label_widget (GTK_FRAME (frame26), label224);

  vbox60 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox60, "vbox60");
  gtk_widget_show (vbox60);
  gtk_box_pack_start (GTK_BOX (hbox110), vbox60, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (vbox60), 2);

  button_filter_text_reset = gtk_button_new ();
  gtk_widget_set_name (button_filter_text_reset, "button_filter_text_reset");
  gtk_widget_show (button_filter_text_reset);
  gtk_box_pack_start (GTK_BOX (vbox60), button_filter_text_reset, FALSE, FALSE, 0);

  alignment121 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment121, "alignment121");
  gtk_widget_show (alignment121);
  gtk_container_add (GTK_CONTAINER (button_filter_text_reset), alignment121);

  hbox9314 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox9314, "hbox9314");
  gtk_widget_show (hbox9314);
  gtk_container_add (GTK_CONTAINER (alignment121), hbox9314);

  image1160 = gtk_image_new_from_stock ("gtk-refresh", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image1160, "image1160");
  gtk_widget_show (image1160);
  gtk_box_pack_start (GTK_BOX (hbox9314), image1160, FALSE, FALSE, 0);

  label968 = gtk_label_new_with_mnemonic (_("_Reset stats"));
  gtk_widget_set_name (label968, "label968");
  gtk_widget_show (label968);
  gtk_box_pack_start (GTK_BOX (hbox9314), label968, FALSE, FALSE, 0);

  hbox138 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox138, "hbox138");
  gtk_widget_show (hbox138);
  gtk_box_pack_start (GTK_BOX (vbox60), hbox138, TRUE, TRUE, 0);

  button_filter_text_add = gtk_button_new ();
  gtk_widget_set_name (button_filter_text_add, "button_filter_text_add");
  gtk_widget_show (button_filter_text_add);
  gtk_box_pack_start (GTK_BOX (hbox138), button_filter_text_add, FALSE, FALSE, 0);

  alignment61 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment61, "alignment61");
  gtk_widget_show (alignment61);
  gtk_container_add (GTK_CONTAINER (button_filter_text_add), alignment61);

  hbox193 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox193, "hbox193");
  gtk_widget_show (hbox193);
  gtk_container_add (GTK_CONTAINER (alignment61), hbox193);

  image93 = gtk_image_new_from_stock ("gtk-save", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image93, "image93");
  gtk_widget_show (image93);
  gtk_box_pack_start (GTK_BOX (hbox193), image93, FALSE, FALSE, 0);

  label465 = gtk_label_new_with_mnemonic (_("Save"));
  gtk_widget_set_name (label465, "label465");
  gtk_widget_show (label465);
  gtk_box_pack_start (GTK_BOX (hbox193), label465, FALSE, FALSE, 0);

  button_filter_text_remove = gtk_button_new ();
  gtk_widget_set_name (button_filter_text_remove, "button_filter_text_remove");
  gtk_widget_show (button_filter_text_remove);
  gtk_box_pack_start (GTK_BOX (hbox138), button_filter_text_remove, FALSE, FALSE, 0);

  alignment66 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment66, "alignment66");
  gtk_widget_show (alignment66);
  gtk_container_add (GTK_CONTAINER (button_filter_text_remove), alignment66);

  hbox198 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox198, "hbox198");
  gtk_widget_show (hbox198);
  gtk_container_add (GTK_CONTAINER (alignment66), hbox198);

  image98 = gtk_image_new_from_stock ("gtk-delete", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image98, "image98");
  gtk_widget_show (image98);
  gtk_box_pack_start (GTK_BOX (hbox198), image98, FALSE, FALSE, 0);

  label470 = gtk_label_new_with_mnemonic (_("Delete"));
  gtk_widget_set_name (label470, "label470");
  gtk_widget_show (label470);
  gtk_box_pack_start (GTK_BOX (hbox198), label470, FALSE, FALSE, 0);

  button16 = gtk_button_new ();
  gtk_widget_set_name (button16, "button16");
  gtk_widget_show (button16);
  gtk_box_pack_start (GTK_BOX (hbox138), button16, FALSE, FALSE, 0);

  alignment67 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment67, "alignment67");
  gtk_widget_show (alignment67);
  gtk_container_add (GTK_CONTAINER (button16), alignment67);

  hbox199 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox199, "hbox199");
  gtk_widget_show (hbox199);
  gtk_container_add (GTK_CONTAINER (alignment67), hbox199);

  image99 = gtk_image_new_from_stock ("gtk-cancel", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image99, "image99");
  gtk_widget_show (image99);
  gtk_box_pack_start (GTK_BOX (hbox199), image99, FALSE, FALSE, 0);

  label471 = gtk_label_new_with_mnemonic (_("Abort"));
  gtk_widget_set_name (label471, "label471");
  gtk_widget_show (label471);
  gtk_box_pack_start (GTK_BOX (hbox199), label471, FALSE, FALSE, 0);

  g_signal_connect ((gpointer) button_filter_text_reset, "clicked",
                    G_CALLBACK (on_button_filter_reset_rule_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_filter_text_add, "clicked",
                    G_CALLBACK (on_button_filter_add_rule_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_filter_text_remove, "clicked",
                    G_CALLBACK (on_button_filter_remove_rule_clicked),
                    NULL);
  g_signal_connect ((gpointer) button16, "clicked",
                    G_CALLBACK (on_button_filter_abort_rule_clicked),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (dlg_filters_text_tab, dlg_filters_text_tab, "dlg_filters_text_tab");
  GLADE_HOOKUP_OBJECT (dlg_filters_text_tab, vbox52, "vbox52");
  GLADE_HOOKUP_OBJECT (dlg_filters_text_tab, alignment12, "alignment12");
  GLADE_HOOKUP_OBJECT (dlg_filters_text_tab, hbox120, "hbox120");
  GLADE_HOOKUP_OBJECT (dlg_filters_text_tab, frame31, "frame31");
  GLADE_HOOKUP_OBJECT (dlg_filters_text_tab, vbox55, "vbox55");
  GLADE_HOOKUP_OBJECT (dlg_filters_text_tab, checkbutton_filter_text_invert_cond, "checkbutton_filter_text_invert_cond");
  GLADE_HOOKUP_OBJECT (dlg_filters_text_tab, checkbutton_filter_text_active, "checkbutton_filter_text_active");
  GLADE_HOOKUP_OBJECT (dlg_filters_text_tab, checkbutton_filter_text_soft, "checkbutton_filter_text_soft");
  GLADE_HOOKUP_OBJECT (dlg_filters_text_tab, label222, "label222");
  GLADE_HOOKUP_OBJECT (dlg_filters_text_tab, frame25, "frame25");
  GLADE_HOOKUP_OBJECT (dlg_filters_text_tab, hbox117, "hbox117");
  GLADE_HOOKUP_OBJECT (dlg_filters_text_tab, table22, "table22");
  GLADE_HOOKUP_OBJECT (dlg_filters_text_tab, optionmenu_filter_text_type, "optionmenu_filter_text_type");
  GLADE_HOOKUP_OBJECT (dlg_filters_text_tab, convertwidget33, "convertwidget33");
  GLADE_HOOKUP_OBJECT (dlg_filters_text_tab, entry_filter_text_pattern, "entry_filter_text_pattern");
  GLADE_HOOKUP_OBJECT (dlg_filters_text_tab, checkbutton_filter_text_case, "checkbutton_filter_text_case");
  GLADE_HOOKUP_OBJECT (dlg_filters_text_tab, label223, "label223");
  GLADE_HOOKUP_OBJECT (dlg_filters_text_tab, hbox110, "hbox110");
  GLADE_HOOKUP_OBJECT (dlg_filters_text_tab, frame26, "frame26");
  GLADE_HOOKUP_OBJECT (dlg_filters_text_tab, optionmenu_filter_text_target, "optionmenu_filter_text_target");
  GLADE_HOOKUP_OBJECT (dlg_filters_text_tab, convertwidget34, "convertwidget34");
  GLADE_HOOKUP_OBJECT (dlg_filters_text_tab, label224, "label224");
  GLADE_HOOKUP_OBJECT (dlg_filters_text_tab, vbox60, "vbox60");
  GLADE_HOOKUP_OBJECT (dlg_filters_text_tab, button_filter_text_reset, "button_filter_text_reset");
  GLADE_HOOKUP_OBJECT (dlg_filters_text_tab, alignment121, "alignment121");
  GLADE_HOOKUP_OBJECT (dlg_filters_text_tab, hbox9314, "hbox9314");
  GLADE_HOOKUP_OBJECT (dlg_filters_text_tab, image1160, "image1160");
  GLADE_HOOKUP_OBJECT (dlg_filters_text_tab, label968, "label968");
  GLADE_HOOKUP_OBJECT (dlg_filters_text_tab, hbox138, "hbox138");
  GLADE_HOOKUP_OBJECT (dlg_filters_text_tab, button_filter_text_add, "button_filter_text_add");
  GLADE_HOOKUP_OBJECT (dlg_filters_text_tab, alignment61, "alignment61");
  GLADE_HOOKUP_OBJECT (dlg_filters_text_tab, hbox193, "hbox193");
  GLADE_HOOKUP_OBJECT (dlg_filters_text_tab, image93, "image93");
  GLADE_HOOKUP_OBJECT (dlg_filters_text_tab, label465, "label465");
  GLADE_HOOKUP_OBJECT (dlg_filters_text_tab, button_filter_text_remove, "button_filter_text_remove");
  GLADE_HOOKUP_OBJECT (dlg_filters_text_tab, alignment66, "alignment66");
  GLADE_HOOKUP_OBJECT (dlg_filters_text_tab, hbox198, "hbox198");
  GLADE_HOOKUP_OBJECT (dlg_filters_text_tab, image98, "image98");
  GLADE_HOOKUP_OBJECT (dlg_filters_text_tab, label470, "label470");
  GLADE_HOOKUP_OBJECT (dlg_filters_text_tab, button16, "button16");
  GLADE_HOOKUP_OBJECT (dlg_filters_text_tab, alignment67, "alignment67");
  GLADE_HOOKUP_OBJECT (dlg_filters_text_tab, hbox199, "hbox199");
  GLADE_HOOKUP_OBJECT (dlg_filters_text_tab, image99, "image99");
  GLADE_HOOKUP_OBJECT (dlg_filters_text_tab, label471, "label471");

  return dlg_filters_text_tab;
}

GtkWidget*
create_dlg_filters_ip_tab (void)
{
  GtkWidget *dlg_filters_ip_tab;
  GtkWidget *vbox51;
  GtkWidget *alignment11;
  GtkWidget *hbox121;
  GtkWidget *frame32;
  GtkWidget *vbox56;
  GtkWidget *checkbutton_filter_ip_invert_cond;
  GtkWidget *checkbutton_filter_ip_active;
  GtkWidget *checkbutton_filter_ip_soft;
  GtkWidget *label225;
  GtkWidget *frame23;
  GtkWidget *hbox118;
  GtkWidget *table23;
  GtkWidget *label191;
  GtkWidget *entry_filter_ip_address;
  GtkWidget *label_d226;
  GtkWidget *hbox109;
  GtkWidget *frame24;
  GtkWidget *optionmenu_filter_ip_target;
  GtkWidget *convertwidget35;
  GtkWidget *label227;
  GtkWidget *vbox61;
  GtkWidget *button_filter_ip_reset;
  GtkWidget *alignment122;
  GtkWidget *hbox9315;
  GtkWidget *image1161;
  GtkWidget *label969;
  GtkWidget *hbox9305;
  GtkWidget *button_filter_ip_add;
  GtkWidget *alignment114;
  GtkWidget *hbox9306;
  GtkWidget *image1153;
  GtkWidget *label961;
  GtkWidget *button_filter_ip_remove;
  GtkWidget *alignment115;
  GtkWidget *hbox9307;
  GtkWidget *image1154;
  GtkWidget *label962;
  GtkWidget *button_filter_ip_abort;
  GtkWidget *alignment116;
  GtkWidget *hbox9308;
  GtkWidget *image1155;
  GtkWidget *label963;

  dlg_filters_ip_tab = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_widget_set_name (dlg_filters_ip_tab, "dlg_filters_ip_tab");

  vbox51 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox51, "vbox51");
  gtk_widget_show (vbox51);
  gtk_container_add (GTK_CONTAINER (dlg_filters_ip_tab), vbox51);

  alignment11 = gtk_alignment_new (0.5, 0, 1, 1);
  gtk_widget_set_name (alignment11, "alignment11");
  gtk_widget_show (alignment11);
  gtk_box_pack_start (GTK_BOX (vbox51), alignment11, TRUE, TRUE, 0);

  hbox121 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox121, "hbox121");
  gtk_widget_show (hbox121);
  gtk_container_add (GTK_CONTAINER (alignment11), hbox121);

  frame32 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame32, "frame32");
  gtk_widget_show (frame32);
  gtk_box_pack_start (GTK_BOX (hbox121), frame32, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame32), 2);

  vbox56 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox56, "vbox56");
  gtk_widget_show (vbox56);
  gtk_container_add (GTK_CONTAINER (frame32), vbox56);

  checkbutton_filter_ip_invert_cond = gtk_check_button_new_with_mnemonic (_("invert condition"));
  gtk_widget_set_name (checkbutton_filter_ip_invert_cond, "checkbutton_filter_ip_invert_cond");
  gtk_widget_show (checkbutton_filter_ip_invert_cond);
  gtk_box_pack_start (GTK_BOX (vbox56), checkbutton_filter_ip_invert_cond, FALSE, FALSE, 0);

  checkbutton_filter_ip_active = gtk_check_button_new_with_mnemonic (_("active"));
  gtk_widget_set_name (checkbutton_filter_ip_active, "checkbutton_filter_ip_active");
  gtk_widget_show (checkbutton_filter_ip_active);
  gtk_box_pack_start (GTK_BOX (vbox56), checkbutton_filter_ip_active, FALSE, FALSE, 0);

  checkbutton_filter_ip_soft = gtk_check_button_new_with_mnemonic (_("mark only"));
  gtk_widget_set_name (checkbutton_filter_ip_soft, "checkbutton_filter_ip_soft");
  gtk_widget_show (checkbutton_filter_ip_soft);
  gtk_box_pack_start (GTK_BOX (vbox56), checkbutton_filter_ip_soft, FALSE, FALSE, 0);

  label225 = gtk_label_new (_("Flags"));
  gtk_widget_set_name (label225, "label225");
  gtk_widget_show (label225);
  gtk_frame_set_label_widget (GTK_FRAME (frame32), label225);

  frame23 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame23, "frame23");
  gtk_widget_show (frame23);
  gtk_box_pack_start (GTK_BOX (hbox121), frame23, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame23), 2);

  hbox118 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox118, "hbox118");
  gtk_widget_show (hbox118);
  gtk_container_add (GTK_CONTAINER (frame23), hbox118);

  table23 = gtk_table_new (1, 2, FALSE);
  gtk_widget_set_name (table23, "table23");
  gtk_widget_show (table23);
  gtk_box_pack_start (GTK_BOX (hbox118), table23, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (table23), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table23), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table23), 4);

  label191 = gtk_label_new (_("IP address/mask"));
  gtk_widget_set_name (label191, "label191");
  gtk_widget_show (label191);
  gtk_table_attach (GTK_TABLE (table23), label191, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label191), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label191), 0, 0.5);

  entry_filter_ip_address = gtk_entry_new ();
  gtk_widget_set_name (entry_filter_ip_address, "entry_filter_ip_address");
  gtk_widget_show (entry_filter_ip_address);
  gtk_table_attach (GTK_TABLE (table23), entry_filter_ip_address, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label_d226 = gtk_label_new (_("Condition: If IP address matches"));
  gtk_widget_set_name (label_d226, "label_d226");
  gtk_widget_show (label_d226);
  gtk_frame_set_label_widget (GTK_FRAME (frame23), label_d226);

  hbox109 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox109, "hbox109");
  gtk_widget_show (hbox109);
  gtk_box_pack_start (GTK_BOX (vbox51), hbox109, FALSE, FALSE, 0);

  frame24 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame24, "frame24");
  gtk_widget_show (frame24);
  gtk_box_pack_start (GTK_BOX (hbox109), frame24, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame24), 2);

  optionmenu_filter_ip_target = gtk_option_menu_new ();
  gtk_widget_set_name (optionmenu_filter_ip_target, "optionmenu_filter_ip_target");
  gtk_widget_show (optionmenu_filter_ip_target);
  gtk_container_add (GTK_CONTAINER (frame24), optionmenu_filter_ip_target);

  convertwidget35 = gtk_menu_new ();
  gtk_widget_set_name (convertwidget35, "convertwidget35");

  gtk_option_menu_set_menu (GTK_OPTION_MENU (optionmenu_filter_ip_target), convertwidget35);

  label227 = gtk_label_new (_("Target"));
  gtk_widget_set_name (label227, "label227");
  gtk_widget_show (label227);
  gtk_frame_set_label_widget (GTK_FRAME (frame24), label227);

  vbox61 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox61, "vbox61");
  gtk_widget_show (vbox61);
  gtk_box_pack_start (GTK_BOX (hbox109), vbox61, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (vbox61), 2);

  button_filter_ip_reset = gtk_button_new ();
  gtk_widget_set_name (button_filter_ip_reset, "button_filter_ip_reset");
  gtk_widget_show (button_filter_ip_reset);
  gtk_box_pack_start (GTK_BOX (vbox61), button_filter_ip_reset, FALSE, FALSE, 0);

  alignment122 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment122, "alignment122");
  gtk_widget_show (alignment122);
  gtk_container_add (GTK_CONTAINER (button_filter_ip_reset), alignment122);

  hbox9315 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox9315, "hbox9315");
  gtk_widget_show (hbox9315);
  gtk_container_add (GTK_CONTAINER (alignment122), hbox9315);

  image1161 = gtk_image_new_from_stock ("gtk-refresh", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image1161, "image1161");
  gtk_widget_show (image1161);
  gtk_box_pack_start (GTK_BOX (hbox9315), image1161, FALSE, FALSE, 0);

  label969 = gtk_label_new_with_mnemonic (_("_Reset stats"));
  gtk_widget_set_name (label969, "label969");
  gtk_widget_show (label969);
  gtk_box_pack_start (GTK_BOX (hbox9315), label969, FALSE, FALSE, 0);

  hbox9305 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox9305, "hbox9305");
  gtk_widget_show (hbox9305);
  gtk_box_pack_start (GTK_BOX (vbox61), hbox9305, FALSE, FALSE, 0);

  button_filter_ip_add = gtk_button_new ();
  gtk_widget_set_name (button_filter_ip_add, "button_filter_ip_add");
  gtk_widget_show (button_filter_ip_add);
  gtk_box_pack_start (GTK_BOX (hbox9305), button_filter_ip_add, FALSE, FALSE, 0);

  alignment114 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment114, "alignment114");
  gtk_widget_show (alignment114);
  gtk_container_add (GTK_CONTAINER (button_filter_ip_add), alignment114);

  hbox9306 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox9306, "hbox9306");
  gtk_widget_show (hbox9306);
  gtk_container_add (GTK_CONTAINER (alignment114), hbox9306);

  image1153 = gtk_image_new_from_stock ("gtk-save", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image1153, "image1153");
  gtk_widget_show (image1153);
  gtk_box_pack_start (GTK_BOX (hbox9306), image1153, FALSE, FALSE, 0);

  label961 = gtk_label_new_with_mnemonic (_("Save"));
  gtk_widget_set_name (label961, "label961");
  gtk_widget_show (label961);
  gtk_box_pack_start (GTK_BOX (hbox9306), label961, FALSE, FALSE, 0);

  button_filter_ip_remove = gtk_button_new ();
  gtk_widget_set_name (button_filter_ip_remove, "button_filter_ip_remove");
  gtk_widget_show (button_filter_ip_remove);
  gtk_box_pack_start (GTK_BOX (hbox9305), button_filter_ip_remove, FALSE, FALSE, 0);

  alignment115 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment115, "alignment115");
  gtk_widget_show (alignment115);
  gtk_container_add (GTK_CONTAINER (button_filter_ip_remove), alignment115);

  hbox9307 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox9307, "hbox9307");
  gtk_widget_show (hbox9307);
  gtk_container_add (GTK_CONTAINER (alignment115), hbox9307);

  image1154 = gtk_image_new_from_stock ("gtk-delete", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image1154, "image1154");
  gtk_widget_show (image1154);
  gtk_box_pack_start (GTK_BOX (hbox9307), image1154, FALSE, FALSE, 0);

  label962 = gtk_label_new_with_mnemonic (_("Delete"));
  gtk_widget_set_name (label962, "label962");
  gtk_widget_show (label962);
  gtk_box_pack_start (GTK_BOX (hbox9307), label962, FALSE, FALSE, 0);

  button_filter_ip_abort = gtk_button_new ();
  gtk_widget_set_name (button_filter_ip_abort, "button_filter_ip_abort");
  gtk_widget_show (button_filter_ip_abort);
  gtk_box_pack_start (GTK_BOX (hbox9305), button_filter_ip_abort, FALSE, FALSE, 0);

  alignment116 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment116, "alignment116");
  gtk_widget_show (alignment116);
  gtk_container_add (GTK_CONTAINER (button_filter_ip_abort), alignment116);

  hbox9308 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox9308, "hbox9308");
  gtk_widget_show (hbox9308);
  gtk_container_add (GTK_CONTAINER (alignment116), hbox9308);

  image1155 = gtk_image_new_from_stock ("gtk-cancel", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image1155, "image1155");
  gtk_widget_show (image1155);
  gtk_box_pack_start (GTK_BOX (hbox9308), image1155, FALSE, FALSE, 0);

  label963 = gtk_label_new_with_mnemonic (_("Abort"));
  gtk_widget_set_name (label963, "label963");
  gtk_widget_show (label963);
  gtk_box_pack_start (GTK_BOX (hbox9308), label963, FALSE, FALSE, 0);

  g_signal_connect ((gpointer) button_filter_ip_reset, "clicked",
                    G_CALLBACK (on_button_filter_reset_rule_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_filter_ip_add, "clicked",
                    G_CALLBACK (on_button_filter_add_rule_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_filter_ip_remove, "clicked",
                    G_CALLBACK (on_button_filter_remove_rule_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_filter_ip_abort, "clicked",
                    G_CALLBACK (on_button_filter_abort_rule_clicked),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (dlg_filters_ip_tab, dlg_filters_ip_tab, "dlg_filters_ip_tab");
  GLADE_HOOKUP_OBJECT (dlg_filters_ip_tab, vbox51, "vbox51");
  GLADE_HOOKUP_OBJECT (dlg_filters_ip_tab, alignment11, "alignment11");
  GLADE_HOOKUP_OBJECT (dlg_filters_ip_tab, hbox121, "hbox121");
  GLADE_HOOKUP_OBJECT (dlg_filters_ip_tab, frame32, "frame32");
  GLADE_HOOKUP_OBJECT (dlg_filters_ip_tab, vbox56, "vbox56");
  GLADE_HOOKUP_OBJECT (dlg_filters_ip_tab, checkbutton_filter_ip_invert_cond, "checkbutton_filter_ip_invert_cond");
  GLADE_HOOKUP_OBJECT (dlg_filters_ip_tab, checkbutton_filter_ip_active, "checkbutton_filter_ip_active");
  GLADE_HOOKUP_OBJECT (dlg_filters_ip_tab, checkbutton_filter_ip_soft, "checkbutton_filter_ip_soft");
  GLADE_HOOKUP_OBJECT (dlg_filters_ip_tab, label225, "label225");
  GLADE_HOOKUP_OBJECT (dlg_filters_ip_tab, frame23, "frame23");
  GLADE_HOOKUP_OBJECT (dlg_filters_ip_tab, hbox118, "hbox118");
  GLADE_HOOKUP_OBJECT (dlg_filters_ip_tab, table23, "table23");
  GLADE_HOOKUP_OBJECT (dlg_filters_ip_tab, label191, "label191");
  GLADE_HOOKUP_OBJECT (dlg_filters_ip_tab, entry_filter_ip_address, "entry_filter_ip_address");
  GLADE_HOOKUP_OBJECT (dlg_filters_ip_tab, label_d226, "label_d226");
  GLADE_HOOKUP_OBJECT (dlg_filters_ip_tab, hbox109, "hbox109");
  GLADE_HOOKUP_OBJECT (dlg_filters_ip_tab, frame24, "frame24");
  GLADE_HOOKUP_OBJECT (dlg_filters_ip_tab, optionmenu_filter_ip_target, "optionmenu_filter_ip_target");
  GLADE_HOOKUP_OBJECT (dlg_filters_ip_tab, convertwidget35, "convertwidget35");
  GLADE_HOOKUP_OBJECT (dlg_filters_ip_tab, label227, "label227");
  GLADE_HOOKUP_OBJECT (dlg_filters_ip_tab, vbox61, "vbox61");
  GLADE_HOOKUP_OBJECT (dlg_filters_ip_tab, button_filter_ip_reset, "button_filter_ip_reset");
  GLADE_HOOKUP_OBJECT (dlg_filters_ip_tab, alignment122, "alignment122");
  GLADE_HOOKUP_OBJECT (dlg_filters_ip_tab, hbox9315, "hbox9315");
  GLADE_HOOKUP_OBJECT (dlg_filters_ip_tab, image1161, "image1161");
  GLADE_HOOKUP_OBJECT (dlg_filters_ip_tab, label969, "label969");
  GLADE_HOOKUP_OBJECT (dlg_filters_ip_tab, hbox9305, "hbox9305");
  GLADE_HOOKUP_OBJECT (dlg_filters_ip_tab, button_filter_ip_add, "button_filter_ip_add");
  GLADE_HOOKUP_OBJECT (dlg_filters_ip_tab, alignment114, "alignment114");
  GLADE_HOOKUP_OBJECT (dlg_filters_ip_tab, hbox9306, "hbox9306");
  GLADE_HOOKUP_OBJECT (dlg_filters_ip_tab, image1153, "image1153");
  GLADE_HOOKUP_OBJECT (dlg_filters_ip_tab, label961, "label961");
  GLADE_HOOKUP_OBJECT (dlg_filters_ip_tab, button_filter_ip_remove, "button_filter_ip_remove");
  GLADE_HOOKUP_OBJECT (dlg_filters_ip_tab, alignment115, "alignment115");
  GLADE_HOOKUP_OBJECT (dlg_filters_ip_tab, hbox9307, "hbox9307");
  GLADE_HOOKUP_OBJECT (dlg_filters_ip_tab, image1154, "image1154");
  GLADE_HOOKUP_OBJECT (dlg_filters_ip_tab, label962, "label962");
  GLADE_HOOKUP_OBJECT (dlg_filters_ip_tab, button_filter_ip_abort, "button_filter_ip_abort");
  GLADE_HOOKUP_OBJECT (dlg_filters_ip_tab, alignment116, "alignment116");
  GLADE_HOOKUP_OBJECT (dlg_filters_ip_tab, hbox9308, "hbox9308");
  GLADE_HOOKUP_OBJECT (dlg_filters_ip_tab, image1155, "image1155");
  GLADE_HOOKUP_OBJECT (dlg_filters_ip_tab, label963, "label963");

  return dlg_filters_ip_tab;
}

GtkWidget*
create_dlg_filters_size_tab (void)
{
  GtkWidget *dlg_filters_size_tab;
  GtkWidget *vbox49;
  GtkWidget *alignment10;
  GtkWidget *hbox122;
  GtkWidget *frame33;
  GtkWidget *vbox57;
  GtkWidget *checkbutton_filter_size_invert_cond;
  GtkWidget *checkbutton_filter_size_active;
  GtkWidget *checkbutton_filter_size_soft;
  GtkWidget *label228;
  GtkWidget *frame22;
  GtkWidget *hbox119;
  GtkWidget *table24;
  GtkWidget *label192;
  GtkWidget *label193;
  GtkWidget *label194;
  GtkWidget *label195;
  GtkWidget *entry_filter_size_min;
  GtkWidget *entry_filter_size_max;
  GtkWidget *label916;
  GtkWidget *label229;
  GtkWidget *hbox108;
  GtkWidget *frame21;
  GtkWidget *optionmenu_filter_size_target;
  GtkWidget *convertwidget36;
  GtkWidget *label230;
  GtkWidget *vbox62;
  GtkWidget *button_filter_size_reset;
  GtkWidget *alignment120;
  GtkWidget *hbox9313;
  GtkWidget *image1159;
  GtkWidget *label967;
  GtkWidget *hbox9309;
  GtkWidget *button26;
  GtkWidget *alignment117;
  GtkWidget *hbox9310;
  GtkWidget *image1156;
  GtkWidget *label964;
  GtkWidget *button27;
  GtkWidget *alignment118;
  GtkWidget *hbox9311;
  GtkWidget *image1157;
  GtkWidget *label965;
  GtkWidget *button28;
  GtkWidget *alignment119;
  GtkWidget *hbox9312;
  GtkWidget *image1158;
  GtkWidget *label966;

  dlg_filters_size_tab = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_widget_set_name (dlg_filters_size_tab, "dlg_filters_size_tab");

  vbox49 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox49, "vbox49");
  gtk_widget_show (vbox49);
  gtk_container_add (GTK_CONTAINER (dlg_filters_size_tab), vbox49);

  alignment10 = gtk_alignment_new (0.5, 0, 1, 1);
  gtk_widget_set_name (alignment10, "alignment10");
  gtk_widget_show (alignment10);
  gtk_box_pack_start (GTK_BOX (vbox49), alignment10, TRUE, TRUE, 0);

  hbox122 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox122, "hbox122");
  gtk_widget_show (hbox122);
  gtk_container_add (GTK_CONTAINER (alignment10), hbox122);

  frame33 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame33, "frame33");
  gtk_widget_show (frame33);
  gtk_box_pack_start (GTK_BOX (hbox122), frame33, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame33), 2);

  vbox57 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox57, "vbox57");
  gtk_widget_show (vbox57);
  gtk_container_add (GTK_CONTAINER (frame33), vbox57);

  checkbutton_filter_size_invert_cond = gtk_check_button_new_with_mnemonic (_("invert condition"));
  gtk_widget_set_name (checkbutton_filter_size_invert_cond, "checkbutton_filter_size_invert_cond");
  gtk_widget_show (checkbutton_filter_size_invert_cond);
  gtk_box_pack_start (GTK_BOX (vbox57), checkbutton_filter_size_invert_cond, FALSE, FALSE, 0);

  checkbutton_filter_size_active = gtk_check_button_new_with_mnemonic (_("active"));
  gtk_widget_set_name (checkbutton_filter_size_active, "checkbutton_filter_size_active");
  gtk_widget_show (checkbutton_filter_size_active);
  gtk_box_pack_start (GTK_BOX (vbox57), checkbutton_filter_size_active, FALSE, FALSE, 0);

  checkbutton_filter_size_soft = gtk_check_button_new_with_mnemonic (_("mark only"));
  gtk_widget_set_name (checkbutton_filter_size_soft, "checkbutton_filter_size_soft");
  gtk_widget_show (checkbutton_filter_size_soft);
  gtk_box_pack_start (GTK_BOX (vbox57), checkbutton_filter_size_soft, FALSE, FALSE, 0);

  label228 = gtk_label_new (_("Flags"));
  gtk_widget_set_name (label228, "label228");
  gtk_widget_show (label228);
  gtk_frame_set_label_widget (GTK_FRAME (frame33), label228);

  frame22 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame22, "frame22");
  gtk_widget_show (frame22);
  gtk_box_pack_start (GTK_BOX (hbox122), frame22, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame22), 2);

  hbox119 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox119, "hbox119");
  gtk_widget_show (hbox119);
  gtk_container_add (GTK_CONTAINER (frame22), hbox119);

  table24 = gtk_table_new (3, 3, FALSE);
  gtk_widget_set_name (table24, "table24");
  gtk_widget_show (table24);
  gtk_box_pack_start (GTK_BOX (hbox119), table24, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (table24), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table24), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table24), 4);

  label192 = gtk_label_new (_("Minimum size:"));
  gtk_widget_set_name (label192, "label192");
  gtk_widget_show (label192);
  gtk_table_attach (GTK_TABLE (table24), label192, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label192), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label192), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label192), 4, 0);

  label193 = gtk_label_new (_("Maximum size:"));
  gtk_widget_set_name (label193, "label193");
  gtk_widget_show (label193);
  gtk_table_attach (GTK_TABLE (table24), label193, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label193), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label193), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label193), 4, 0);

  label194 = gtk_label_new (_("bytes"));
  gtk_widget_set_name (label194, "label194");
  gtk_widget_show (label194);
  gtk_table_attach (GTK_TABLE (table24), label194, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label194), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label194), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label194), 4, 0);

  label195 = gtk_label_new (_("bytes"));
  gtk_widget_set_name (label195, "label195");
  gtk_widget_show (label195);
  gtk_table_attach (GTK_TABLE (table24), label195, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label195), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label195), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label195), 4, 0);

  entry_filter_size_min = gtk_entry_new ();
  gtk_widget_set_name (entry_filter_size_min, "entry_filter_size_min");
  gtk_widget_show (entry_filter_size_min);
  gtk_table_attach (GTK_TABLE (table24), entry_filter_size_min, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_filter_size_max = gtk_entry_new ();
  gtk_widget_set_name (entry_filter_size_max, "entry_filter_size_max");
  gtk_widget_show (entry_filter_size_max);
  gtk_table_attach (GTK_TABLE (table24), entry_filter_size_max, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label916 = gtk_label_new (_("You can use suffixes such as KB, KiB, MB, MiB, GB, GiB etc."));
  gtk_widget_set_name (label916, "label916");
  gtk_widget_show (label916);
  gtk_table_attach (GTK_TABLE (table24), label916, 0, 3, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_line_wrap (GTK_LABEL (label916), TRUE);
  gtk_misc_set_alignment (GTK_MISC (label916), 0, 0.5);

  label229 = gtk_label_new (_("Condition: If file size matches"));
  gtk_widget_set_name (label229, "label229");
  gtk_widget_show (label229);
  gtk_frame_set_label_widget (GTK_FRAME (frame22), label229);

  hbox108 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox108, "hbox108");
  gtk_widget_show (hbox108);
  gtk_box_pack_start (GTK_BOX (vbox49), hbox108, FALSE, TRUE, 0);

  frame21 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame21, "frame21");
  gtk_widget_show (frame21);
  gtk_box_pack_start (GTK_BOX (hbox108), frame21, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame21), 2);

  optionmenu_filter_size_target = gtk_option_menu_new ();
  gtk_widget_set_name (optionmenu_filter_size_target, "optionmenu_filter_size_target");
  gtk_widget_show (optionmenu_filter_size_target);
  gtk_container_add (GTK_CONTAINER (frame21), optionmenu_filter_size_target);

  convertwidget36 = gtk_menu_new ();
  gtk_widget_set_name (convertwidget36, "convertwidget36");

  gtk_option_menu_set_menu (GTK_OPTION_MENU (optionmenu_filter_size_target), convertwidget36);

  label230 = gtk_label_new (_("Target"));
  gtk_widget_set_name (label230, "label230");
  gtk_widget_show (label230);
  gtk_frame_set_label_widget (GTK_FRAME (frame21), label230);

  vbox62 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox62, "vbox62");
  gtk_widget_show (vbox62);
  gtk_box_pack_start (GTK_BOX (hbox108), vbox62, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (vbox62), 2);

  button_filter_size_reset = gtk_button_new ();
  gtk_widget_set_name (button_filter_size_reset, "button_filter_size_reset");
  gtk_widget_show (button_filter_size_reset);
  gtk_box_pack_start (GTK_BOX (vbox62), button_filter_size_reset, FALSE, FALSE, 0);

  alignment120 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment120, "alignment120");
  gtk_widget_show (alignment120);
  gtk_container_add (GTK_CONTAINER (button_filter_size_reset), alignment120);

  hbox9313 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox9313, "hbox9313");
  gtk_widget_show (hbox9313);
  gtk_container_add (GTK_CONTAINER (alignment120), hbox9313);

  image1159 = gtk_image_new_from_stock ("gtk-refresh", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image1159, "image1159");
  gtk_widget_show (image1159);
  gtk_box_pack_start (GTK_BOX (hbox9313), image1159, FALSE, FALSE, 0);

  label967 = gtk_label_new_with_mnemonic (_("_Reset stats"));
  gtk_widget_set_name (label967, "label967");
  gtk_widget_show (label967);
  gtk_box_pack_start (GTK_BOX (hbox9313), label967, FALSE, FALSE, 0);

  hbox9309 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox9309, "hbox9309");
  gtk_widget_show (hbox9309);
  gtk_box_pack_start (GTK_BOX (vbox62), hbox9309, FALSE, FALSE, 0);

  button26 = gtk_button_new ();
  gtk_widget_set_name (button26, "button26");
  gtk_widget_show (button26);
  gtk_box_pack_start (GTK_BOX (hbox9309), button26, FALSE, FALSE, 0);

  alignment117 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment117, "alignment117");
  gtk_widget_show (alignment117);
  gtk_container_add (GTK_CONTAINER (button26), alignment117);

  hbox9310 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox9310, "hbox9310");
  gtk_widget_show (hbox9310);
  gtk_container_add (GTK_CONTAINER (alignment117), hbox9310);

  image1156 = gtk_image_new_from_stock ("gtk-save", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image1156, "image1156");
  gtk_widget_show (image1156);
  gtk_box_pack_start (GTK_BOX (hbox9310), image1156, FALSE, FALSE, 0);

  label964 = gtk_label_new_with_mnemonic (_("Save"));
  gtk_widget_set_name (label964, "label964");
  gtk_widget_show (label964);
  gtk_box_pack_start (GTK_BOX (hbox9310), label964, FALSE, FALSE, 0);

  button27 = gtk_button_new ();
  gtk_widget_set_name (button27, "button27");
  gtk_widget_show (button27);
  gtk_box_pack_start (GTK_BOX (hbox9309), button27, FALSE, FALSE, 0);

  alignment118 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment118, "alignment118");
  gtk_widget_show (alignment118);
  gtk_container_add (GTK_CONTAINER (button27), alignment118);

  hbox9311 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox9311, "hbox9311");
  gtk_widget_show (hbox9311);
  gtk_container_add (GTK_CONTAINER (alignment118), hbox9311);

  image1157 = gtk_image_new_from_stock ("gtk-delete", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image1157, "image1157");
  gtk_widget_show (image1157);
  gtk_box_pack_start (GTK_BOX (hbox9311), image1157, FALSE, FALSE, 0);

  label965 = gtk_label_new_with_mnemonic (_("Delete"));
  gtk_widget_set_name (label965, "label965");
  gtk_widget_show (label965);
  gtk_box_pack_start (GTK_BOX (hbox9311), label965, FALSE, FALSE, 0);

  button28 = gtk_button_new ();
  gtk_widget_set_name (button28, "button28");
  gtk_widget_show (button28);
  gtk_box_pack_start (GTK_BOX (hbox9309), button28, FALSE, FALSE, 0);

  alignment119 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment119, "alignment119");
  gtk_widget_show (alignment119);
  gtk_container_add (GTK_CONTAINER (button28), alignment119);

  hbox9312 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox9312, "hbox9312");
  gtk_widget_show (hbox9312);
  gtk_container_add (GTK_CONTAINER (alignment119), hbox9312);

  image1158 = gtk_image_new_from_stock ("gtk-cancel", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image1158, "image1158");
  gtk_widget_show (image1158);
  gtk_box_pack_start (GTK_BOX (hbox9312), image1158, FALSE, FALSE, 0);

  label966 = gtk_label_new_with_mnemonic (_("Abort"));
  gtk_widget_set_name (label966, "label966");
  gtk_widget_show (label966);
  gtk_box_pack_start (GTK_BOX (hbox9312), label966, FALSE, FALSE, 0);

  g_signal_connect ((gpointer) entry_filter_size_min, "focus_out_event",
                    G_CALLBACK (on_entry_filter_size_focus_out_event),
                    NULL);
  g_signal_connect ((gpointer) entry_filter_size_min, "key_press_event",
                    G_CALLBACK (on_entry_filter_size_key_press_event),
                    NULL);
  g_signal_connect ((gpointer) entry_filter_size_max, "focus_out_event",
                    G_CALLBACK (on_entry_filter_size_focus_out_event),
                    NULL);
  g_signal_connect ((gpointer) entry_filter_size_max, "key_press_event",
                    G_CALLBACK (on_entry_filter_size_key_press_event),
                    NULL);
  g_signal_connect ((gpointer) button_filter_size_reset, "clicked",
                    G_CALLBACK (on_button_filter_reset_rule_clicked),
                    NULL);
  g_signal_connect ((gpointer) button26, "clicked",
                    G_CALLBACK (on_button_filter_add_rule_clicked),
                    NULL);
  g_signal_connect ((gpointer) button27, "clicked",
                    G_CALLBACK (on_button_filter_remove_rule_clicked),
                    NULL);
  g_signal_connect ((gpointer) button28, "clicked",
                    G_CALLBACK (on_button_filter_abort_rule_clicked),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (dlg_filters_size_tab, dlg_filters_size_tab, "dlg_filters_size_tab");
  GLADE_HOOKUP_OBJECT (dlg_filters_size_tab, vbox49, "vbox49");
  GLADE_HOOKUP_OBJECT (dlg_filters_size_tab, alignment10, "alignment10");
  GLADE_HOOKUP_OBJECT (dlg_filters_size_tab, hbox122, "hbox122");
  GLADE_HOOKUP_OBJECT (dlg_filters_size_tab, frame33, "frame33");
  GLADE_HOOKUP_OBJECT (dlg_filters_size_tab, vbox57, "vbox57");
  GLADE_HOOKUP_OBJECT (dlg_filters_size_tab, checkbutton_filter_size_invert_cond, "checkbutton_filter_size_invert_cond");
  GLADE_HOOKUP_OBJECT (dlg_filters_size_tab, checkbutton_filter_size_active, "checkbutton_filter_size_active");
  GLADE_HOOKUP_OBJECT (dlg_filters_size_tab, checkbutton_filter_size_soft, "checkbutton_filter_size_soft");
  GLADE_HOOKUP_OBJECT (dlg_filters_size_tab, label228, "label228");
  GLADE_HOOKUP_OBJECT (dlg_filters_size_tab, frame22, "frame22");
  GLADE_HOOKUP_OBJECT (dlg_filters_size_tab, hbox119, "hbox119");
  GLADE_HOOKUP_OBJECT (dlg_filters_size_tab, table24, "table24");
  GLADE_HOOKUP_OBJECT (dlg_filters_size_tab, label192, "label192");
  GLADE_HOOKUP_OBJECT (dlg_filters_size_tab, label193, "label193");
  GLADE_HOOKUP_OBJECT (dlg_filters_size_tab, label194, "label194");
  GLADE_HOOKUP_OBJECT (dlg_filters_size_tab, label195, "label195");
  GLADE_HOOKUP_OBJECT (dlg_filters_size_tab, entry_filter_size_min, "entry_filter_size_min");
  GLADE_HOOKUP_OBJECT (dlg_filters_size_tab, entry_filter_size_max, "entry_filter_size_max");
  GLADE_HOOKUP_OBJECT (dlg_filters_size_tab, label916, "label916");
  GLADE_HOOKUP_OBJECT (dlg_filters_size_tab, label229, "label229");
  GLADE_HOOKUP_OBJECT (dlg_filters_size_tab, hbox108, "hbox108");
  GLADE_HOOKUP_OBJECT (dlg_filters_size_tab, frame21, "frame21");
  GLADE_HOOKUP_OBJECT (dlg_filters_size_tab, optionmenu_filter_size_target, "optionmenu_filter_size_target");
  GLADE_HOOKUP_OBJECT (dlg_filters_size_tab, convertwidget36, "convertwidget36");
  GLADE_HOOKUP_OBJECT (dlg_filters_size_tab, label230, "label230");
  GLADE_HOOKUP_OBJECT (dlg_filters_size_tab, vbox62, "vbox62");
  GLADE_HOOKUP_OBJECT (dlg_filters_size_tab, button_filter_size_reset, "button_filter_size_reset");
  GLADE_HOOKUP_OBJECT (dlg_filters_size_tab, alignment120, "alignment120");
  GLADE_HOOKUP_OBJECT (dlg_filters_size_tab, hbox9313, "hbox9313");
  GLADE_HOOKUP_OBJECT (dlg_filters_size_tab, image1159, "image1159");
  GLADE_HOOKUP_OBJECT (dlg_filters_size_tab, label967, "label967");
  GLADE_HOOKUP_OBJECT (dlg_filters_size_tab, hbox9309, "hbox9309");
  GLADE_HOOKUP_OBJECT (dlg_filters_size_tab, button26, "button26");
  GLADE_HOOKUP_OBJECT (dlg_filters_size_tab, alignment117, "alignment117");
  GLADE_HOOKUP_OBJECT (dlg_filters_size_tab, hbox9310, "hbox9310");
  GLADE_HOOKUP_OBJECT (dlg_filters_size_tab, image1156, "image1156");
  GLADE_HOOKUP_OBJECT (dlg_filters_size_tab, label964, "label964");
  GLADE_HOOKUP_OBJECT (dlg_filters_size_tab, button27, "button27");
  GLADE_HOOKUP_OBJECT (dlg_filters_size_tab, alignment118, "alignment118");
  GLADE_HOOKUP_OBJECT (dlg_filters_size_tab, hbox9311, "hbox9311");
  GLADE_HOOKUP_OBJECT (dlg_filters_size_tab, image1157, "image1157");
  GLADE_HOOKUP_OBJECT (dlg_filters_size_tab, label965, "label965");
  GLADE_HOOKUP_OBJECT (dlg_filters_size_tab, button28, "button28");
  GLADE_HOOKUP_OBJECT (dlg_filters_size_tab, alignment119, "alignment119");
  GLADE_HOOKUP_OBJECT (dlg_filters_size_tab, hbox9312, "hbox9312");
  GLADE_HOOKUP_OBJECT (dlg_filters_size_tab, image1158, "image1158");
  GLADE_HOOKUP_OBJECT (dlg_filters_size_tab, label966, "label966");

  return dlg_filters_size_tab;
}

GtkWidget*
create_dlg_filters_jump_tab (void)
{
  GtkWidget *dlg_filters_jump_tab;
  GtkWidget *vbox54;
  GtkWidget *alignment24;
  GtkWidget *hbox123;
  GtkWidget *frame34;
  GtkWidget *vbox58;
  GtkWidget *checkbutton_filter_jump_active;
  GtkWidget *label231;
  GtkWidget *frame29;
  GtkWidget *hbox115;
  GtkWidget *label209;
  GtkWidget *label232;
  GtkWidget *alignment17;
  GtkWidget *hbox114;
  GtkWidget *frame28;
  GtkWidget *optionmenu_filter_jump_target;
  GtkWidget *convertwidget37;
  GtkWidget *label233;
  GtkWidget *vbox63;
  GtkWidget *button_filter_jump_reset;
  GtkWidget *alignment126;
  GtkWidget *hbox9320;
  GtkWidget *image1165;
  GtkWidget *label973;
  GtkWidget *hbox9316;
  GtkWidget *button29;
  GtkWidget *alignment123;
  GtkWidget *hbox9317;
  GtkWidget *image1162;
  GtkWidget *label970;
  GtkWidget *button30;
  GtkWidget *alignment124;
  GtkWidget *hbox9318;
  GtkWidget *image1163;
  GtkWidget *label971;
  GtkWidget *button31;
  GtkWidget *alignment125;
  GtkWidget *hbox9319;
  GtkWidget *image1164;
  GtkWidget *label972;

  dlg_filters_jump_tab = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_widget_set_name (dlg_filters_jump_tab, "dlg_filters_jump_tab");

  vbox54 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox54, "vbox54");
  gtk_widget_show (vbox54);
  gtk_container_add (GTK_CONTAINER (dlg_filters_jump_tab), vbox54);

  alignment24 = gtk_alignment_new (0.5, 7.45058e-09, 1, 1);
  gtk_widget_set_name (alignment24, "alignment24");
  gtk_widget_show (alignment24);
  gtk_box_pack_start (GTK_BOX (vbox54), alignment24, TRUE, TRUE, 0);

  hbox123 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox123, "hbox123");
  gtk_widget_show (hbox123);
  gtk_container_add (GTK_CONTAINER (alignment24), hbox123);

  frame34 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame34, "frame34");
  gtk_widget_show (frame34);
  gtk_box_pack_start (GTK_BOX (hbox123), frame34, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame34), 2);

  vbox58 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox58, "vbox58");
  gtk_widget_show (vbox58);
  gtk_container_add (GTK_CONTAINER (frame34), vbox58);

  checkbutton_filter_jump_active = gtk_check_button_new_with_mnemonic (_("active"));
  gtk_widget_set_name (checkbutton_filter_jump_active, "checkbutton_filter_jump_active");
  gtk_widget_show (checkbutton_filter_jump_active);
  gtk_box_pack_start (GTK_BOX (vbox58), checkbutton_filter_jump_active, FALSE, FALSE, 0);

  label231 = gtk_label_new (_("Flags"));
  gtk_widget_set_name (label231, "label231");
  gtk_widget_show (label231);
  gtk_frame_set_label_widget (GTK_FRAME (frame34), label231);

  frame29 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame29, "frame29");
  gtk_widget_show (frame29);
  gtk_box_pack_start (GTK_BOX (hbox123), frame29, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame29), 2);

  hbox115 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox115, "hbox115");
  gtk_widget_show (hbox115);
  gtk_container_add (GTK_CONTAINER (frame29), hbox115);
  gtk_container_set_border_width (GTK_CONTAINER (hbox115), 2);

  label209 = gtk_label_new (_("There is no condition. When this rule is reached, the matching will continue in the specified target filter. That's also why you can't invert this condition. If you could, this rule would just be ignored."));
  gtk_widget_set_name (label209, "label209");
  gtk_widget_show (label209);
  gtk_box_pack_start (GTK_BOX (hbox115), label209, TRUE, TRUE, 0);
  gtk_label_set_justify (GTK_LABEL (label209), GTK_JUSTIFY_FILL);
  gtk_label_set_line_wrap (GTK_LABEL (label209), TRUE);

  label232 = gtk_label_new (_("Condition: always"));
  gtk_widget_set_name (label232, "label232");
  gtk_widget_show (label232);
  gtk_frame_set_label_widget (GTK_FRAME (frame29), label232);

  alignment17 = gtk_alignment_new (0.5, 1, 1, 0);
  gtk_widget_set_name (alignment17, "alignment17");
  gtk_widget_show (alignment17);
  gtk_box_pack_start (GTK_BOX (vbox54), alignment17, TRUE, TRUE, 0);

  hbox114 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox114, "hbox114");
  gtk_widget_show (hbox114);
  gtk_container_add (GTK_CONTAINER (alignment17), hbox114);

  frame28 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame28, "frame28");
  gtk_widget_show (frame28);
  gtk_box_pack_start (GTK_BOX (hbox114), frame28, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame28), 2);

  optionmenu_filter_jump_target = gtk_option_menu_new ();
  gtk_widget_set_name (optionmenu_filter_jump_target, "optionmenu_filter_jump_target");
  gtk_widget_show (optionmenu_filter_jump_target);
  gtk_container_add (GTK_CONTAINER (frame28), optionmenu_filter_jump_target);

  convertwidget37 = gtk_menu_new ();
  gtk_widget_set_name (convertwidget37, "convertwidget37");

  gtk_option_menu_set_menu (GTK_OPTION_MENU (optionmenu_filter_jump_target), convertwidget37);

  label233 = gtk_label_new (_("Target"));
  gtk_widget_set_name (label233, "label233");
  gtk_widget_show (label233);
  gtk_frame_set_label_widget (GTK_FRAME (frame28), label233);

  vbox63 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox63, "vbox63");
  gtk_widget_show (vbox63);
  gtk_box_pack_start (GTK_BOX (hbox114), vbox63, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (vbox63), 2);

  button_filter_jump_reset = gtk_button_new ();
  gtk_widget_set_name (button_filter_jump_reset, "button_filter_jump_reset");
  gtk_widget_show (button_filter_jump_reset);
  gtk_box_pack_start (GTK_BOX (vbox63), button_filter_jump_reset, FALSE, FALSE, 0);

  alignment126 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment126, "alignment126");
  gtk_widget_show (alignment126);
  gtk_container_add (GTK_CONTAINER (button_filter_jump_reset), alignment126);

  hbox9320 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox9320, "hbox9320");
  gtk_widget_show (hbox9320);
  gtk_container_add (GTK_CONTAINER (alignment126), hbox9320);

  image1165 = gtk_image_new_from_stock ("gtk-refresh", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image1165, "image1165");
  gtk_widget_show (image1165);
  gtk_box_pack_start (GTK_BOX (hbox9320), image1165, FALSE, FALSE, 0);

  label973 = gtk_label_new_with_mnemonic (_("_Reset stats"));
  gtk_widget_set_name (label973, "label973");
  gtk_widget_show (label973);
  gtk_box_pack_start (GTK_BOX (hbox9320), label973, FALSE, FALSE, 0);

  hbox9316 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox9316, "hbox9316");
  gtk_widget_show (hbox9316);
  gtk_box_pack_start (GTK_BOX (vbox63), hbox9316, FALSE, FALSE, 0);

  button29 = gtk_button_new ();
  gtk_widget_set_name (button29, "button29");
  gtk_widget_show (button29);
  gtk_box_pack_start (GTK_BOX (hbox9316), button29, FALSE, FALSE, 0);

  alignment123 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment123, "alignment123");
  gtk_widget_show (alignment123);
  gtk_container_add (GTK_CONTAINER (button29), alignment123);

  hbox9317 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox9317, "hbox9317");
  gtk_widget_show (hbox9317);
  gtk_container_add (GTK_CONTAINER (alignment123), hbox9317);

  image1162 = gtk_image_new_from_stock ("gtk-save", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image1162, "image1162");
  gtk_widget_show (image1162);
  gtk_box_pack_start (GTK_BOX (hbox9317), image1162, FALSE, FALSE, 0);

  label970 = gtk_label_new_with_mnemonic (_("Save"));
  gtk_widget_set_name (label970, "label970");
  gtk_widget_show (label970);
  gtk_box_pack_start (GTK_BOX (hbox9317), label970, FALSE, FALSE, 0);

  button30 = gtk_button_new ();
  gtk_widget_set_name (button30, "button30");
  gtk_widget_show (button30);
  gtk_box_pack_start (GTK_BOX (hbox9316), button30, FALSE, FALSE, 0);

  alignment124 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment124, "alignment124");
  gtk_widget_show (alignment124);
  gtk_container_add (GTK_CONTAINER (button30), alignment124);

  hbox9318 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox9318, "hbox9318");
  gtk_widget_show (hbox9318);
  gtk_container_add (GTK_CONTAINER (alignment124), hbox9318);

  image1163 = gtk_image_new_from_stock ("gtk-delete", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image1163, "image1163");
  gtk_widget_show (image1163);
  gtk_box_pack_start (GTK_BOX (hbox9318), image1163, FALSE, FALSE, 0);

  label971 = gtk_label_new_with_mnemonic (_("Delete"));
  gtk_widget_set_name (label971, "label971");
  gtk_widget_show (label971);
  gtk_box_pack_start (GTK_BOX (hbox9318), label971, FALSE, FALSE, 0);

  button31 = gtk_button_new ();
  gtk_widget_set_name (button31, "button31");
  gtk_widget_show (button31);
  gtk_box_pack_start (GTK_BOX (hbox9316), button31, FALSE, FALSE, 0);

  alignment125 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment125, "alignment125");
  gtk_widget_show (alignment125);
  gtk_container_add (GTK_CONTAINER (button31), alignment125);

  hbox9319 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox9319, "hbox9319");
  gtk_widget_show (hbox9319);
  gtk_container_add (GTK_CONTAINER (alignment125), hbox9319);

  image1164 = gtk_image_new_from_stock ("gtk-cancel", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image1164, "image1164");
  gtk_widget_show (image1164);
  gtk_box_pack_start (GTK_BOX (hbox9319), image1164, FALSE, FALSE, 0);

  label972 = gtk_label_new_with_mnemonic (_("Abort"));
  gtk_widget_set_name (label972, "label972");
  gtk_widget_show (label972);
  gtk_box_pack_start (GTK_BOX (hbox9319), label972, FALSE, FALSE, 0);

  g_signal_connect ((gpointer) button_filter_jump_reset, "clicked",
                    G_CALLBACK (on_button_filter_reset_rule_clicked),
                    NULL);
  g_signal_connect ((gpointer) button29, "clicked",
                    G_CALLBACK (on_button_filter_add_rule_clicked),
                    NULL);
  g_signal_connect ((gpointer) button30, "clicked",
                    G_CALLBACK (on_button_filter_remove_rule_clicked),
                    NULL);
  g_signal_connect ((gpointer) button31, "clicked",
                    G_CALLBACK (on_button_filter_abort_rule_clicked),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (dlg_filters_jump_tab, dlg_filters_jump_tab, "dlg_filters_jump_tab");
  GLADE_HOOKUP_OBJECT (dlg_filters_jump_tab, vbox54, "vbox54");
  GLADE_HOOKUP_OBJECT (dlg_filters_jump_tab, alignment24, "alignment24");
  GLADE_HOOKUP_OBJECT (dlg_filters_jump_tab, hbox123, "hbox123");
  GLADE_HOOKUP_OBJECT (dlg_filters_jump_tab, frame34, "frame34");
  GLADE_HOOKUP_OBJECT (dlg_filters_jump_tab, vbox58, "vbox58");
  GLADE_HOOKUP_OBJECT (dlg_filters_jump_tab, checkbutton_filter_jump_active, "checkbutton_filter_jump_active");
  GLADE_HOOKUP_OBJECT (dlg_filters_jump_tab, label231, "label231");
  GLADE_HOOKUP_OBJECT (dlg_filters_jump_tab, frame29, "frame29");
  GLADE_HOOKUP_OBJECT (dlg_filters_jump_tab, hbox115, "hbox115");
  GLADE_HOOKUP_OBJECT (dlg_filters_jump_tab, label209, "label209");
  GLADE_HOOKUP_OBJECT (dlg_filters_jump_tab, label232, "label232");
  GLADE_HOOKUP_OBJECT (dlg_filters_jump_tab, alignment17, "alignment17");
  GLADE_HOOKUP_OBJECT (dlg_filters_jump_tab, hbox114, "hbox114");
  GLADE_HOOKUP_OBJECT (dlg_filters_jump_tab, frame28, "frame28");
  GLADE_HOOKUP_OBJECT (dlg_filters_jump_tab, optionmenu_filter_jump_target, "optionmenu_filter_jump_target");
  GLADE_HOOKUP_OBJECT (dlg_filters_jump_tab, convertwidget37, "convertwidget37");
  GLADE_HOOKUP_OBJECT (dlg_filters_jump_tab, label233, "label233");
  GLADE_HOOKUP_OBJECT (dlg_filters_jump_tab, vbox63, "vbox63");
  GLADE_HOOKUP_OBJECT (dlg_filters_jump_tab, button_filter_jump_reset, "button_filter_jump_reset");
  GLADE_HOOKUP_OBJECT (dlg_filters_jump_tab, alignment126, "alignment126");
  GLADE_HOOKUP_OBJECT (dlg_filters_jump_tab, hbox9320, "hbox9320");
  GLADE_HOOKUP_OBJECT (dlg_filters_jump_tab, image1165, "image1165");
  GLADE_HOOKUP_OBJECT (dlg_filters_jump_tab, label973, "label973");
  GLADE_HOOKUP_OBJECT (dlg_filters_jump_tab, hbox9316, "hbox9316");
  GLADE_HOOKUP_OBJECT (dlg_filters_jump_tab, button29, "button29");
  GLADE_HOOKUP_OBJECT (dlg_filters_jump_tab, alignment123, "alignment123");
  GLADE_HOOKUP_OBJECT (dlg_filters_jump_tab, hbox9317, "hbox9317");
  GLADE_HOOKUP_OBJECT (dlg_filters_jump_tab, image1162, "image1162");
  GLADE_HOOKUP_OBJECT (dlg_filters_jump_tab, label970, "label970");
  GLADE_HOOKUP_OBJECT (dlg_filters_jump_tab, button30, "button30");
  GLADE_HOOKUP_OBJECT (dlg_filters_jump_tab, alignment124, "alignment124");
  GLADE_HOOKUP_OBJECT (dlg_filters_jump_tab, hbox9318, "hbox9318");
  GLADE_HOOKUP_OBJECT (dlg_filters_jump_tab, image1163, "image1163");
  GLADE_HOOKUP_OBJECT (dlg_filters_jump_tab, label971, "label971");
  GLADE_HOOKUP_OBJECT (dlg_filters_jump_tab, button31, "button31");
  GLADE_HOOKUP_OBJECT (dlg_filters_jump_tab, alignment125, "alignment125");
  GLADE_HOOKUP_OBJECT (dlg_filters_jump_tab, hbox9319, "hbox9319");
  GLADE_HOOKUP_OBJECT (dlg_filters_jump_tab, image1164, "image1164");
  GLADE_HOOKUP_OBJECT (dlg_filters_jump_tab, label972, "label972");

  return dlg_filters_jump_tab;
}

GtkWidget*
create_dlg_filters_sha1_tab (void)
{
  GtkWidget *dlg_filters_sha1_tab;
  GtkWidget *vbox64;
  GtkWidget *alignment20;
  GtkWidget *hbox126;
  GtkWidget *frame35;
  GtkWidget *vbox65;
  GtkWidget *checkbutton_filter_sha1_invert_cond;
  GtkWidget *checkbutton_filter_sha1_active;
  GtkWidget *checkbutton_filter_sha1_soft;
  GtkWidget *label234;
  GtkWidget *frame36;
  GtkWidget *hbox127;
  GtkWidget *table25;
  GtkWidget *label226;
  GtkWidget *entry_filter_sha1_hash;
  GtkWidget *hbox132;
  GtkWidget *label245;
  GtkWidget *entry_filter_sha1_origfile;
  GtkWidget *label235;
  GtkWidget *hbox128;
  GtkWidget *frame37;
  GtkWidget *optionmenu_filter_sha1_target;
  GtkWidget *convertwidget38;
  GtkWidget *label246;
  GtkWidget *vbox66;
  GtkWidget *button_filter_sha1_reset;
  GtkWidget *alignment130;
  GtkWidget *hbox9325;
  GtkWidget *image1169;
  GtkWidget *label977;
  GtkWidget *hbox9321;
  GtkWidget *button32;
  GtkWidget *alignment127;
  GtkWidget *hbox9322;
  GtkWidget *image1166;
  GtkWidget *label974;
  GtkWidget *button33;
  GtkWidget *alignment128;
  GtkWidget *hbox9323;
  GtkWidget *image1167;
  GtkWidget *label975;
  GtkWidget *button34;
  GtkWidget *alignment129;
  GtkWidget *hbox9324;
  GtkWidget *image1168;
  GtkWidget *label976;

  dlg_filters_sha1_tab = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_widget_set_name (dlg_filters_sha1_tab, "dlg_filters_sha1_tab");

  vbox64 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox64, "vbox64");
  gtk_widget_show (vbox64);
  gtk_container_add (GTK_CONTAINER (dlg_filters_sha1_tab), vbox64);

  alignment20 = gtk_alignment_new (0.5, 0, 1, 1);
  gtk_widget_set_name (alignment20, "alignment20");
  gtk_widget_show (alignment20);
  gtk_box_pack_start (GTK_BOX (vbox64), alignment20, TRUE, TRUE, 0);

  hbox126 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox126, "hbox126");
  gtk_widget_show (hbox126);
  gtk_container_add (GTK_CONTAINER (alignment20), hbox126);

  frame35 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame35, "frame35");
  gtk_widget_show (frame35);
  gtk_box_pack_start (GTK_BOX (hbox126), frame35, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame35), 2);

  vbox65 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox65, "vbox65");
  gtk_widget_show (vbox65);
  gtk_container_add (GTK_CONTAINER (frame35), vbox65);

  checkbutton_filter_sha1_invert_cond = gtk_check_button_new_with_mnemonic (_("invert condition"));
  gtk_widget_set_name (checkbutton_filter_sha1_invert_cond, "checkbutton_filter_sha1_invert_cond");
  gtk_box_pack_start (GTK_BOX (vbox65), checkbutton_filter_sha1_invert_cond, FALSE, FALSE, 0);

  checkbutton_filter_sha1_active = gtk_check_button_new_with_mnemonic (_("active"));
  gtk_widget_set_name (checkbutton_filter_sha1_active, "checkbutton_filter_sha1_active");
  gtk_widget_show (checkbutton_filter_sha1_active);
  gtk_box_pack_start (GTK_BOX (vbox65), checkbutton_filter_sha1_active, FALSE, FALSE, 0);
  gtk_widget_set_sensitive (checkbutton_filter_sha1_active, FALSE);

  checkbutton_filter_sha1_soft = gtk_check_button_new_with_mnemonic (_("mark only"));
  gtk_widget_set_name (checkbutton_filter_sha1_soft, "checkbutton_filter_sha1_soft");
  gtk_box_pack_start (GTK_BOX (vbox65), checkbutton_filter_sha1_soft, FALSE, FALSE, 0);

  label234 = gtk_label_new (_("Flags"));
  gtk_widget_set_name (label234, "label234");
  gtk_widget_show (label234);
  gtk_frame_set_label_widget (GTK_FRAME (frame35), label234);

  frame36 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame36, "frame36");
  gtk_widget_show (frame36);
  gtk_box_pack_start (GTK_BOX (hbox126), frame36, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame36), 2);

  hbox127 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox127, "hbox127");
  gtk_widget_show (hbox127);
  gtk_container_add (GTK_CONTAINER (frame36), hbox127);

  table25 = gtk_table_new (3, 1, FALSE);
  gtk_widget_set_name (table25, "table25");
  gtk_widget_show (table25);
  gtk_box_pack_start (GTK_BOX (hbox127), table25, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (table25), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table25), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table25), 4);

  label226 = gtk_label_new (_("SHA1 hash (not editable, add from search popup)"));
  gtk_widget_set_name (label226, "label226");
  gtk_widget_show (label226);
  gtk_table_attach (GTK_TABLE (table25), label226, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label226), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label226), 0, 0.5);

  entry_filter_sha1_hash = gtk_entry_new ();
  gtk_widget_set_name (entry_filter_sha1_hash, "entry_filter_sha1_hash");
  gtk_widget_show (entry_filter_sha1_hash);
  gtk_table_attach (GTK_TABLE (table25), entry_filter_sha1_hash, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_editable_set_editable (GTK_EDITABLE (entry_filter_sha1_hash), FALSE);

  hbox132 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox132, "hbox132");
  gtk_widget_show (hbox132);
  gtk_table_attach (GTK_TABLE (table25), hbox132, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  label245 = gtk_label_new (_("Originally obtained from"));
  gtk_widget_set_name (label245, "label245");
  gtk_widget_show (label245);
  gtk_box_pack_start (GTK_BOX (hbox132), label245, FALSE, FALSE, 0);
  gtk_label_set_justify (GTK_LABEL (label245), GTK_JUSTIFY_CENTER);

  entry_filter_sha1_origfile = gtk_entry_new ();
  gtk_widget_set_name (entry_filter_sha1_origfile, "entry_filter_sha1_origfile");
  gtk_widget_show (entry_filter_sha1_origfile);
  gtk_box_pack_start (GTK_BOX (hbox132), entry_filter_sha1_origfile, TRUE, TRUE, 0);
  gtk_editable_set_editable (GTK_EDITABLE (entry_filter_sha1_origfile), FALSE);

  label235 = gtk_label_new (_("Condition: If urn:sha1 matches"));
  gtk_widget_set_name (label235, "label235");
  gtk_widget_show (label235);
  gtk_frame_set_label_widget (GTK_FRAME (frame36), label235);

  hbox128 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox128, "hbox128");
  gtk_widget_show (hbox128);
  gtk_box_pack_start (GTK_BOX (vbox64), hbox128, FALSE, FALSE, 0);

  frame37 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame37, "frame37");
  gtk_widget_show (frame37);
  gtk_box_pack_start (GTK_BOX (hbox128), frame37, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame37), 2);

  optionmenu_filter_sha1_target = gtk_option_menu_new ();
  gtk_widget_set_name (optionmenu_filter_sha1_target, "optionmenu_filter_sha1_target");
  gtk_widget_show (optionmenu_filter_sha1_target);
  gtk_container_add (GTK_CONTAINER (frame37), optionmenu_filter_sha1_target);
  gtk_widget_set_sensitive (optionmenu_filter_sha1_target, FALSE);

  convertwidget38 = gtk_menu_new ();
  gtk_widget_set_name (convertwidget38, "convertwidget38");

  gtk_option_menu_set_menu (GTK_OPTION_MENU (optionmenu_filter_sha1_target), convertwidget38);

  label246 = gtk_label_new (_("Target"));
  gtk_widget_set_name (label246, "label246");
  gtk_widget_show (label246);
  gtk_frame_set_label_widget (GTK_FRAME (frame37), label246);

  vbox66 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox66, "vbox66");
  gtk_widget_show (vbox66);
  gtk_box_pack_start (GTK_BOX (hbox128), vbox66, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (vbox66), 2);

  button_filter_sha1_reset = gtk_button_new ();
  gtk_widget_set_name (button_filter_sha1_reset, "button_filter_sha1_reset");
  gtk_widget_show (button_filter_sha1_reset);
  gtk_box_pack_start (GTK_BOX (vbox66), button_filter_sha1_reset, FALSE, FALSE, 0);

  alignment130 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment130, "alignment130");
  gtk_widget_show (alignment130);
  gtk_container_add (GTK_CONTAINER (button_filter_sha1_reset), alignment130);

  hbox9325 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox9325, "hbox9325");
  gtk_widget_show (hbox9325);
  gtk_container_add (GTK_CONTAINER (alignment130), hbox9325);

  image1169 = gtk_image_new_from_stock ("gtk-refresh", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image1169, "image1169");
  gtk_widget_show (image1169);
  gtk_box_pack_start (GTK_BOX (hbox9325), image1169, FALSE, FALSE, 0);

  label977 = gtk_label_new_with_mnemonic (_("_Reset stats"));
  gtk_widget_set_name (label977, "label977");
  gtk_widget_show (label977);
  gtk_box_pack_start (GTK_BOX (hbox9325), label977, FALSE, FALSE, 0);

  hbox9321 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox9321, "hbox9321");
  gtk_widget_show (hbox9321);
  gtk_box_pack_start (GTK_BOX (vbox66), hbox9321, FALSE, FALSE, 0);

  button32 = gtk_button_new ();
  gtk_widget_set_name (button32, "button32");
  gtk_widget_show (button32);
  gtk_box_pack_start (GTK_BOX (hbox9321), button32, FALSE, FALSE, 0);

  alignment127 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment127, "alignment127");
  gtk_widget_show (alignment127);
  gtk_container_add (GTK_CONTAINER (button32), alignment127);

  hbox9322 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox9322, "hbox9322");
  gtk_widget_show (hbox9322);
  gtk_container_add (GTK_CONTAINER (alignment127), hbox9322);

  image1166 = gtk_image_new_from_stock ("gtk-save", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image1166, "image1166");
  gtk_widget_show (image1166);
  gtk_box_pack_start (GTK_BOX (hbox9322), image1166, FALSE, FALSE, 0);

  label974 = gtk_label_new_with_mnemonic (_("Save"));
  gtk_widget_set_name (label974, "label974");
  gtk_widget_show (label974);
  gtk_box_pack_start (GTK_BOX (hbox9322), label974, FALSE, FALSE, 0);

  button33 = gtk_button_new ();
  gtk_widget_set_name (button33, "button33");
  gtk_widget_show (button33);
  gtk_box_pack_start (GTK_BOX (hbox9321), button33, FALSE, FALSE, 0);

  alignment128 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment128, "alignment128");
  gtk_widget_show (alignment128);
  gtk_container_add (GTK_CONTAINER (button33), alignment128);

  hbox9323 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox9323, "hbox9323");
  gtk_widget_show (hbox9323);
  gtk_container_add (GTK_CONTAINER (alignment128), hbox9323);

  image1167 = gtk_image_new_from_stock ("gtk-delete", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image1167, "image1167");
  gtk_widget_show (image1167);
  gtk_box_pack_start (GTK_BOX (hbox9323), image1167, FALSE, FALSE, 0);

  label975 = gtk_label_new_with_mnemonic (_("Delete"));
  gtk_widget_set_name (label975, "label975");
  gtk_widget_show (label975);
  gtk_box_pack_start (GTK_BOX (hbox9323), label975, FALSE, FALSE, 0);

  button34 = gtk_button_new ();
  gtk_widget_set_name (button34, "button34");
  gtk_widget_show (button34);
  gtk_box_pack_start (GTK_BOX (hbox9321), button34, FALSE, FALSE, 0);

  alignment129 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment129, "alignment129");
  gtk_widget_show (alignment129);
  gtk_container_add (GTK_CONTAINER (button34), alignment129);

  hbox9324 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox9324, "hbox9324");
  gtk_widget_show (hbox9324);
  gtk_container_add (GTK_CONTAINER (alignment129), hbox9324);

  image1168 = gtk_image_new_from_stock ("gtk-cancel", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image1168, "image1168");
  gtk_widget_show (image1168);
  gtk_box_pack_start (GTK_BOX (hbox9324), image1168, FALSE, FALSE, 0);

  label976 = gtk_label_new_with_mnemonic (_("Abort"));
  gtk_widget_set_name (label976, "label976");
  gtk_widget_show (label976);
  gtk_box_pack_start (GTK_BOX (hbox9324), label976, FALSE, FALSE, 0);

  g_signal_connect ((gpointer) button_filter_sha1_reset, "clicked",
                    G_CALLBACK (on_button_filter_reset_rule_clicked),
                    NULL);
  g_signal_connect ((gpointer) button32, "clicked",
                    G_CALLBACK (on_button_filter_add_rule_clicked),
                    NULL);
  g_signal_connect ((gpointer) button33, "clicked",
                    G_CALLBACK (on_button_filter_remove_rule_clicked),
                    NULL);
  g_signal_connect ((gpointer) button34, "clicked",
                    G_CALLBACK (on_button_filter_abort_rule_clicked),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (dlg_filters_sha1_tab, dlg_filters_sha1_tab, "dlg_filters_sha1_tab");
  GLADE_HOOKUP_OBJECT (dlg_filters_sha1_tab, vbox64, "vbox64");
  GLADE_HOOKUP_OBJECT (dlg_filters_sha1_tab, alignment20, "alignment20");
  GLADE_HOOKUP_OBJECT (dlg_filters_sha1_tab, hbox126, "hbox126");
  GLADE_HOOKUP_OBJECT (dlg_filters_sha1_tab, frame35, "frame35");
  GLADE_HOOKUP_OBJECT (dlg_filters_sha1_tab, vbox65, "vbox65");
  GLADE_HOOKUP_OBJECT (dlg_filters_sha1_tab, checkbutton_filter_sha1_invert_cond, "checkbutton_filter_sha1_invert_cond");
  GLADE_HOOKUP_OBJECT (dlg_filters_sha1_tab, checkbutton_filter_sha1_active, "checkbutton_filter_sha1_active");
  GLADE_HOOKUP_OBJECT (dlg_filters_sha1_tab, checkbutton_filter_sha1_soft, "checkbutton_filter_sha1_soft");
  GLADE_HOOKUP_OBJECT (dlg_filters_sha1_tab, label234, "label234");
  GLADE_HOOKUP_OBJECT (dlg_filters_sha1_tab, frame36, "frame36");
  GLADE_HOOKUP_OBJECT (dlg_filters_sha1_tab, hbox127, "hbox127");
  GLADE_HOOKUP_OBJECT (dlg_filters_sha1_tab, table25, "table25");
  GLADE_HOOKUP_OBJECT (dlg_filters_sha1_tab, label226, "label226");
  GLADE_HOOKUP_OBJECT (dlg_filters_sha1_tab, entry_filter_sha1_hash, "entry_filter_sha1_hash");
  GLADE_HOOKUP_OBJECT (dlg_filters_sha1_tab, hbox132, "hbox132");
  GLADE_HOOKUP_OBJECT (dlg_filters_sha1_tab, label245, "label245");
  GLADE_HOOKUP_OBJECT (dlg_filters_sha1_tab, entry_filter_sha1_origfile, "entry_filter_sha1_origfile");
  GLADE_HOOKUP_OBJECT (dlg_filters_sha1_tab, label235, "label235");
  GLADE_HOOKUP_OBJECT (dlg_filters_sha1_tab, hbox128, "hbox128");
  GLADE_HOOKUP_OBJECT (dlg_filters_sha1_tab, frame37, "frame37");
  GLADE_HOOKUP_OBJECT (dlg_filters_sha1_tab, optionmenu_filter_sha1_target, "optionmenu_filter_sha1_target");
  GLADE_HOOKUP_OBJECT (dlg_filters_sha1_tab, convertwidget38, "convertwidget38");
  GLADE_HOOKUP_OBJECT (dlg_filters_sha1_tab, label246, "label246");
  GLADE_HOOKUP_OBJECT (dlg_filters_sha1_tab, vbox66, "vbox66");
  GLADE_HOOKUP_OBJECT (dlg_filters_sha1_tab, button_filter_sha1_reset, "button_filter_sha1_reset");
  GLADE_HOOKUP_OBJECT (dlg_filters_sha1_tab, alignment130, "alignment130");
  GLADE_HOOKUP_OBJECT (dlg_filters_sha1_tab, hbox9325, "hbox9325");
  GLADE_HOOKUP_OBJECT (dlg_filters_sha1_tab, image1169, "image1169");
  GLADE_HOOKUP_OBJECT (dlg_filters_sha1_tab, label977, "label977");
  GLADE_HOOKUP_OBJECT (dlg_filters_sha1_tab, hbox9321, "hbox9321");
  GLADE_HOOKUP_OBJECT (dlg_filters_sha1_tab, button32, "button32");
  GLADE_HOOKUP_OBJECT (dlg_filters_sha1_tab, alignment127, "alignment127");
  GLADE_HOOKUP_OBJECT (dlg_filters_sha1_tab, hbox9322, "hbox9322");
  GLADE_HOOKUP_OBJECT (dlg_filters_sha1_tab, image1166, "image1166");
  GLADE_HOOKUP_OBJECT (dlg_filters_sha1_tab, label974, "label974");
  GLADE_HOOKUP_OBJECT (dlg_filters_sha1_tab, button33, "button33");
  GLADE_HOOKUP_OBJECT (dlg_filters_sha1_tab, alignment128, "alignment128");
  GLADE_HOOKUP_OBJECT (dlg_filters_sha1_tab, hbox9323, "hbox9323");
  GLADE_HOOKUP_OBJECT (dlg_filters_sha1_tab, image1167, "image1167");
  GLADE_HOOKUP_OBJECT (dlg_filters_sha1_tab, label975, "label975");
  GLADE_HOOKUP_OBJECT (dlg_filters_sha1_tab, button34, "button34");
  GLADE_HOOKUP_OBJECT (dlg_filters_sha1_tab, alignment129, "alignment129");
  GLADE_HOOKUP_OBJECT (dlg_filters_sha1_tab, hbox9324, "hbox9324");
  GLADE_HOOKUP_OBJECT (dlg_filters_sha1_tab, image1168, "image1168");
  GLADE_HOOKUP_OBJECT (dlg_filters_sha1_tab, label976, "label976");

  return dlg_filters_sha1_tab;
}

GtkWidget*
create_dlg_filters_flags_tab (void)
{
  GtkWidget *dlg_filters_flags_tab;
  GtkWidget *vbox68;
  GtkWidget *alignment21;
  GtkWidget *hbox129;
  GtkWidget *frame38;
  GtkWidget *vbox69;
  GtkWidget *checkbutton_filter_flag_active;
  GtkWidget *checkbutton_filter_flag_soft;
  GtkWidget *label247;
  GtkWidget *frame39;
  GtkWidget *hbox130;
  GtkWidget *table26;
  GtkWidget *label_d230;
  GtkWidget *label_d231;
  GtkWidget *radiobutton_filter_flag_busy_ignore;
  GSList *radiobutton_filter_flag_busy_ignore_group = NULL;
  GtkWidget *alignment47;
  GtkWidget *hbox179;
  GtkWidget *image79;
  GtkWidget *label444;
  GtkWidget *radiobutton_filter_flag_push_ignore;
  GSList *radiobutton_filter_flag_push_ignore_group = NULL;
  GtkWidget *alignment48;
  GtkWidget *hbox180;
  GtkWidget *image80;
  GtkWidget *label445;
  GtkWidget *radiobutton_filter_flag_push_unset;
  GtkWidget *alignment42;
  GtkWidget *hbox174;
  GtkWidget *image74;
  GtkWidget *label439;
  GtkWidget *radiobutton_filter_flag_push_set;
  GtkWidget *alignment51;
  GtkWidget *hbox183;
  GtkWidget *image83;
  GtkWidget *label448;
  GtkWidget *radiobutton_filter_flag_busy_set;
  GtkWidget *alignment50;
  GtkWidget *hbox182;
  GtkWidget *image82;
  GtkWidget *label447;
  GtkWidget *label_d232;
  GtkWidget *radiobutton_filter_flag_stable_set;
  GSList *radiobutton_filter_flag_stable_set_group = NULL;
  GtkWidget *alignment49;
  GtkWidget *hbox181;
  GtkWidget *image81;
  GtkWidget *label446;
  GtkWidget *radiobutton_filter_flag_stable_unset;
  GtkWidget *alignment41;
  GtkWidget *hbox173;
  GtkWidget *image73;
  GtkWidget *label438;
  GtkWidget *radiobutton_filter_flag_stable_ignore;
  GtkWidget *alignment46;
  GtkWidget *hbox178;
  GtkWidget *image78;
  GtkWidget *label443;
  GtkWidget *radiobutton_filter_flag_busy_unset;
  GtkWidget *alignment40;
  GtkWidget *hbox172;
  GtkWidget *image72;
  GtkWidget *label437;
  GtkWidget *label248;
  GtkWidget *hbox131;
  GtkWidget *frame40;
  GtkWidget *optionmenu_filter_flag_target;
  GtkWidget *convertwidget39;
  GtkWidget *label249;
  GtkWidget *vbox70;
  GtkWidget *button_filter_flag_reset;
  GtkWidget *alignment134;
  GtkWidget *hbox9330;
  GtkWidget *image1173;
  GtkWidget *label981;
  GtkWidget *hbox9326;
  GtkWidget *button35;
  GtkWidget *alignment131;
  GtkWidget *hbox9327;
  GtkWidget *image1170;
  GtkWidget *label978;
  GtkWidget *button36;
  GtkWidget *alignment132;
  GtkWidget *hbox9328;
  GtkWidget *image1171;
  GtkWidget *label979;
  GtkWidget *button37;
  GtkWidget *alignment133;
  GtkWidget *hbox9329;
  GtkWidget *image1172;
  GtkWidget *label980;

  dlg_filters_flags_tab = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_widget_set_name (dlg_filters_flags_tab, "dlg_filters_flags_tab");

  vbox68 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox68, "vbox68");
  gtk_widget_show (vbox68);
  gtk_container_add (GTK_CONTAINER (dlg_filters_flags_tab), vbox68);

  alignment21 = gtk_alignment_new (0.5, 0, 1, 1);
  gtk_widget_set_name (alignment21, "alignment21");
  gtk_widget_show (alignment21);
  gtk_box_pack_start (GTK_BOX (vbox68), alignment21, TRUE, TRUE, 0);

  hbox129 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox129, "hbox129");
  gtk_widget_show (hbox129);
  gtk_container_add (GTK_CONTAINER (alignment21), hbox129);

  frame38 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame38, "frame38");
  gtk_widget_show (frame38);
  gtk_box_pack_start (GTK_BOX (hbox129), frame38, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame38), 2);

  vbox69 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox69, "vbox69");
  gtk_widget_show (vbox69);
  gtk_container_add (GTK_CONTAINER (frame38), vbox69);

  checkbutton_filter_flag_active = gtk_check_button_new_with_mnemonic (_("active"));
  gtk_widget_set_name (checkbutton_filter_flag_active, "checkbutton_filter_flag_active");
  gtk_widget_show (checkbutton_filter_flag_active);
  gtk_box_pack_start (GTK_BOX (vbox69), checkbutton_filter_flag_active, FALSE, FALSE, 0);

  checkbutton_filter_flag_soft = gtk_check_button_new_with_mnemonic (_("mark only"));
  gtk_widget_set_name (checkbutton_filter_flag_soft, "checkbutton_filter_flag_soft");
  gtk_widget_show (checkbutton_filter_flag_soft);
  gtk_box_pack_start (GTK_BOX (vbox69), checkbutton_filter_flag_soft, FALSE, FALSE, 0);

  label247 = gtk_label_new (_("Flags"));
  gtk_widget_set_name (label247, "label247");
  gtk_widget_show (label247);
  gtk_frame_set_label_widget (GTK_FRAME (frame38), label247);

  frame39 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame39, "frame39");
  gtk_widget_show (frame39);
  gtk_box_pack_start (GTK_BOX (hbox129), frame39, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame39), 2);

  hbox130 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox130, "hbox130");
  gtk_widget_show (hbox130);
  gtk_container_add (GTK_CONTAINER (frame39), hbox130);

  table26 = gtk_table_new (3, 4, TRUE);
  gtk_widget_set_name (table26, "table26");
  gtk_widget_show (table26);
  gtk_box_pack_start (GTK_BOX (hbox130), table26, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (table26), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table26), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table26), 4);

  label_d230 = gtk_label_new (_("Busy"));
  gtk_widget_set_name (label_d230, "label_d230");
  gtk_widget_show (label_d230);
  gtk_table_attach (GTK_TABLE (table26), label_d230, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label_d230), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label_d230), 0, 0.5);

  label_d231 = gtk_label_new (_("Push"));
  gtk_widget_set_name (label_d231, "label_d231");
  gtk_widget_show (label_d231);
  gtk_table_attach (GTK_TABLE (table26), label_d231, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label_d231), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label_d231), 0, 0.5);

  radiobutton_filter_flag_busy_ignore = gtk_radio_button_new (NULL);
  gtk_widget_set_name (radiobutton_filter_flag_busy_ignore, "radiobutton_filter_flag_busy_ignore");
  gtk_widget_show (radiobutton_filter_flag_busy_ignore);
  gtk_table_attach (GTK_TABLE (table26), radiobutton_filter_flag_busy_ignore, 3, 4, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_radio_button_set_group (GTK_RADIO_BUTTON (radiobutton_filter_flag_busy_ignore), radiobutton_filter_flag_busy_ignore_group);
  radiobutton_filter_flag_busy_ignore_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radiobutton_filter_flag_busy_ignore));
  gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (radiobutton_filter_flag_busy_ignore), FALSE);

  alignment47 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment47, "alignment47");
  gtk_widget_show (alignment47);
  gtk_container_add (GTK_CONTAINER (radiobutton_filter_flag_busy_ignore), alignment47);

  hbox179 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox179, "hbox179");
  gtk_widget_show (hbox179);
  gtk_container_add (GTK_CONTAINER (alignment47), hbox179);

  image79 = gtk_image_new_from_stock ("gtk-go-forward", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image79, "image79");
  gtk_widget_show (image79);
  gtk_box_pack_start (GTK_BOX (hbox179), image79, FALSE, FALSE, 0);

  label444 = gtk_label_new_with_mnemonic (_("ignored"));
  gtk_widget_set_name (label444, "label444");
  gtk_widget_show (label444);
  gtk_box_pack_start (GTK_BOX (hbox179), label444, FALSE, FALSE, 0);

  radiobutton_filter_flag_push_ignore = gtk_radio_button_new (NULL);
  gtk_widget_set_name (radiobutton_filter_flag_push_ignore, "radiobutton_filter_flag_push_ignore");
  gtk_widget_show (radiobutton_filter_flag_push_ignore);
  gtk_table_attach (GTK_TABLE (table26), radiobutton_filter_flag_push_ignore, 3, 4, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_radio_button_set_group (GTK_RADIO_BUTTON (radiobutton_filter_flag_push_ignore), radiobutton_filter_flag_push_ignore_group);
  radiobutton_filter_flag_push_ignore_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radiobutton_filter_flag_push_ignore));
  gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (radiobutton_filter_flag_push_ignore), FALSE);

  alignment48 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment48, "alignment48");
  gtk_widget_show (alignment48);
  gtk_container_add (GTK_CONTAINER (radiobutton_filter_flag_push_ignore), alignment48);

  hbox180 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox180, "hbox180");
  gtk_widget_show (hbox180);
  gtk_container_add (GTK_CONTAINER (alignment48), hbox180);

  image80 = gtk_image_new_from_stock ("gtk-go-forward", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image80, "image80");
  gtk_widget_show (image80);
  gtk_box_pack_start (GTK_BOX (hbox180), image80, FALSE, FALSE, 0);

  label445 = gtk_label_new_with_mnemonic (_("ignored"));
  gtk_widget_set_name (label445, "label445");
  gtk_widget_show (label445);
  gtk_box_pack_start (GTK_BOX (hbox180), label445, FALSE, FALSE, 0);

  radiobutton_filter_flag_push_unset = gtk_radio_button_new (NULL);
  gtk_widget_set_name (radiobutton_filter_flag_push_unset, "radiobutton_filter_flag_push_unset");
  gtk_widget_show (radiobutton_filter_flag_push_unset);
  gtk_table_attach (GTK_TABLE (table26), radiobutton_filter_flag_push_unset, 2, 3, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_radio_button_set_group (GTK_RADIO_BUTTON (radiobutton_filter_flag_push_unset), radiobutton_filter_flag_push_ignore_group);
  radiobutton_filter_flag_push_ignore_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radiobutton_filter_flag_push_unset));
  gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (radiobutton_filter_flag_push_unset), FALSE);

  alignment42 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment42, "alignment42");
  gtk_widget_show (alignment42);
  gtk_container_add (GTK_CONTAINER (radiobutton_filter_flag_push_unset), alignment42);

  hbox174 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox174, "hbox174");
  gtk_widget_show (hbox174);
  gtk_container_add (GTK_CONTAINER (alignment42), hbox174);

  image74 = gtk_image_new_from_stock ("gtk-no", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image74, "image74");
  gtk_widget_show (image74);
  gtk_box_pack_start (GTK_BOX (hbox174), image74, FALSE, FALSE, 0);

  label439 = gtk_label_new_with_mnemonic (_("unset"));
  gtk_widget_set_name (label439, "label439");
  gtk_widget_show (label439);
  gtk_box_pack_start (GTK_BOX (hbox174), label439, FALSE, FALSE, 0);

  radiobutton_filter_flag_push_set = gtk_radio_button_new (NULL);
  gtk_widget_set_name (radiobutton_filter_flag_push_set, "radiobutton_filter_flag_push_set");
  gtk_widget_show (radiobutton_filter_flag_push_set);
  gtk_table_attach (GTK_TABLE (table26), radiobutton_filter_flag_push_set, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_radio_button_set_group (GTK_RADIO_BUTTON (radiobutton_filter_flag_push_set), radiobutton_filter_flag_push_ignore_group);
  radiobutton_filter_flag_push_ignore_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radiobutton_filter_flag_push_set));
  gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (radiobutton_filter_flag_push_set), FALSE);

  alignment51 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment51, "alignment51");
  gtk_widget_show (alignment51);
  gtk_container_add (GTK_CONTAINER (radiobutton_filter_flag_push_set), alignment51);

  hbox183 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox183, "hbox183");
  gtk_widget_show (hbox183);
  gtk_container_add (GTK_CONTAINER (alignment51), hbox183);

  image83 = gtk_image_new_from_stock ("gtk-yes", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image83, "image83");
  gtk_widget_show (image83);
  gtk_box_pack_start (GTK_BOX (hbox183), image83, FALSE, FALSE, 0);

  label448 = gtk_label_new_with_mnemonic (_("set"));
  gtk_widget_set_name (label448, "label448");
  gtk_widget_show (label448);
  gtk_box_pack_start (GTK_BOX (hbox183), label448, FALSE, FALSE, 0);

  radiobutton_filter_flag_busy_set = gtk_radio_button_new (NULL);
  gtk_widget_set_name (radiobutton_filter_flag_busy_set, "radiobutton_filter_flag_busy_set");
  gtk_widget_show (radiobutton_filter_flag_busy_set);
  gtk_table_attach (GTK_TABLE (table26), radiobutton_filter_flag_busy_set, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND), 0, 0);
  gtk_radio_button_set_group (GTK_RADIO_BUTTON (radiobutton_filter_flag_busy_set), radiobutton_filter_flag_busy_ignore_group);
  radiobutton_filter_flag_busy_ignore_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radiobutton_filter_flag_busy_set));
  gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (radiobutton_filter_flag_busy_set), FALSE);

  alignment50 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment50, "alignment50");
  gtk_widget_show (alignment50);
  gtk_container_add (GTK_CONTAINER (radiobutton_filter_flag_busy_set), alignment50);

  hbox182 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox182, "hbox182");
  gtk_widget_show (hbox182);
  gtk_container_add (GTK_CONTAINER (alignment50), hbox182);

  image82 = gtk_image_new_from_stock ("gtk-yes", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image82, "image82");
  gtk_widget_show (image82);
  gtk_box_pack_start (GTK_BOX (hbox182), image82, FALSE, FALSE, 0);

  label447 = gtk_label_new_with_mnemonic (_("set"));
  gtk_widget_set_name (label447, "label447");
  gtk_widget_show (label447);
  gtk_box_pack_start (GTK_BOX (hbox182), label447, FALSE, FALSE, 0);

  label_d232 = gtk_label_new (_("Stable"));
  gtk_widget_set_name (label_d232, "label_d232");
  gtk_widget_show (label_d232);
  gtk_table_attach (GTK_TABLE (table26), label_d232, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label_d232), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label_d232), 0, 0.5);

  radiobutton_filter_flag_stable_set = gtk_radio_button_new (NULL);
  gtk_widget_set_name (radiobutton_filter_flag_stable_set, "radiobutton_filter_flag_stable_set");
  gtk_widget_show (radiobutton_filter_flag_stable_set);
  gtk_table_attach (GTK_TABLE (table26), radiobutton_filter_flag_stable_set, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_radio_button_set_group (GTK_RADIO_BUTTON (radiobutton_filter_flag_stable_set), radiobutton_filter_flag_stable_set_group);
  radiobutton_filter_flag_stable_set_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radiobutton_filter_flag_stable_set));
  gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (radiobutton_filter_flag_stable_set), FALSE);

  alignment49 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment49, "alignment49");
  gtk_widget_show (alignment49);
  gtk_container_add (GTK_CONTAINER (radiobutton_filter_flag_stable_set), alignment49);

  hbox181 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox181, "hbox181");
  gtk_widget_show (hbox181);
  gtk_container_add (GTK_CONTAINER (alignment49), hbox181);

  image81 = gtk_image_new_from_stock ("gtk-yes", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image81, "image81");
  gtk_widget_show (image81);
  gtk_box_pack_start (GTK_BOX (hbox181), image81, FALSE, FALSE, 0);

  label446 = gtk_label_new_with_mnemonic (_("set"));
  gtk_widget_set_name (label446, "label446");
  gtk_widget_show (label446);
  gtk_box_pack_start (GTK_BOX (hbox181), label446, FALSE, FALSE, 0);

  radiobutton_filter_flag_stable_unset = gtk_radio_button_new (NULL);
  gtk_widget_set_name (radiobutton_filter_flag_stable_unset, "radiobutton_filter_flag_stable_unset");
  gtk_widget_show (radiobutton_filter_flag_stable_unset);
  gtk_table_attach (GTK_TABLE (table26), radiobutton_filter_flag_stable_unset, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_radio_button_set_group (GTK_RADIO_BUTTON (radiobutton_filter_flag_stable_unset), radiobutton_filter_flag_stable_set_group);
  radiobutton_filter_flag_stable_set_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radiobutton_filter_flag_stable_unset));
  gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (radiobutton_filter_flag_stable_unset), FALSE);

  alignment41 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment41, "alignment41");
  gtk_widget_show (alignment41);
  gtk_container_add (GTK_CONTAINER (radiobutton_filter_flag_stable_unset), alignment41);

  hbox173 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox173, "hbox173");
  gtk_widget_show (hbox173);
  gtk_container_add (GTK_CONTAINER (alignment41), hbox173);

  image73 = gtk_image_new_from_stock ("gtk-no", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image73, "image73");
  gtk_widget_show (image73);
  gtk_box_pack_start (GTK_BOX (hbox173), image73, FALSE, FALSE, 0);

  label438 = gtk_label_new_with_mnemonic (_("unset"));
  gtk_widget_set_name (label438, "label438");
  gtk_widget_show (label438);
  gtk_box_pack_start (GTK_BOX (hbox173), label438, FALSE, FALSE, 0);

  radiobutton_filter_flag_stable_ignore = gtk_radio_button_new (NULL);
  gtk_widget_set_name (radiobutton_filter_flag_stable_ignore, "radiobutton_filter_flag_stable_ignore");
  gtk_widget_show (radiobutton_filter_flag_stable_ignore);
  gtk_table_attach (GTK_TABLE (table26), radiobutton_filter_flag_stable_ignore, 3, 4, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_radio_button_set_group (GTK_RADIO_BUTTON (radiobutton_filter_flag_stable_ignore), radiobutton_filter_flag_stable_set_group);
  radiobutton_filter_flag_stable_set_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radiobutton_filter_flag_stable_ignore));
  gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (radiobutton_filter_flag_stable_ignore), FALSE);

  alignment46 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment46, "alignment46");
  gtk_widget_show (alignment46);
  gtk_container_add (GTK_CONTAINER (radiobutton_filter_flag_stable_ignore), alignment46);

  hbox178 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox178, "hbox178");
  gtk_widget_show (hbox178);
  gtk_container_add (GTK_CONTAINER (alignment46), hbox178);

  image78 = gtk_image_new_from_stock ("gtk-go-forward", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image78, "image78");
  gtk_widget_show (image78);
  gtk_box_pack_start (GTK_BOX (hbox178), image78, FALSE, FALSE, 0);

  label443 = gtk_label_new_with_mnemonic (_("ignored"));
  gtk_widget_set_name (label443, "label443");
  gtk_widget_show (label443);
  gtk_box_pack_start (GTK_BOX (hbox178), label443, FALSE, FALSE, 0);

  radiobutton_filter_flag_busy_unset = gtk_radio_button_new (NULL);
  gtk_widget_set_name (radiobutton_filter_flag_busy_unset, "radiobutton_filter_flag_busy_unset");
  gtk_widget_show (radiobutton_filter_flag_busy_unset);
  gtk_table_attach (GTK_TABLE (table26), radiobutton_filter_flag_busy_unset, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_radio_button_set_group (GTK_RADIO_BUTTON (radiobutton_filter_flag_busy_unset), radiobutton_filter_flag_busy_ignore_group);
  radiobutton_filter_flag_busy_ignore_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radiobutton_filter_flag_busy_unset));
  gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (radiobutton_filter_flag_busy_unset), FALSE);

  alignment40 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment40, "alignment40");
  gtk_widget_show (alignment40);
  gtk_container_add (GTK_CONTAINER (radiobutton_filter_flag_busy_unset), alignment40);

  hbox172 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox172, "hbox172");
  gtk_widget_show (hbox172);
  gtk_container_add (GTK_CONTAINER (alignment40), hbox172);

  image72 = gtk_image_new_from_stock ("gtk-no", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image72, "image72");
  gtk_widget_show (image72);
  gtk_box_pack_start (GTK_BOX (hbox172), image72, FALSE, FALSE, 0);

  label437 = gtk_label_new_with_mnemonic (_("unset"));
  gtk_widget_set_name (label437, "label437");
  gtk_widget_show (label437);
  gtk_box_pack_start (GTK_BOX (hbox172), label437, FALSE, FALSE, 0);

  label248 = gtk_label_new (_("Condition: If result has flags"));
  gtk_widget_set_name (label248, "label248");
  gtk_widget_show (label248);
  gtk_frame_set_label_widget (GTK_FRAME (frame39), label248);

  hbox131 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox131, "hbox131");
  gtk_widget_show (hbox131);
  gtk_box_pack_start (GTK_BOX (vbox68), hbox131, FALSE, FALSE, 0);

  frame40 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame40, "frame40");
  gtk_widget_show (frame40);
  gtk_box_pack_start (GTK_BOX (hbox131), frame40, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame40), 2);

  optionmenu_filter_flag_target = gtk_option_menu_new ();
  gtk_widget_set_name (optionmenu_filter_flag_target, "optionmenu_filter_flag_target");
  gtk_widget_show (optionmenu_filter_flag_target);
  gtk_container_add (GTK_CONTAINER (frame40), optionmenu_filter_flag_target);

  convertwidget39 = gtk_menu_new ();
  gtk_widget_set_name (convertwidget39, "convertwidget39");

  gtk_option_menu_set_menu (GTK_OPTION_MENU (optionmenu_filter_flag_target), convertwidget39);

  label249 = gtk_label_new (_("Target"));
  gtk_widget_set_name (label249, "label249");
  gtk_widget_show (label249);
  gtk_frame_set_label_widget (GTK_FRAME (frame40), label249);

  vbox70 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox70, "vbox70");
  gtk_widget_show (vbox70);
  gtk_box_pack_start (GTK_BOX (hbox131), vbox70, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (vbox70), 2);

  button_filter_flag_reset = gtk_button_new ();
  gtk_widget_set_name (button_filter_flag_reset, "button_filter_flag_reset");
  gtk_widget_show (button_filter_flag_reset);
  gtk_box_pack_start (GTK_BOX (vbox70), button_filter_flag_reset, FALSE, FALSE, 0);

  alignment134 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment134, "alignment134");
  gtk_widget_show (alignment134);
  gtk_container_add (GTK_CONTAINER (button_filter_flag_reset), alignment134);

  hbox9330 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox9330, "hbox9330");
  gtk_widget_show (hbox9330);
  gtk_container_add (GTK_CONTAINER (alignment134), hbox9330);

  image1173 = gtk_image_new_from_stock ("gtk-refresh", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image1173, "image1173");
  gtk_widget_show (image1173);
  gtk_box_pack_start (GTK_BOX (hbox9330), image1173, FALSE, FALSE, 0);

  label981 = gtk_label_new_with_mnemonic (_("_Reset stats"));
  gtk_widget_set_name (label981, "label981");
  gtk_widget_show (label981);
  gtk_box_pack_start (GTK_BOX (hbox9330), label981, FALSE, FALSE, 0);

  hbox9326 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox9326, "hbox9326");
  gtk_widget_show (hbox9326);
  gtk_box_pack_start (GTK_BOX (vbox70), hbox9326, FALSE, FALSE, 0);

  button35 = gtk_button_new ();
  gtk_widget_set_name (button35, "button35");
  gtk_widget_show (button35);
  gtk_box_pack_start (GTK_BOX (hbox9326), button35, FALSE, FALSE, 0);

  alignment131 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment131, "alignment131");
  gtk_widget_show (alignment131);
  gtk_container_add (GTK_CONTAINER (button35), alignment131);

  hbox9327 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox9327, "hbox9327");
  gtk_widget_show (hbox9327);
  gtk_container_add (GTK_CONTAINER (alignment131), hbox9327);

  image1170 = gtk_image_new_from_stock ("gtk-save", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image1170, "image1170");
  gtk_widget_show (image1170);
  gtk_box_pack_start (GTK_BOX (hbox9327), image1170, FALSE, FALSE, 0);

  label978 = gtk_label_new_with_mnemonic (_("Save"));
  gtk_widget_set_name (label978, "label978");
  gtk_widget_show (label978);
  gtk_box_pack_start (GTK_BOX (hbox9327), label978, FALSE, FALSE, 0);

  button36 = gtk_button_new ();
  gtk_widget_set_name (button36, "button36");
  gtk_widget_show (button36);
  gtk_box_pack_start (GTK_BOX (hbox9326), button36, FALSE, FALSE, 0);

  alignment132 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment132, "alignment132");
  gtk_widget_show (alignment132);
  gtk_container_add (GTK_CONTAINER (button36), alignment132);

  hbox9328 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox9328, "hbox9328");
  gtk_widget_show (hbox9328);
  gtk_container_add (GTK_CONTAINER (alignment132), hbox9328);

  image1171 = gtk_image_new_from_stock ("gtk-delete", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image1171, "image1171");
  gtk_widget_show (image1171);
  gtk_box_pack_start (GTK_BOX (hbox9328), image1171, FALSE, FALSE, 0);

  label979 = gtk_label_new_with_mnemonic (_("Delete"));
  gtk_widget_set_name (label979, "label979");
  gtk_widget_show (label979);
  gtk_box_pack_start (GTK_BOX (hbox9328), label979, FALSE, FALSE, 0);

  button37 = gtk_button_new ();
  gtk_widget_set_name (button37, "button37");
  gtk_widget_show (button37);
  gtk_box_pack_start (GTK_BOX (hbox9326), button37, FALSE, FALSE, 0);

  alignment133 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment133, "alignment133");
  gtk_widget_show (alignment133);
  gtk_container_add (GTK_CONTAINER (button37), alignment133);

  hbox9329 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox9329, "hbox9329");
  gtk_widget_show (hbox9329);
  gtk_container_add (GTK_CONTAINER (alignment133), hbox9329);

  image1172 = gtk_image_new_from_stock ("gtk-cancel", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image1172, "image1172");
  gtk_widget_show (image1172);
  gtk_box_pack_start (GTK_BOX (hbox9329), image1172, FALSE, FALSE, 0);

  label980 = gtk_label_new_with_mnemonic (_("Abort"));
  gtk_widget_set_name (label980, "label980");
  gtk_widget_show (label980);
  gtk_box_pack_start (GTK_BOX (hbox9329), label980, FALSE, FALSE, 0);

  g_signal_connect ((gpointer) button_filter_flag_reset, "clicked",
                    G_CALLBACK (on_button_filter_reset_rule_clicked),
                    NULL);
  g_signal_connect ((gpointer) button35, "clicked",
                    G_CALLBACK (on_button_filter_add_rule_clicked),
                    NULL);
  g_signal_connect ((gpointer) button36, "clicked",
                    G_CALLBACK (on_button_filter_remove_rule_clicked),
                    NULL);
  g_signal_connect ((gpointer) button37, "clicked",
                    G_CALLBACK (on_button_filter_abort_rule_clicked),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (dlg_filters_flags_tab, dlg_filters_flags_tab, "dlg_filters_flags_tab");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, vbox68, "vbox68");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, alignment21, "alignment21");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, hbox129, "hbox129");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, frame38, "frame38");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, vbox69, "vbox69");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, checkbutton_filter_flag_active, "checkbutton_filter_flag_active");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, checkbutton_filter_flag_soft, "checkbutton_filter_flag_soft");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, label247, "label247");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, frame39, "frame39");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, hbox130, "hbox130");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, table26, "table26");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, label_d230, "label_d230");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, label_d231, "label_d231");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, radiobutton_filter_flag_busy_ignore, "radiobutton_filter_flag_busy_ignore");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, alignment47, "alignment47");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, hbox179, "hbox179");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, image79, "image79");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, label444, "label444");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, radiobutton_filter_flag_push_ignore, "radiobutton_filter_flag_push_ignore");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, alignment48, "alignment48");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, hbox180, "hbox180");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, image80, "image80");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, label445, "label445");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, radiobutton_filter_flag_push_unset, "radiobutton_filter_flag_push_unset");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, alignment42, "alignment42");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, hbox174, "hbox174");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, image74, "image74");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, label439, "label439");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, radiobutton_filter_flag_push_set, "radiobutton_filter_flag_push_set");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, alignment51, "alignment51");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, hbox183, "hbox183");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, image83, "image83");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, label448, "label448");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, radiobutton_filter_flag_busy_set, "radiobutton_filter_flag_busy_set");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, alignment50, "alignment50");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, hbox182, "hbox182");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, image82, "image82");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, label447, "label447");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, label_d232, "label_d232");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, radiobutton_filter_flag_stable_set, "radiobutton_filter_flag_stable_set");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, alignment49, "alignment49");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, hbox181, "hbox181");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, image81, "image81");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, label446, "label446");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, radiobutton_filter_flag_stable_unset, "radiobutton_filter_flag_stable_unset");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, alignment41, "alignment41");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, hbox173, "hbox173");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, image73, "image73");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, label438, "label438");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, radiobutton_filter_flag_stable_ignore, "radiobutton_filter_flag_stable_ignore");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, alignment46, "alignment46");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, hbox178, "hbox178");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, image78, "image78");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, label443, "label443");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, radiobutton_filter_flag_busy_unset, "radiobutton_filter_flag_busy_unset");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, alignment40, "alignment40");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, hbox172, "hbox172");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, image72, "image72");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, label437, "label437");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, label248, "label248");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, hbox131, "hbox131");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, frame40, "frame40");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, optionmenu_filter_flag_target, "optionmenu_filter_flag_target");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, convertwidget39, "convertwidget39");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, label249, "label249");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, vbox70, "vbox70");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, button_filter_flag_reset, "button_filter_flag_reset");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, alignment134, "alignment134");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, hbox9330, "hbox9330");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, image1173, "image1173");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, label981, "label981");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, hbox9326, "hbox9326");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, button35, "button35");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, alignment131, "alignment131");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, hbox9327, "hbox9327");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, image1170, "image1170");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, label978, "label978");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, button36, "button36");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, alignment132, "alignment132");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, hbox9328, "hbox9328");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, image1171, "image1171");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, label979, "label979");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, button37, "button37");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, alignment133, "alignment133");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, hbox9329, "hbox9329");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, image1172, "image1172");
  GLADE_HOOKUP_OBJECT (dlg_filters_flags_tab, label980, "label980");

  return dlg_filters_flags_tab;
}

GtkWidget*
create_dlg_filters_state_tab (void)
{
  GtkWidget *dlg_filters_state_tab;
  GtkWidget *vbox71;
  GtkWidget *alignment22;
  GtkWidget *hbox133;
  GtkWidget *frame41;
  GtkWidget *vbox74;
  GtkWidget *checkbutton_filter_state_invert_cond;
  GtkWidget *checkbutton_filter_state_active;
  GtkWidget *checkbutton_filter_state_soft;
  GtkWidget *label250;
  GtkWidget *frame42;
  GtkWidget *alignment23;
  GtkWidget *table27;
  GtkWidget *label_d249;
  GtkWidget *radiobutton_filter_state_download_dont;
  GSList *radiobutton_filter_state_download_dont_group = NULL;
  GtkWidget *alignment55;
  GtkWidget *hbox187;
  GtkWidget *image87;
  GtkWidget *label452;
  GtkWidget *radiobutton_filter_state_download_undef;
  GtkWidget *alignment57;
  GtkWidget *hbox189;
  GtkWidget *image89;
  GtkWidget *label454;
  GtkWidget *label257;
  GtkWidget *radiobutton_filter_state_download_do;
  GtkWidget *alignment53;
  GtkWidget *hbox185;
  GtkWidget *image85;
  GtkWidget *label450;
  GtkWidget *radiobutton_filter_state_display_do;
  GSList *radiobutton_filter_state_display_do_group = NULL;
  GtkWidget *alignment52;
  GtkWidget *hbox184;
  GtkWidget *image84;
  GtkWidget *label449;
  GtkWidget *radiobutton_filter_state_display_dont;
  GtkWidget *alignment54;
  GtkWidget *hbox186;
  GtkWidget *image86;
  GtkWidget *label451;
  GtkWidget *radiobutton_filter_state_display_undef;
  GtkWidget *alignment56;
  GtkWidget *hbox188;
  GtkWidget *image88;
  GtkWidget *label453;
  GtkWidget *radiobutton_filter_state_display_ignore;
  GtkWidget *alignment58;
  GtkWidget *hbox190;
  GtkWidget *image90;
  GtkWidget *label455;
  GtkWidget *radiobutton_filter_state_download_ignore;
  GtkWidget *alignment59;
  GtkWidget *hbox191;
  GtkWidget *image91;
  GtkWidget *label456;
  GtkWidget *label_d251;
  GtkWidget *hbox136;
  GtkWidget *frame43;
  GtkWidget *optionmenu_filter_state_target;
  GtkWidget *convertwidget40;
  GtkWidget *label263;
  GtkWidget *vbox73;
  GtkWidget *button_filter_state_reset;
  GtkWidget *alignment138;
  GtkWidget *hbox9336;
  GtkWidget *image1799;
  GtkWidget *label997;
  GtkWidget *hbox9337;
  GtkWidget *button38;
  GtkWidget *alignment139;
  GtkWidget *hbox9338;
  GtkWidget *image1815;
  GtkWidget *label998;
  GtkWidget *button39;
  GtkWidget *alignment140;
  GtkWidget *hbox9339;
  GtkWidget *image1816;
  GtkWidget *label999;
  GtkWidget *button40;
  GtkWidget *alignment141;
  GtkWidget *hbox9340;
  GtkWidget *image1817;
  GtkWidget *label1000;

  dlg_filters_state_tab = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_widget_set_name (dlg_filters_state_tab, "dlg_filters_state_tab");

  vbox71 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox71, "vbox71");
  gtk_widget_show (vbox71);
  gtk_container_add (GTK_CONTAINER (dlg_filters_state_tab), vbox71);

  alignment22 = gtk_alignment_new (0.5, 0, 1, 1);
  gtk_widget_set_name (alignment22, "alignment22");
  gtk_widget_show (alignment22);
  gtk_box_pack_start (GTK_BOX (vbox71), alignment22, TRUE, TRUE, 0);

  hbox133 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox133, "hbox133");
  gtk_widget_show (hbox133);
  gtk_container_add (GTK_CONTAINER (alignment22), hbox133);

  frame41 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame41, "frame41");
  gtk_widget_show (frame41);
  gtk_box_pack_start (GTK_BOX (hbox133), frame41, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame41), 2);

  vbox74 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox74, "vbox74");
  gtk_widget_show (vbox74);
  gtk_container_add (GTK_CONTAINER (frame41), vbox74);

  checkbutton_filter_state_invert_cond = gtk_check_button_new_with_mnemonic (_("invert condition"));
  gtk_widget_set_name (checkbutton_filter_state_invert_cond, "checkbutton_filter_state_invert_cond");
  gtk_widget_show (checkbutton_filter_state_invert_cond);
  gtk_box_pack_start (GTK_BOX (vbox74), checkbutton_filter_state_invert_cond, FALSE, FALSE, 0);

  checkbutton_filter_state_active = gtk_check_button_new_with_mnemonic (_("active"));
  gtk_widget_set_name (checkbutton_filter_state_active, "checkbutton_filter_state_active");
  gtk_widget_show (checkbutton_filter_state_active);
  gtk_box_pack_start (GTK_BOX (vbox74), checkbutton_filter_state_active, FALSE, FALSE, 0);

  checkbutton_filter_state_soft = gtk_check_button_new_with_mnemonic (_("mark only"));
  gtk_widget_set_name (checkbutton_filter_state_soft, "checkbutton_filter_state_soft");
  gtk_widget_show (checkbutton_filter_state_soft);
  gtk_box_pack_start (GTK_BOX (vbox74), checkbutton_filter_state_soft, FALSE, FALSE, 0);

  label250 = gtk_label_new (_("Flags"));
  gtk_widget_set_name (label250, "label250");
  gtk_widget_show (label250);
  gtk_frame_set_label_widget (GTK_FRAME (frame41), label250);

  frame42 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame42, "frame42");
  gtk_widget_show (frame42);
  gtk_box_pack_start (GTK_BOX (hbox133), frame42, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame42), 2);

  alignment23 = gtk_alignment_new (0, 7.45058e-09, 1, 0);
  gtk_widget_set_name (alignment23, "alignment23");
  gtk_widget_show (alignment23);
  gtk_container_add (GTK_CONTAINER (frame42), alignment23);

  table27 = gtk_table_new (2, 5, FALSE);
  gtk_widget_set_name (table27, "table27");
  gtk_widget_show (table27);
  gtk_container_add (GTK_CONTAINER (alignment23), table27);
  gtk_container_set_border_width (GTK_CONTAINER (table27), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table27), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table27), 4);

  label_d249 = gtk_label_new (_("DOWNLOAD"));
  gtk_widget_set_name (label_d249, "label_d249");
  gtk_widget_show (label_d249);
  gtk_table_attach (GTK_TABLE (table27), label_d249, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label_d249), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label_d249), 0, 0.5);

  radiobutton_filter_state_download_dont = gtk_radio_button_new (NULL);
  gtk_widget_set_name (radiobutton_filter_state_download_dont, "radiobutton_filter_state_download_dont");
  gtk_widget_show (radiobutton_filter_state_download_dont);
  gtk_table_attach (GTK_TABLE (table27), radiobutton_filter_state_download_dont, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_radio_button_set_group (GTK_RADIO_BUTTON (radiobutton_filter_state_download_dont), radiobutton_filter_state_download_dont_group);
  radiobutton_filter_state_download_dont_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radiobutton_filter_state_download_dont));
  gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (radiobutton_filter_state_download_dont), FALSE);

  alignment55 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment55, "alignment55");
  gtk_widget_show (alignment55);
  gtk_container_add (GTK_CONTAINER (radiobutton_filter_state_download_dont), alignment55);

  hbox187 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox187, "hbox187");
  gtk_widget_show (hbox187);
  gtk_container_add (GTK_CONTAINER (alignment55), hbox187);

  image87 = gtk_image_new_from_stock ("gtk-no", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image87, "image87");
  gtk_widget_show (image87);
  gtk_box_pack_start (GTK_BOX (hbox187), image87, FALSE, FALSE, 0);

  label452 = gtk_label_new_with_mnemonic (_("don't"));
  gtk_widget_set_name (label452, "label452");
  gtk_widget_show (label452);
  gtk_box_pack_start (GTK_BOX (hbox187), label452, FALSE, FALSE, 0);

  radiobutton_filter_state_download_undef = gtk_radio_button_new (NULL);
  gtk_widget_set_name (radiobutton_filter_state_download_undef, "radiobutton_filter_state_download_undef");
  gtk_widget_show (radiobutton_filter_state_download_undef);
  gtk_table_attach (GTK_TABLE (table27), radiobutton_filter_state_download_undef, 3, 4, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_radio_button_set_group (GTK_RADIO_BUTTON (radiobutton_filter_state_download_undef), radiobutton_filter_state_download_dont_group);
  radiobutton_filter_state_download_dont_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radiobutton_filter_state_download_undef));
  gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (radiobutton_filter_state_download_undef), FALSE);

  alignment57 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment57, "alignment57");
  gtk_widget_show (alignment57);
  gtk_container_add (GTK_CONTAINER (radiobutton_filter_state_download_undef), alignment57);

  hbox189 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox189, "hbox189");
  gtk_widget_show (hbox189);
  gtk_container_add (GTK_CONTAINER (alignment57), hbox189);

  image89 = gtk_image_new_from_stock ("gtk-dialog-question", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image89, "image89");
  gtk_widget_show (image89);
  gtk_box_pack_start (GTK_BOX (hbox189), image89, FALSE, FALSE, 0);

  label454 = gtk_label_new_with_mnemonic (_("undefined"));
  gtk_widget_set_name (label454, "label454");
  gtk_widget_show (label454);
  gtk_box_pack_start (GTK_BOX (hbox189), label454, FALSE, FALSE, 0);

  label257 = gtk_label_new (_("DISPLAY"));
  gtk_widget_set_name (label257, "label257");
  gtk_widget_show (label257);
  gtk_table_attach (GTK_TABLE (table27), label257, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label257), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label257), 0, 0.5);

  radiobutton_filter_state_download_do = gtk_radio_button_new (NULL);
  gtk_widget_set_name (radiobutton_filter_state_download_do, "radiobutton_filter_state_download_do");
  gtk_widget_show (radiobutton_filter_state_download_do);
  gtk_table_attach (GTK_TABLE (table27), radiobutton_filter_state_download_do, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_radio_button_set_group (GTK_RADIO_BUTTON (radiobutton_filter_state_download_do), radiobutton_filter_state_download_dont_group);
  radiobutton_filter_state_download_dont_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radiobutton_filter_state_download_do));
  gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (radiobutton_filter_state_download_do), FALSE);

  alignment53 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment53, "alignment53");
  gtk_widget_show (alignment53);
  gtk_container_add (GTK_CONTAINER (radiobutton_filter_state_download_do), alignment53);

  hbox185 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox185, "hbox185");
  gtk_widget_show (hbox185);
  gtk_container_add (GTK_CONTAINER (alignment53), hbox185);

  image85 = gtk_image_new_from_stock ("gtk-yes", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image85, "image85");
  gtk_widget_show (image85);
  gtk_box_pack_start (GTK_BOX (hbox185), image85, FALSE, FALSE, 0);

  label450 = gtk_label_new_with_mnemonic (_("do"));
  gtk_widget_set_name (label450, "label450");
  gtk_widget_show (label450);
  gtk_box_pack_start (GTK_BOX (hbox185), label450, FALSE, FALSE, 0);

  radiobutton_filter_state_display_do = gtk_radio_button_new (NULL);
  gtk_widget_set_name (radiobutton_filter_state_display_do, "radiobutton_filter_state_display_do");
  gtk_widget_show (radiobutton_filter_state_display_do);
  gtk_table_attach (GTK_TABLE (table27), radiobutton_filter_state_display_do, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_radio_button_set_group (GTK_RADIO_BUTTON (radiobutton_filter_state_display_do), radiobutton_filter_state_display_do_group);
  radiobutton_filter_state_display_do_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radiobutton_filter_state_display_do));
  gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (radiobutton_filter_state_display_do), FALSE);

  alignment52 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment52, "alignment52");
  gtk_widget_show (alignment52);
  gtk_container_add (GTK_CONTAINER (radiobutton_filter_state_display_do), alignment52);

  hbox184 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox184, "hbox184");
  gtk_widget_show (hbox184);
  gtk_container_add (GTK_CONTAINER (alignment52), hbox184);

  image84 = gtk_image_new_from_stock ("gtk-yes", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image84, "image84");
  gtk_widget_show (image84);
  gtk_box_pack_start (GTK_BOX (hbox184), image84, FALSE, FALSE, 0);

  label449 = gtk_label_new_with_mnemonic (_("do"));
  gtk_widget_set_name (label449, "label449");
  gtk_widget_show (label449);
  gtk_box_pack_start (GTK_BOX (hbox184), label449, FALSE, FALSE, 0);

  radiobutton_filter_state_display_dont = gtk_radio_button_new (NULL);
  gtk_widget_set_name (radiobutton_filter_state_display_dont, "radiobutton_filter_state_display_dont");
  gtk_widget_show (radiobutton_filter_state_display_dont);
  gtk_table_attach (GTK_TABLE (table27), radiobutton_filter_state_display_dont, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_radio_button_set_group (GTK_RADIO_BUTTON (radiobutton_filter_state_display_dont), radiobutton_filter_state_display_do_group);
  radiobutton_filter_state_display_do_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radiobutton_filter_state_display_dont));
  gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (radiobutton_filter_state_display_dont), FALSE);

  alignment54 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment54, "alignment54");
  gtk_widget_show (alignment54);
  gtk_container_add (GTK_CONTAINER (radiobutton_filter_state_display_dont), alignment54);

  hbox186 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox186, "hbox186");
  gtk_widget_show (hbox186);
  gtk_container_add (GTK_CONTAINER (alignment54), hbox186);

  image86 = gtk_image_new_from_stock ("gtk-no", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image86, "image86");
  gtk_widget_show (image86);
  gtk_box_pack_start (GTK_BOX (hbox186), image86, FALSE, FALSE, 0);

  label451 = gtk_label_new_with_mnemonic (_("don't"));
  gtk_widget_set_name (label451, "label451");
  gtk_widget_show (label451);
  gtk_box_pack_start (GTK_BOX (hbox186), label451, FALSE, FALSE, 0);

  radiobutton_filter_state_display_undef = gtk_radio_button_new (NULL);
  gtk_widget_set_name (radiobutton_filter_state_display_undef, "radiobutton_filter_state_display_undef");
  gtk_widget_show (radiobutton_filter_state_display_undef);
  gtk_table_attach (GTK_TABLE (table27), radiobutton_filter_state_display_undef, 3, 4, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_radio_button_set_group (GTK_RADIO_BUTTON (radiobutton_filter_state_display_undef), radiobutton_filter_state_display_do_group);
  radiobutton_filter_state_display_do_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radiobutton_filter_state_display_undef));
  gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (radiobutton_filter_state_display_undef), FALSE);

  alignment56 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment56, "alignment56");
  gtk_widget_show (alignment56);
  gtk_container_add (GTK_CONTAINER (radiobutton_filter_state_display_undef), alignment56);

  hbox188 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox188, "hbox188");
  gtk_widget_show (hbox188);
  gtk_container_add (GTK_CONTAINER (alignment56), hbox188);

  image88 = gtk_image_new_from_stock ("gtk-dialog-question", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image88, "image88");
  gtk_widget_show (image88);
  gtk_box_pack_start (GTK_BOX (hbox188), image88, FALSE, FALSE, 0);

  label453 = gtk_label_new_with_mnemonic (_("undefined"));
  gtk_widget_set_name (label453, "label453");
  gtk_widget_show (label453);
  gtk_box_pack_start (GTK_BOX (hbox188), label453, FALSE, FALSE, 0);

  radiobutton_filter_state_display_ignore = gtk_radio_button_new (NULL);
  gtk_widget_set_name (radiobutton_filter_state_display_ignore, "radiobutton_filter_state_display_ignore");
  gtk_widget_show (radiobutton_filter_state_display_ignore);
  gtk_table_attach (GTK_TABLE (table27), radiobutton_filter_state_display_ignore, 4, 5, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_radio_button_set_group (GTK_RADIO_BUTTON (radiobutton_filter_state_display_ignore), radiobutton_filter_state_display_do_group);
  radiobutton_filter_state_display_do_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radiobutton_filter_state_display_ignore));
  gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (radiobutton_filter_state_display_ignore), FALSE);

  alignment58 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment58, "alignment58");
  gtk_widget_show (alignment58);
  gtk_container_add (GTK_CONTAINER (radiobutton_filter_state_display_ignore), alignment58);

  hbox190 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox190, "hbox190");
  gtk_widget_show (hbox190);
  gtk_container_add (GTK_CONTAINER (alignment58), hbox190);

  image90 = gtk_image_new_from_stock ("gtk-go-forward", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image90, "image90");
  gtk_widget_show (image90);
  gtk_box_pack_start (GTK_BOX (hbox190), image90, FALSE, FALSE, 0);

  label455 = gtk_label_new_with_mnemonic (_("ignore"));
  gtk_widget_set_name (label455, "label455");
  gtk_widget_show (label455);
  gtk_box_pack_start (GTK_BOX (hbox190), label455, FALSE, FALSE, 0);

  radiobutton_filter_state_download_ignore = gtk_radio_button_new (NULL);
  gtk_widget_set_name (radiobutton_filter_state_download_ignore, "radiobutton_filter_state_download_ignore");
  gtk_widget_show (radiobutton_filter_state_download_ignore);
  gtk_table_attach (GTK_TABLE (table27), radiobutton_filter_state_download_ignore, 4, 5, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_radio_button_set_group (GTK_RADIO_BUTTON (radiobutton_filter_state_download_ignore), radiobutton_filter_state_download_dont_group);
  radiobutton_filter_state_download_dont_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radiobutton_filter_state_download_ignore));
  gtk_toggle_button_set_mode (GTK_TOGGLE_BUTTON (radiobutton_filter_state_download_ignore), FALSE);

  alignment59 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment59, "alignment59");
  gtk_widget_show (alignment59);
  gtk_container_add (GTK_CONTAINER (radiobutton_filter_state_download_ignore), alignment59);

  hbox191 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox191, "hbox191");
  gtk_widget_show (hbox191);
  gtk_container_add (GTK_CONTAINER (alignment59), hbox191);

  image91 = gtk_image_new_from_stock ("gtk-go-forward", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image91, "image91");
  gtk_widget_show (image91);
  gtk_box_pack_start (GTK_BOX (hbox191), image91, FALSE, FALSE, 0);

  label456 = gtk_label_new_with_mnemonic (_("ignore"));
  gtk_widget_set_name (label456, "label456");
  gtk_widget_show (label456);
  gtk_box_pack_start (GTK_BOX (hbox191), label456, FALSE, FALSE, 0);

  label_d251 = gtk_label_new (_("Condition: If current filter result properties match"));
  gtk_widget_set_name (label_d251, "label_d251");
  gtk_widget_show (label_d251);
  gtk_frame_set_label_widget (GTK_FRAME (frame42), label_d251);

  hbox136 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox136, "hbox136");
  gtk_widget_show (hbox136);
  gtk_box_pack_start (GTK_BOX (vbox71), hbox136, FALSE, FALSE, 0);

  frame43 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame43, "frame43");
  gtk_widget_show (frame43);
  gtk_box_pack_start (GTK_BOX (hbox136), frame43, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame43), 2);

  optionmenu_filter_state_target = gtk_option_menu_new ();
  gtk_widget_set_name (optionmenu_filter_state_target, "optionmenu_filter_state_target");
  gtk_widget_show (optionmenu_filter_state_target);
  gtk_container_add (GTK_CONTAINER (frame43), optionmenu_filter_state_target);

  convertwidget40 = gtk_menu_new ();
  gtk_widget_set_name (convertwidget40, "convertwidget40");

  gtk_option_menu_set_menu (GTK_OPTION_MENU (optionmenu_filter_state_target), convertwidget40);

  label263 = gtk_label_new (_("Target"));
  gtk_widget_set_name (label263, "label263");
  gtk_widget_show (label263);
  gtk_frame_set_label_widget (GTK_FRAME (frame43), label263);

  vbox73 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox73, "vbox73");
  gtk_widget_show (vbox73);
  gtk_box_pack_start (GTK_BOX (hbox136), vbox73, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (vbox73), 2);

  button_filter_state_reset = gtk_button_new ();
  gtk_widget_set_name (button_filter_state_reset, "button_filter_state_reset");
  gtk_widget_show (button_filter_state_reset);
  gtk_box_pack_start (GTK_BOX (vbox73), button_filter_state_reset, FALSE, FALSE, 0);

  alignment138 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment138, "alignment138");
  gtk_widget_show (alignment138);
  gtk_container_add (GTK_CONTAINER (button_filter_state_reset), alignment138);

  hbox9336 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox9336, "hbox9336");
  gtk_widget_show (hbox9336);
  gtk_container_add (GTK_CONTAINER (alignment138), hbox9336);

  image1799 = gtk_image_new_from_stock ("gtk-refresh", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image1799, "image1799");
  gtk_widget_show (image1799);
  gtk_box_pack_start (GTK_BOX (hbox9336), image1799, FALSE, FALSE, 0);

  label997 = gtk_label_new_with_mnemonic (_("_Reset stats"));
  gtk_widget_set_name (label997, "label997");
  gtk_widget_show (label997);
  gtk_box_pack_start (GTK_BOX (hbox9336), label997, FALSE, FALSE, 0);

  hbox9337 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox9337, "hbox9337");
  gtk_widget_show (hbox9337);
  gtk_box_pack_start (GTK_BOX (vbox73), hbox9337, FALSE, FALSE, 0);

  button38 = gtk_button_new ();
  gtk_widget_set_name (button38, "button38");
  gtk_widget_show (button38);
  gtk_box_pack_start (GTK_BOX (hbox9337), button38, FALSE, FALSE, 0);

  alignment139 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment139, "alignment139");
  gtk_widget_show (alignment139);
  gtk_container_add (GTK_CONTAINER (button38), alignment139);

  hbox9338 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox9338, "hbox9338");
  gtk_widget_show (hbox9338);
  gtk_container_add (GTK_CONTAINER (alignment139), hbox9338);

  image1815 = gtk_image_new_from_stock ("gtk-save", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image1815, "image1815");
  gtk_widget_show (image1815);
  gtk_box_pack_start (GTK_BOX (hbox9338), image1815, FALSE, FALSE, 0);

  label998 = gtk_label_new_with_mnemonic (_("Save"));
  gtk_widget_set_name (label998, "label998");
  gtk_widget_show (label998);
  gtk_box_pack_start (GTK_BOX (hbox9338), label998, FALSE, FALSE, 0);

  button39 = gtk_button_new ();
  gtk_widget_set_name (button39, "button39");
  gtk_widget_show (button39);
  gtk_box_pack_start (GTK_BOX (hbox9337), button39, FALSE, FALSE, 0);

  alignment140 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment140, "alignment140");
  gtk_widget_show (alignment140);
  gtk_container_add (GTK_CONTAINER (button39), alignment140);

  hbox9339 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox9339, "hbox9339");
  gtk_widget_show (hbox9339);
  gtk_container_add (GTK_CONTAINER (alignment140), hbox9339);

  image1816 = gtk_image_new_from_stock ("gtk-delete", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image1816, "image1816");
  gtk_widget_show (image1816);
  gtk_box_pack_start (GTK_BOX (hbox9339), image1816, FALSE, FALSE, 0);

  label999 = gtk_label_new_with_mnemonic (_("Delete"));
  gtk_widget_set_name (label999, "label999");
  gtk_widget_show (label999);
  gtk_box_pack_start (GTK_BOX (hbox9339), label999, FALSE, FALSE, 0);

  button40 = gtk_button_new ();
  gtk_widget_set_name (button40, "button40");
  gtk_widget_show (button40);
  gtk_box_pack_start (GTK_BOX (hbox9337), button40, FALSE, FALSE, 0);

  alignment141 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment141, "alignment141");
  gtk_widget_show (alignment141);
  gtk_container_add (GTK_CONTAINER (button40), alignment141);

  hbox9340 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox9340, "hbox9340");
  gtk_widget_show (hbox9340);
  gtk_container_add (GTK_CONTAINER (alignment141), hbox9340);

  image1817 = gtk_image_new_from_stock ("gtk-cancel", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image1817, "image1817");
  gtk_widget_show (image1817);
  gtk_box_pack_start (GTK_BOX (hbox9340), image1817, FALSE, FALSE, 0);

  label1000 = gtk_label_new_with_mnemonic (_("Abort"));
  gtk_widget_set_name (label1000, "label1000");
  gtk_widget_show (label1000);
  gtk_box_pack_start (GTK_BOX (hbox9340), label1000, FALSE, FALSE, 0);

  g_signal_connect ((gpointer) button_filter_state_reset, "clicked",
                    G_CALLBACK (on_button_filter_reset_rule_clicked),
                    NULL);
  g_signal_connect ((gpointer) button38, "clicked",
                    G_CALLBACK (on_button_filter_add_rule_clicked),
                    NULL);
  g_signal_connect ((gpointer) button39, "clicked",
                    G_CALLBACK (on_button_filter_remove_rule_clicked),
                    NULL);
  g_signal_connect ((gpointer) button40, "clicked",
                    G_CALLBACK (on_button_filter_abort_rule_clicked),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (dlg_filters_state_tab, dlg_filters_state_tab, "dlg_filters_state_tab");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, vbox71, "vbox71");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, alignment22, "alignment22");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, hbox133, "hbox133");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, frame41, "frame41");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, vbox74, "vbox74");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, checkbutton_filter_state_invert_cond, "checkbutton_filter_state_invert_cond");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, checkbutton_filter_state_active, "checkbutton_filter_state_active");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, checkbutton_filter_state_soft, "checkbutton_filter_state_soft");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, label250, "label250");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, frame42, "frame42");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, alignment23, "alignment23");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, table27, "table27");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, label_d249, "label_d249");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, radiobutton_filter_state_download_dont, "radiobutton_filter_state_download_dont");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, alignment55, "alignment55");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, hbox187, "hbox187");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, image87, "image87");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, label452, "label452");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, radiobutton_filter_state_download_undef, "radiobutton_filter_state_download_undef");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, alignment57, "alignment57");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, hbox189, "hbox189");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, image89, "image89");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, label454, "label454");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, label257, "label257");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, radiobutton_filter_state_download_do, "radiobutton_filter_state_download_do");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, alignment53, "alignment53");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, hbox185, "hbox185");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, image85, "image85");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, label450, "label450");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, radiobutton_filter_state_display_do, "radiobutton_filter_state_display_do");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, alignment52, "alignment52");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, hbox184, "hbox184");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, image84, "image84");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, label449, "label449");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, radiobutton_filter_state_display_dont, "radiobutton_filter_state_display_dont");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, alignment54, "alignment54");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, hbox186, "hbox186");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, image86, "image86");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, label451, "label451");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, radiobutton_filter_state_display_undef, "radiobutton_filter_state_display_undef");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, alignment56, "alignment56");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, hbox188, "hbox188");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, image88, "image88");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, label453, "label453");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, radiobutton_filter_state_display_ignore, "radiobutton_filter_state_display_ignore");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, alignment58, "alignment58");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, hbox190, "hbox190");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, image90, "image90");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, label455, "label455");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, radiobutton_filter_state_download_ignore, "radiobutton_filter_state_download_ignore");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, alignment59, "alignment59");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, hbox191, "hbox191");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, image91, "image91");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, label456, "label456");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, label_d251, "label_d251");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, hbox136, "hbox136");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, frame43, "frame43");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, optionmenu_filter_state_target, "optionmenu_filter_state_target");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, convertwidget40, "convertwidget40");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, label263, "label263");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, vbox73, "vbox73");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, button_filter_state_reset, "button_filter_state_reset");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, alignment138, "alignment138");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, hbox9336, "hbox9336");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, image1799, "image1799");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, label997, "label997");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, hbox9337, "hbox9337");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, button38, "button38");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, alignment139, "alignment139");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, hbox9338, "hbox9338");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, image1815, "image1815");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, label998, "label998");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, button39, "button39");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, alignment140, "alignment140");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, hbox9339, "hbox9339");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, image1816, "image1816");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, label999, "label999");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, button40, "button40");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, alignment141, "alignment141");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, hbox9340, "hbox9340");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, image1817, "image1817");
  GLADE_HOOKUP_OBJECT (dlg_filters_state_tab, label1000, "label1000");

  return dlg_filters_state_tab;
}

GtkWidget*
create_popup_nodes (void)
{
  GtkWidget *popup_nodes;
  GtkWidget *popup_nodes_disconnect;
  GtkWidget *image1262;
  GtkWidget *popup_nodes_reverse_lookup;
  GtkWidget *image1263;
  GtkWidget *popup_nodes_browse_host;
  GtkWidget *image1264;
  GtkWidget *separator30;
  GtkWidget *popup_nodes_config_cols;
  GtkWidget *image1265;

  popup_nodes = gtk_menu_new ();
  gtk_widget_set_name (popup_nodes, "popup_nodes");

  popup_nodes_disconnect = gtk_image_menu_item_new_with_mnemonic (_("Disconnect"));
  gtk_widget_set_name (popup_nodes_disconnect, "popup_nodes_disconnect");
  gtk_widget_show (popup_nodes_disconnect);
  gtk_container_add (GTK_CONTAINER (popup_nodes), popup_nodes_disconnect);

  image1262 = gtk_image_new_from_stock ("gtk-cancel", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image1262, "image1262");
  gtk_widget_show (image1262);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (popup_nodes_disconnect), image1262);

  popup_nodes_reverse_lookup = gtk_image_menu_item_new_with_mnemonic (_("Reverse DNS lookup"));
  gtk_widget_set_name (popup_nodes_reverse_lookup, "popup_nodes_reverse_lookup");
  gtk_widget_show (popup_nodes_reverse_lookup);
  gtk_container_add (GTK_CONTAINER (popup_nodes), popup_nodes_reverse_lookup);

  image1263 = gtk_image_new_from_stock ("gtk-dialog-info", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image1263, "image1263");
  gtk_widget_show (image1263);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (popup_nodes_reverse_lookup), image1263);

  popup_nodes_browse_host = gtk_image_menu_item_new_with_mnemonic (_("Browse Host"));
  gtk_widget_set_name (popup_nodes_browse_host, "popup_nodes_browse_host");
  gtk_widget_show (popup_nodes_browse_host);
  gtk_container_add (GTK_CONTAINER (popup_nodes), popup_nodes_browse_host);

  image1264 = gtk_image_new_from_stock ("gtk-zoom-in", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image1264, "image1264");
  gtk_widget_show (image1264);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (popup_nodes_browse_host), image1264);

  separator30 = gtk_separator_menu_item_new ();
  gtk_widget_set_name (separator30, "separator30");
  gtk_widget_show (separator30);
  gtk_container_add (GTK_CONTAINER (popup_nodes), separator30);
  gtk_widget_set_sensitive (separator30, FALSE);

  popup_nodes_config_cols = gtk_image_menu_item_new_with_mnemonic (_("Configure columns"));
  gtk_widget_set_name (popup_nodes_config_cols, "popup_nodes_config_cols");
  gtk_widget_show (popup_nodes_config_cols);
  gtk_container_add (GTK_CONTAINER (popup_nodes), popup_nodes_config_cols);

  image1265 = gtk_image_new_from_stock ("gtk-preferences", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image1265, "image1265");
  gtk_widget_show (image1265);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (popup_nodes_config_cols), image1265);

  g_signal_connect ((gpointer) popup_nodes_disconnect, "activate",
                    G_CALLBACK (on_popup_nodes_disconnect_activate),
                    NULL);
  g_signal_connect ((gpointer) popup_nodes_reverse_lookup, "activate",
                    G_CALLBACK (on_popup_nodes_reverse_lookup_activate),
                    NULL);
  g_signal_connect ((gpointer) popup_nodes_browse_host, "activate",
                    G_CALLBACK (on_popup_nodes_browse_host_activate),
                    NULL);
  g_signal_connect ((gpointer) popup_nodes_config_cols, "activate",
                    G_CALLBACK (on_popup_nodes_config_cols_activate),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (popup_nodes, popup_nodes, "popup_nodes");
  GLADE_HOOKUP_OBJECT (popup_nodes, popup_nodes_disconnect, "popup_nodes_disconnect");
  GLADE_HOOKUP_OBJECT (popup_nodes, image1262, "image1262");
  GLADE_HOOKUP_OBJECT (popup_nodes, popup_nodes_reverse_lookup, "popup_nodes_reverse_lookup");
  GLADE_HOOKUP_OBJECT (popup_nodes, image1263, "image1263");
  GLADE_HOOKUP_OBJECT (popup_nodes, popup_nodes_browse_host, "popup_nodes_browse_host");
  GLADE_HOOKUP_OBJECT (popup_nodes, image1264, "image1264");
  GLADE_HOOKUP_OBJECT (popup_nodes, separator30, "separator30");
  GLADE_HOOKUP_OBJECT (popup_nodes, popup_nodes_config_cols, "popup_nodes_config_cols");
  GLADE_HOOKUP_OBJECT (popup_nodes, image1265, "image1265");

  return popup_nodes;
}

GtkWidget*
create_main_window_hostcache_tab (void)
{
  GtkWidget *main_window_hostcache_tab;
  GtkWidget *vbox133;
  GtkWidget *scrolledwindow75;
  GtkWidget *treeview_hcache;
  GtkWidget *frame114;
  GtkWidget *hbox266;
  GtkWidget *vbox134;
  GtkWidget *progressbar_hosts_in_catcher;
  GtkWidget *hbox267;
  GtkWidget *label547;
  GtkObject *spinbutton_max_hosts_cached_adj;
  GtkWidget *spinbutton_max_hosts_cached;
  GtkWidget *button_host_catcher_clear;
  GtkWidget *vbox135;
  GtkWidget *progressbar_hosts_in_ultra_catcher;
  GtkWidget *hbox268;
  GtkWidget *label548;
  GtkObject *spinbutton_max_ultra_hosts_cached_adj;
  GtkWidget *spinbutton_max_ultra_hosts_cached;
  GtkWidget *button_ultra_catcher_clear;
  GtkWidget *vbox136;
  GtkWidget *progressbar_hosts_in_bad_catcher;
  GtkWidget *hbox269;
  GtkWidget *label845;
  GtkObject *spinbutton_max_bad_hosts_cached_adj;
  GtkWidget *spinbutton_max_bad_hosts_cached;
  GtkWidget *button_hostcache_clear_bad;
  GtkWidget *vbox161;
  GtkWidget *progressbar_hosts_in_g2hub_catcher;
  GtkWidget *hbox9353;
  GtkWidget *label1078;
  GtkObject *spinbutton_max_g2hub_hosts_cached_adj;
  GtkWidget *spinbutton_max_g2hub_hosts_cached;
  GtkWidget *button_g2hub_catcher_clear;
  GtkWidget *label843;

  main_window_hostcache_tab = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_widget_set_name (main_window_hostcache_tab, "main_window_hostcache_tab");

  vbox133 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox133, "vbox133");
  gtk_widget_show (vbox133);
  gtk_container_add (GTK_CONTAINER (main_window_hostcache_tab), vbox133);

  scrolledwindow75 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow75, "scrolledwindow75");
  gtk_widget_show (scrolledwindow75);
  gtk_box_pack_start (GTK_BOX (vbox133), scrolledwindow75, TRUE, TRUE, 0);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow75), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolledwindow75), GTK_SHADOW_IN);

  treeview_hcache = gtk_tree_view_new ();
  gtk_widget_set_name (treeview_hcache, "treeview_hcache");
  gtk_widget_show (treeview_hcache);
  gtk_container_add (GTK_CONTAINER (scrolledwindow75), treeview_hcache);

  frame114 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame114, "frame114");
  gtk_widget_show (frame114);
  gtk_box_pack_start (GTK_BOX (vbox133), frame114, FALSE, TRUE, 0);

  hbox266 = gtk_hbox_new (TRUE, 4);
  gtk_widget_set_name (hbox266, "hbox266");
  gtk_widget_show (hbox266);
  gtk_container_add (GTK_CONTAINER (frame114), hbox266);

  vbox134 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox134, "vbox134");
  gtk_widget_show (vbox134);
  gtk_box_pack_start (GTK_BOX (hbox266), vbox134, TRUE, TRUE, 0);

  progressbar_hosts_in_catcher = gtk_progress_bar_new ();
  gtk_widget_set_name (progressbar_hosts_in_catcher, "progressbar_hosts_in_catcher");
  gtk_widget_show (progressbar_hosts_in_catcher);
  gtk_box_pack_start (GTK_BOX (vbox134), progressbar_hosts_in_catcher, FALSE, FALSE, 0);

  hbox267 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox267, "hbox267");
  gtk_widget_show (hbox267);
  gtk_box_pack_start (GTK_BOX (vbox134), hbox267, TRUE, TRUE, 0);

  label547 = gtk_label_new (_("Regular hosts"));
  gtk_widget_set_name (label547, "label547");
  gtk_widget_show (label547);
  gtk_box_pack_start (GTK_BOX (hbox267), label547, FALSE, FALSE, 0);
  gtk_label_set_justify (GTK_LABEL (label547), GTK_JUSTIFY_CENTER);
  gtk_misc_set_padding (GTK_MISC (label547), 5, 0);

  spinbutton_max_hosts_cached_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 0);
  spinbutton_max_hosts_cached = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_max_hosts_cached_adj), 1, 0);
  gtk_widget_set_name (spinbutton_max_hosts_cached, "spinbutton_max_hosts_cached");
  gtk_widget_show (spinbutton_max_hosts_cached);
  gtk_box_pack_start (GTK_BOX (hbox267), spinbutton_max_hosts_cached, TRUE, TRUE, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_max_hosts_cached), TRUE);

  button_host_catcher_clear = gtk_button_new_with_mnemonic (_("Clear"));
  gtk_widget_set_name (button_host_catcher_clear, "button_host_catcher_clear");
  gtk_widget_show (button_host_catcher_clear);
  gtk_box_pack_start (GTK_BOX (hbox267), button_host_catcher_clear, FALSE, FALSE, 0);

  vbox135 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox135, "vbox135");
  gtk_widget_show (vbox135);
  gtk_box_pack_start (GTK_BOX (hbox266), vbox135, TRUE, TRUE, 0);

  progressbar_hosts_in_ultra_catcher = gtk_progress_bar_new ();
  gtk_widget_set_name (progressbar_hosts_in_ultra_catcher, "progressbar_hosts_in_ultra_catcher");
  gtk_widget_show (progressbar_hosts_in_ultra_catcher);
  gtk_box_pack_start (GTK_BOX (vbox135), progressbar_hosts_in_ultra_catcher, FALSE, FALSE, 0);

  hbox268 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox268, "hbox268");
  gtk_widget_show (hbox268);
  gtk_box_pack_start (GTK_BOX (vbox135), hbox268, TRUE, TRUE, 0);

  label548 = gtk_label_new (_("Ultrapeers"));
  gtk_widget_set_name (label548, "label548");
  gtk_widget_show (label548);
  gtk_box_pack_start (GTK_BOX (hbox268), label548, FALSE, FALSE, 0);
  gtk_label_set_justify (GTK_LABEL (label548), GTK_JUSTIFY_CENTER);
  gtk_misc_set_padding (GTK_MISC (label548), 5, 0);

  spinbutton_max_ultra_hosts_cached_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 0);
  spinbutton_max_ultra_hosts_cached = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_max_ultra_hosts_cached_adj), 1, 0);
  gtk_widget_set_name (spinbutton_max_ultra_hosts_cached, "spinbutton_max_ultra_hosts_cached");
  gtk_widget_show (spinbutton_max_ultra_hosts_cached);
  gtk_box_pack_start (GTK_BOX (hbox268), spinbutton_max_ultra_hosts_cached, TRUE, TRUE, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_max_ultra_hosts_cached), TRUE);

  button_ultra_catcher_clear = gtk_button_new_with_mnemonic (_("Clear"));
  gtk_widget_set_name (button_ultra_catcher_clear, "button_ultra_catcher_clear");
  gtk_widget_show (button_ultra_catcher_clear);
  gtk_box_pack_start (GTK_BOX (hbox268), button_ultra_catcher_clear, FALSE, FALSE, 0);

  vbox136 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox136, "vbox136");
  gtk_widget_show (vbox136);
  gtk_box_pack_start (GTK_BOX (hbox266), vbox136, TRUE, TRUE, 0);

  progressbar_hosts_in_bad_catcher = gtk_progress_bar_new ();
  gtk_widget_set_name (progressbar_hosts_in_bad_catcher, "progressbar_hosts_in_bad_catcher");
  gtk_widget_show (progressbar_hosts_in_bad_catcher);
  gtk_box_pack_start (GTK_BOX (vbox136), progressbar_hosts_in_bad_catcher, FALSE, FALSE, 0);

  hbox269 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox269, "hbox269");
  gtk_widget_show (hbox269);
  gtk_box_pack_start (GTK_BOX (vbox136), hbox269, TRUE, TRUE, 0);

  label845 = gtk_label_new (_("Bad hosts"));
  gtk_widget_set_name (label845, "label845");
  gtk_widget_show (label845);
  gtk_box_pack_start (GTK_BOX (hbox269), label845, FALSE, FALSE, 0);
  gtk_label_set_justify (GTK_LABEL (label845), GTK_JUSTIFY_CENTER);
  gtk_misc_set_padding (GTK_MISC (label845), 5, 0);

  spinbutton_max_bad_hosts_cached_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 0);
  spinbutton_max_bad_hosts_cached = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_max_bad_hosts_cached_adj), 1, 0);
  gtk_widget_set_name (spinbutton_max_bad_hosts_cached, "spinbutton_max_bad_hosts_cached");
  gtk_widget_show (spinbutton_max_bad_hosts_cached);
  gtk_box_pack_start (GTK_BOX (hbox269), spinbutton_max_bad_hosts_cached, TRUE, TRUE, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_max_bad_hosts_cached), TRUE);

  button_hostcache_clear_bad = gtk_button_new_with_mnemonic (_("Clear"));
  gtk_widget_set_name (button_hostcache_clear_bad, "button_hostcache_clear_bad");
  gtk_widget_show (button_hostcache_clear_bad);
  gtk_box_pack_start (GTK_BOX (hbox269), button_hostcache_clear_bad, FALSE, FALSE, 0);

  vbox161 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox161, "vbox161");
  gtk_widget_show (vbox161);
  gtk_box_pack_start (GTK_BOX (hbox266), vbox161, TRUE, TRUE, 0);

  progressbar_hosts_in_g2hub_catcher = gtk_progress_bar_new ();
  gtk_widget_set_name (progressbar_hosts_in_g2hub_catcher, "progressbar_hosts_in_g2hub_catcher");
  gtk_widget_show (progressbar_hosts_in_g2hub_catcher);
  gtk_box_pack_start (GTK_BOX (vbox161), progressbar_hosts_in_g2hub_catcher, FALSE, FALSE, 0);

  hbox9353 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox9353, "hbox9353");
  gtk_widget_show (hbox9353);
  gtk_box_pack_start (GTK_BOX (vbox161), hbox9353, TRUE, TRUE, 0);

  label1078 = gtk_label_new (_("G2 hubs"));
  gtk_widget_set_name (label1078, "label1078");
  gtk_widget_show (label1078);
  gtk_box_pack_start (GTK_BOX (hbox9353), label1078, FALSE, FALSE, 0);
  gtk_label_set_justify (GTK_LABEL (label1078), GTK_JUSTIFY_CENTER);
  gtk_misc_set_padding (GTK_MISC (label1078), 5, 0);

  spinbutton_max_g2hub_hosts_cached_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 0);
  spinbutton_max_g2hub_hosts_cached = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_max_g2hub_hosts_cached_adj), 1, 0);
  gtk_widget_set_name (spinbutton_max_g2hub_hosts_cached, "spinbutton_max_g2hub_hosts_cached");
  gtk_widget_show (spinbutton_max_g2hub_hosts_cached);
  gtk_box_pack_start (GTK_BOX (hbox9353), spinbutton_max_g2hub_hosts_cached, TRUE, TRUE, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_max_g2hub_hosts_cached), TRUE);

  button_g2hub_catcher_clear = gtk_button_new_with_mnemonic (_("Clear"));
  gtk_widget_set_name (button_g2hub_catcher_clear, "button_g2hub_catcher_clear");
  gtk_widget_show (button_g2hub_catcher_clear);
  gtk_box_pack_start (GTK_BOX (hbox9353), button_g2hub_catcher_clear, FALSE, FALSE, 0);

  label843 = gtk_label_new (_("Hostcache capacity"));
  gtk_widget_set_name (label843, "label843");
  gtk_widget_show (label843);
  gtk_frame_set_label_widget (GTK_FRAME (frame114), label843);
  gtk_label_set_use_markup (GTK_LABEL (label843), TRUE);

  g_signal_connect ((gpointer) button_host_catcher_clear, "clicked",
                    G_CALLBACK (on_button_host_catcher_clear_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_ultra_catcher_clear, "clicked",
                    G_CALLBACK (on_button_ultra_catcher_clear_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_hostcache_clear_bad, "clicked",
                    G_CALLBACK (on_button_hostcache_clear_bad_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_g2hub_catcher_clear, "clicked",
                    G_CALLBACK (on_button_hostcache_clear_bad_clicked),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (main_window_hostcache_tab, main_window_hostcache_tab, "main_window_hostcache_tab");
  GLADE_HOOKUP_OBJECT (main_window_hostcache_tab, vbox133, "vbox133");
  GLADE_HOOKUP_OBJECT (main_window_hostcache_tab, scrolledwindow75, "scrolledwindow75");
  GLADE_HOOKUP_OBJECT (main_window_hostcache_tab, treeview_hcache, "treeview_hcache");
  GLADE_HOOKUP_OBJECT (main_window_hostcache_tab, frame114, "frame114");
  GLADE_HOOKUP_OBJECT (main_window_hostcache_tab, hbox266, "hbox266");
  GLADE_HOOKUP_OBJECT (main_window_hostcache_tab, vbox134, "vbox134");
  GLADE_HOOKUP_OBJECT (main_window_hostcache_tab, progressbar_hosts_in_catcher, "progressbar_hosts_in_catcher");
  GLADE_HOOKUP_OBJECT (main_window_hostcache_tab, hbox267, "hbox267");
  GLADE_HOOKUP_OBJECT (main_window_hostcache_tab, label547, "label547");
  GLADE_HOOKUP_OBJECT (main_window_hostcache_tab, spinbutton_max_hosts_cached, "spinbutton_max_hosts_cached");
  GLADE_HOOKUP_OBJECT (main_window_hostcache_tab, button_host_catcher_clear, "button_host_catcher_clear");
  GLADE_HOOKUP_OBJECT (main_window_hostcache_tab, vbox135, "vbox135");
  GLADE_HOOKUP_OBJECT (main_window_hostcache_tab, progressbar_hosts_in_ultra_catcher, "progressbar_hosts_in_ultra_catcher");
  GLADE_HOOKUP_OBJECT (main_window_hostcache_tab, hbox268, "hbox268");
  GLADE_HOOKUP_OBJECT (main_window_hostcache_tab, label548, "label548");
  GLADE_HOOKUP_OBJECT (main_window_hostcache_tab, spinbutton_max_ultra_hosts_cached, "spinbutton_max_ultra_hosts_cached");
  GLADE_HOOKUP_OBJECT (main_window_hostcache_tab, button_ultra_catcher_clear, "button_ultra_catcher_clear");
  GLADE_HOOKUP_OBJECT (main_window_hostcache_tab, vbox136, "vbox136");
  GLADE_HOOKUP_OBJECT (main_window_hostcache_tab, progressbar_hosts_in_bad_catcher, "progressbar_hosts_in_bad_catcher");
  GLADE_HOOKUP_OBJECT (main_window_hostcache_tab, hbox269, "hbox269");
  GLADE_HOOKUP_OBJECT (main_window_hostcache_tab, label845, "label845");
  GLADE_HOOKUP_OBJECT (main_window_hostcache_tab, spinbutton_max_bad_hosts_cached, "spinbutton_max_bad_hosts_cached");
  GLADE_HOOKUP_OBJECT (main_window_hostcache_tab, button_hostcache_clear_bad, "button_hostcache_clear_bad");
  GLADE_HOOKUP_OBJECT (main_window_hostcache_tab, vbox161, "vbox161");
  GLADE_HOOKUP_OBJECT (main_window_hostcache_tab, progressbar_hosts_in_g2hub_catcher, "progressbar_hosts_in_g2hub_catcher");
  GLADE_HOOKUP_OBJECT (main_window_hostcache_tab, hbox9353, "hbox9353");
  GLADE_HOOKUP_OBJECT (main_window_hostcache_tab, label1078, "label1078");
  GLADE_HOOKUP_OBJECT (main_window_hostcache_tab, spinbutton_max_g2hub_hosts_cached, "spinbutton_max_g2hub_hosts_cached");
  GLADE_HOOKUP_OBJECT (main_window_hostcache_tab, button_g2hub_catcher_clear, "button_g2hub_catcher_clear");
  GLADE_HOOKUP_OBJECT (main_window_hostcache_tab, label843, "label843");

  return main_window_hostcache_tab;
}

GtkWidget*
create_popup_upload_stats (void)
{
  GtkWidget *popup_upload_stats;
  GtkWidget *popup_upload_stats_config_cols_activate;
  GtkWidget *image332;

  popup_upload_stats = gtk_menu_new ();
  gtk_widget_set_name (popup_upload_stats, "popup_upload_stats");

  popup_upload_stats_config_cols_activate = gtk_image_menu_item_new_with_mnemonic (_("Configure columns"));
  gtk_widget_set_name (popup_upload_stats_config_cols_activate, "popup_upload_stats_config_cols_activate");
  gtk_widget_show (popup_upload_stats_config_cols_activate);
  gtk_container_add (GTK_CONTAINER (popup_upload_stats), popup_upload_stats_config_cols_activate);

  image332 = gtk_image_new_from_stock ("gtk-preferences", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image332, "image332");
  gtk_widget_show (image332);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (popup_upload_stats_config_cols_activate), image332);

  g_signal_connect ((gpointer) popup_upload_stats_config_cols_activate, "activate",
                    G_CALLBACK (on_popup_upload_stats_config_cols_activate),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (popup_upload_stats, popup_upload_stats, "popup_upload_stats");
  GLADE_HOOKUP_OBJECT (popup_upload_stats, popup_upload_stats_config_cols_activate, "popup_upload_stats_config_cols_activate");
  GLADE_HOOKUP_OBJECT (popup_upload_stats, image332, "image332");

  return popup_upload_stats;
}

GtkWidget*
create_dlg_prefs (void)
{
  GtkWidget *dlg_prefs;
  GtkWidget *dialog_vbox3;
  GtkWidget *notebook_prefs;
  GtkWidget *empty_notebook_page;
  GtkWidget *label869;
  GtkWidget *dialog_action_area3;
  GtkWidget *button_prefs_close;

  dlg_prefs = gtk_dialog_new ();
  gtk_widget_set_name (dlg_prefs, "dlg_prefs");
  gtk_window_set_title (GTK_WINDOW (dlg_prefs), _("Preferences"));
  gtk_window_set_position (GTK_WINDOW (dlg_prefs), GTK_WIN_POS_MOUSE);
  gtk_window_set_default_size (GTK_WINDOW (dlg_prefs), 640, 480);
  gtk_window_set_type_hint (GTK_WINDOW (dlg_prefs), GDK_WINDOW_TYPE_HINT_DIALOG);

  dialog_vbox3 = GTK_DIALOG (dlg_prefs)->vbox;
  gtk_widget_set_name (dialog_vbox3, "dialog_vbox3");
  gtk_widget_show (dialog_vbox3);

  notebook_prefs = gtk_notebook_new ();
  gtk_widget_set_name (notebook_prefs, "notebook_prefs");
  gtk_widget_show (notebook_prefs);
  gtk_box_pack_start (GTK_BOX (dialog_vbox3), notebook_prefs, TRUE, TRUE, 0);

  empty_notebook_page = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (empty_notebook_page);
  gtk_container_add (GTK_CONTAINER (notebook_prefs), empty_notebook_page);

  label869 = gtk_label_new ("");
  gtk_widget_set_name (label869, "label869");
  gtk_widget_show (label869);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_prefs), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_prefs), 0), label869);

  dialog_action_area3 = GTK_DIALOG (dlg_prefs)->action_area;
  gtk_widget_set_name (dialog_action_area3, "dialog_action_area3");
  gtk_widget_show (dialog_action_area3);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area3), GTK_BUTTONBOX_END);

  button_prefs_close = gtk_button_new_from_stock ("gtk-close");
  gtk_widget_set_name (button_prefs_close, "button_prefs_close");
  gtk_widget_show (button_prefs_close);
  gtk_dialog_add_action_widget (GTK_DIALOG (dlg_prefs), button_prefs_close, GTK_RESPONSE_CLOSE);
  GTK_WIDGET_SET_FLAGS (button_prefs_close, GTK_CAN_DEFAULT);

  g_signal_connect ((gpointer) dlg_prefs, "delete_event",
                    G_CALLBACK (on_dlg_prefs_delete_event),
                    NULL);
  g_signal_connect ((gpointer) button_prefs_close, "clicked",
                    G_CALLBACK (on_button_prefs_close_clicked),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (dlg_prefs, dlg_prefs, "dlg_prefs");
  GLADE_HOOKUP_OBJECT_NO_REF (dlg_prefs, dialog_vbox3, "dialog_vbox3");
  GLADE_HOOKUP_OBJECT (dlg_prefs, notebook_prefs, "notebook_prefs");
  GLADE_HOOKUP_OBJECT (dlg_prefs, label869, "label869");
  GLADE_HOOKUP_OBJECT_NO_REF (dlg_prefs, dialog_action_area3, "dialog_action_area3");
  GLADE_HOOKUP_OBJECT (dlg_prefs, button_prefs_close, "button_prefs_close");

  return dlg_prefs;
}

GtkWidget*
create_dlg_prefs_net_tab (void)
{
  GtkWidget *dlg_prefs_net_tab;
  GtkWidget *scrolledwindow38;
  GtkWidget *viewport2;
  GtkWidget *vbox24;
  GtkWidget *frame13;
  GtkWidget *vbox30;
  GtkWidget *hbox79;
  GtkWidget *label128;
  GtkWidget *label_current_port;
  GtkWidget *hseparator2;
  GtkWidget *table102;
  GtkWidget *label35;
  GtkWidget *label129;
  GtkWidget *checkbutton_enable_udp;
  GtkWidget *option_menu_config_network_protocol;
  GtkWidget *label986;
  GtkObject *spinbutton_config_port_adj;
  GtkWidget *spinbutton_config_port;
  GtkWidget *checkbutton_give_server_hostname;
  GtkWidget *entry_server_hostname;
  GtkWidget *checkbutton_enable_dht;
  GtkWidget *label287;
  GtkWidget *frame144;
  GtkWidget *vbox147;
  GtkWidget *table111;
  GtkWidget *checkbutton_config_force_ip;
  GtkWidget *checkbutton_config_bind_ipv4;
  GtkWidget *entry_config_force_ip;
  GtkWidget *label1007;
  GtkWidget *frame145;
  GtkWidget *vbox148;
  GtkWidget *table112;
  GtkWidget *checkbutton_config_force_ipv6;
  GtkWidget *entry_config_force_ipv6;
  GtkWidget *checkbutton_config_bind_ipv6;
  GtkWidget *checkbutton_config_ipv6_trt_enable;
  GtkWidget *entry_config_ipv6_trt_prefix;
  GtkWidget *label1008;
  GtkWidget *frame_expert_nw_port_mapping;
  AtkObject *atko;
  GtkWidget *table118;
  GtkWidget *checkbutton_enable_natpmp;
  GtkWidget *checkbutton_enable_upnp;
  GtkWidget *label1077;
  GtkObject *spinbutton_config_upnp_mapping_lease_time_adj;
  GtkWidget *spinbutton_config_upnp_mapping_lease_time;
  GtkWidget *label1054;
  GtkWidget *frame_proxy_settings;
  GtkWidget *vbox28;
  GtkWidget *table47;
  GtkWidget *label91;
  GtkWidget *label92;
  GtkWidget *entry_config_proxy_hostname;
  GtkObject *spinbutton_config_proxy_port_adj;
  GtkWidget *spinbutton_config_proxy_port;
  GtkWidget *frame136;
  GtkWidget *option_menu_config_proxy_protocol;
  GtkWidget *label90;
  GtkWidget *hbox88;
  GtkWidget *checkbutton_config_proxy_auth;
  GtkWidget *hbox61;
  GtkWidget *label93;
  GtkWidget *entry_config_socks_username;
  GtkWidget *label94;
  GtkWidget *entry_config_socks_password;
  GtkWidget *label288;
  GtkWidget *frame_expert_nw_local;
  GtkWidget *vbox23_2;
  GtkWidget *hbox77;
  GtkWidget *checkbutton_config_use_netmasks;
  GtkWidget *checkbutton_config_no_rfc1918;
  GtkWidget *hbox78;
  GtkWidget *label126_2;
  GtkWidget *entry_config_netmasks;
  GtkWidget *label289;
  GtkWidget *frame_expert_nw_misc;
  GtkWidget *table43;
  GtkObject *spinbutton_config_ban_ratio_fds_adj;
  GtkWidget *spinbutton_config_ban_ratio_fds;
  GtkObject *spinbutton_config_ban_max_fds_adj;
  GtkWidget *spinbutton_config_ban_max_fds;
  GtkWidget *label835;
  GtkWidget *frame110;
  GtkWidget *label_banned_count;
  GtkWidget *viewport471;
  GtkWidget *entry_config_max_banned_fd;
  GtkWidget *checkbutton_use_global_hostiles;
  GtkWidget *label583;
  GtkWidget *label516;
  GtkWidget *label515;
  GtkWidget *label514;
  GtkWidget *table108;
  GtkWidget *frame83;
  GtkWidget *table72;
  GtkWidget *label701;
  GtkWidget *frame109;
  GtkWidget *label_clock_skew;
  GtkWidget *checkbutton_host_runs_ntp;
  GtkWidget *label698;
  GtkWidget *frame99;
  GtkWidget *vbox118;
  GtkWidget *checkbutton_enable_remote_shell;
  GtkWidget *label783;
  GtkWidget *frame_expert_rx_buffers;
  GtkWidget *table77;
  GtkWidget *label_kbytes_1;
  GtkWidget *label_kbytes;
  GtkObject *spinbutton_download_rx_size_adj;
  GtkWidget *spinbutton_download_rx_size;
  GtkObject *spinbutton_node_rx_size_adj;
  GtkWidget *spinbutton_node_rx_size;
  GtkWidget *label_download_rx_buffer;
  GtkWidget *label_node_rx_buffer;
  GtkWidget *label736;
  GtkTooltips *tooltips;

  tooltips = gtk_tooltips_new ();

  dlg_prefs_net_tab = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_widget_set_name (dlg_prefs_net_tab, "dlg_prefs_net_tab");
  gtk_window_set_title (GTK_WINDOW (dlg_prefs_net_tab), _("Network"));
  gtk_window_set_default_size (GTK_WINDOW (dlg_prefs_net_tab), 600, 400);

  scrolledwindow38 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow38, "scrolledwindow38");
  gtk_widget_show (scrolledwindow38);
  gtk_container_add (GTK_CONTAINER (dlg_prefs_net_tab), scrolledwindow38);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow38), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);

  viewport2 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport2, "viewport2");
  gtk_widget_show (viewport2);
  gtk_container_add (GTK_CONTAINER (scrolledwindow38), viewport2);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport2), GTK_SHADOW_NONE);

  vbox24 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox24, "vbox24");
  gtk_widget_show (vbox24);
  gtk_container_add (GTK_CONTAINER (viewport2), vbox24);
  gtk_container_set_border_width (GTK_CONTAINER (vbox24), 2);

  frame13 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame13, "frame13");
  gtk_widget_show (frame13);
  gtk_box_pack_start (GTK_BOX (vbox24), frame13, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame13), 4);

  vbox30 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox30, "vbox30");
  gtk_widget_show (vbox30);
  gtk_container_add (GTK_CONTAINER (frame13), vbox30);
  gtk_container_set_border_width (GTK_CONTAINER (vbox30), 2);

  hbox79 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox79, "hbox79");
  gtk_widget_show (hbox79);
  gtk_box_pack_start (GTK_BOX (vbox30), hbox79, FALSE, TRUE, 0);

  label128 = gtk_label_new (_("Current IP settings (Address:Port):"));
  gtk_widget_set_name (label128, "label128");
  gtk_widget_show (label128);
  gtk_box_pack_start (GTK_BOX (hbox79), label128, FALSE, FALSE, 0);
  gtk_label_set_justify (GTK_LABEL (label128), GTK_JUSTIFY_CENTER);

  label_current_port = gtk_label_new (_("not yet determined"));
  gtk_widget_set_name (label_current_port, "label_current_port");
  gtk_widget_show (label_current_port);
  gtk_box_pack_start (GTK_BOX (hbox79), label_current_port, FALSE, FALSE, 0);
  GTK_WIDGET_SET_FLAGS (label_current_port, GTK_CAN_FOCUS);
  gtk_label_set_justify (GTK_LABEL (label_current_port), GTK_JUSTIFY_CENTER);
  gtk_label_set_selectable (GTK_LABEL (label_current_port), TRUE);

  hseparator2 = gtk_hseparator_new ();
  gtk_widget_set_name (hseparator2, "hseparator2");
  gtk_widget_show (hseparator2);
  gtk_box_pack_start (GTK_BOX (vbox30), hseparator2, FALSE, TRUE, 3);

  table102 = gtk_table_new (2, 9, FALSE);
  gtk_widget_set_name (table102, "table102");
  gtk_widget_show (table102);
  gtk_box_pack_start (GTK_BOX (vbox30), table102, FALSE, TRUE, 0);
  gtk_table_set_row_spacings (GTK_TABLE (table102), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table102), 4);

  label35 = gtk_label_new (_("(Disable: 0, Random: 1)"));
  gtk_widget_set_name (label35, "label35");
  gtk_widget_show (label35);
  gtk_table_attach (GTK_TABLE (table102), label35, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label35), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label35), 0, 0.5);

  label129 = gtk_label_new_with_mnemonic (_("_Listen port"));
  gtk_widget_set_name (label129, "label129");
  gtk_widget_show (label129);
  gtk_table_attach (GTK_TABLE (table102), label129, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label129), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label129), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label129), 4, 0);

  checkbutton_enable_udp = gtk_check_button_new_with_mnemonic (_("Enable _UDP"));
  gtk_widget_set_name (checkbutton_enable_udp, "checkbutton_enable_udp");
  gtk_widget_show (checkbutton_enable_udp);
  gtk_table_attach (GTK_TABLE (table102), checkbutton_enable_udp, 6, 9, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  option_menu_config_network_protocol = gtk_option_menu_new ();
  gtk_widget_set_name (option_menu_config_network_protocol, "option_menu_config_network_protocol");
  gtk_widget_show (option_menu_config_network_protocol);
  gtk_table_attach (GTK_TABLE (table102), option_menu_config_network_protocol, 5, 6, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label986 = gtk_label_new (_("Network protocol:"));
  gtk_widget_set_name (label986, "label986");
  gtk_widget_show (label986);
  gtk_table_attach (GTK_TABLE (table102), label986, 3, 5, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 4, 0);
  gtk_misc_set_alignment (GTK_MISC (label986), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label986), 4, 0);

  spinbutton_config_port_adj = gtk_adjustment_new (6346, 0, 65535, 1, 10, 0);
  spinbutton_config_port = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_port_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_port, "spinbutton_config_port");
  gtk_widget_show (spinbutton_config_port);
  gtk_table_attach (GTK_TABLE (table102), spinbutton_config_port, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_port), TRUE);

  checkbutton_give_server_hostname = gtk_check_button_new_with_mnemonic (_("Public _hostname"));
  gtk_widget_set_name (checkbutton_give_server_hostname, "checkbutton_give_server_hostname");
  gtk_widget_show (checkbutton_give_server_hostname);
  gtk_table_attach (GTK_TABLE (table102), checkbutton_give_server_hostname, 0, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_server_hostname = gtk_entry_new ();
  gtk_widget_set_name (entry_server_hostname, "entry_server_hostname");
  gtk_widget_show (entry_server_hostname);
  gtk_table_attach (GTK_TABLE (table102), entry_server_hostname, 2, 5, 1, 2,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_enable_dht = gtk_check_button_new_with_mnemonic (_("Enable _DHT"));
  gtk_widget_set_name (checkbutton_enable_dht, "checkbutton_enable_dht");
  gtk_widget_show (checkbutton_enable_dht);
  gtk_table_attach (GTK_TABLE (table102), checkbutton_enable_dht, 6, 7, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label287 = gtk_label_new (_("IP settings"));
  gtk_widget_set_name (label287, "label287");
  gtk_widget_show (label287);
  gtk_frame_set_label_widget (GTK_FRAME (frame13), label287);

  frame144 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame144, "frame144");
  gtk_widget_show (frame144);
  gtk_box_pack_start (GTK_BOX (vbox24), frame144, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame144), 4);

  vbox147 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox147, "vbox147");
  gtk_widget_show (vbox147);
  gtk_container_add (GTK_CONTAINER (frame144), vbox147);
  gtk_container_set_border_width (GTK_CONTAINER (vbox147), 2);

  table111 = gtk_table_new (1, 3, FALSE);
  gtk_widget_set_name (table111, "table111");
  gtk_widget_show (table111);
  gtk_box_pack_start (GTK_BOX (vbox147), table111, FALSE, TRUE, 0);
  gtk_table_set_row_spacings (GTK_TABLE (table111), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table111), 4);

  checkbutton_config_force_ip = gtk_check_button_new_with_mnemonic (_("Force external IPv4 address to"));
  gtk_widget_set_name (checkbutton_config_force_ip, "checkbutton_config_force_ip");
  gtk_widget_show (checkbutton_config_force_ip);
  gtk_table_attach (GTK_TABLE (table111), checkbutton_config_force_ip, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_config_bind_ipv4 = gtk_check_button_new_with_mnemonic (_("_Bind to this address"));
  gtk_widget_set_name (checkbutton_config_bind_ipv4, "checkbutton_config_bind_ipv4");
  gtk_widget_show (checkbutton_config_bind_ipv4);
  gtk_table_attach (GTK_TABLE (table111), checkbutton_config_bind_ipv4, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_config_force_ip = gtk_entry_new ();
  gtk_widget_set_name (entry_config_force_ip, "entry_config_force_ip");
  gtk_widget_show (entry_config_force_ip);
  gtk_table_attach (GTK_TABLE (table111), entry_config_force_ip, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_entry_set_width_chars (GTK_ENTRY (entry_config_force_ip), 17);

  label1007 = gtk_label_new_with_mnemonic (_("IPv_4 settings"));
  gtk_widget_set_name (label1007, "label1007");
  gtk_widget_show (label1007);
  gtk_frame_set_label_widget (GTK_FRAME (frame144), label1007);

  frame145 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame145, "frame145");
  gtk_widget_show (frame145);
  gtk_box_pack_start (GTK_BOX (vbox24), frame145, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame145), 4);

  vbox148 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox148, "vbox148");
  gtk_widget_show (vbox148);
  gtk_container_add (GTK_CONTAINER (frame145), vbox148);

  table112 = gtk_table_new (2, 3, FALSE);
  gtk_widget_set_name (table112, "table112");
  gtk_widget_show (table112);
  gtk_box_pack_start (GTK_BOX (vbox148), table112, FALSE, TRUE, 0);
  gtk_table_set_row_spacings (GTK_TABLE (table112), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table112), 4);

  checkbutton_config_force_ipv6 = gtk_check_button_new_with_mnemonic (_("Force external IPv6 address to"));
  gtk_widget_set_name (checkbutton_config_force_ipv6, "checkbutton_config_force_ipv6");
  gtk_widget_show (checkbutton_config_force_ipv6);
  gtk_table_attach (GTK_TABLE (table112), checkbutton_config_force_ipv6, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_config_force_ipv6 = gtk_entry_new ();
  gtk_widget_set_name (entry_config_force_ipv6, "entry_config_force_ipv6");
  gtk_widget_show (entry_config_force_ipv6);
  gtk_table_attach (GTK_TABLE (table112), entry_config_force_ipv6, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_entry_set_width_chars (GTK_ENTRY (entry_config_force_ipv6), 50);

  checkbutton_config_bind_ipv6 = gtk_check_button_new_with_mnemonic (_("Bind to this address"));
  gtk_widget_set_name (checkbutton_config_bind_ipv6, "checkbutton_config_bind_ipv6");
  gtk_widget_show (checkbutton_config_bind_ipv6);
  gtk_table_attach (GTK_TABLE (table112), checkbutton_config_bind_ipv6, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_config_ipv6_trt_enable = gtk_check_button_new_with_mnemonic (_("Use IPv6-to-IPv4 TRT prefix:"));
  gtk_widget_set_name (checkbutton_config_ipv6_trt_enable, "checkbutton_config_ipv6_trt_enable");
  gtk_widget_show (checkbutton_config_ipv6_trt_enable);
  gtk_table_attach (GTK_TABLE (table112), checkbutton_config_ipv6_trt_enable, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_config_ipv6_trt_prefix = gtk_entry_new ();
  gtk_widget_set_name (entry_config_ipv6_trt_prefix, "entry_config_ipv6_trt_prefix");
  gtk_widget_show (entry_config_ipv6_trt_prefix);
  gtk_table_attach (GTK_TABLE (table112), entry_config_ipv6_trt_prefix, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_entry_set_width_chars (GTK_ENTRY (entry_config_ipv6_trt_prefix), 50);

  label1008 = gtk_label_new_with_mnemonic (_("IPv_6 settings"));
  gtk_widget_set_name (label1008, "label1008");
  gtk_widget_show (label1008);
  gtk_frame_set_label_widget (GTK_FRAME (frame145), label1008);

  frame_expert_nw_port_mapping = gtk_frame_new (NULL);
  gtk_widget_set_name (frame_expert_nw_port_mapping, "frame_expert_nw_port_mapping");
  gtk_widget_show (frame_expert_nw_port_mapping);
  gtk_box_pack_start (GTK_BOX (vbox24), frame_expert_nw_port_mapping, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame_expert_nw_port_mapping), 4);

  table118 = gtk_table_new (2, 2, FALSE);
  gtk_widget_set_name (table118, "table118");
  gtk_widget_show (table118);
  gtk_container_add (GTK_CONTAINER (frame_expert_nw_port_mapping), table118);
  gtk_container_set_border_width (GTK_CONTAINER (table118), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table118), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table118), 4);

  checkbutton_enable_natpmp = gtk_check_button_new_with_mnemonic (_("Enable NAT-PMP"));
  gtk_widget_set_name (checkbutton_enable_natpmp, "checkbutton_enable_natpmp");
  gtk_widget_show (checkbutton_enable_natpmp);
  gtk_table_attach (GTK_TABLE (table118), checkbutton_enable_natpmp, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_enable_upnp = gtk_check_button_new_with_mnemonic (_("Enable UPnP"));
  gtk_widget_set_name (checkbutton_enable_upnp, "checkbutton_enable_upnp");
  gtk_widget_show (checkbutton_enable_upnp);
  gtk_table_attach (GTK_TABLE (table118), checkbutton_enable_upnp, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label1077 = gtk_label_new (_("Mapping lease time"));
  gtk_widget_set_name (label1077, "label1077");
  gtk_widget_show (label1077);
  gtk_table_attach (GTK_TABLE (table118), label1077, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label1077), 0, 0.5);

  spinbutton_config_upnp_mapping_lease_time_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 0);
  spinbutton_config_upnp_mapping_lease_time = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_upnp_mapping_lease_time_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_upnp_mapping_lease_time, "spinbutton_config_upnp_mapping_lease_time");
  gtk_widget_show (spinbutton_config_upnp_mapping_lease_time);
  gtk_table_attach (GTK_TABLE (table118), spinbutton_config_upnp_mapping_lease_time, 1, 2, 1, 2,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);

  label1054 = gtk_label_new (_("Port Mapping"));
  gtk_widget_set_name (label1054, "label1054");
  gtk_widget_show (label1054);
  gtk_frame_set_label_widget (GTK_FRAME (frame_expert_nw_port_mapping), label1054);

  frame_proxy_settings = gtk_frame_new (NULL);
  gtk_widget_set_name (frame_proxy_settings, "frame_proxy_settings");
  gtk_widget_show (frame_proxy_settings);
  gtk_box_pack_start (GTK_BOX (vbox24), frame_proxy_settings, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame_proxy_settings), 4);

  vbox28 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox28, "vbox28");
  gtk_widget_show (vbox28);
  gtk_container_add (GTK_CONTAINER (frame_proxy_settings), vbox28);
  gtk_container_set_border_width (GTK_CONTAINER (vbox28), 2);

  table47 = gtk_table_new (1, 6, FALSE);
  gtk_widget_set_name (table47, "table47");
  gtk_widget_show (table47);
  gtk_box_pack_start (GTK_BOX (vbox28), table47, FALSE, TRUE, 0);
  gtk_table_set_row_spacings (GTK_TABLE (table47), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table47), 4);

  label91 = gtk_label_new_with_mnemonic (_("H_ost:"));
  gtk_widget_set_name (label91, "label91");
  gtk_widget_show (label91);
  gtk_table_attach (GTK_TABLE (table47), label91, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label91), 0, 0.5);

  label92 = gtk_label_new_with_mnemonic (_("TCP _Port:"));
  gtk_widget_set_name (label92, "label92");
  gtk_widget_show (label92);
  gtk_table_attach (GTK_TABLE (table47), label92, 4, 5, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label92), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label92), 0, 0.5);

  entry_config_proxy_hostname = gtk_entry_new ();
  gtk_widget_set_name (entry_config_proxy_hostname, "entry_config_proxy_hostname");
  gtk_widget_show (entry_config_proxy_hostname);
  gtk_table_attach (GTK_TABLE (table47), entry_config_proxy_hostname, 3, 4, 0, 1,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  spinbutton_config_proxy_port_adj = gtk_adjustment_new (3128, 1, 65535, 1, 10, 0);
  spinbutton_config_proxy_port = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_proxy_port_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_proxy_port, "spinbutton_config_proxy_port");
  gtk_widget_show (spinbutton_config_proxy_port);
  gtk_table_attach (GTK_TABLE (table47), spinbutton_config_proxy_port, 5, 6, 0, 1,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_proxy_port), TRUE);

  frame136 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame136, "frame136");
  gtk_widget_show (frame136);
  gtk_table_attach (GTK_TABLE (table47), frame136, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  option_menu_config_proxy_protocol = gtk_option_menu_new ();
  gtk_widget_set_name (option_menu_config_proxy_protocol, "option_menu_config_proxy_protocol");
  gtk_widget_show (option_menu_config_proxy_protocol);
  gtk_container_add (GTK_CONTAINER (frame136), option_menu_config_proxy_protocol);

  label90 = gtk_label_new_with_mnemonic (_("Proxy _type:"));
  gtk_widget_set_name (label90, "label90");
  gtk_widget_show (label90);
  gtk_table_attach (GTK_TABLE (table47), label90, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label90), 0, 0.5);

  hbox88 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox88, "hbox88");
  gtk_widget_show (hbox88);
  gtk_box_pack_start (GTK_BOX (vbox28), hbox88, FALSE, FALSE, 0);

  checkbutton_config_proxy_auth = gtk_check_button_new_with_mnemonic (_("Use username and password to _authenticate to proxy"));
  gtk_widget_set_name (checkbutton_config_proxy_auth, "checkbutton_config_proxy_auth");
  gtk_widget_show (checkbutton_config_proxy_auth);
  gtk_box_pack_start (GTK_BOX (hbox88), checkbutton_config_proxy_auth, FALSE, FALSE, 0);

  hbox61 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox61, "hbox61");
  gtk_widget_show (hbox61);
  gtk_box_pack_start (GTK_BOX (vbox28), hbox61, FALSE, TRUE, 0);

  label93 = gtk_label_new_with_mnemonic (_("_Username"));
  gtk_widget_set_name (label93, "label93");
  gtk_widget_show (label93);
  gtk_box_pack_start (GTK_BOX (hbox61), label93, FALSE, FALSE, 0);
  gtk_label_set_justify (GTK_LABEL (label93), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label93), 0, 0.5);

  entry_config_socks_username = gtk_entry_new ();
  gtk_widget_set_name (entry_config_socks_username, "entry_config_socks_username");
  gtk_widget_show (entry_config_socks_username);
  gtk_box_pack_start (GTK_BOX (hbox61), entry_config_socks_username, FALSE, FALSE, 0);

  label94 = gtk_label_new_with_mnemonic (_("Pass_word"));
  gtk_widget_set_name (label94, "label94");
  gtk_widget_show (label94);
  gtk_box_pack_start (GTK_BOX (hbox61), label94, FALSE, FALSE, 0);
  gtk_label_set_justify (GTK_LABEL (label94), GTK_JUSTIFY_CENTER);

  entry_config_socks_password = gtk_entry_new ();
  gtk_widget_set_name (entry_config_socks_password, "entry_config_socks_password");
  gtk_widget_show (entry_config_socks_password);
  gtk_box_pack_start (GTK_BOX (hbox61), entry_config_socks_password, FALSE, FALSE, 0);

  label288 = gtk_label_new (_("Proxy settings"));
  gtk_widget_set_name (label288, "label288");
  gtk_widget_show (label288);
  gtk_frame_set_label_widget (GTK_FRAME (frame_proxy_settings), label288);

  frame_expert_nw_local = gtk_frame_new (NULL);
  gtk_widget_set_name (frame_expert_nw_local, "frame_expert_nw_local");
  gtk_widget_show (frame_expert_nw_local);
  gtk_box_pack_start (GTK_BOX (vbox24), frame_expert_nw_local, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame_expert_nw_local), 4);

  vbox23_2 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox23_2, "vbox23_2");
  gtk_widget_show (vbox23_2);
  gtk_container_add (GTK_CONTAINER (frame_expert_nw_local), vbox23_2);
  gtk_container_set_border_width (GTK_CONTAINER (vbox23_2), 2);

  hbox77 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox77, "hbox77");
  gtk_widget_show (hbox77);
  gtk_box_pack_start (GTK_BOX (vbox23_2), hbox77, FALSE, TRUE, 0);

  checkbutton_config_use_netmasks = gtk_check_button_new_with_mnemonic (_("_Try to connect to local networks first"));
  gtk_widget_set_name (checkbutton_config_use_netmasks, "checkbutton_config_use_netmasks");
  gtk_widget_show (checkbutton_config_use_netmasks);
  gtk_box_pack_start (GTK_BOX (hbox77), checkbutton_config_use_netmasks, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, checkbutton_config_use_netmasks, _("This option can give performance boosts to those on a large network with many peers by trying to locate files on the local networks first."), NULL);

  checkbutton_config_no_rfc1918 = gtk_check_button_new_with_mnemonic (_("Allow connections from and to _LAN addresses"));
  gtk_widget_set_name (checkbutton_config_no_rfc1918, "checkbutton_config_no_rfc1918");
  gtk_widget_show (checkbutton_config_no_rfc1918);
  gtk_box_pack_start (GTK_BOX (hbox77), checkbutton_config_no_rfc1918, FALSE, FALSE, 0);
  gtk_tooltips_set_tip (tooltips, checkbutton_config_no_rfc1918, _("Check this button if you want to use gtk-gnutella on your Local Area Network. RFC1918 will be ignored."), NULL);

  hbox78 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox78, "hbox78");
  gtk_widget_show (hbox78);
  gtk_box_pack_start (GTK_BOX (vbox23_2), hbox78, FALSE, FALSE, 0);

  label126_2 = gtk_label_new_with_mnemonic (_("_Addresses of local network(s)"));
  gtk_widget_set_name (label126_2, "label126_2");
  gtk_widget_show (label126_2);
  gtk_box_pack_start (GTK_BOX (hbox78), label126_2, FALSE, FALSE, 0);
  gtk_label_set_justify (GTK_LABEL (label126_2), GTK_JUSTIFY_CENTER);
  gtk_misc_set_padding (GTK_MISC (label126_2), 4, 0);

  entry_config_netmasks = gtk_entry_new ();
  gtk_widget_set_name (entry_config_netmasks, "entry_config_netmasks");
  gtk_widget_show (entry_config_netmasks);
  gtk_box_pack_start (GTK_BOX (hbox78), entry_config_netmasks, TRUE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, entry_config_netmasks, _("Enter a semicolon separated list of networks that are local to you in the form of ip/bits or ip/netmask (eg 192.168.1.0/24 or 192.168.1.0/255.255.255.0)"), NULL);

  label289 = gtk_label_new (_("Local networks"));
  gtk_widget_set_name (label289, "label289");
  gtk_widget_show (label289);
  gtk_frame_set_label_widget (GTK_FRAME (frame_expert_nw_local), label289);

  frame_expert_nw_misc = gtk_frame_new (NULL);
  gtk_widget_set_name (frame_expert_nw_misc, "frame_expert_nw_misc");
  gtk_widget_show (frame_expert_nw_misc);
  gtk_box_pack_start (GTK_BOX (vbox24), frame_expert_nw_misc, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame_expert_nw_misc), 4);

  table43 = gtk_table_new (4, 4, FALSE);
  gtk_widget_set_name (table43, "table43");
  gtk_widget_show (table43);
  gtk_container_add (GTK_CONTAINER (frame_expert_nw_misc), table43);
  gtk_container_set_border_width (GTK_CONTAINER (table43), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table43), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table43), 4);

  spinbutton_config_ban_ratio_fds_adj = gtk_adjustment_new (0, 0, 100, 1, 10, 0);
  spinbutton_config_ban_ratio_fds = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_ban_ratio_fds_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_ban_ratio_fds, "spinbutton_config_ban_ratio_fds");
  gtk_widget_show (spinbutton_config_ban_ratio_fds);
  gtk_table_attach (GTK_TABLE (table43), spinbutton_config_ban_ratio_fds, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  spinbutton_config_ban_max_fds_adj = gtk_adjustment_new (0, 0, 100, 1, 10, 0);
  spinbutton_config_ban_max_fds = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_ban_max_fds_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_ban_max_fds, "spinbutton_config_ban_max_fds");
  gtk_widget_show (spinbutton_config_ban_max_fds);
  gtk_table_attach (GTK_TABLE (table43), spinbutton_config_ban_max_fds, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label835 = gtk_label_new (_("Currently used"));
  gtk_widget_set_name (label835, "label835");
  gtk_widget_show (label835);
  gtk_table_attach (GTK_TABLE (table43), label835, 2, 3, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label835), 0, 0.5);

  frame110 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame110, "frame110");
  gtk_widget_show (frame110);
  gtk_table_attach (GTK_TABLE (table43), frame110, 3, 4, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_frame_set_shadow_type (GTK_FRAME (frame110), GTK_SHADOW_NONE);

  label_banned_count = gtk_label_new ("[banned count]");
  gtk_widget_set_name (label_banned_count, "label_banned_count");
  gtk_widget_show (label_banned_count);
  gtk_container_add (GTK_CONTAINER (frame110), label_banned_count);
  gtk_misc_set_padding (GTK_MISC (label_banned_count), 5, 0);

  viewport471 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport471, "viewport471");
  gtk_widget_show (viewport471);
  gtk_table_attach (GTK_TABLE (table43), viewport471, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport471), GTK_SHADOW_ETCHED_IN);

  entry_config_max_banned_fd = gtk_entry_new ();
  gtk_widget_set_name (entry_config_max_banned_fd, "entry_config_max_banned_fd");
  gtk_widget_show (entry_config_max_banned_fd);
  gtk_container_add (GTK_CONTAINER (viewport471), entry_config_max_banned_fd);
  gtk_tooltips_set_tip (tooltips, entry_config_max_banned_fd, _("Actual amount of file descriptors used -- cannot be changed at runtime"), NULL);
  gtk_editable_set_editable (GTK_EDITABLE (entry_config_max_banned_fd), FALSE);
  gtk_entry_set_has_frame (GTK_ENTRY (entry_config_max_banned_fd), FALSE);
  gtk_entry_set_width_chars (GTK_ENTRY (entry_config_max_banned_fd), 6);

  checkbutton_use_global_hostiles = gtk_check_button_new_with_mnemonic (_("Use global hostiles.txt"));
  gtk_widget_set_name (checkbutton_use_global_hostiles, "checkbutton_use_global_hostiles");
  gtk_widget_show (checkbutton_use_global_hostiles);
  gtk_table_attach (GTK_TABLE (table43), checkbutton_use_global_hostiles, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label583 = gtk_label_new_with_mnemonic (_("Hard limit of _file descriptors used"));
  gtk_widget_set_name (label583, "label583");
  gtk_widget_show (label583);
  gtk_table_attach (GTK_TABLE (table43), label583, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label583), 0, 0.5);

  label516 = gtk_label_new_with_mnemonic (_("Max. _percentage of file descriptors"));
  gtk_widget_set_name (label516, "label516");
  gtk_widget_show (label516);
  gtk_table_attach (GTK_TABLE (table43), label516, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label516), 0, 0.5);

  label515 = gtk_label_new_with_mnemonic (_("Max. file _descriptors reserved"));
  gtk_widget_set_name (label515, "label515");
  gtk_widget_show (label515);
  gtk_table_attach (GTK_TABLE (table43), label515, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label515), 0, 0.5);

  label514 = gtk_label_new (_("Banning"));
  gtk_widget_set_name (label514, "label514");
  gtk_widget_show (label514);
  gtk_frame_set_label_widget (GTK_FRAME (frame_expert_nw_misc), label514);

  table108 = gtk_table_new (2, 2, FALSE);
  gtk_widget_set_name (table108, "table108");
  gtk_widget_show (table108);
  gtk_box_pack_start (GTK_BOX (vbox24), table108, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (table108), 4);
  gtk_table_set_row_spacings (GTK_TABLE (table108), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table108), 4);

  frame83 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame83, "frame83");
  gtk_widget_show (frame83);
  gtk_table_attach (GTK_TABLE (table108), frame83, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  table72 = gtk_table_new (1, 3, FALSE);
  gtk_widget_set_name (table72, "table72");
  gtk_widget_show (table72);
  gtk_container_add (GTK_CONTAINER (frame83), table72);
  gtk_container_set_border_width (GTK_CONTAINER (table72), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table72), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table72), 20);

  label701 = gtk_label_new (_("Clock skew:"));
  gtk_widget_set_name (label701, "label701");
  gtk_widget_show (label701);
  gtk_table_attach (GTK_TABLE (table72), label701, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label701), 1, 0.5);

  frame109 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame109, "frame109");
  gtk_widget_show (frame109);
  gtk_table_attach (GTK_TABLE (table72), frame109, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_frame_set_shadow_type (GTK_FRAME (frame109), GTK_SHADOW_NONE);

  label_clock_skew = gtk_label_new ("[clock skew]");
  gtk_widget_set_name (label_clock_skew, "label_clock_skew");
  gtk_widget_show (label_clock_skew);
  gtk_container_add (GTK_CONTAINER (frame109), label_clock_skew);
  gtk_misc_set_alignment (GTK_MISC (label_clock_skew), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_clock_skew), 4, 0);

  checkbutton_host_runs_ntp = gtk_check_button_new_with_mnemonic (_("Host runs _NTP"));
  gtk_widget_set_name (checkbutton_host_runs_ntp, "checkbutton_host_runs_ntp");
  gtk_widget_show (checkbutton_host_runs_ntp);
  gtk_table_attach (GTK_TABLE (table72), checkbutton_host_runs_ntp, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  label698 = gtk_label_new (_("Clock synchronization"));
  gtk_widget_set_name (label698, "label698");
  gtk_widget_show (label698);
  gtk_frame_set_label_widget (GTK_FRAME (frame83), label698);

  frame99 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame99, "frame99");
  gtk_widget_show (frame99);
  gtk_table_attach (GTK_TABLE (table108), frame99, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  vbox118 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox118, "vbox118");
  gtk_widget_show (vbox118);
  gtk_container_add (GTK_CONTAINER (frame99), vbox118);
  gtk_container_set_border_width (GTK_CONTAINER (vbox118), 2);

  checkbutton_enable_remote_shell = gtk_check_button_new_with_mnemonic (_("Enable remote _shell control interface"));
  gtk_widget_set_name (checkbutton_enable_remote_shell, "checkbutton_enable_remote_shell");
  gtk_widget_show (checkbutton_enable_remote_shell);
  gtk_box_pack_start (GTK_BOX (vbox118), checkbutton_enable_remote_shell, FALSE, FALSE, 0);

  label783 = gtk_label_new (_("Miscellaneous"));
  gtk_widget_set_name (label783, "label783");
  gtk_widget_show (label783);
  gtk_frame_set_label_widget (GTK_FRAME (frame99), label783);

  frame_expert_rx_buffers = gtk_frame_new (NULL);
  gtk_widget_set_name (frame_expert_rx_buffers, "frame_expert_rx_buffers");
  gtk_widget_show (frame_expert_rx_buffers);
  gtk_table_attach (GTK_TABLE (table108), frame_expert_rx_buffers, 1, 2, 0, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  table77 = gtk_table_new (2, 3, FALSE);
  gtk_widget_set_name (table77, "table77");
  gtk_widget_show (table77);
  gtk_container_add (GTK_CONTAINER (frame_expert_rx_buffers), table77);
  gtk_container_set_border_width (GTK_CONTAINER (table77), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table77), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table77), 4);

  label_kbytes_1 = gtk_label_new ("KiB");
  gtk_widget_set_name (label_kbytes_1, "label_kbytes_1");
  gtk_widget_show (label_kbytes_1);
  gtk_table_attach (GTK_TABLE (table77), label_kbytes_1, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_padding (GTK_MISC (label_kbytes_1), 2, 2);

  label_kbytes = gtk_label_new ("KiB");
  gtk_widget_set_name (label_kbytes, "label_kbytes");
  gtk_widget_show (label_kbytes);
  gtk_table_attach (GTK_TABLE (table77), label_kbytes, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_kbytes), 0, 0);
  gtk_misc_set_padding (GTK_MISC (label_kbytes), 2, 2);

  spinbutton_download_rx_size_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 0);
  spinbutton_download_rx_size = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_download_rx_size_adj), 1, 0);
  gtk_widget_set_name (spinbutton_download_rx_size, "spinbutton_download_rx_size");
  gtk_widget_show (spinbutton_download_rx_size);
  gtk_table_attach (GTK_TABLE (table77), spinbutton_download_rx_size, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  spinbutton_node_rx_size_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 0);
  spinbutton_node_rx_size = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_node_rx_size_adj), 1, 0);
  gtk_widget_set_name (spinbutton_node_rx_size, "spinbutton_node_rx_size");
  gtk_widget_show (spinbutton_node_rx_size);
  gtk_table_attach (GTK_TABLE (table77), spinbutton_node_rx_size, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label_download_rx_buffer = gtk_label_new_with_mnemonic (_("_Download RX buffer:"));
  gtk_widget_set_name (label_download_rx_buffer, "label_download_rx_buffer");
  gtk_widget_show (label_download_rx_buffer);
  gtk_table_attach (GTK_TABLE (table77), label_download_rx_buffer, 0, 1, 0, 1,
                    (GtkAttachOptions) (0),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_download_rx_buffer), 0, 0.5);

  label_node_rx_buffer = gtk_label_new_with_mnemonic (_("_Gnutella RX buffer:"));
  gtk_widget_set_name (label_node_rx_buffer, "label_node_rx_buffer");
  gtk_widget_show (label_node_rx_buffer);
  gtk_table_attach (GTK_TABLE (table77), label_node_rx_buffer, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label_node_rx_buffer), 0, 0.5);

  label736 = gtk_label_new (_("Socket receive buffer size"));
  gtk_widget_set_name (label736, "label736");
  gtk_widget_show (label736);
  gtk_frame_set_label_widget (GTK_FRAME (frame_expert_rx_buffers), label736);

  g_signal_connect ((gpointer) entry_server_hostname, "activate",
                    G_CALLBACK (on_entry_server_hostname_activate),
                    NULL);
  g_signal_connect ((gpointer) entry_server_hostname, "focus_out_event",
                    G_CALLBACK (on_entry_server_hostname_focus_out_event),
                    NULL);
  g_signal_connect ((gpointer) entry_config_force_ip, "activate",
                    G_CALLBACK (on_entry_config_force_ip_activate),
                    NULL);
  g_signal_connect ((gpointer) entry_config_force_ip, "focus_out_event",
                    G_CALLBACK (on_entry_config_force_ip_focus_out_event),
                    NULL);
  g_signal_connect ((gpointer) entry_config_force_ipv6, "activate",
                    G_CALLBACK (on_entry_config_force_ipv6_activate),
                    NULL);
  g_signal_connect ((gpointer) entry_config_force_ipv6, "focus_out_event",
                    G_CALLBACK (on_entry_config_force_ipv6_focus_out_event),
                    NULL);
  g_signal_connect ((gpointer) entry_config_ipv6_trt_prefix, "activate",
                    G_CALLBACK (on_entry_config_ipv6_trt_prefix_activate),
                    NULL);
  g_signal_connect ((gpointer) entry_config_ipv6_trt_prefix, "focus_out_event",
                    G_CALLBACK (on_entry_config_ipv6_trt_prefix_focus_out_event),
                    NULL);
  g_signal_connect ((gpointer) entry_config_proxy_hostname, "activate",
                    G_CALLBACK (on_entry_config_proxy_hostname_activate),
                    NULL);
  g_signal_connect ((gpointer) entry_config_proxy_hostname, "focus_out_event",
                    G_CALLBACK (on_entry_config_proxy_hostname_focus_out_event),
                    NULL);
  g_signal_connect ((gpointer) entry_config_socks_username, "activate",
                    G_CALLBACK (on_entry_config_socks_username_activate),
                    NULL);
  g_signal_connect ((gpointer) entry_config_socks_username, "focus_out_event",
                    G_CALLBACK (on_entry_config_socks_username_focus_out_event),
                    NULL);
  g_signal_connect ((gpointer) entry_config_socks_password, "activate",
                    G_CALLBACK (on_entry_config_socks_password_activate),
                    NULL);
  g_signal_connect ((gpointer) entry_config_socks_password, "focus_out_event",
                    G_CALLBACK (on_entry_config_socks_password_focus_out_event),
                    NULL);
  g_signal_connect ((gpointer) entry_config_netmasks, "focus_out_event",
                    G_CALLBACK (on_entry_config_netmask_focus_out_event),
                    NULL);
  g_signal_connect ((gpointer) entry_config_netmasks, "activate",
                    G_CALLBACK (on_entry_config_netmask_activate),
                    NULL);

  gtk_label_set_mnemonic_widget (GTK_LABEL (label129), spinbutton_config_port);
  gtk_label_set_mnemonic_widget (GTK_LABEL (label91), entry_config_proxy_hostname);
  gtk_label_set_mnemonic_widget (GTK_LABEL (label92), spinbutton_config_proxy_port);
  gtk_label_set_mnemonic_widget (GTK_LABEL (label93), entry_config_socks_username);
  gtk_label_set_mnemonic_widget (GTK_LABEL (label94), entry_config_socks_password);
  gtk_label_set_mnemonic_widget (GTK_LABEL (label126_2), entry_config_netmasks);
  gtk_label_set_mnemonic_widget (GTK_LABEL (label583), entry_config_max_banned_fd);
  gtk_label_set_mnemonic_widget (GTK_LABEL (label516), spinbutton_config_ban_ratio_fds);
  gtk_label_set_mnemonic_widget (GTK_LABEL (label515), spinbutton_config_ban_max_fds);
  gtk_label_set_mnemonic_widget (GTK_LABEL (label_download_rx_buffer), spinbutton_download_rx_size);
  gtk_label_set_mnemonic_widget (GTK_LABEL (label_node_rx_buffer), spinbutton_node_rx_size);

  atko = gtk_widget_get_accessible (frame_expert_nw_port_mapping);
  atk_object_set_name (atko, _("Port Mapping"));

  atko = gtk_widget_get_accessible (label1054);
  atk_object_set_name (atko, _("Port Mapping"));


  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (dlg_prefs_net_tab, dlg_prefs_net_tab, "dlg_prefs_net_tab");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, scrolledwindow38, "scrolledwindow38");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, viewport2, "viewport2");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, vbox24, "vbox24");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, frame13, "frame13");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, vbox30, "vbox30");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, hbox79, "hbox79");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, label128, "label128");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, label_current_port, "label_current_port");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, hseparator2, "hseparator2");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, table102, "table102");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, label35, "label35");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, label129, "label129");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, checkbutton_enable_udp, "checkbutton_enable_udp");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, option_menu_config_network_protocol, "option_menu_config_network_protocol");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, label986, "label986");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, spinbutton_config_port, "spinbutton_config_port");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, checkbutton_give_server_hostname, "checkbutton_give_server_hostname");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, entry_server_hostname, "entry_server_hostname");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, checkbutton_enable_dht, "checkbutton_enable_dht");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, label287, "label287");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, frame144, "frame144");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, vbox147, "vbox147");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, table111, "table111");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, checkbutton_config_force_ip, "checkbutton_config_force_ip");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, checkbutton_config_bind_ipv4, "checkbutton_config_bind_ipv4");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, entry_config_force_ip, "entry_config_force_ip");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, label1007, "label1007");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, frame145, "frame145");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, vbox148, "vbox148");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, table112, "table112");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, checkbutton_config_force_ipv6, "checkbutton_config_force_ipv6");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, entry_config_force_ipv6, "entry_config_force_ipv6");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, checkbutton_config_bind_ipv6, "checkbutton_config_bind_ipv6");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, checkbutton_config_ipv6_trt_enable, "checkbutton_config_ipv6_trt_enable");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, entry_config_ipv6_trt_prefix, "entry_config_ipv6_trt_prefix");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, label1008, "label1008");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, frame_expert_nw_port_mapping, "frame_expert_nw_port_mapping");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, table118, "table118");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, checkbutton_enable_natpmp, "checkbutton_enable_natpmp");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, checkbutton_enable_upnp, "checkbutton_enable_upnp");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, label1077, "label1077");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, spinbutton_config_upnp_mapping_lease_time, "spinbutton_config_upnp_mapping_lease_time");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, label1054, "label1054");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, frame_proxy_settings, "frame_proxy_settings");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, vbox28, "vbox28");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, table47, "table47");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, label91, "label91");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, label92, "label92");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, entry_config_proxy_hostname, "entry_config_proxy_hostname");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, spinbutton_config_proxy_port, "spinbutton_config_proxy_port");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, frame136, "frame136");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, option_menu_config_proxy_protocol, "option_menu_config_proxy_protocol");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, label90, "label90");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, hbox88, "hbox88");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, checkbutton_config_proxy_auth, "checkbutton_config_proxy_auth");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, hbox61, "hbox61");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, label93, "label93");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, entry_config_socks_username, "entry_config_socks_username");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, label94, "label94");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, entry_config_socks_password, "entry_config_socks_password");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, label288, "label288");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, frame_expert_nw_local, "frame_expert_nw_local");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, vbox23_2, "vbox23_2");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, hbox77, "hbox77");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, checkbutton_config_use_netmasks, "checkbutton_config_use_netmasks");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, checkbutton_config_no_rfc1918, "checkbutton_config_no_rfc1918");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, hbox78, "hbox78");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, label126_2, "label126_2");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, entry_config_netmasks, "entry_config_netmasks");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, label289, "label289");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, frame_expert_nw_misc, "frame_expert_nw_misc");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, table43, "table43");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, spinbutton_config_ban_ratio_fds, "spinbutton_config_ban_ratio_fds");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, spinbutton_config_ban_max_fds, "spinbutton_config_ban_max_fds");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, label835, "label835");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, frame110, "frame110");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, label_banned_count, "label_banned_count");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, viewport471, "viewport471");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, entry_config_max_banned_fd, "entry_config_max_banned_fd");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, checkbutton_use_global_hostiles, "checkbutton_use_global_hostiles");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, label583, "label583");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, label516, "label516");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, label515, "label515");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, label514, "label514");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, table108, "table108");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, frame83, "frame83");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, table72, "table72");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, label701, "label701");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, frame109, "frame109");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, label_clock_skew, "label_clock_skew");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, checkbutton_host_runs_ntp, "checkbutton_host_runs_ntp");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, label698, "label698");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, frame99, "frame99");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, vbox118, "vbox118");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, checkbutton_enable_remote_shell, "checkbutton_enable_remote_shell");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, label783, "label783");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, frame_expert_rx_buffers, "frame_expert_rx_buffers");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, table77, "table77");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, label_kbytes_1, "label_kbytes_1");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, label_kbytes, "label_kbytes");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, spinbutton_download_rx_size, "spinbutton_download_rx_size");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, spinbutton_node_rx_size, "spinbutton_node_rx_size");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, label_download_rx_buffer, "label_download_rx_buffer");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, label_node_rx_buffer, "label_node_rx_buffer");
  GLADE_HOOKUP_OBJECT (dlg_prefs_net_tab, label736, "label736");
  GLADE_HOOKUP_OBJECT_NO_REF (dlg_prefs_net_tab, tooltips, "tooltips");

  return dlg_prefs_net_tab;
}

GtkWidget*
create_dlg_prefs_gnet_tab (void)
{
  GtkWidget *dlg_prefs_gnet_tab;
  GtkWidget *scrolledwindow40;
  GtkWidget *viewport4;
  GtkWidget *vbox25;
  GtkWidget *frame92;
  GtkWidget *hbox253;
  GtkWidget *table91;
  GtkWidget *frame78;
  GtkWidget *table92;
  GtkObject *spinbutton_normal_connections_adj;
  GtkWidget *spinbutton_normal_connections;
  GtkWidget *label577;
  GtkObject *spinbutton_config_max_leaves_adj;
  GtkWidget *spinbutton_config_max_leaves;
  GtkWidget *label576;
  GtkWidget *label575;
  GtkWidget *checkbutton_gnet_monitor_ip;
  GtkWidget *checkbutton_gnet_monitor_servents;
  GtkWidget *label537;
  GtkWidget *frame135;
  GtkWidget *option_menu_config_peermode;
  GtkWidget *frame_gnet_can_become_ultra;
  GtkWidget *frame138;
  GtkWidget *vbox116;
  GtkWidget *table83;
  GtkWidget *label752;
  GtkWidget *label753;
  GtkWidget *viewport75;
  GtkWidget *label_last_ultra_leaf_switch;
  GtkWidget *viewport74;
  GtkWidget *label_node_last_ultracheck;
  GtkWidget *hseparator12;
  GtkWidget *table84;
  GtkWidget *label756;
  GtkWidget *label757;
  GtkWidget *label758;
  GtkWidget *label759;
  GtkWidget *label768;
  GtkWidget *label769;
  GtkWidget *label767;
  GtkWidget *viewport79;
  GtkWidget *label_up_req_enough_bw;
  GtkWidget *viewport78;
  GtkWidget *label_up_req_enough_fd;
  GtkWidget *viewport77;
  GtkWidget *label_up_req_node_uptime;
  GtkWidget *viewport76;
  GtkWidget *label_up_req_avg_servent_uptime;
  GtkWidget *viewport80;
  GtkWidget *label_up_req_avg_ip_uptime;
  GtkWidget *viewport81;
  GtkWidget *label_up_req_not_firewalled;
  GtkWidget *viewport82;
  GtkWidget *label_up_req_enough_mem;
  GtkWidget *viewport107;
  GtkWidget *label_up_req_enough_conn;
  GtkWidget *label868;
  GtkWidget *vseparator3;
  GtkWidget *label994;
  GtkWidget *viewport476;
  GtkWidget *label_up_req_good_udp;
  GtkWidget *label920;
  GtkWidget *label739;
  GtkWidget *hbox286;
  GtkWidget *frame_searches;
  GtkWidget *hbox254;
  GtkWidget *table17;
  GtkObject *spinbutton_config_search_items_adj;
  GtkWidget *spinbutton_config_search_items;
  GtkObject *spinbutton_config_search_reissue_timeout_adj;
  GtkWidget *spinbutton_config_search_reissue_timeout;
  GtkWidget *label38;
  GtkWidget *label37;
  GtkWidget *label364;
  GtkWidget *label365;
  GtkWidget *checkbutton_enable_guess;
  GtkWidget *checkbutton_enable_guess_client;
  GtkWidget *checkbutton_enable_g2;
  GtkWidget *label293;
  GtkWidget *frame_expert_oob_queries;
  GtkWidget *table101;
  GtkWidget *checkbutton_send_oob_queries;
  GtkWidget *checkbutton_process_oob_queries;
  GtkWidget *checkbutton_proxy_oob_queries;
  GtkWidget *label885;
  GtkWidget *vbox158;
  GtkWidget *frame_expert_search_queue;
  GtkWidget *table100;
  GtkWidget *label771;
  GtkWidget *label772;
  GtkObject *spinbutton_search_queue_size_adj;
  GtkWidget *spinbutton_search_queue_size;
  GtkObject *spinbutton_search_queue_spacing_adj;
  GtkWidget *spinbutton_search_queue_spacing;
  GtkWidget *label983;
  GtkWidget *label984;
  GtkWidget *label770;
  GtkWidget *checkbutton_config_query_request_partials;
  GtkWidget *checkbutton_config_search_smart_stop;
  GtkWidget *checkbutton_search_restart_when_pending;
  GtkWidget *hbox9352;
  GtkWidget *frame_expert_gnet_timeout;
  GtkWidget *table10;
  GtkWidget *label175;
  GtkWidget *label177;
  GtkWidget *label176;
  GtkWidget *label584;
  GtkObject *spinbutton_config_node_connecting_timeout_adj;
  GtkWidget *spinbutton_config_node_connecting_timeout;
  GtkObject *spinbutton_config_node_tx_flowc_timeout_adj;
  GtkWidget *spinbutton_config_node_tx_flowc_timeout;
  GtkObject *spinbutton_config_node_connected_timeout_adj;
  GtkWidget *spinbutton_config_node_connected_timeout;
  GtkObject *spinbutton_config_incoming_connecting_timeout_adj;
  GtkWidget *spinbutton_config_incoming_connecting_timeout;
  GtkWidget *label294;
  GtkWidget *frame_expert_gnet_dht;
  GtkWidget *table120;
  GtkWidget *label1075;
  GtkWidget *option_menu_config_dht_mode;
  GtkWidget *checkbutton_config_dht_storage_in_memory;
  GtkWidget *label1074;
  GtkWidget *frame_expert_gnet_ttl;
  GtkWidget *vbox143;
  GtkWidget *table9;
  GtkObject *spinbutton_config_maxttl_adj;
  GtkWidget *spinbutton_config_maxttl;
  GtkObject *spinbutton_config_myttl_adj;
  GtkWidget *spinbutton_config_myttl;
  GtkWidget *label84;
  GtkWidget *label85;
  GtkWidget *label159;
  GtkObject *spinbutton_config_hard_ttl_limit_adj;
  GtkWidget *spinbutton_config_hard_ttl_limit;
  GtkWidget *vbox144;
  GtkWidget *hbox9294;
  GtkWidget *label157;
  GtkObject *spinbutton_config_max_high_ttl_msg_adj;
  GtkWidget *spinbutton_config_max_high_ttl_msg;
  GtkWidget *label158;
  GtkObject *spinbutton_config_max_high_ttl_radius_adj;
  GtkWidget *spinbutton_config_max_high_ttl_radius;
  GtkWidget *label160;
  GtkWidget *label295;
  GtkWidget *frame_expert_gnet_quality;
  GtkWidget *table37;
  GtkWidget *label433;
  GtkObject *spinbutton_config_min_dup_msg_adj;
  GtkWidget *spinbutton_config_min_dup_msg;
  GtkObject *spinbutton_config_min_dup_ratio_adj;
  GtkWidget *spinbutton_config_min_dup_ratio;
  GtkWidget *label431;
  GtkWidget *label430;
  GtkWidget *label574;
  GtkObject *spinbutton_config_node_rx_flowc_ratio_adj;
  GtkWidget *spinbutton_config_node_rx_flowc_ratio;
  GtkWidget *label573;
  GtkWidget *label773;
  GtkObject *spinbutton_node_queries_half_life_adj;
  GtkWidget *spinbutton_node_queries_half_life;
  GtkWidget *label774;
  GtkObject *spinbutton_node_requery_threshold_adj;
  GtkWidget *spinbutton_node_requery_threshold;
  GtkWidget *checkbutton_node_watch_similar_queries;
  GtkWidget *label982;
  GtkWidget *vseparator4;
  GtkWidget *label1076;
  GtkObject *spinbutton_config_search_muid_track_amount_adj;
  GtkWidget *spinbutton_config_search_muid_track_amount;
  GtkWidget *label429;
  GtkWidget *hbox287;
  GtkWidget *frame_expert_gnet_connections;
  GtkWidget *table74;
  GtkWidget *label728;
  GtkWidget *label730;
  GtkWidget *label731;
  GtkWidget *label729;
  GtkObject *spinbutton_config_reserve_gtkg_nodes_adj;
  GtkWidget *spinbutton_config_reserve_gtkg_nodes;
  GtkObject *spinbutton_config_unique_nodes_adj;
  GtkWidget *spinbutton_config_unique_nodes;
  GtkWidget *label727;
  GtkWidget *frame_expert_gnet_other;
  GtkWidget *table51;
  GtkObject *spinbutton_config_hops_random_factor_adj;
  GtkWidget *spinbutton_config_hops_random_factor;
  GtkWidget *label518;
  GtkWidget *checkbutton_gnet_compact_query;
  GtkWidget *checkbutton_config_spam_lut_in_memory;
  GtkWidget *label362;
  GtkWidget *frame_expert_gnet_message_size;
  GtkWidget *table85;
  GtkWidget *label777;
  GtkWidget *label778;
  GtkWidget *label782;
  GtkObject *spinbutton_search_queries_forward_size_adj;
  GtkWidget *spinbutton_search_queries_forward_size;
  GtkObject *spinbutton_search_answers_forward_size_adj;
  GtkWidget *spinbutton_search_answers_forward_size;
  GtkObject *spinbutton_search_queries_kick_size_adj;
  GtkWidget *spinbutton_search_queries_kick_size;
  GtkObject *spinbutton_search_answers_kick_size_adj;
  GtkWidget *spinbutton_search_answers_kick_size;
  GtkObject *spinbutton_other_messages_kick_size_adj;
  GtkWidget *spinbutton_other_messages_kick_size;
  GtkWidget *label776;
  GtkWidget *label779;
  GtkWidget *label780;
  GtkWidget *label781;
  GtkWidget *label775;
  GtkTooltips *tooltips;

  tooltips = gtk_tooltips_new ();

  dlg_prefs_gnet_tab = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_widget_set_name (dlg_prefs_gnet_tab, "dlg_prefs_gnet_tab");
  gtk_window_set_title (GTK_WINDOW (dlg_prefs_gnet_tab), _("Gnutella"));
  gtk_window_set_default_size (GTK_WINDOW (dlg_prefs_gnet_tab), 600, 400);

  scrolledwindow40 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow40, "scrolledwindow40");
  gtk_widget_show (scrolledwindow40);
  gtk_container_add (GTK_CONTAINER (dlg_prefs_gnet_tab), scrolledwindow40);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow40), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);

  viewport4 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport4, "viewport4");
  gtk_widget_show (viewport4);
  gtk_container_add (GTK_CONTAINER (scrolledwindow40), viewport4);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport4), GTK_SHADOW_NONE);

  vbox25 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox25, "vbox25");
  gtk_widget_show (vbox25);
  gtk_container_add (GTK_CONTAINER (viewport4), vbox25);
  gtk_container_set_border_width (GTK_CONTAINER (vbox25), 2);

  frame92 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame92, "frame92");
  gtk_widget_show (frame92);
  gtk_box_pack_start (GTK_BOX (vbox25), frame92, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame92), 4);

  hbox253 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox253, "hbox253");
  gtk_widget_show (hbox253);
  gtk_container_add (GTK_CONTAINER (frame92), hbox253);
  gtk_container_set_border_width (GTK_CONTAINER (hbox253), 2);

  table91 = gtk_table_new (4, 2, FALSE);
  gtk_widget_set_name (table91, "table91");
  gtk_widget_show (table91);
  gtk_box_pack_start (GTK_BOX (hbox253), table91, FALSE, TRUE, 0);
  gtk_table_set_row_spacings (GTK_TABLE (table91), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table91), 4);

  frame78 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame78, "frame78");
  gtk_widget_show (frame78);
  gtk_table_attach (GTK_TABLE (table91), frame78, 0, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  table92 = gtk_table_new (2, 2, FALSE);
  gtk_widget_set_name (table92, "table92");
  gtk_widget_show (table92);
  gtk_container_add (GTK_CONTAINER (frame78), table92);
  gtk_container_set_border_width (GTK_CONTAINER (table92), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table92), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table92), 4);

  spinbutton_normal_connections_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 0);
  spinbutton_normal_connections = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_normal_connections_adj), 1, 0);
  gtk_widget_set_name (spinbutton_normal_connections, "spinbutton_normal_connections");
  gtk_widget_show (spinbutton_normal_connections);
  gtk_table_attach (GTK_TABLE (table92), spinbutton_normal_connections, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  label577 = gtk_label_new (_("Maximum # of leaves"));
  gtk_widget_set_name (label577, "label577");
  gtk_widget_show (label577);
  gtk_table_attach (GTK_TABLE (table92), label577, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label577), 0, 0.5);

  spinbutton_config_max_leaves_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 0);
  spinbutton_config_max_leaves = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_max_leaves_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_max_leaves, "spinbutton_config_max_leaves");
  gtk_widget_show (spinbutton_config_max_leaves);
  gtk_table_attach (GTK_TABLE (table92), spinbutton_config_max_leaves, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  label576 = gtk_label_new (_("Legacy connections"));
  gtk_widget_set_name (label576, "label576");
  gtk_widget_show (label576);
  gtk_table_attach (GTK_TABLE (table92), label576, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 4, 4);
  gtk_misc_set_alignment (GTK_MISC (label576), 0, 0.5);

  label575 = gtk_label_new (_("Ultrapeer mode settings"));
  gtk_widget_set_name (label575, "label575");
  gtk_widget_show (label575);
  gtk_frame_set_label_widget (GTK_FRAME (frame78), label575);

  checkbutton_gnet_monitor_ip = gtk_check_button_new_with_mnemonic (_("Monitor bad node IP addresses"));
  gtk_widget_set_name (checkbutton_gnet_monitor_ip, "checkbutton_gnet_monitor_ip");
  gtk_widget_show (checkbutton_gnet_monitor_ip);
  gtk_table_attach (GTK_TABLE (table91), checkbutton_gnet_monitor_ip, 0, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 4, 0);
  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton_gnet_monitor_ip), TRUE);

  checkbutton_gnet_monitor_servents = gtk_check_button_new_with_mnemonic (_("Monitor and auto-ban unstable servent types"));
  gtk_widget_set_name (checkbutton_gnet_monitor_servents, "checkbutton_gnet_monitor_servents");
  gtk_widget_show (checkbutton_gnet_monitor_servents);
  gtk_table_attach (GTK_TABLE (table91), checkbutton_gnet_monitor_servents, 0, 2, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 4, 0);
  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton_gnet_monitor_servents), TRUE);

  label537 = gtk_label_new (_("Configured peermode"));
  gtk_widget_set_name (label537, "label537");
  gtk_widget_show (label537);
  gtk_table_attach (GTK_TABLE (table91), label537, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 4, 0);

  frame135 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame135, "frame135");
  gtk_widget_show (frame135);
  gtk_table_attach (GTK_TABLE (table91), frame135, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL), 0, 0);

  option_menu_config_peermode = gtk_option_menu_new ();
  gtk_widget_set_name (option_menu_config_peermode, "option_menu_config_peermode");
  gtk_widget_show (option_menu_config_peermode);
  gtk_container_add (GTK_CONTAINER (frame135), option_menu_config_peermode);

  frame_gnet_can_become_ultra = gtk_frame_new (NULL);
  gtk_widget_set_name (frame_gnet_can_become_ultra, "frame_gnet_can_become_ultra");
  gtk_widget_show (frame_gnet_can_become_ultra);
  gtk_box_pack_start (GTK_BOX (hbox253), frame_gnet_can_become_ultra, FALSE, TRUE, 0);
  gtk_frame_set_label_align (GTK_FRAME (frame_gnet_can_become_ultra), 0, 0);
  gtk_frame_set_shadow_type (GTK_FRAME (frame_gnet_can_become_ultra), GTK_SHADOW_OUT);

  frame138 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame138, "frame138");
  gtk_widget_show (frame138);
  gtk_container_add (GTK_CONTAINER (frame_gnet_can_become_ultra), frame138);
  gtk_container_set_border_width (GTK_CONTAINER (frame138), 2);

  vbox116 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox116, "vbox116");
  gtk_widget_show (vbox116);
  gtk_container_add (GTK_CONTAINER (frame138), vbox116);

  table83 = gtk_table_new (1, 4, FALSE);
  gtk_widget_set_name (table83, "table83");
  gtk_widget_show (table83);
  gtk_box_pack_start (GTK_BOX (vbox116), table83, FALSE, TRUE, 0);
  gtk_table_set_row_spacings (GTK_TABLE (table83), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table83), 4);

  label752 = gtk_label_new (_("Last check"));
  gtk_widget_set_name (label752, "label752");
  gtk_widget_show (label752);
  gtk_table_attach (GTK_TABLE (table83), label752, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label752), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label752), 4, 0);

  label753 = gtk_label_new (_("Last switch"));
  gtk_widget_set_name (label753, "label753");
  gtk_widget_show (label753);
  gtk_table_attach (GTK_TABLE (table83), label753, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label753), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label753), 2, 0);

  viewport75 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport75, "viewport75");
  gtk_widget_show (viewport75);
  gtk_table_attach (GTK_TABLE (table83), viewport75, 3, 4, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport75), GTK_SHADOW_NONE);

  label_last_ultra_leaf_switch = gtk_label_new ("[place holder]");
  gtk_widget_set_name (label_last_ultra_leaf_switch, "label_last_ultra_leaf_switch");
  gtk_widget_show (label_last_ultra_leaf_switch);
  gtk_container_add (GTK_CONTAINER (viewport75), label_last_ultra_leaf_switch);

  viewport74 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport74, "viewport74");
  gtk_widget_show (viewport74);
  gtk_table_attach (GTK_TABLE (table83), viewport74, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport74), GTK_SHADOW_NONE);

  label_node_last_ultracheck = gtk_label_new ("[place holder]");
  gtk_widget_set_name (label_node_last_ultracheck, "label_node_last_ultracheck");
  gtk_widget_show (label_node_last_ultracheck);
  gtk_container_add (GTK_CONTAINER (viewport74), label_node_last_ultracheck);
  gtk_label_set_justify (GTK_LABEL (label_node_last_ultracheck), GTK_JUSTIFY_CENTER);

  hseparator12 = gtk_hseparator_new ();
  gtk_widget_set_name (hseparator12, "hseparator12");
  gtk_widget_show (hseparator12);
  gtk_box_pack_start (GTK_BOX (vbox116), hseparator12, FALSE, TRUE, 0);

  table84 = gtk_table_new (5, 5, FALSE);
  gtk_widget_set_name (table84, "table84");
  gtk_widget_show (table84);
  gtk_box_pack_start (GTK_BOX (vbox116), table84, TRUE, TRUE, 0);
  gtk_table_set_row_spacings (GTK_TABLE (table84), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table84), 4);

  label756 = gtk_label_new (_("Sufficient average uptime"));
  gtk_widget_set_name (label756, "label756");
  gtk_widget_show (label756);
  gtk_table_attach (GTK_TABLE (table84), label756, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label756), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label756), 4, 0);

  label757 = gtk_label_new (_("Large enough uptime"));
  gtk_widget_set_name (label757, "label757");
  gtk_widget_show (label757);
  gtk_table_attach (GTK_TABLE (table84), label757, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label757), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label757), 4, 0);

  label758 = gtk_label_new (_("Enough file descriptors"));
  gtk_widget_set_name (label758, "label758");
  gtk_widget_show (label758);
  gtk_table_attach (GTK_TABLE (table84), label758, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label758), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label758), 4, 0);

  label759 = gtk_label_new (_("Enough available bandwidth"));
  gtk_widget_set_name (label759, "label759");
  gtk_widget_show (label759);
  gtk_table_attach (GTK_TABLE (table84), label759, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label759), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label759), 4, 0);

  label768 = gtk_label_new (_("Not firewalled"));
  gtk_widget_set_name (label768, "label768");
  gtk_widget_show (label768);
  gtk_table_attach (GTK_TABLE (table84), label768, 3, 4, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label768), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label768), 4, 0);

  label769 = gtk_label_new (_("Enough physical memory"));
  gtk_widget_set_name (label769, "label769");
  gtk_widget_show (label769);
  gtk_table_attach (GTK_TABLE (table84), label769, 3, 4, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label769), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label769), 4, 0);

  label767 = gtk_label_new (_("IP address stability"));
  gtk_widget_set_name (label767, "label767");
  gtk_widget_show (label767);
  gtk_table_attach (GTK_TABLE (table84), label767, 3, 4, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label767), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label767), 4, 0);

  viewport79 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport79, "viewport79");
  gtk_widget_show (viewport79);
  gtk_table_attach (GTK_TABLE (table84), viewport79, 1, 2, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport79), GTK_SHADOW_NONE);

  label_up_req_enough_bw = gtk_label_new ("[no]");
  gtk_widget_set_name (label_up_req_enough_bw, "label_up_req_enough_bw");
  gtk_widget_show (label_up_req_enough_bw);
  gtk_container_add (GTK_CONTAINER (viewport79), label_up_req_enough_bw);
  gtk_label_set_justify (GTK_LABEL (label_up_req_enough_bw), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label_up_req_enough_bw), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_up_req_enough_bw), 5, 0);

  viewport78 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport78, "viewport78");
  gtk_widget_show (viewport78);
  gtk_table_attach (GTK_TABLE (table84), viewport78, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport78), GTK_SHADOW_NONE);

  label_up_req_enough_fd = gtk_label_new ("[no]");
  gtk_widget_set_name (label_up_req_enough_fd, "label_up_req_enough_fd");
  gtk_widget_show (label_up_req_enough_fd);
  gtk_container_add (GTK_CONTAINER (viewport78), label_up_req_enough_fd);
  gtk_misc_set_alignment (GTK_MISC (label_up_req_enough_fd), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_up_req_enough_fd), 5, 0);

  viewport77 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport77, "viewport77");
  gtk_widget_show (viewport77);
  gtk_table_attach (GTK_TABLE (table84), viewport77, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport77), GTK_SHADOW_NONE);

  label_up_req_node_uptime = gtk_label_new ("[no]");
  gtk_widget_set_name (label_up_req_node_uptime, "label_up_req_node_uptime");
  gtk_widget_show (label_up_req_node_uptime);
  gtk_container_add (GTK_CONTAINER (viewport77), label_up_req_node_uptime);
  gtk_label_set_justify (GTK_LABEL (label_up_req_node_uptime), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label_up_req_node_uptime), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_up_req_node_uptime), 5, 0);

  viewport76 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport76, "viewport76");
  gtk_widget_show (viewport76);
  gtk_table_attach (GTK_TABLE (table84), viewport76, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport76), GTK_SHADOW_NONE);

  label_up_req_avg_servent_uptime = gtk_label_new ("[no]");
  gtk_widget_set_name (label_up_req_avg_servent_uptime, "label_up_req_avg_servent_uptime");
  gtk_widget_show (label_up_req_avg_servent_uptime);
  gtk_container_add (GTK_CONTAINER (viewport76), label_up_req_avg_servent_uptime);
  gtk_label_set_justify (GTK_LABEL (label_up_req_avg_servent_uptime), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label_up_req_avg_servent_uptime), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_up_req_avg_servent_uptime), 5, 0);

  viewport80 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport80, "viewport80");
  gtk_widget_show (viewport80);
  gtk_table_attach (GTK_TABLE (table84), viewport80, 4, 5, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport80), GTK_SHADOW_NONE);

  label_up_req_avg_ip_uptime = gtk_label_new ("[no]");
  gtk_widget_set_name (label_up_req_avg_ip_uptime, "label_up_req_avg_ip_uptime");
  gtk_widget_show (label_up_req_avg_ip_uptime);
  gtk_container_add (GTK_CONTAINER (viewport80), label_up_req_avg_ip_uptime);
  gtk_label_set_justify (GTK_LABEL (label_up_req_avg_ip_uptime), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label_up_req_avg_ip_uptime), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_up_req_avg_ip_uptime), 5, 0);

  viewport81 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport81, "viewport81");
  gtk_widget_show (viewport81);
  gtk_table_attach (GTK_TABLE (table84), viewport81, 4, 5, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport81), GTK_SHADOW_NONE);

  label_up_req_not_firewalled = gtk_label_new ("[no]");
  gtk_widget_set_name (label_up_req_not_firewalled, "label_up_req_not_firewalled");
  gtk_widget_show (label_up_req_not_firewalled);
  gtk_container_add (GTK_CONTAINER (viewport81), label_up_req_not_firewalled);
  gtk_label_set_justify (GTK_LABEL (label_up_req_not_firewalled), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label_up_req_not_firewalled), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_up_req_not_firewalled), 5, 0);

  viewport82 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport82, "viewport82");
  gtk_widget_show (viewport82);
  gtk_table_attach (GTK_TABLE (table84), viewport82, 4, 5, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport82), GTK_SHADOW_NONE);

  label_up_req_enough_mem = gtk_label_new ("[no]");
  gtk_widget_set_name (label_up_req_enough_mem, "label_up_req_enough_mem");
  gtk_widget_show (label_up_req_enough_mem);
  gtk_container_add (GTK_CONTAINER (viewport82), label_up_req_enough_mem);
  gtk_label_set_justify (GTK_LABEL (label_up_req_enough_mem), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label_up_req_enough_mem), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_up_req_enough_mem), 5, 0);

  viewport107 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport107, "viewport107");
  gtk_widget_show (viewport107);
  gtk_table_attach (GTK_TABLE (table84), viewport107, 4, 5, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport107), GTK_SHADOW_NONE);

  label_up_req_enough_conn = gtk_label_new ("[no]");
  gtk_widget_set_name (label_up_req_enough_conn, "label_up_req_enough_conn");
  gtk_widget_show (label_up_req_enough_conn);
  gtk_container_add (GTK_CONTAINER (viewport107), label_up_req_enough_conn);
  gtk_label_set_justify (GTK_LABEL (label_up_req_enough_conn), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label_up_req_enough_conn), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_up_req_enough_conn), 5, 0);

  label868 = gtk_label_new (_("Enough min # of connections"));
  gtk_widget_set_name (label868, "label868");
  gtk_widget_show (label868);
  gtk_table_attach (GTK_TABLE (table84), label868, 3, 4, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label868), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label868), 4, 0);

  vseparator3 = gtk_vseparator_new ();
  gtk_widget_set_name (vseparator3, "vseparator3");
  gtk_widget_show (vseparator3);
  gtk_table_attach (GTK_TABLE (table84), vseparator3, 2, 3, 0, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  label994 = gtk_label_new (_("Enough UDP support"));
  gtk_widget_set_name (label994, "label994");
  gtk_widget_show (label994);
  gtk_table_attach (GTK_TABLE (table84), label994, 0, 1, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label994), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label994), 4, 0);

  viewport476 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport476, "viewport476");
  gtk_widget_show (viewport476);
  gtk_table_attach (GTK_TABLE (table84), viewport476, 1, 2, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport476), GTK_SHADOW_NONE);

  label_up_req_good_udp = gtk_label_new ("[no]");
  gtk_widget_set_name (label_up_req_good_udp, "label_up_req_good_udp");
  gtk_widget_show (label_up_req_good_udp);
  gtk_container_add (GTK_CONTAINER (viewport476), label_up_req_good_udp);
  gtk_label_set_justify (GTK_LABEL (label_up_req_good_udp), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label_up_req_good_udp), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_up_req_good_udp), 5, 0);

  label920 = gtk_label_new (_("Ultrapeer promotion statistics"));
  gtk_widget_set_name (label920, "label920");
  gtk_widget_show (label920);
  gtk_frame_set_label_widget (GTK_FRAME (frame138), label920);
  gtk_label_set_use_markup (GTK_LABEL (label920), TRUE);

  label739 = gtk_label_new (_("Gnutella network mode"));
  gtk_widget_set_name (label739, "label739");
  gtk_widget_show (label739);
  gtk_frame_set_label_widget (GTK_FRAME (frame92), label739);

  hbox286 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox286, "hbox286");
  gtk_widget_show (hbox286);
  gtk_box_pack_start (GTK_BOX (vbox25), hbox286, FALSE, FALSE, 0);

  frame_searches = gtk_frame_new (NULL);
  gtk_widget_set_name (frame_searches, "frame_searches");
  gtk_widget_show (frame_searches);
  gtk_box_pack_start (GTK_BOX (hbox286), frame_searches, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame_searches), 4);

  hbox254 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox254, "hbox254");
  gtk_widget_show (hbox254);
  gtk_container_add (GTK_CONTAINER (frame_searches), hbox254);
  gtk_container_set_border_width (GTK_CONTAINER (hbox254), 2);

  table17 = gtk_table_new (5, 3, FALSE);
  gtk_widget_set_name (table17, "table17");
  gtk_widget_show (table17);
  gtk_box_pack_start (GTK_BOX (hbox254), table17, FALSE, TRUE, 0);
  gtk_table_set_row_spacings (GTK_TABLE (table17), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table17), 4);

  spinbutton_config_search_items_adj = gtk_adjustment_new (1, 1, 255, 1, 10, 0);
  spinbutton_config_search_items = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_search_items_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_search_items, "spinbutton_config_search_items");
  gtk_widget_show (spinbutton_config_search_items);
  gtk_table_attach (GTK_TABLE (table17), spinbutton_config_search_items, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_tooltips_set_tip (tooltips, spinbutton_config_search_items, _("This limits how many results gnutella returns to other people searching your files."), NULL);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_search_items), TRUE);

  spinbutton_config_search_reissue_timeout_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 0);
  spinbutton_config_search_reissue_timeout = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_search_reissue_timeout_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_search_reissue_timeout, "spinbutton_config_search_reissue_timeout");
  gtk_widget_show (spinbutton_config_search_reissue_timeout);
  gtk_table_attach (GTK_TABLE (table17), spinbutton_config_search_reissue_timeout, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_search_reissue_timeout), TRUE);

  label38 = gtk_label_new (_("items"));
  gtk_widget_set_name (label38, "label38");
  gtk_widget_show (label38);
  gtk_table_attach (GTK_TABLE (table17), label38, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label38), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label38), 7.45058e-09, 0.5);

  label37 = gtk_label_new_with_mnemonic (_("Limit search _results to "));
  gtk_widget_set_name (label37, "label37");
  gtk_widget_show (label37);
  gtk_table_attach (GTK_TABLE (table17), label37, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label37), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label37), 7.45058e-09, 0.5);
  gtk_misc_set_padding (GTK_MISC (label37), 4, 0);

  label364 = gtk_label_new_with_mnemonic (_("Default search _reissue timeout"));
  gtk_widget_set_name (label364, "label364");
  gtk_widget_show (label364);
  gtk_table_attach (GTK_TABLE (table17), label364, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label364), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label364), 4, 0);

  label365 = gtk_label_new (_("seconds (0 - disable)"));
  gtk_widget_set_name (label365, "label365");
  gtk_widget_show (label365);
  gtk_table_attach (GTK_TABLE (table17), label365, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label365), 0, 0.5);

  checkbutton_enable_guess = gtk_check_button_new_with_mnemonic (_("Enable GUESS (additional querying)"));
  gtk_widget_set_name (checkbutton_enable_guess, "checkbutton_enable_guess");
  gtk_widget_show (checkbutton_enable_guess);
  gtk_table_attach (GTK_TABLE (table17), checkbutton_enable_guess, 0, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_enable_guess_client = gtk_check_button_new_with_mnemonic (_("Issue GUESS queries as well"));
  gtk_widget_set_name (checkbutton_enable_guess_client, "checkbutton_enable_guess_client");
  gtk_widget_show (checkbutton_enable_guess_client);
  gtk_table_attach (GTK_TABLE (table17), checkbutton_enable_guess_client, 0, 2, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_enable_g2 = gtk_check_button_new_with_mnemonic (_("Enable the G2 network"));
  gtk_widget_set_name (checkbutton_enable_g2, "checkbutton_enable_g2");
  gtk_widget_show (checkbutton_enable_g2);
  gtk_table_attach (GTK_TABLE (table17), checkbutton_enable_g2, 0, 2, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label293 = gtk_label_new_with_mnemonic (_("Searches"));
  gtk_widget_set_name (label293, "label293");
  gtk_widget_show (label293);
  gtk_frame_set_label_widget (GTK_FRAME (frame_searches), label293);

  frame_expert_oob_queries = gtk_frame_new (NULL);
  gtk_widget_set_name (frame_expert_oob_queries, "frame_expert_oob_queries");
  gtk_widget_show (frame_expert_oob_queries);
  gtk_box_pack_start (GTK_BOX (hbox286), frame_expert_oob_queries, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame_expert_oob_queries), 4);

  table101 = gtk_table_new (3, 1, FALSE);
  gtk_widget_set_name (table101, "table101");
  gtk_widget_show (table101);
  gtk_container_add (GTK_CONTAINER (frame_expert_oob_queries), table101);

  checkbutton_send_oob_queries = gtk_check_button_new_with_mnemonic (_("Queries ask for OOB results"));
  gtk_widget_set_name (checkbutton_send_oob_queries, "checkbutton_send_oob_queries");
  gtk_widget_show (checkbutton_send_oob_queries);
  gtk_table_attach (GTK_TABLE (table101), checkbutton_send_oob_queries, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 4, 0);

  checkbutton_process_oob_queries = gtk_check_button_new_with_mnemonic (_("Honor OOB flag in queries"));
  gtk_widget_set_name (checkbutton_process_oob_queries, "checkbutton_process_oob_queries");
  gtk_widget_show (checkbutton_process_oob_queries);
  gtk_table_attach (GTK_TABLE (table101), checkbutton_process_oob_queries, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 4, 0);
  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton_process_oob_queries), TRUE);

  checkbutton_proxy_oob_queries = gtk_check_button_new_with_mnemonic (_("Act as OOB proxy for leaves"));
  gtk_widget_set_name (checkbutton_proxy_oob_queries, "checkbutton_proxy_oob_queries");
  gtk_widget_show (checkbutton_proxy_oob_queries);
  gtk_table_attach (GTK_TABLE (table101), checkbutton_proxy_oob_queries, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 4, 0);

  label885 = gtk_label_new (_("Out of Band Querying"));
  gtk_widget_set_name (label885, "label885");
  gtk_widget_show (label885);
  gtk_frame_set_label_widget (GTK_FRAME (frame_expert_oob_queries), label885);

  vbox158 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox158, "vbox158");
  gtk_widget_show (vbox158);
  gtk_box_pack_start (GTK_BOX (hbox286), vbox158, TRUE, TRUE, 0);

  frame_expert_search_queue = gtk_frame_new (NULL);
  gtk_widget_set_name (frame_expert_search_queue, "frame_expert_search_queue");
  gtk_widget_show (frame_expert_search_queue);
  gtk_box_pack_start (GTK_BOX (vbox158), frame_expert_search_queue, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame_expert_search_queue), 4);

  table100 = gtk_table_new (2, 3, FALSE);
  gtk_widget_set_name (table100, "table100");
  gtk_widget_show (table100);
  gtk_container_add (GTK_CONTAINER (frame_expert_search_queue), table100);

  label771 = gtk_label_new (_("Size"));
  gtk_widget_set_name (label771, "label771");
  gtk_widget_show (label771);
  gtk_table_attach (GTK_TABLE (table100), label771, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label771), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label771), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label771), 4, 0);

  label772 = gtk_label_new (_("Spacing"));
  gtk_widget_set_name (label772, "label772");
  gtk_widget_show (label772);
  gtk_table_attach (GTK_TABLE (table100), label772, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label772), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label772), 4, 0);

  spinbutton_search_queue_size_adj = gtk_adjustment_new (1000, 0, 1000, 1, 10, 0);
  spinbutton_search_queue_size = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_search_queue_size_adj), 1, 0);
  gtk_widget_set_name (spinbutton_search_queue_size, "spinbutton_search_queue_size");
  gtk_widget_show (spinbutton_search_queue_size);
  gtk_table_attach (GTK_TABLE (table100), spinbutton_search_queue_size, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  spinbutton_search_queue_spacing_adj = gtk_adjustment_new (60, 0, 100, 1, 10, 0);
  spinbutton_search_queue_spacing = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_search_queue_spacing_adj), 1, 0);
  gtk_widget_set_name (spinbutton_search_queue_spacing, "spinbutton_search_queue_spacing");
  gtk_widget_show (spinbutton_search_queue_spacing);
  gtk_table_attach (GTK_TABLE (table100), spinbutton_search_queue_spacing, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  label983 = gtk_label_new (_("slots"));
  gtk_widget_set_name (label983, "label983");
  gtk_widget_show (label983);
  gtk_table_attach (GTK_TABLE (table100), label983, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label983), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label983), 4, 0);

  label984 = gtk_label_new (Q_("unit_of_time|s"));
  gtk_widget_set_name (label984, "label984");
  gtk_widget_show (label984);
  gtk_table_attach (GTK_TABLE (table100), label984, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label984), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label984), 4, 0);

  label770 = gtk_label_new (_("Search queue"));
  gtk_widget_set_name (label770, "label770");
  gtk_widget_show (label770);
  gtk_frame_set_label_widget (GTK_FRAME (frame_expert_search_queue), label770);

  checkbutton_config_query_request_partials = gtk_check_button_new_with_mnemonic (_("Query for partial files as well"));
  gtk_widget_set_name (checkbutton_config_query_request_partials, "checkbutton_config_query_request_partials");
  gtk_widget_show (checkbutton_config_query_request_partials);
  gtk_box_pack_start (GTK_BOX (vbox158), checkbutton_config_query_request_partials, FALSE, FALSE, 0);

  checkbutton_config_search_smart_stop = gtk_check_button_new_with_mnemonic (_("Stop search when last download completes"));
  gtk_widget_set_name (checkbutton_config_search_smart_stop, "checkbutton_config_search_smart_stop");
  gtk_widget_show (checkbutton_config_search_smart_stop);
  gtk_box_pack_start (GTK_BOX (vbox158), checkbutton_config_search_smart_stop, FALSE, FALSE, 0);

  checkbutton_search_restart_when_pending = gtk_check_button_new_with_mnemonic (_("Restart session-only searches with pending downloads"));
  gtk_widget_set_name (checkbutton_search_restart_when_pending, "checkbutton_search_restart_when_pending");
  gtk_widget_show (checkbutton_search_restart_when_pending);
  gtk_box_pack_start (GTK_BOX (vbox158), checkbutton_search_restart_when_pending, FALSE, FALSE, 0);

  hbox9352 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox9352, "hbox9352");
  gtk_widget_show (hbox9352);
  gtk_box_pack_start (GTK_BOX (vbox25), hbox9352, FALSE, TRUE, 0);

  frame_expert_gnet_timeout = gtk_frame_new (NULL);
  gtk_widget_set_name (frame_expert_gnet_timeout, "frame_expert_gnet_timeout");
  gtk_widget_show (frame_expert_gnet_timeout);
  gtk_box_pack_start (GTK_BOX (hbox9352), frame_expert_gnet_timeout, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame_expert_gnet_timeout), 4);

  table10 = gtk_table_new (2, 4, FALSE);
  gtk_widget_set_name (table10, "table10");
  gtk_widget_show (table10);
  gtk_container_add (GTK_CONTAINER (frame_expert_gnet_timeout), table10);
  gtk_container_set_border_width (GTK_CONTAINER (table10), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table10), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table10), 4);

  label175 = gtk_label_new_with_mnemonic (_("Connectin_g timeout"));
  gtk_widget_set_name (label175, "label175");
  gtk_widget_show (label175);
  gtk_table_attach (GTK_TABLE (table10), label175, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label175), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label175), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label175), 4, 0);

  label177 = gtk_label_new_with_mnemonic (_("T_X flow control timeout"));
  gtk_widget_set_name (label177, "label177");
  gtk_widget_show (label177);
  gtk_table_attach (GTK_TABLE (table10), label177, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label177), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label177), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label177), 4, 0);

  label176 = gtk_label_new_with_mnemonic (_("Connected time_out"));
  gtk_widget_set_name (label176, "label176");
  gtk_widget_show (label176);
  gtk_table_attach (GTK_TABLE (table10), label176, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label176), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label176), 0, 0.5);

  label584 = gtk_label_new (_("Incoming connecting timeout"));
  gtk_widget_set_name (label584, "label584");
  gtk_widget_show (label584);
  gtk_table_attach (GTK_TABLE (table10), label584, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label584), 0, 0.5);

  spinbutton_config_node_connecting_timeout_adj = gtk_adjustment_new (1, 1, 100000, 1, 10, 0);
  spinbutton_config_node_connecting_timeout = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_node_connecting_timeout_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_node_connecting_timeout, "spinbutton_config_node_connecting_timeout");
  gtk_widget_show (spinbutton_config_node_connecting_timeout);
  gtk_table_attach (GTK_TABLE (table10), spinbutton_config_node_connecting_timeout, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_node_connecting_timeout), TRUE);

  spinbutton_config_node_tx_flowc_timeout_adj = gtk_adjustment_new (1, 1, 100000, 1, 10, 0);
  spinbutton_config_node_tx_flowc_timeout = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_node_tx_flowc_timeout_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_node_tx_flowc_timeout, "spinbutton_config_node_tx_flowc_timeout");
  gtk_widget_show (spinbutton_config_node_tx_flowc_timeout);
  gtk_table_attach (GTK_TABLE (table10), spinbutton_config_node_tx_flowc_timeout, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_node_tx_flowc_timeout), TRUE);

  spinbutton_config_node_connected_timeout_adj = gtk_adjustment_new (1, 1, 100000, 1, 10, 0);
  spinbutton_config_node_connected_timeout = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_node_connected_timeout_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_node_connected_timeout, "spinbutton_config_node_connected_timeout");
  gtk_widget_show (spinbutton_config_node_connected_timeout);
  gtk_table_attach (GTK_TABLE (table10), spinbutton_config_node_connected_timeout, 3, 4, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_node_connected_timeout), TRUE);

  spinbutton_config_incoming_connecting_timeout_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 0);
  spinbutton_config_incoming_connecting_timeout = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_incoming_connecting_timeout_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_incoming_connecting_timeout, "spinbutton_config_incoming_connecting_timeout");
  gtk_widget_show (spinbutton_config_incoming_connecting_timeout);
  gtk_table_attach (GTK_TABLE (table10), spinbutton_config_incoming_connecting_timeout, 3, 4, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_incoming_connecting_timeout), TRUE);

  label294 = gtk_label_new (_("Gnutella timeouts (all values in seconds)"));
  gtk_widget_set_name (label294, "label294");
  gtk_widget_show (label294);
  gtk_frame_set_label_widget (GTK_FRAME (frame_expert_gnet_timeout), label294);

  frame_expert_gnet_dht = gtk_frame_new (NULL);
  gtk_widget_set_name (frame_expert_gnet_dht, "frame_expert_gnet_dht");
  gtk_widget_show (frame_expert_gnet_dht);
  gtk_box_pack_start (GTK_BOX (hbox9352), frame_expert_gnet_dht, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame_expert_gnet_dht), 4);

  table120 = gtk_table_new (2, 2, FALSE);
  gtk_widget_set_name (table120, "table120");
  gtk_widget_show (table120);
  gtk_container_add (GTK_CONTAINER (frame_expert_gnet_dht), table120);
  gtk_table_set_col_spacings (GTK_TABLE (table120), 4);

  label1075 = gtk_label_new (_("Configured DHT mode"));
  gtk_widget_set_name (label1075, "label1075");
  gtk_widget_show (label1075);
  gtk_table_attach (GTK_TABLE (table120), label1075, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label1075), 0, 0.5);

  option_menu_config_dht_mode = gtk_option_menu_new ();
  gtk_widget_set_name (option_menu_config_dht_mode, "option_menu_config_dht_mode");
  gtk_widget_show (option_menu_config_dht_mode);
  gtk_table_attach (GTK_TABLE (table120), option_menu_config_dht_mode, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_config_dht_storage_in_memory = gtk_check_button_new_with_mnemonic (_("Store DHT keys/values in memory"));
  gtk_widget_set_name (checkbutton_config_dht_storage_in_memory, "checkbutton_config_dht_storage_in_memory");
  gtk_widget_show (checkbutton_config_dht_storage_in_memory);
  gtk_table_attach (GTK_TABLE (table120), checkbutton_config_dht_storage_in_memory, 0, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label1074 = gtk_label_new (_("Gnutella Distributed Hash Table"));
  gtk_widget_set_name (label1074, "label1074");
  gtk_widget_show (label1074);
  gtk_frame_set_label_widget (GTK_FRAME (frame_expert_gnet_dht), label1074);

  frame_expert_gnet_ttl = gtk_frame_new (NULL);
  gtk_widget_set_name (frame_expert_gnet_ttl, "frame_expert_gnet_ttl");
  gtk_widget_show (frame_expert_gnet_ttl);
  gtk_box_pack_start (GTK_BOX (vbox25), frame_expert_gnet_ttl, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame_expert_gnet_ttl), 4);

  vbox143 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox143, "vbox143");
  gtk_widget_show (vbox143);
  gtk_container_add (GTK_CONTAINER (frame_expert_gnet_ttl), vbox143);

  table9 = gtk_table_new (1, 6, FALSE);
  gtk_widget_set_name (table9, "table9");
  gtk_widget_show (table9);
  gtk_box_pack_start (GTK_BOX (vbox143), table9, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (table9), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table9), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table9), 4);

  spinbutton_config_maxttl_adj = gtk_adjustment_new (1, 1, 99, 1, 5, 0);
  spinbutton_config_maxttl = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_maxttl_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_maxttl, "spinbutton_config_maxttl");
  gtk_widget_show (spinbutton_config_maxttl);
  gtk_table_attach (GTK_TABLE (table9), spinbutton_config_maxttl, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_maxttl), TRUE);

  spinbutton_config_myttl_adj = gtk_adjustment_new (1, 1, 99, 1, 5, 0);
  spinbutton_config_myttl = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_myttl_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_myttl, "spinbutton_config_myttl");
  gtk_widget_show (spinbutton_config_myttl);
  gtk_table_attach (GTK_TABLE (table9), spinbutton_config_myttl, 3, 4, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_myttl), TRUE);

  label84 = gtk_label_new_with_mnemonic (_("Max _TTL"));
  gtk_widget_set_name (label84, "label84");
  gtk_widget_show (label84);
  gtk_table_attach (GTK_TABLE (table9), label84, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label84), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label84), 4, 0);

  label85 = gtk_label_new_with_mnemonic (_("M_y TTL"));
  gtk_widget_set_name (label85, "label85");
  gtk_widget_show (label85);
  gtk_table_attach (GTK_TABLE (table9), label85, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label85), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label85), 1, 0.5);

  label159 = gtk_label_new_with_mnemonic (_("H_ard TTL limit"));
  gtk_widget_set_name (label159, "label159");
  gtk_widget_show (label159);
  gtk_table_attach (GTK_TABLE (table9), label159, 4, 5, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label159), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label159), 4, 0);

  spinbutton_config_hard_ttl_limit_adj = gtk_adjustment_new (5, 5, 99, 1, 10, 0);
  spinbutton_config_hard_ttl_limit = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_hard_ttl_limit_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_hard_ttl_limit, "spinbutton_config_hard_ttl_limit");
  gtk_widget_show (spinbutton_config_hard_ttl_limit);
  gtk_table_attach (GTK_TABLE (table9), spinbutton_config_hard_ttl_limit, 5, 6, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_tooltips_set_tip (tooltips, spinbutton_config_hard_ttl_limit, _("Max hard TTL limit (hop+ttl) on message"), NULL);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_hard_ttl_limit), TRUE);

  vbox144 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox144, "vbox144");
  gtk_widget_show (vbox144);
  gtk_box_pack_start (GTK_BOX (vbox143), vbox144, TRUE, TRUE, 0);

  hbox9294 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox9294, "hbox9294");
  gtk_widget_show (hbox9294);
  gtk_box_pack_start (GTK_BOX (vbox144), hbox9294, FALSE, TRUE, 0);

  label157 = gtk_label_new_with_mnemonic (_("Max # of _high TTL msg"));
  gtk_widget_set_name (label157, "label157");
  gtk_widget_show (label157);
  gtk_box_pack_start (GTK_BOX (hbox9294), label157, FALSE, FALSE, 0);
  gtk_misc_set_alignment (GTK_MISC (label157), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label157), 4, 0);

  spinbutton_config_max_high_ttl_msg_adj = gtk_adjustment_new (1, 0, 99, 1, 10, 0);
  spinbutton_config_max_high_ttl_msg = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_max_high_ttl_msg_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_max_high_ttl_msg, "spinbutton_config_max_high_ttl_msg");
  gtk_widget_show (spinbutton_config_max_high_ttl_msg);
  gtk_box_pack_start (GTK_BOX (hbox9294), spinbutton_config_max_high_ttl_msg, FALSE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, spinbutton_config_max_high_ttl_msg, _("Amount of tolerable messages above hard TTL limit per node"), NULL);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_max_high_ttl_msg), TRUE);

  label158 = gtk_label_new_with_mnemonic (_("from _nodes within a"));
  gtk_widget_set_name (label158, "label158");
  gtk_widget_show (label158);
  gtk_box_pack_start (GTK_BOX (hbox9294), label158, FALSE, FALSE, 0);
  gtk_label_set_justify (GTK_LABEL (label158), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label158), 0, 0.5);

  spinbutton_config_max_high_ttl_radius_adj = gtk_adjustment_new (1, 1, 99, 1, 10, 0);
  spinbutton_config_max_high_ttl_radius = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_max_high_ttl_radius_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_max_high_ttl_radius, "spinbutton_config_max_high_ttl_radius");
  gtk_widget_show (spinbutton_config_max_high_ttl_radius);
  gtk_box_pack_start (GTK_BOX (hbox9294), spinbutton_config_max_high_ttl_radius, FALSE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, spinbutton_config_max_high_ttl_radius, _("Hop radius for counting high TTL limit messages (#hops lower than...)"), NULL);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_max_high_ttl_radius), TRUE);

  label160 = gtk_label_new (_("hops radius"));
  gtk_widget_set_name (label160, "label160");
  gtk_widget_show (label160);
  gtk_box_pack_start (GTK_BOX (hbox9294), label160, FALSE, FALSE, 0);
  gtk_label_set_justify (GTK_LABEL (label160), GTK_JUSTIFY_CENTER);

  label295 = gtk_label_new (_("Gnutella TTL settings"));
  gtk_widget_set_name (label295, "label295");
  gtk_widget_show (label295);
  gtk_frame_set_label_widget (GTK_FRAME (frame_expert_gnet_ttl), label295);

  frame_expert_gnet_quality = gtk_frame_new (NULL);
  gtk_widget_set_name (frame_expert_gnet_quality, "frame_expert_gnet_quality");
  gtk_widget_show (frame_expert_gnet_quality);
  gtk_box_pack_start (GTK_BOX (vbox25), frame_expert_gnet_quality, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame_expert_gnet_quality), 4);

  table37 = gtk_table_new (4, 7, FALSE);
  gtk_widget_set_name (table37, "table37");
  gtk_widget_show (table37);
  gtk_container_add (GTK_CONTAINER (frame_expert_gnet_quality), table37);
  gtk_container_set_border_width (GTK_CONTAINER (table37), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table37), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table37), 4);

  label433 = gtk_label_new ("%");
  gtk_widget_set_name (label433, "label433");
  gtk_widget_show (label433);
  gtk_table_attach (GTK_TABLE (table37), label433, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label433), 0, 0.5);

  spinbutton_config_min_dup_msg_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 0);
  spinbutton_config_min_dup_msg = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_min_dup_msg_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_min_dup_msg, "spinbutton_config_min_dup_msg");
  gtk_widget_show (spinbutton_config_min_dup_msg);
  gtk_table_attach (GTK_TABLE (table37), spinbutton_config_min_dup_msg, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_min_dup_msg), TRUE);

  spinbutton_config_min_dup_ratio_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 0);
  spinbutton_config_min_dup_ratio = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_min_dup_ratio_adj), 1, 2);
  gtk_widget_set_name (spinbutton_config_min_dup_ratio, "spinbutton_config_min_dup_ratio");
  gtk_widget_show (spinbutton_config_min_dup_ratio);
  gtk_table_attach (GTK_TABLE (table37), spinbutton_config_min_dup_ratio, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_min_dup_ratio), TRUE);

  label431 = gtk_label_new_with_mnemonic (_("Ratio of tolerable duplicate messages per _node"));
  gtk_widget_set_name (label431, "label431");
  gtk_widget_show (label431);
  gtk_table_attach (GTK_TABLE (table37), label431, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label431), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label431), 4, 0);

  label430 = gtk_label_new_with_mnemonic (_("Number of tolerable _duplicate messages per node"));
  gtk_widget_set_name (label430, "label430");
  gtk_widget_show (label430);
  gtk_table_attach (GTK_TABLE (table37), label430, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label430), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label430), 4, 0);

  label574 = gtk_label_new ("%");
  gtk_widget_set_name (label574, "label574");
  gtk_widget_show (label574);
  gtk_table_attach (GTK_TABLE (table37), label574, 2, 3, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label574), 0, 0.5);

  spinbutton_config_node_rx_flowc_ratio_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 0);
  spinbutton_config_node_rx_flowc_ratio = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_node_rx_flowc_ratio_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_node_rx_flowc_ratio, "spinbutton_config_node_rx_flowc_ratio");
  gtk_widget_show (spinbutton_config_node_rx_flowc_ratio);
  gtk_table_attach (GTK_TABLE (table37), spinbutton_config_node_rx_flowc_ratio, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_node_rx_flowc_ratio), TRUE);

  label573 = gtk_label_new (_("RX flow control ratio"));
  gtk_widget_set_name (label573, "label573");
  gtk_widget_show (label573);
  gtk_table_attach (GTK_TABLE (table37), label573, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label573), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label573), 4, 0);

  label773 = gtk_label_new (_("Similar query half-life"));
  gtk_widget_set_name (label773, "label773");
  gtk_widget_show (label773);
  gtk_table_attach (GTK_TABLE (table37), label773, 4, 5, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label773), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label773), 4, 0);

  spinbutton_node_queries_half_life_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 0);
  spinbutton_node_queries_half_life = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_node_queries_half_life_adj), 1, 0);
  gtk_widget_set_name (spinbutton_node_queries_half_life, "spinbutton_node_queries_half_life");
  gtk_widget_show (spinbutton_node_queries_half_life);
  gtk_table_attach (GTK_TABLE (table37), spinbutton_node_queries_half_life, 5, 6, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label774 = gtk_label_new (_("Leaf requery threshold"));
  gtk_widget_set_name (label774, "label774");
  gtk_widget_show (label774);
  gtk_table_attach (GTK_TABLE (table37), label774, 4, 5, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label774), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label774), 4, 0);

  spinbutton_node_requery_threshold_adj = gtk_adjustment_new (1700, 0, 1800, 1, 10, 0);
  spinbutton_node_requery_threshold = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_node_requery_threshold_adj), 1, 0);
  gtk_widget_set_name (spinbutton_node_requery_threshold, "spinbutton_node_requery_threshold");
  gtk_widget_show (spinbutton_node_requery_threshold);
  gtk_table_attach (GTK_TABLE (table37), spinbutton_node_requery_threshold, 5, 6, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_node_watch_similar_queries = gtk_check_button_new_with_mnemonic (_("Watch for similar queries"));
  gtk_widget_set_name (checkbutton_node_watch_similar_queries, "checkbutton_node_watch_similar_queries");
  gtk_widget_show (checkbutton_node_watch_similar_queries);
  gtk_table_attach (GTK_TABLE (table37), checkbutton_node_watch_similar_queries, 4, 6, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 4, 0);

  label982 = gtk_label_new (Q_("unit_of_time|s"));
  gtk_widget_set_name (label982, "label982");
  gtk_widget_show (label982);
  gtk_table_attach (GTK_TABLE (table37), label982, 6, 7, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label982), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label982), 4, 0);

  vseparator4 = gtk_vseparator_new ();
  gtk_widget_set_name (vseparator4, "vseparator4");
  gtk_widget_show (vseparator4);
  gtk_table_attach (GTK_TABLE (table37), vseparator4, 3, 4, 0, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  label1076 = gtk_label_new (_("Relayed queries remembered"));
  gtk_widget_set_name (label1076, "label1076");
  gtk_widget_show (label1076);
  gtk_table_attach (GTK_TABLE (table37), label1076, 4, 5, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label1076), 0, 0.5);

  spinbutton_config_search_muid_track_amount_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 0);
  spinbutton_config_search_muid_track_amount = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_search_muid_track_amount_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_search_muid_track_amount, "spinbutton_config_search_muid_track_amount");
  gtk_widget_show (spinbutton_config_search_muid_track_amount);
  gtk_table_attach (GTK_TABLE (table37), spinbutton_config_search_muid_track_amount, 5, 6, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label429 = gtk_label_new (_("Quality management"));
  gtk_widget_set_name (label429, "label429");
  gtk_widget_show (label429);
  gtk_frame_set_label_widget (GTK_FRAME (frame_expert_gnet_quality), label429);

  hbox287 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox287, "hbox287");
  gtk_widget_show (hbox287);
  gtk_box_pack_start (GTK_BOX (vbox25), hbox287, FALSE, TRUE, 0);

  frame_expert_gnet_connections = gtk_frame_new (NULL);
  gtk_widget_set_name (frame_expert_gnet_connections, "frame_expert_gnet_connections");
  gtk_widget_show (frame_expert_gnet_connections);
  gtk_box_pack_start (GTK_BOX (hbox287), frame_expert_gnet_connections, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame_expert_gnet_connections), 4);

  table74 = gtk_table_new (2, 3, FALSE);
  gtk_widget_set_name (table74, "table74");
  gtk_widget_show (table74);
  gtk_container_add (GTK_CONTAINER (frame_expert_gnet_connections), table74);
  gtk_container_set_border_width (GTK_CONTAINER (table74), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table74), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table74), 4);

  label728 = gtk_label_new (_("Connections reserved for gtk-gnutella nodes"));
  gtk_widget_set_name (label728, "label728");
  gtk_widget_show (label728);
  gtk_table_attach (GTK_TABLE (table74), label728, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label728), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label728), 4, 0);

  label730 = gtk_label_new ("%");
  gtk_widget_set_name (label730, "label730");
  gtk_widget_show (label730);
  gtk_table_attach (GTK_TABLE (table74), label730, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label730), 0, 0.5);

  label731 = gtk_label_new ("%");
  gtk_widget_set_name (label731, "label731");
  gtk_widget_show (label731);
  gtk_table_attach (GTK_TABLE (table74), label731, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label731), 0, 0.5);

  label729 = gtk_label_new (_("Max connections allowed per unique vendor"));
  gtk_widget_set_name (label729, "label729");
  gtk_widget_show (label729);
  gtk_table_attach (GTK_TABLE (table74), label729, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label729), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label729), 4, 0);

  spinbutton_config_reserve_gtkg_nodes_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 0);
  spinbutton_config_reserve_gtkg_nodes = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_reserve_gtkg_nodes_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_reserve_gtkg_nodes, "spinbutton_config_reserve_gtkg_nodes");
  gtk_widget_show (spinbutton_config_reserve_gtkg_nodes);
  gtk_table_attach (GTK_TABLE (table74), spinbutton_config_reserve_gtkg_nodes, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_tooltips_set_tip (tooltips, spinbutton_config_reserve_gtkg_nodes, _("Percentage of the number of connections we should reserve for gtk-gnutella nodes."), NULL);

  spinbutton_config_unique_nodes_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 0);
  spinbutton_config_unique_nodes = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_unique_nodes_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_unique_nodes, "spinbutton_config_unique_nodes");
  gtk_widget_show (spinbutton_config_unique_nodes);
  gtk_table_attach (GTK_TABLE (table74), spinbutton_config_unique_nodes, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_tooltips_set_tip (tooltips, spinbutton_config_unique_nodes, _("Maximum percentage of connection slots a vendor can occupy."), NULL);

  label727 = gtk_label_new (_("Connection settings"));
  gtk_widget_set_name (label727, "label727");
  gtk_widget_show (label727);
  gtk_frame_set_label_widget (GTK_FRAME (frame_expert_gnet_connections), label727);

  frame_expert_gnet_other = gtk_frame_new (NULL);
  gtk_widget_set_name (frame_expert_gnet_other, "frame_expert_gnet_other");
  gtk_widget_show (frame_expert_gnet_other);
  gtk_box_pack_start (GTK_BOX (hbox287), frame_expert_gnet_other, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame_expert_gnet_other), 4);

  table51 = gtk_table_new (3, 2, FALSE);
  gtk_widget_set_name (table51, "table51");
  gtk_widget_show (table51);
  gtk_container_add (GTK_CONTAINER (frame_expert_gnet_other), table51);
  gtk_container_set_border_width (GTK_CONTAINER (table51), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table51), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table51), 4);

  spinbutton_config_hops_random_factor_adj = gtk_adjustment_new (0, 0, 100, 1, 10, 0);
  spinbutton_config_hops_random_factor = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_hops_random_factor_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_hops_random_factor, "spinbutton_config_hops_random_factor");
  gtk_widget_show (spinbutton_config_hops_random_factor);
  gtk_table_attach (GTK_TABLE (table51), spinbutton_config_hops_random_factor, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_hops_random_factor), TRUE);

  label518 = gtk_label_new (_("Hops random factor"));
  gtk_widget_set_name (label518, "label518");
  gtk_widget_show (label518);
  gtk_table_attach (GTK_TABLE (table51), label518, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label518), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label518), 4, 0);

  checkbutton_gnet_compact_query = gtk_check_button_new_with_mnemonic (_("Clean up queries before processing"));
  gtk_widget_set_name (checkbutton_gnet_compact_query, "checkbutton_gnet_compact_query");
  gtk_widget_show (checkbutton_gnet_compact_query);
  gtk_table_attach (GTK_TABLE (table51), checkbutton_gnet_compact_query, 0, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 4, 0);

  checkbutton_config_spam_lut_in_memory = gtk_check_button_new_with_mnemonic (_("Store SPAM SHA1 table in memory"));
  gtk_widget_set_name (checkbutton_config_spam_lut_in_memory, "checkbutton_config_spam_lut_in_memory");
  gtk_widget_show (checkbutton_config_spam_lut_in_memory);
  gtk_table_attach (GTK_TABLE (table51), checkbutton_config_spam_lut_in_memory, 0, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 4, 0);

  label362 = gtk_label_new (_("Other"));
  gtk_widget_set_name (label362, "label362");
  gtk_widget_show (label362);
  gtk_frame_set_label_widget (GTK_FRAME (frame_expert_gnet_other), label362);

  frame_expert_gnet_message_size = gtk_frame_new (NULL);
  gtk_widget_set_name (frame_expert_gnet_message_size, "frame_expert_gnet_message_size");
  gtk_widget_show (frame_expert_gnet_message_size);
  gtk_box_pack_start (GTK_BOX (vbox25), frame_expert_gnet_message_size, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame_expert_gnet_message_size), 4);

  table85 = gtk_table_new (4, 3, FALSE);
  gtk_widget_set_name (table85, "table85");
  gtk_widget_show (table85);
  gtk_container_add (GTK_CONTAINER (frame_expert_gnet_message_size), table85);
  gtk_container_set_border_width (GTK_CONTAINER (table85), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table85), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table85), 4);

  label777 = gtk_label_new (_("Maximum size\nallowed"));
  gtk_widget_set_name (label777, "label777");
  gtk_widget_show (label777);
  gtk_table_attach (GTK_TABLE (table85), label777, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label777), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label777), 0, 0.5);

  label778 = gtk_label_new (_("Size threshold\nbefore kicking"));
  gtk_widget_set_name (label778, "label778");
  gtk_widget_show (label778);
  gtk_table_attach (GTK_TABLE (table85), label778, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label778), 0, 0.5);

  label782 = gtk_label_new (_("(not forwarded)"));
  gtk_widget_set_name (label782, "label782");
  gtk_widget_show (label782);
  gtk_table_attach (GTK_TABLE (table85), label782, 1, 2, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label782), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label782), 0, 0.5);

  spinbutton_search_queries_forward_size_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 0);
  spinbutton_search_queries_forward_size = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_search_queries_forward_size_adj), 1, 0);
  gtk_widget_set_name (spinbutton_search_queries_forward_size, "spinbutton_search_queries_forward_size");
  gtk_widget_show (spinbutton_search_queries_forward_size);
  gtk_table_attach (GTK_TABLE (table85), spinbutton_search_queries_forward_size, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  spinbutton_search_answers_forward_size_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 0);
  spinbutton_search_answers_forward_size = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_search_answers_forward_size_adj), 1, 0);
  gtk_widget_set_name (spinbutton_search_answers_forward_size, "spinbutton_search_answers_forward_size");
  gtk_widget_show (spinbutton_search_answers_forward_size);
  gtk_table_attach (GTK_TABLE (table85), spinbutton_search_answers_forward_size, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  spinbutton_search_queries_kick_size_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 0);
  spinbutton_search_queries_kick_size = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_search_queries_kick_size_adj), 1, 0);
  gtk_widget_set_name (spinbutton_search_queries_kick_size, "spinbutton_search_queries_kick_size");
  gtk_widget_show (spinbutton_search_queries_kick_size);
  gtk_table_attach (GTK_TABLE (table85), spinbutton_search_queries_kick_size, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  spinbutton_search_answers_kick_size_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 0);
  spinbutton_search_answers_kick_size = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_search_answers_kick_size_adj), 1, 0);
  gtk_widget_set_name (spinbutton_search_answers_kick_size, "spinbutton_search_answers_kick_size");
  gtk_widget_show (spinbutton_search_answers_kick_size);
  gtk_table_attach (GTK_TABLE (table85), spinbutton_search_answers_kick_size, 2, 3, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  spinbutton_other_messages_kick_size_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 0);
  spinbutton_other_messages_kick_size = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_other_messages_kick_size_adj), 1, 0);
  gtk_widget_set_name (spinbutton_other_messages_kick_size, "spinbutton_other_messages_kick_size");
  gtk_widget_show (spinbutton_other_messages_kick_size);
  gtk_table_attach (GTK_TABLE (table85), spinbutton_other_messages_kick_size, 2, 3, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label776 = gtk_label_new (_("Forwarded\nmessage"));
  gtk_widget_set_name (label776, "label776");
  gtk_widget_show (label776);
  gtk_table_attach (GTK_TABLE (table85), label776, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 4, 0);
  gtk_label_set_justify (GTK_LABEL (label776), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label776), 0, 0.5);

  label779 = gtk_label_new (_("Query"));
  gtk_widget_set_name (label779, "label779");
  gtk_widget_show (label779);
  gtk_table_attach (GTK_TABLE (table85), label779, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 4, 0);
  gtk_misc_set_alignment (GTK_MISC (label779), 0, 0.5);

  label780 = gtk_label_new (_("Query hit"));
  gtk_widget_set_name (label780, "label780");
  gtk_widget_show (label780);
  gtk_table_attach (GTK_TABLE (table85), label780, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 4, 0);
  gtk_misc_set_alignment (GTK_MISC (label780), 0, 0.5);

  label781 = gtk_label_new (_("Unknown"));
  gtk_widget_set_name (label781, "label781");
  gtk_widget_show (label781);
  gtk_table_attach (GTK_TABLE (table85), label781, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 4, 0);
  gtk_misc_set_alignment (GTK_MISC (label781), 0, 0.5);

  label775 = gtk_label_new (_("Gnutella message size limits"));
  gtk_widget_set_name (label775, "label775");
  gtk_widget_show (label775);
  gtk_frame_set_label_widget (GTK_FRAME (frame_expert_gnet_message_size), label775);

  gtk_label_set_mnemonic_widget (GTK_LABEL (label37), spinbutton_config_search_items);
  gtk_label_set_mnemonic_widget (GTK_LABEL (label364), spinbutton_config_search_reissue_timeout);
  gtk_label_set_mnemonic_widget (GTK_LABEL (label175), spinbutton_config_node_connecting_timeout);
  gtk_label_set_mnemonic_widget (GTK_LABEL (label177), spinbutton_config_node_tx_flowc_timeout);
  gtk_label_set_mnemonic_widget (GTK_LABEL (label176), spinbutton_config_node_connected_timeout);
  gtk_label_set_mnemonic_widget (GTK_LABEL (label84), spinbutton_config_maxttl);
  gtk_label_set_mnemonic_widget (GTK_LABEL (label85), spinbutton_config_myttl);
  gtk_label_set_mnemonic_widget (GTK_LABEL (label159), spinbutton_config_hard_ttl_limit);
  gtk_label_set_mnemonic_widget (GTK_LABEL (label157), spinbutton_config_max_high_ttl_msg);
  gtk_label_set_mnemonic_widget (GTK_LABEL (label158), spinbutton_config_max_high_ttl_radius);
  gtk_label_set_mnemonic_widget (GTK_LABEL (label431), spinbutton_config_min_dup_ratio);
  gtk_label_set_mnemonic_widget (GTK_LABEL (label430), spinbutton_config_min_dup_msg);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (dlg_prefs_gnet_tab, dlg_prefs_gnet_tab, "dlg_prefs_gnet_tab");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, scrolledwindow40, "scrolledwindow40");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, viewport4, "viewport4");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, vbox25, "vbox25");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, frame92, "frame92");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, hbox253, "hbox253");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, table91, "table91");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, frame78, "frame78");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, table92, "table92");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, spinbutton_normal_connections, "spinbutton_normal_connections");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label577, "label577");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, spinbutton_config_max_leaves, "spinbutton_config_max_leaves");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label576, "label576");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label575, "label575");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, checkbutton_gnet_monitor_ip, "checkbutton_gnet_monitor_ip");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, checkbutton_gnet_monitor_servents, "checkbutton_gnet_monitor_servents");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label537, "label537");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, frame135, "frame135");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, option_menu_config_peermode, "option_menu_config_peermode");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, frame_gnet_can_become_ultra, "frame_gnet_can_become_ultra");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, frame138, "frame138");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, vbox116, "vbox116");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, table83, "table83");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label752, "label752");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label753, "label753");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, viewport75, "viewport75");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label_last_ultra_leaf_switch, "label_last_ultra_leaf_switch");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, viewport74, "viewport74");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label_node_last_ultracheck, "label_node_last_ultracheck");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, hseparator12, "hseparator12");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, table84, "table84");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label756, "label756");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label757, "label757");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label758, "label758");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label759, "label759");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label768, "label768");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label769, "label769");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label767, "label767");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, viewport79, "viewport79");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label_up_req_enough_bw, "label_up_req_enough_bw");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, viewport78, "viewport78");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label_up_req_enough_fd, "label_up_req_enough_fd");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, viewport77, "viewport77");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label_up_req_node_uptime, "label_up_req_node_uptime");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, viewport76, "viewport76");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label_up_req_avg_servent_uptime, "label_up_req_avg_servent_uptime");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, viewport80, "viewport80");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label_up_req_avg_ip_uptime, "label_up_req_avg_ip_uptime");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, viewport81, "viewport81");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label_up_req_not_firewalled, "label_up_req_not_firewalled");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, viewport82, "viewport82");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label_up_req_enough_mem, "label_up_req_enough_mem");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, viewport107, "viewport107");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label_up_req_enough_conn, "label_up_req_enough_conn");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label868, "label868");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, vseparator3, "vseparator3");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label994, "label994");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, viewport476, "viewport476");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label_up_req_good_udp, "label_up_req_good_udp");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label920, "label920");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label739, "label739");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, hbox286, "hbox286");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, frame_searches, "frame_searches");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, hbox254, "hbox254");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, table17, "table17");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, spinbutton_config_search_items, "spinbutton_config_search_items");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, spinbutton_config_search_reissue_timeout, "spinbutton_config_search_reissue_timeout");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label38, "label38");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label37, "label37");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label364, "label364");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label365, "label365");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, checkbutton_enable_guess, "checkbutton_enable_guess");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, checkbutton_enable_guess_client, "checkbutton_enable_guess_client");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, checkbutton_enable_g2, "checkbutton_enable_g2");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label293, "label293");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, frame_expert_oob_queries, "frame_expert_oob_queries");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, table101, "table101");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, checkbutton_send_oob_queries, "checkbutton_send_oob_queries");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, checkbutton_process_oob_queries, "checkbutton_process_oob_queries");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, checkbutton_proxy_oob_queries, "checkbutton_proxy_oob_queries");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label885, "label885");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, vbox158, "vbox158");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, frame_expert_search_queue, "frame_expert_search_queue");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, table100, "table100");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label771, "label771");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label772, "label772");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, spinbutton_search_queue_size, "spinbutton_search_queue_size");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, spinbutton_search_queue_spacing, "spinbutton_search_queue_spacing");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label983, "label983");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label984, "label984");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label770, "label770");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, checkbutton_config_query_request_partials, "checkbutton_config_query_request_partials");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, checkbutton_config_search_smart_stop, "checkbutton_config_search_smart_stop");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, checkbutton_search_restart_when_pending, "checkbutton_search_restart_when_pending");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, hbox9352, "hbox9352");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, frame_expert_gnet_timeout, "frame_expert_gnet_timeout");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, table10, "table10");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label175, "label175");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label177, "label177");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label176, "label176");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label584, "label584");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, spinbutton_config_node_connecting_timeout, "spinbutton_config_node_connecting_timeout");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, spinbutton_config_node_tx_flowc_timeout, "spinbutton_config_node_tx_flowc_timeout");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, spinbutton_config_node_connected_timeout, "spinbutton_config_node_connected_timeout");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, spinbutton_config_incoming_connecting_timeout, "spinbutton_config_incoming_connecting_timeout");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label294, "label294");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, frame_expert_gnet_dht, "frame_expert_gnet_dht");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, table120, "table120");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label1075, "label1075");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, option_menu_config_dht_mode, "option_menu_config_dht_mode");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, checkbutton_config_dht_storage_in_memory, "checkbutton_config_dht_storage_in_memory");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label1074, "label1074");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, frame_expert_gnet_ttl, "frame_expert_gnet_ttl");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, vbox143, "vbox143");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, table9, "table9");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, spinbutton_config_maxttl, "spinbutton_config_maxttl");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, spinbutton_config_myttl, "spinbutton_config_myttl");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label84, "label84");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label85, "label85");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label159, "label159");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, spinbutton_config_hard_ttl_limit, "spinbutton_config_hard_ttl_limit");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, vbox144, "vbox144");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, hbox9294, "hbox9294");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label157, "label157");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, spinbutton_config_max_high_ttl_msg, "spinbutton_config_max_high_ttl_msg");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label158, "label158");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, spinbutton_config_max_high_ttl_radius, "spinbutton_config_max_high_ttl_radius");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label160, "label160");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label295, "label295");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, frame_expert_gnet_quality, "frame_expert_gnet_quality");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, table37, "table37");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label433, "label433");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, spinbutton_config_min_dup_msg, "spinbutton_config_min_dup_msg");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, spinbutton_config_min_dup_ratio, "spinbutton_config_min_dup_ratio");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label431, "label431");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label430, "label430");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label574, "label574");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, spinbutton_config_node_rx_flowc_ratio, "spinbutton_config_node_rx_flowc_ratio");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label573, "label573");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label773, "label773");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, spinbutton_node_queries_half_life, "spinbutton_node_queries_half_life");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label774, "label774");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, spinbutton_node_requery_threshold, "spinbutton_node_requery_threshold");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, checkbutton_node_watch_similar_queries, "checkbutton_node_watch_similar_queries");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label982, "label982");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, vseparator4, "vseparator4");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label1076, "label1076");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, spinbutton_config_search_muid_track_amount, "spinbutton_config_search_muid_track_amount");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label429, "label429");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, hbox287, "hbox287");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, frame_expert_gnet_connections, "frame_expert_gnet_connections");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, table74, "table74");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label728, "label728");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label730, "label730");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label731, "label731");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label729, "label729");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, spinbutton_config_reserve_gtkg_nodes, "spinbutton_config_reserve_gtkg_nodes");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, spinbutton_config_unique_nodes, "spinbutton_config_unique_nodes");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label727, "label727");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, frame_expert_gnet_other, "frame_expert_gnet_other");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, table51, "table51");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, spinbutton_config_hops_random_factor, "spinbutton_config_hops_random_factor");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label518, "label518");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, checkbutton_gnet_compact_query, "checkbutton_gnet_compact_query");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, checkbutton_config_spam_lut_in_memory, "checkbutton_config_spam_lut_in_memory");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label362, "label362");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, frame_expert_gnet_message_size, "frame_expert_gnet_message_size");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, table85, "table85");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label777, "label777");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label778, "label778");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label782, "label782");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, spinbutton_search_queries_forward_size, "spinbutton_search_queries_forward_size");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, spinbutton_search_answers_forward_size, "spinbutton_search_answers_forward_size");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, spinbutton_search_queries_kick_size, "spinbutton_search_queries_kick_size");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, spinbutton_search_answers_kick_size, "spinbutton_search_answers_kick_size");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, spinbutton_other_messages_kick_size, "spinbutton_other_messages_kick_size");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label776, "label776");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label779, "label779");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label780, "label780");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label781, "label781");
  GLADE_HOOKUP_OBJECT (dlg_prefs_gnet_tab, label775, "label775");
  GLADE_HOOKUP_OBJECT_NO_REF (dlg_prefs_gnet_tab, tooltips, "tooltips");

  return dlg_prefs_gnet_tab;
}

GtkWidget*
create_dlg_prefs_bw_tab (void)
{
  GtkWidget *dlg_prefs_bw_tab;
  GtkWidget *scrolledwindow39;
  GtkWidget *viewport3;
  GtkWidget *vbox29;
  GtkWidget *frame72;
  GtkWidget *hbox255;
  GtkWidget *table99;
  GtkWidget *checkbutton_config_bw_allow_stealing;
  GtkWidget *checkbutton_prefer_compressed_gnet;
  GtkWidget *checkbutton_config_use_ip_tos;
  GtkWidget *viewport116;
  GtkWidget *frame93;
  GtkWidget *table79;
  GtkWidget *label741;
  GtkWidget *label742;
  GtkWidget *label743;
  GtkWidget *label744;
  GtkWidget *label745;
  GtkWidget *label746;
  GtkWidget *viewport72;
  GtkWidget *label_output_bw_limit;
  GtkWidget *viewport73;
  GtkWidget *label_dl_http_latency;
  GtkWidget *viewport71;
  GtkWidget *label_input_bw_limit;
  GtkWidget *label740;
  GtkWidget *label536;
  GtkWidget *frame20;
  GtkWidget *hbox281;
  GtkWidget *viewport114;
  GtkWidget *frame127;
  GtkWidget *table13;
  GtkWidget *label181;
  GtkWidget *label182;
  GtkObject *spinbutton_config_bws_gin_adj;
  GtkWidget *spinbutton_config_bws_gin;
  GtkObject *spinbutton_config_bws_gout_adj;
  GtkWidget *spinbutton_config_bws_gout;
  GtkWidget *checkbutton_config_bws_gin;
  GtkWidget *checkbutton_config_bws_gout;
  GtkWidget *label884;
  GtkWidget *viewport115;
  GtkWidget *frame79;
  GtkWidget *table62;
  GtkWidget *label581;
  GtkObject *spinbutton_config_bws_glin_adj;
  GtkWidget *spinbutton_config_bws_glin;
  GtkWidget *checkbutton_config_bws_glin;
  GtkWidget *label1040;
  GtkWidget *checkbutton_config_bws_glout;
  GtkObject *spinbutton_config_bws_glout_adj;
  GtkWidget *spinbutton_config_bws_glout;
  GtkWidget *label582;
  GtkWidget *label1041;
  GtkWidget *label1042;
  GtkWidget *label1043;
  GtkWidget *viewport480;
  GtkWidget *label_http_in_avail;
  GtkWidget *viewport481;
  GtkWidget *label_http_out_avail;
  GtkWidget *label578;
  GtkWidget *label290;
  GtkWidget *frame148;
  GtkWidget *alignment142;
  GtkWidget *vbox156;
  GtkWidget *table116;
  GtkWidget *label1033;
  GtkObject *spinbutton_config_bws_dht_out_adj;
  GtkWidget *spinbutton_config_bws_dht_out;
  GtkWidget *checkbutton_config_bws_dht_out;
  GtkWidget *frame149;
  GtkWidget *alignment143;
  GtkWidget *table117;
  GtkWidget *label1036;
  GtkWidget *label1037;
  GtkObject *spinbutton_config_input_dht_lookup_bw_adj;
  GtkWidget *spinbutton_config_input_dht_lookup_bw;
  GtkObject *spinbutton_config_output_dht_lookup_bw_adj;
  GtkWidget *spinbutton_config_output_dht_lookup_bw;
  GtkWidget *label1038;
  GtkWidget *label1039;
  GtkWidget *label1035;
  GtkWidget *label1032;
  GtkWidget *frame12;
  GtkWidget *vbox27;
  GtkWidget *table4;
  GtkWidget *label125;
  GtkWidget *label126;
  GtkObject *spinbutton_config_bws_in_adj;
  GtkWidget *spinbutton_config_bws_in;
  GtkObject *spinbutton_config_bws_out_adj;
  GtkWidget *spinbutton_config_bws_out;
  GtkObject *spinbutton_config_ul_usage_min_percentage_adj;
  GtkWidget *spinbutton_config_ul_usage_min_percentage;
  GtkObject *spinbutton_config_speed_adj;
  GtkWidget *spinbutton_config_speed;
  GtkWidget *label210;
  GtkWidget *label36;
  GtkWidget *hseparator8;
  GtkWidget *label156;
  GtkWidget *checkbutton_compute_connection_speed;
  GtkWidget *checkbutton_config_bw_ul_usage_enabled;
  GtkWidget *checkbutton_config_bws_out;
  GtkWidget *checkbutton_config_bws_in;
  GtkWidget *label291;
  GtkWidget *frame150;
  GtkWidget *vbox157;
  GtkWidget *table119;
  GtkWidget *label1057;
  GtkObject *spinbutton_config_bw_guess_out_adj;
  GtkWidget *spinbutton_config_bw_guess_out;
  GtkWidget *label1063;
  GtkWidget *checkbutton_guess_maximize_bw;
  GtkWidget *label1062;
  GtkTooltips *tooltips;

  tooltips = gtk_tooltips_new ();

  dlg_prefs_bw_tab = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_widget_set_name (dlg_prefs_bw_tab, "dlg_prefs_bw_tab");
  gtk_window_set_title (GTK_WINDOW (dlg_prefs_bw_tab), _("Bandwidth"));
  gtk_window_set_default_size (GTK_WINDOW (dlg_prefs_bw_tab), 600, 400);

  scrolledwindow39 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow39, "scrolledwindow39");
  gtk_widget_show (scrolledwindow39);
  gtk_container_add (GTK_CONTAINER (dlg_prefs_bw_tab), scrolledwindow39);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow39), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);

  viewport3 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport3, "viewport3");
  gtk_widget_show (viewport3);
  gtk_container_add (GTK_CONTAINER (scrolledwindow39), viewport3);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport3), GTK_SHADOW_NONE);

  vbox29 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox29, "vbox29");
  gtk_widget_show (vbox29);
  gtk_container_add (GTK_CONTAINER (viewport3), vbox29);
  gtk_container_set_border_width (GTK_CONTAINER (vbox29), 2);

  frame72 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame72, "frame72");
  gtk_widget_show (frame72);
  gtk_box_pack_start (GTK_BOX (vbox29), frame72, FALSE, TRUE, 0);

  hbox255 = gtk_hbox_new (FALSE, 5);
  gtk_widget_set_name (hbox255, "hbox255");
  gtk_widget_show (hbox255);
  gtk_container_add (GTK_CONTAINER (frame72), hbox255);
  gtk_container_set_border_width (GTK_CONTAINER (hbox255), 2);

  table99 = gtk_table_new (3, 1, FALSE);
  gtk_widget_set_name (table99, "table99");
  gtk_widget_show (table99);
  gtk_box_pack_start (GTK_BOX (hbox255), table99, TRUE, TRUE, 0);

  checkbutton_config_bw_allow_stealing = gtk_check_button_new_with_mnemonic (_("Use _surplus bandwidth"));
  gtk_widget_set_name (checkbutton_config_bw_allow_stealing, "checkbutton_config_bw_allow_stealing");
  gtk_widget_show (checkbutton_config_bw_allow_stealing);
  gtk_table_attach (GTK_TABLE (table99), checkbutton_config_bw_allow_stealing, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 4, 0);

  checkbutton_prefer_compressed_gnet = gtk_check_button_new_with_mnemonic (_("Prefer _compressed connections"));
  gtk_widget_set_name (checkbutton_prefer_compressed_gnet, "checkbutton_prefer_compressed_gnet");
  gtk_widget_show (checkbutton_prefer_compressed_gnet);
  gtk_table_attach (GTK_TABLE (table99), checkbutton_prefer_compressed_gnet, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 4, 0);

  checkbutton_config_use_ip_tos = gtk_check_button_new_with_mnemonic (_("Use IP _Type of Service (TOS)"));
  gtk_widget_set_name (checkbutton_config_use_ip_tos, "checkbutton_config_use_ip_tos");
  gtk_widget_show (checkbutton_config_use_ip_tos);
  gtk_table_attach (GTK_TABLE (table99), checkbutton_config_use_ip_tos, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 4, 0);

  viewport116 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport116, "viewport116");
  gtk_widget_show (viewport116);
  gtk_box_pack_start (GTK_BOX (hbox255), viewport116, TRUE, TRUE, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport116), GTK_SHADOW_OUT);

  frame93 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame93, "frame93");
  gtk_widget_show (frame93);
  gtk_container_add (GTK_CONTAINER (viewport116), frame93);
  gtk_container_set_border_width (GTK_CONTAINER (frame93), 2);

  table79 = gtk_table_new (3, 3, FALSE);
  gtk_widget_set_name (table79, "table79");
  gtk_widget_show (table79);
  gtk_container_add (GTK_CONTAINER (frame93), table79);
  gtk_container_set_border_width (GTK_CONTAINER (table79), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table79), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table79), 4);

  label741 = gtk_label_new (_("Total input bandwidth limit:"));
  gtk_widget_set_name (label741, "label741");
  gtk_widget_show (label741);
  gtk_table_attach (GTK_TABLE (table79), label741, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label741), 0, 0.5);

  label742 = gtk_label_new (_("Total output bandwidth limit:"));
  gtk_widget_set_name (label742, "label742");
  gtk_widget_show (label742);
  gtk_table_attach (GTK_TABLE (table79), label742, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label742), 0, 0.5);

  label743 = gtk_label_new (_("Measured HTTP latency:"));
  gtk_widget_set_name (label743, "label743");
  gtk_widget_show (label743);
  gtk_table_attach (GTK_TABLE (table79), label743, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label743), 0, 0.5);

  label744 = gtk_label_new (_("KiB/s"));
  gtk_widget_set_name (label744, "label744");
  gtk_widget_show (label744);
  gtk_table_attach (GTK_TABLE (table79), label744, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label744), 0, 0.5);

  label745 = gtk_label_new (_("KiB/s"));
  gtk_widget_set_name (label745, "label745");
  gtk_widget_show (label745);
  gtk_table_attach (GTK_TABLE (table79), label745, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label745), 0, 0.5);

  label746 = gtk_label_new (Q_("unit_of_time|s"));
  gtk_widget_set_name (label746, "label746");
  gtk_widget_show (label746);
  gtk_table_attach (GTK_TABLE (table79), label746, 2, 3, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label746), 0, 0.5);

  viewport72 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport72, "viewport72");
  gtk_widget_show (viewport72);
  gtk_table_attach (GTK_TABLE (table79), viewport72, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport72), GTK_SHADOW_NONE);

  label_output_bw_limit = gtk_label_new ("[label_output_bw_limit]");
  gtk_widget_set_name (label_output_bw_limit, "label_output_bw_limit");
  gtk_widget_show (label_output_bw_limit);
  gtk_container_add (GTK_CONTAINER (viewport72), label_output_bw_limit);
  gtk_misc_set_alignment (GTK_MISC (label_output_bw_limit), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_output_bw_limit), 5, 0);

  viewport73 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport73, "viewport73");
  gtk_widget_show (viewport73);
  gtk_table_attach (GTK_TABLE (table79), viewport73, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport73), GTK_SHADOW_NONE);

  label_dl_http_latency = gtk_label_new ("[label_http_latency]");
  gtk_widget_set_name (label_dl_http_latency, "label_dl_http_latency");
  gtk_widget_show (label_dl_http_latency);
  gtk_container_add (GTK_CONTAINER (viewport73), label_dl_http_latency);
  gtk_misc_set_alignment (GTK_MISC (label_dl_http_latency), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_dl_http_latency), 5, 0);

  viewport71 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport71, "viewport71");
  gtk_widget_show (viewport71);
  gtk_table_attach (GTK_TABLE (table79), viewport71, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport71), GTK_SHADOW_NONE);

  label_input_bw_limit = gtk_label_new ("[label_input_bw_limit]");
  gtk_widget_set_name (label_input_bw_limit, "label_input_bw_limit");
  gtk_widget_show (label_input_bw_limit);
  gtk_container_add (GTK_CONTAINER (viewport71), label_input_bw_limit);
  gtk_misc_set_alignment (GTK_MISC (label_input_bw_limit), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_input_bw_limit), 5, 0);

  label740 = gtk_label_new (_("Available bandwidth"));
  gtk_widget_set_name (label740, "label740");
  gtk_widget_show (label740);
  gtk_frame_set_label_widget (GTK_FRAME (frame93), label740);

  label536 = gtk_label_new (_("General"));
  gtk_widget_set_name (label536, "label536");
  gtk_widget_show (label536);
  gtk_frame_set_label_widget (GTK_FRAME (frame72), label536);

  frame20 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame20, "frame20");
  gtk_widget_show (frame20);
  gtk_box_pack_start (GTK_BOX (vbox29), frame20, TRUE, TRUE, 0);

  hbox281 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox281, "hbox281");
  gtk_widget_show (hbox281);
  gtk_container_add (GTK_CONTAINER (frame20), hbox281);
  gtk_container_set_border_width (GTK_CONTAINER (hbox281), 2);

  viewport114 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport114, "viewport114");
  gtk_widget_show (viewport114);
  gtk_box_pack_start (GTK_BOX (hbox281), viewport114, FALSE, TRUE, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport114), GTK_SHADOW_OUT);

  frame127 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame127, "frame127");
  gtk_widget_show (frame127);
  gtk_container_add (GTK_CONTAINER (viewport114), frame127);
  gtk_container_set_border_width (GTK_CONTAINER (frame127), 2);

  table13 = gtk_table_new (2, 3, FALSE);
  gtk_widget_set_name (table13, "table13");
  gtk_widget_show (table13);
  gtk_container_add (GTK_CONTAINER (frame127), table13);
  gtk_container_set_border_width (GTK_CONTAINER (table13), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table13), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table13), 4);

  label181 = gtk_label_new (_("KiB/s"));
  gtk_widget_set_name (label181, "label181");
  gtk_widget_show (label181);
  gtk_table_attach (GTK_TABLE (table13), label181, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label181), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label181), 0, 0.5);

  label182 = gtk_label_new (_("KiB/s"));
  gtk_widget_set_name (label182, "label182");
  gtk_widget_show (label182);
  gtk_table_attach (GTK_TABLE (table13), label182, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label182), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label182), 0, 0.5);

  spinbutton_config_bws_gin_adj = gtk_adjustment_new (1, 1, 2000, 1, 16, 0);
  spinbutton_config_bws_gin = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_bws_gin_adj), 1, 2);
  gtk_widget_set_name (spinbutton_config_bws_gin, "spinbutton_config_bws_gin");
  gtk_widget_show (spinbutton_config_bws_gin);
  gtk_table_attach (GTK_TABLE (table13), spinbutton_config_bws_gin, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_bws_gin), TRUE);

  spinbutton_config_bws_gout_adj = gtk_adjustment_new (1, 1, 2000, 1, 16, 0);
  spinbutton_config_bws_gout = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_bws_gout_adj), 1, 2);
  gtk_widget_set_name (spinbutton_config_bws_gout, "spinbutton_config_bws_gout");
  gtk_widget_show (spinbutton_config_bws_gout);
  gtk_table_attach (GTK_TABLE (table13), spinbutton_config_bws_gout, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_bws_gout), TRUE);

  checkbutton_config_bws_gin = gtk_check_button_new_with_mnemonic (_("_Incoming traffic"));
  gtk_widget_set_name (checkbutton_config_bws_gin, "checkbutton_config_bws_gin");
  gtk_widget_show (checkbutton_config_bws_gin);
  gtk_table_attach (GTK_TABLE (table13), checkbutton_config_bws_gin, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_config_bws_gout = gtk_check_button_new_with_mnemonic (_("_Outgoing traffic"));
  gtk_widget_set_name (checkbutton_config_bws_gout, "checkbutton_config_bws_gout");
  gtk_widget_show (checkbutton_config_bws_gout);
  gtk_table_attach (GTK_TABLE (table13), checkbutton_config_bws_gout, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label884 = gtk_label_new (_("General"));
  gtk_widget_set_name (label884, "label884");
  gtk_widget_show (label884);
  gtk_frame_set_label_widget (GTK_FRAME (frame127), label884);
  gtk_label_set_use_markup (GTK_LABEL (label884), TRUE);

  viewport115 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport115, "viewport115");
  gtk_widget_show (viewport115);
  gtk_box_pack_start (GTK_BOX (hbox281), viewport115, TRUE, TRUE, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport115), GTK_SHADOW_OUT);

  frame79 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame79, "frame79");
  gtk_widget_show (frame79);
  gtk_container_add (GTK_CONTAINER (viewport115), frame79);
  gtk_container_set_border_width (GTK_CONTAINER (frame79), 2);

  table62 = gtk_table_new (4, 3, FALSE);
  gtk_widget_set_name (table62, "table62");
  gtk_widget_show (table62);
  gtk_container_add (GTK_CONTAINER (frame79), table62);
  gtk_container_set_border_width (GTK_CONTAINER (table62), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table62), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table62), 4);

  label581 = gtk_label_new (_("KiB/s"));
  gtk_widget_set_name (label581, "label581");
  gtk_widget_show (label581);
  gtk_table_attach (GTK_TABLE (table62), label581, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label581), 0, 0.5);

  spinbutton_config_bws_glin_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 0);
  spinbutton_config_bws_glin = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_bws_glin_adj), 1, 2);
  gtk_widget_set_name (spinbutton_config_bws_glin, "spinbutton_config_bws_glin");
  gtk_widget_show (spinbutton_config_bws_glin);
  gtk_table_attach (GTK_TABLE (table62), spinbutton_config_bws_glin, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_bws_glin), TRUE);

  checkbutton_config_bws_glin = gtk_check_button_new_with_mnemonic (_("Incoming traffic from _leaves"));
  gtk_widget_set_name (checkbutton_config_bws_glin, "checkbutton_config_bws_glin");
  gtk_widget_show (checkbutton_config_bws_glin);
  gtk_table_attach (GTK_TABLE (table62), checkbutton_config_bws_glin, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label1040 = gtk_label_new (_("Available HTTP input bandwidth"));
  gtk_widget_set_name (label1040, "label1040");
  gtk_widget_show (label1040);
  gtk_table_attach (GTK_TABLE (table62), label1040, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label1040), 0, 0.5);

  checkbutton_config_bws_glout = gtk_check_button_new_with_mnemonic (_("Outgoing traffic to lea_ves"));
  gtk_widget_set_name (checkbutton_config_bws_glout, "checkbutton_config_bws_glout");
  gtk_widget_show (checkbutton_config_bws_glout);
  gtk_table_attach (GTK_TABLE (table62), checkbutton_config_bws_glout, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  spinbutton_config_bws_glout_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 0);
  spinbutton_config_bws_glout = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_bws_glout_adj), 1, 2);
  gtk_widget_set_name (spinbutton_config_bws_glout, "spinbutton_config_bws_glout");
  gtk_widget_show (spinbutton_config_bws_glout);
  gtk_table_attach (GTK_TABLE (table62), spinbutton_config_bws_glout, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_bws_glout), TRUE);

  label582 = gtk_label_new (_("KiB/s"));
  gtk_widget_set_name (label582, "label582");
  gtk_widget_show (label582);
  gtk_table_attach (GTK_TABLE (table62), label582, 2, 3, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label582), 0, 0.5);

  label1041 = gtk_label_new (_("KiB/s"));
  gtk_widget_set_name (label1041, "label1041");
  gtk_widget_show (label1041);
  gtk_table_attach (GTK_TABLE (table62), label1041, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label1041), 0, 0.5);

  label1042 = gtk_label_new (_("KiB/s"));
  gtk_widget_set_name (label1042, "label1042");
  gtk_widget_show (label1042);
  gtk_table_attach (GTK_TABLE (table62), label1042, 2, 3, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label1042), 0, 0.5);

  label1043 = gtk_label_new (_("Available HTTP output bandwidth"));
  gtk_widget_set_name (label1043, "label1043");
  gtk_widget_show (label1043);
  gtk_table_attach (GTK_TABLE (table62), label1043, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label1043), 0, 0.5);

  viewport480 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport480, "viewport480");
  gtk_widget_show (viewport480);
  gtk_table_attach (GTK_TABLE (table62), viewport480, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport480), GTK_SHADOW_NONE);

  label_http_in_avail = gtk_label_new ("[label_http_in_avail]");
  gtk_widget_set_name (label_http_in_avail, "label_http_in_avail");
  gtk_widget_show (label_http_in_avail);
  gtk_container_add (GTK_CONTAINER (viewport480), label_http_in_avail);
  gtk_misc_set_alignment (GTK_MISC (label_http_in_avail), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_http_in_avail), 5, 0);

  viewport481 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport481, "viewport481");
  gtk_widget_show (viewport481);
  gtk_table_attach (GTK_TABLE (table62), viewport481, 1, 2, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport481), GTK_SHADOW_NONE);

  label_http_out_avail = gtk_label_new ("[label_http_out_avail]");
  gtk_widget_set_name (label_http_out_avail, "label_http_out_avail");
  gtk_widget_show (label_http_out_avail);
  gtk_container_add (GTK_CONTAINER (viewport481), label_http_out_avail);
  gtk_misc_set_alignment (GTK_MISC (label_http_out_avail), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_http_out_avail), 5, 0);

  label578 = gtk_label_new (_("Ultrapeer mode"));
  gtk_widget_set_name (label578, "label578");
  gtk_widget_show (label578);
  gtk_frame_set_label_widget (GTK_FRAME (frame79), label578);

  label290 = gtk_label_new_with_mnemonic (_("Bandwidth limits for Gnutella traffic"));
  gtk_widget_set_name (label290, "label290");
  gtk_widget_show (label290);
  gtk_frame_set_label_widget (GTK_FRAME (frame20), label290);

  frame148 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame148, "frame148");
  gtk_widget_show (frame148);
  gtk_box_pack_start (GTK_BOX (vbox29), frame148, TRUE, TRUE, 0);

  alignment142 = gtk_alignment_new (0.5, 0.5, 1, 1);
  gtk_widget_set_name (alignment142, "alignment142");
  gtk_widget_show (alignment142);
  gtk_container_add (GTK_CONTAINER (frame148), alignment142);
  gtk_alignment_set_padding (GTK_ALIGNMENT (alignment142), 0, 0, 12, 0);

  vbox156 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox156, "vbox156");
  gtk_widget_show (vbox156);
  gtk_container_add (GTK_CONTAINER (alignment142), vbox156);

  table116 = gtk_table_new (1, 3, FALSE);
  gtk_widget_set_name (table116, "table116");
  gtk_widget_show (table116);
  gtk_box_pack_start (GTK_BOX (vbox156), table116, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (table116), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table116), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table116), 4);

  label1033 = gtk_label_new (_("KiB/s"));
  gtk_widget_set_name (label1033, "label1033");
  gtk_widget_show (label1033);
  gtk_table_attach (GTK_TABLE (table116), label1033, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label1033), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label1033), 0, 0.5);

  spinbutton_config_bws_dht_out_adj = gtk_adjustment_new (1, 1, 2000, 1, 16, 0);
  spinbutton_config_bws_dht_out = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_bws_dht_out_adj), 1, 2);
  gtk_widget_set_name (spinbutton_config_bws_dht_out, "spinbutton_config_bws_dht_out");
  gtk_widget_show (spinbutton_config_bws_dht_out);
  gtk_table_attach (GTK_TABLE (table116), spinbutton_config_bws_dht_out, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_bws_dht_out), TRUE);

  checkbutton_config_bws_dht_out = gtk_check_button_new_with_mnemonic (_("Global DHT outgoing traffic"));
  gtk_widget_set_name (checkbutton_config_bws_dht_out, "checkbutton_config_bws_dht_out");
  gtk_widget_show (checkbutton_config_bws_dht_out);
  gtk_table_attach (GTK_TABLE (table116), checkbutton_config_bws_dht_out, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  frame149 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame149, "frame149");
  gtk_widget_show (frame149);
  gtk_box_pack_start (GTK_BOX (vbox156), frame149, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame149), 2);
  gtk_frame_set_shadow_type (GTK_FRAME (frame149), GTK_SHADOW_OUT);

  alignment143 = gtk_alignment_new (0.5, 0.5, 1, 1);
  gtk_widget_set_name (alignment143, "alignment143");
  gtk_widget_show (alignment143);
  gtk_container_add (GTK_CONTAINER (frame149), alignment143);
  gtk_alignment_set_padding (GTK_ALIGNMENT (alignment143), 0, 0, 12, 0);

  table117 = gtk_table_new (2, 3, FALSE);
  gtk_widget_set_name (table117, "table117");
  gtk_widget_show (table117);
  gtk_container_add (GTK_CONTAINER (alignment143), table117);
  gtk_container_set_border_width (GTK_CONTAINER (table117), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table117), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table117), 4);

  label1036 = gtk_label_new (_("KiB/s"));
  gtk_widget_set_name (label1036, "label1036");
  gtk_widget_show (label1036);
  gtk_table_attach (GTK_TABLE (table117), label1036, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label1036), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label1036), 0, 0.5);

  label1037 = gtk_label_new (_("KiB/s"));
  gtk_widget_set_name (label1037, "label1037");
  gtk_widget_show (label1037);
  gtk_table_attach (GTK_TABLE (table117), label1037, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label1037), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label1037), 0, 0.5);

  spinbutton_config_input_dht_lookup_bw_adj = gtk_adjustment_new (1, 1, 2000, 1, 16, 0);
  spinbutton_config_input_dht_lookup_bw = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_input_dht_lookup_bw_adj), 1, 2);
  gtk_widget_set_name (spinbutton_config_input_dht_lookup_bw, "spinbutton_config_input_dht_lookup_bw");
  gtk_widget_show (spinbutton_config_input_dht_lookup_bw);
  gtk_table_attach (GTK_TABLE (table117), spinbutton_config_input_dht_lookup_bw, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_input_dht_lookup_bw), TRUE);

  spinbutton_config_output_dht_lookup_bw_adj = gtk_adjustment_new (1, 1, 2000, 1, 16, 0);
  spinbutton_config_output_dht_lookup_bw = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_output_dht_lookup_bw_adj), 1, 2);
  gtk_widget_set_name (spinbutton_config_output_dht_lookup_bw, "spinbutton_config_output_dht_lookup_bw");
  gtk_widget_show (spinbutton_config_output_dht_lookup_bw);
  gtk_table_attach (GTK_TABLE (table117), spinbutton_config_output_dht_lookup_bw, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_output_dht_lookup_bw), TRUE);

  label1038 = gtk_label_new (_("Input bandwidth average"));
  gtk_widget_set_name (label1038, "label1038");
  gtk_widget_show (label1038);
  gtk_table_attach (GTK_TABLE (table117), label1038, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label1038), 0, 0.5);

  label1039 = gtk_label_new (_("Output bandwidth average"));
  gtk_widget_set_name (label1039, "label1039");
  gtk_widget_show (label1039);
  gtk_table_attach (GTK_TABLE (table117), label1039, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label1039), 0, 0.5);

  label1035 = gtk_label_new (_("Bandwidth targets for node lookups"));
  gtk_widget_set_name (label1035, "label1035");
  gtk_widget_show (label1035);
  gtk_frame_set_label_widget (GTK_FRAME (frame149), label1035);
  gtk_label_set_use_markup (GTK_LABEL (label1035), TRUE);

  label1032 = gtk_label_new (_("Bandwidth limits for the Distributed Hash Table"));
  gtk_widget_set_name (label1032, "label1032");
  gtk_widget_show (label1032);
  gtk_frame_set_label_widget (GTK_FRAME (frame148), label1032);
  gtk_label_set_use_markup (GTK_LABEL (label1032), TRUE);

  frame12 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame12, "frame12");
  gtk_widget_show (frame12);
  gtk_box_pack_start (GTK_BOX (vbox29), frame12, FALSE, TRUE, 0);

  vbox27 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox27, "vbox27");
  gtk_widget_show (vbox27);
  gtk_container_add (GTK_CONTAINER (frame12), vbox27);
  gtk_container_set_border_width (GTK_CONTAINER (vbox27), 2);

  table4 = gtk_table_new (6, 3, FALSE);
  gtk_widget_set_name (table4, "table4");
  gtk_widget_show (table4);
  gtk_box_pack_start (GTK_BOX (vbox27), table4, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (table4), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table4), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table4), 4);

  label125 = gtk_label_new (_("KiB/s"));
  gtk_widget_set_name (label125, "label125");
  gtk_widget_show (label125);
  gtk_table_attach (GTK_TABLE (table4), label125, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label125), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label125), 0, 0.5);

  label126 = gtk_label_new (_("KiB/s"));
  gtk_widget_set_name (label126, "label126");
  gtk_widget_show (label126);
  gtk_table_attach (GTK_TABLE (table4), label126, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label126), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label126), 0, 0.5);

  spinbutton_config_bws_in_adj = gtk_adjustment_new (1, 1, 2000, 1, 16, 0);
  spinbutton_config_bws_in = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_bws_in_adj), 1, 2);
  gtk_widget_set_name (spinbutton_config_bws_in, "spinbutton_config_bws_in");
  gtk_widget_show (spinbutton_config_bws_in);
  gtk_table_attach (GTK_TABLE (table4), spinbutton_config_bws_in, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_bws_in), TRUE);

  spinbutton_config_bws_out_adj = gtk_adjustment_new (1, 1, 2000, 1, 16, 0);
  spinbutton_config_bws_out = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_bws_out_adj), 1, 2);
  gtk_widget_set_name (spinbutton_config_bws_out, "spinbutton_config_bws_out");
  gtk_widget_show (spinbutton_config_bws_out);
  gtk_table_attach (GTK_TABLE (table4), spinbutton_config_bws_out, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_bws_out), TRUE);

  spinbutton_config_ul_usage_min_percentage_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 0);
  spinbutton_config_ul_usage_min_percentage = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_ul_usage_min_percentage_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_ul_usage_min_percentage, "spinbutton_config_ul_usage_min_percentage");
  gtk_widget_show (spinbutton_config_ul_usage_min_percentage);
  gtk_table_attach (GTK_TABLE (table4), spinbutton_config_ul_usage_min_percentage, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_tooltips_set_tip (tooltips, spinbutton_config_ul_usage_min_percentage, _("Until the configured percentage of outgoing HTTP bandwidth is in use, open additional upload slots on request."), NULL);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_ul_usage_min_percentage), TRUE);

  spinbutton_config_speed_adj = gtk_adjustment_new (64, 0, 2000, 1, 16, 0);
  spinbutton_config_speed = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_speed_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_speed, "spinbutton_config_speed");
  gtk_widget_show (spinbutton_config_speed);
  gtk_table_attach (GTK_TABLE (table4), spinbutton_config_speed, 1, 2, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_tooltips_set_tip (tooltips, spinbutton_config_speed, _("What other people see as your connection speed."), NULL);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_speed), TRUE);

  label210 = gtk_label_new ("%");
  gtk_widget_set_name (label210, "label210");
  gtk_widget_show (label210);
  gtk_table_attach (GTK_TABLE (table4), label210, 2, 3, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label210), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label210), 0, 0.5);

  label36 = gtk_label_new (_("kbps to peers"));
  gtk_widget_set_name (label36, "label36");
  gtk_widget_show (label36);
  gtk_table_attach (GTK_TABLE (table4), label36, 2, 3, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label36), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label36), 0, 0.5);

  hseparator8 = gtk_hseparator_new ();
  gtk_widget_set_name (hseparator8, "hseparator8");
  gtk_widget_show (hseparator8);
  gtk_table_attach (GTK_TABLE (table4), hseparator8, 0, 3, 3, 4,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label156 = gtk_label_new_with_mnemonic (_("Report an upload connection _speed of"));
  gtk_widget_set_name (label156, "label156");
  gtk_widget_show (label156);
  gtk_table_attach (GTK_TABLE (table4), label156, 0, 1, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 4, 0);
  gtk_label_set_justify (GTK_LABEL (label156), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label156), 0, 0.5);

  checkbutton_compute_connection_speed = gtk_check_button_new_with_mnemonic (_("_Compute upload connection speed"));
  gtk_widget_set_name (checkbutton_compute_connection_speed, "checkbutton_compute_connection_speed");
  gtk_widget_show (checkbutton_compute_connection_speed);
  gtk_table_attach (GTK_TABLE (table4), checkbutton_compute_connection_speed, 0, 3, 5, 6,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 4, 0);

  checkbutton_config_bw_ul_usage_enabled = gtk_check_button_new_with_mnemonic (_("Enable dynamic upload slots _allocation"));
  gtk_widget_set_name (checkbutton_config_bw_ul_usage_enabled, "checkbutton_config_bw_ul_usage_enabled");
  gtk_widget_show (checkbutton_config_bw_ul_usage_enabled);
  gtk_table_attach (GTK_TABLE (table4), checkbutton_config_bw_ul_usage_enabled, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 4, 0);
  gtk_tooltips_set_tip (tooltips, checkbutton_config_bw_ul_usage_enabled, _("Until the configured percentage of outgoing HTTP bandwidth is in use, open additional upload slots on request."), NULL);

  checkbutton_config_bws_out = gtk_check_button_new_with_mnemonic (_("Cumulative _upload rate"));
  gtk_widget_set_name (checkbutton_config_bws_out, "checkbutton_config_bws_out");
  gtk_widget_show (checkbutton_config_bws_out);
  gtk_table_attach (GTK_TABLE (table4), checkbutton_config_bws_out, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 4, 0);

  checkbutton_config_bws_in = gtk_check_button_new_with_mnemonic (_("Cumulative _download rate"));
  gtk_widget_set_name (checkbutton_config_bws_in, "checkbutton_config_bws_in");
  gtk_widget_show (checkbutton_config_bws_in);
  gtk_table_attach (GTK_TABLE (table4), checkbutton_config_bws_in, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 4, 0);

  label291 = gtk_label_new_with_mnemonic (_("Bandwidth limits for HTTP traffic"));
  gtk_widget_set_name (label291, "label291");
  gtk_widget_show (label291);
  gtk_frame_set_label_widget (GTK_FRAME (frame12), label291);

  frame150 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame150, "frame150");
  gtk_widget_show (frame150);
  gtk_box_pack_start (GTK_BOX (vbox29), frame150, TRUE, TRUE, 0);

  vbox157 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox157, "vbox157");
  gtk_widget_show (vbox157);
  gtk_container_add (GTK_CONTAINER (frame150), vbox157);
  gtk_container_set_border_width (GTK_CONTAINER (vbox157), 2);

  table119 = gtk_table_new (2, 3, FALSE);
  gtk_widget_set_name (table119, "table119");
  gtk_widget_show (table119);
  gtk_box_pack_start (GTK_BOX (vbox157), table119, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (table119), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table119), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table119), 4);

  label1057 = gtk_label_new (_("KiB/s"));
  gtk_widget_set_name (label1057, "label1057");
  gtk_widget_show (label1057);
  gtk_table_attach (GTK_TABLE (table119), label1057, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label1057), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label1057), 0, 0.5);

  spinbutton_config_bw_guess_out_adj = gtk_adjustment_new (1, 1, 2000, 1, 16, 0);
  spinbutton_config_bw_guess_out = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_bw_guess_out_adj), 1, 2);
  gtk_widget_set_name (spinbutton_config_bw_guess_out, "spinbutton_config_bw_guess_out");
  gtk_widget_show (spinbutton_config_bw_guess_out);
  gtk_table_attach (GTK_TABLE (table119), spinbutton_config_bw_guess_out, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_bw_guess_out), TRUE);

  label1063 = gtk_label_new (_("Output bandwidth hint"));
  gtk_widget_set_name (label1063, "label1063");
  gtk_widget_show (label1063);
  gtk_table_attach (GTK_TABLE (table119), label1063, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label1063), 0, 0.5);

  checkbutton_guess_maximize_bw = gtk_check_button_new_with_mnemonic (_("Allow unused Gnutella outgoing bandwidth to supersede hint"));
  gtk_widget_set_name (checkbutton_guess_maximize_bw, "checkbutton_guess_maximize_bw");
  gtk_widget_show (checkbutton_guess_maximize_bw);
  gtk_table_attach (GTK_TABLE (table119), checkbutton_guess_maximize_bw, 0, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label1062 = gtk_label_new_with_mnemonic (_("Bandwidth limits for GUESS queries"));
  gtk_widget_set_name (label1062, "label1062");
  gtk_widget_show (label1062);
  gtk_frame_set_label_widget (GTK_FRAME (frame150), label1062);

  gtk_label_set_mnemonic_widget (GTK_LABEL (label156), spinbutton_config_speed);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (dlg_prefs_bw_tab, dlg_prefs_bw_tab, "dlg_prefs_bw_tab");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, scrolledwindow39, "scrolledwindow39");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, viewport3, "viewport3");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, vbox29, "vbox29");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, frame72, "frame72");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, hbox255, "hbox255");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, table99, "table99");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, checkbutton_config_bw_allow_stealing, "checkbutton_config_bw_allow_stealing");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, checkbutton_prefer_compressed_gnet, "checkbutton_prefer_compressed_gnet");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, checkbutton_config_use_ip_tos, "checkbutton_config_use_ip_tos");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, viewport116, "viewport116");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, frame93, "frame93");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, table79, "table79");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, label741, "label741");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, label742, "label742");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, label743, "label743");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, label744, "label744");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, label745, "label745");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, label746, "label746");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, viewport72, "viewport72");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, label_output_bw_limit, "label_output_bw_limit");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, viewport73, "viewport73");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, label_dl_http_latency, "label_dl_http_latency");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, viewport71, "viewport71");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, label_input_bw_limit, "label_input_bw_limit");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, label740, "label740");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, label536, "label536");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, frame20, "frame20");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, hbox281, "hbox281");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, viewport114, "viewport114");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, frame127, "frame127");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, table13, "table13");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, label181, "label181");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, label182, "label182");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, spinbutton_config_bws_gin, "spinbutton_config_bws_gin");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, spinbutton_config_bws_gout, "spinbutton_config_bws_gout");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, checkbutton_config_bws_gin, "checkbutton_config_bws_gin");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, checkbutton_config_bws_gout, "checkbutton_config_bws_gout");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, label884, "label884");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, viewport115, "viewport115");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, frame79, "frame79");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, table62, "table62");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, label581, "label581");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, spinbutton_config_bws_glin, "spinbutton_config_bws_glin");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, checkbutton_config_bws_glin, "checkbutton_config_bws_glin");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, label1040, "label1040");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, checkbutton_config_bws_glout, "checkbutton_config_bws_glout");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, spinbutton_config_bws_glout, "spinbutton_config_bws_glout");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, label582, "label582");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, label1041, "label1041");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, label1042, "label1042");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, label1043, "label1043");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, viewport480, "viewport480");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, label_http_in_avail, "label_http_in_avail");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, viewport481, "viewport481");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, label_http_out_avail, "label_http_out_avail");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, label578, "label578");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, label290, "label290");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, frame148, "frame148");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, alignment142, "alignment142");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, vbox156, "vbox156");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, table116, "table116");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, label1033, "label1033");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, spinbutton_config_bws_dht_out, "spinbutton_config_bws_dht_out");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, checkbutton_config_bws_dht_out, "checkbutton_config_bws_dht_out");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, frame149, "frame149");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, alignment143, "alignment143");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, table117, "table117");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, label1036, "label1036");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, label1037, "label1037");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, spinbutton_config_input_dht_lookup_bw, "spinbutton_config_input_dht_lookup_bw");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, spinbutton_config_output_dht_lookup_bw, "spinbutton_config_output_dht_lookup_bw");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, label1038, "label1038");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, label1039, "label1039");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, label1035, "label1035");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, label1032, "label1032");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, frame12, "frame12");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, vbox27, "vbox27");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, table4, "table4");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, label125, "label125");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, label126, "label126");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, spinbutton_config_bws_in, "spinbutton_config_bws_in");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, spinbutton_config_bws_out, "spinbutton_config_bws_out");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, spinbutton_config_ul_usage_min_percentage, "spinbutton_config_ul_usage_min_percentage");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, spinbutton_config_speed, "spinbutton_config_speed");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, label210, "label210");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, label36, "label36");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, hseparator8, "hseparator8");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, label156, "label156");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, checkbutton_compute_connection_speed, "checkbutton_compute_connection_speed");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, checkbutton_config_bw_ul_usage_enabled, "checkbutton_config_bw_ul_usage_enabled");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, checkbutton_config_bws_out, "checkbutton_config_bws_out");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, checkbutton_config_bws_in, "checkbutton_config_bws_in");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, label291, "label291");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, frame150, "frame150");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, vbox157, "vbox157");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, table119, "table119");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, label1057, "label1057");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, spinbutton_config_bw_guess_out, "spinbutton_config_bw_guess_out");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, label1063, "label1063");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, checkbutton_guess_maximize_bw, "checkbutton_guess_maximize_bw");
  GLADE_HOOKUP_OBJECT (dlg_prefs_bw_tab, label1062, "label1062");
  GLADE_HOOKUP_OBJECT_NO_REF (dlg_prefs_bw_tab, tooltips, "tooltips");

  return dlg_prefs_bw_tab;
}

GtkWidget*
create_dlg_prefs_dl_tab (void)
{
  GtkWidget *dlg_prefs_dl_tab;
  GtkWidget *scrolledwindow64;
  GtkWidget *viewport32;
  GtkWidget *vbox38;
  GtkWidget *frame_save_new_files;
  GtkWidget *hbox96;
  GtkWidget *entry_config_save_path;
  GtkWidget *button_config_save_path;
  GtkWidget *alignment73;
  GtkWidget *hbox207;
  GtkWidget *image119;
  GtkWidget *label485;
  GtkWidget *label296;
  GtkWidget *frame_move_downloaded_files;
  GtkWidget *hbox95;
  GtkWidget *entry_config_move_path;
  GtkWidget *button_config_move_path;
  GtkWidget *alignment72;
  GtkWidget *hbox206;
  GtkWidget *image118;
  GtkWidget *label484;
  GtkWidget *label297;
  GtkWidget *frame60;
  GtkWidget *hbox201;
  GtkWidget *entry_config_bad_path;
  GtkWidget *button_config_bad_path;
  GtkWidget *alignment71;
  GtkWidget *hbox205;
  GtkWidget *image117;
  GtkWidget *label483;
  GtkWidget *label472;
  GtkWidget *frame123;
  GtkWidget *table97;
  GtkWidget *checkbutton_config_convert_spaces;
  GtkWidget *checkbutton_config_convert_evil_chars;
  GtkWidget *checkbutton_config_convert_old_filenames;
  GtkWidget *checkbutton_config_beautify_filenames;
  GtkWidget *label880;
  GtkWidget *hbox283;
  GtkWidget *frame_expert_dl_source_quality;
  GtkWidget *hbox281;
  GtkWidget *table39;
  GtkWidget *checkbutton_config_download_optimistic_start;
  GtkWidget *checkbutton_config_req_urn;
  GtkWidget *checkbutton_config_req_srv_name;
  GtkWidget *hbox257;
  GtkWidget *vbox126;
  GtkWidget *checkbutton_config_use_alternate_sources;
  GtkWidget *checkbutton_config_strict_sha1_matching;
  GtkWidget *checkbutton_auto_feed_dmesh;
  GtkWidget *checkbutton_config_tth_auto_discovery;
  GtkWidget *label480;
  GtkWidget *frame16;
  GtkWidget *table38;
  GtkWidget *label173;
  GtkObject *spinbutton_config_download_overlap_range_adj;
  GtkWidget *spinbutton_config_download_overlap_range;
  GtkWidget *label172;
  GtkWidget *label171;
  GtkObject *spinbutton_config_download_max_retries_adj;
  GtkWidget *spinbutton_config_download_max_retries;
  GtkWidget *label985;
  GtkWidget *label298;
  GtkWidget *frame_expert_dl_timeout;
  GtkWidget *table8;
  GtkObject *spinbutton_config_download_retry_stopped_delay_adj;
  GtkWidget *spinbutton_config_download_retry_stopped_delay;
  GtkObject *spinbutton_config_download_retry_refused_delay_adj;
  GtkWidget *spinbutton_config_download_retry_refused_delay;
  GtkObject *spinbutton_config_download_retry_busy_delay_adj;
  GtkWidget *spinbutton_config_download_retry_busy_delay;
  GtkObject *spinbutton_config_download_retry_timeout_delay_adj;
  GtkWidget *spinbutton_config_download_retry_timeout_delay;
  GtkObject *spinbutton_config_download_retry_timeout_max_adj;
  GtkWidget *spinbutton_config_download_retry_timeout_max;
  GtkObject *spinbutton_config_download_retry_timeout_min_adj;
  GtkWidget *spinbutton_config_download_retry_timeout_min;
  GtkObject *spinbutton_config_download_connecting_timeout_adj;
  GtkWidget *spinbutton_config_download_connecting_timeout;
  GtkObject *spinbutton_config_download_push_sent_timeout_adj;
  GtkWidget *spinbutton_config_download_push_sent_timeout;
  GtkObject *spinbutton_config_download_connected_timeout_adj;
  GtkWidget *spinbutton_config_download_connected_timeout;
  GtkWidget *label165;
  GtkWidget *label166;
  GtkWidget *label167;
  GtkWidget *label168;
  GtkWidget *label169;
  GtkWidget *label170;
  GtkWidget *label162;
  GtkWidget *label163;
  GtkWidget *label164;
  GtkWidget *label299;
  GtkWidget *frame51;
  GtkWidget *hbox282;
  GtkWidget *table94;
  GtkObject *spinbutton_dl_minchunksize_adj;
  GtkWidget *spinbutton_dl_minchunksize;
  GtkObject *spinbutton_dl_maxchunksize_adj;
  GtkWidget *spinbutton_dl_maxchunksize;
  GtkWidget *checkbutton_config_use_swarming;
  GtkWidget *label368;
  GtkWidget *label369;
  GtkWidget *label918;
  GtkWidget *label919;
  GtkWidget *label936;
  GtkWidget *label934;
  GtkObject *spinbutton_download_buffer_size_adj;
  GtkWidget *spinbutton_download_buffer_size;
  GtkWidget *label1055;
  GtkObject *spinbutton_dl_pipeline_maxchunksize_adj;
  GtkWidget *spinbutton_dl_pipeline_maxchunksize;
  GtkWidget *label1056;
  GtkWidget *checkbutton_config_aggressive_swarming;
  GtkWidget *checkbutton_config_enable_http_pipelining;
  GtkWidget *label366;
  GtkTooltips *tooltips;

  tooltips = gtk_tooltips_new ();

  dlg_prefs_dl_tab = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_widget_set_name (dlg_prefs_dl_tab, "dlg_prefs_dl_tab");
  gtk_window_set_title (GTK_WINDOW (dlg_prefs_dl_tab), _("Downloads"));
  gtk_window_set_default_size (GTK_WINDOW (dlg_prefs_dl_tab), 600, 400);

  scrolledwindow64 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow64, "scrolledwindow64");
  gtk_widget_show (scrolledwindow64);
  gtk_container_add (GTK_CONTAINER (dlg_prefs_dl_tab), scrolledwindow64);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow64), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);

  viewport32 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport32, "viewport32");
  gtk_widget_show (viewport32);
  gtk_container_add (GTK_CONTAINER (scrolledwindow64), viewport32);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport32), GTK_SHADOW_NONE);

  vbox38 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox38, "vbox38");
  gtk_widget_show (vbox38);
  gtk_container_add (GTK_CONTAINER (viewport32), vbox38);
  gtk_container_set_border_width (GTK_CONTAINER (vbox38), 2);

  frame_save_new_files = gtk_frame_new (NULL);
  gtk_widget_set_name (frame_save_new_files, "frame_save_new_files");
  gtk_widget_show (frame_save_new_files);
  gtk_box_pack_start (GTK_BOX (vbox38), frame_save_new_files, FALSE, TRUE, 0);

  hbox96 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox96, "hbox96");
  gtk_widget_show (hbox96);
  gtk_container_add (GTK_CONTAINER (frame_save_new_files), hbox96);
  gtk_container_set_border_width (GTK_CONTAINER (hbox96), 2);

  entry_config_save_path = gtk_entry_new ();
  gtk_widget_set_name (entry_config_save_path, "entry_config_save_path");
  gtk_widget_show (entry_config_save_path);
  gtk_box_pack_start (GTK_BOX (hbox96), entry_config_save_path, TRUE, TRUE, 0);
  gtk_editable_set_editable (GTK_EDITABLE (entry_config_save_path), FALSE);

  button_config_save_path = gtk_button_new ();
  gtk_widget_set_name (button_config_save_path, "button_config_save_path");
  gtk_widget_show (button_config_save_path);
  gtk_box_pack_start (GTK_BOX (hbox96), button_config_save_path, FALSE, FALSE, 0);

  alignment73 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment73, "alignment73");
  gtk_widget_show (alignment73);
  gtk_container_add (GTK_CONTAINER (button_config_save_path), alignment73);

  hbox207 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox207, "hbox207");
  gtk_widget_show (hbox207);
  gtk_container_add (GTK_CONTAINER (alignment73), hbox207);

  image119 = gtk_image_new_from_stock ("gtk-open", GTK_ICON_SIZE_BUTTON);
  gtk_widget_set_name (image119, "image119");
  gtk_widget_show (image119);
  gtk_box_pack_start (GTK_BOX (hbox207), image119, FALSE, FALSE, 0);

  label485 = gtk_label_new_with_mnemonic (_("_Browse"));
  gtk_widget_set_name (label485, "label485");
  gtk_widget_show (label485);
  gtk_box_pack_start (GTK_BOX (hbox207), label485, FALSE, FALSE, 0);

  label296 = gtk_label_new (_("Keep downloading/incomplete files in"));
  gtk_widget_set_name (label296, "label296");
  gtk_widget_show (label296);
  gtk_frame_set_label_widget (GTK_FRAME (frame_save_new_files), label296);

  frame_move_downloaded_files = gtk_frame_new (NULL);
  gtk_widget_set_name (frame_move_downloaded_files, "frame_move_downloaded_files");
  gtk_widget_show (frame_move_downloaded_files);
  gtk_box_pack_start (GTK_BOX (vbox38), frame_move_downloaded_files, FALSE, TRUE, 0);

  hbox95 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox95, "hbox95");
  gtk_widget_show (hbox95);
  gtk_container_add (GTK_CONTAINER (frame_move_downloaded_files), hbox95);
  gtk_container_set_border_width (GTK_CONTAINER (hbox95), 2);

  entry_config_move_path = gtk_entry_new ();
  gtk_widget_set_name (entry_config_move_path, "entry_config_move_path");
  gtk_widget_show (entry_config_move_path);
  gtk_box_pack_start (GTK_BOX (hbox95), entry_config_move_path, TRUE, TRUE, 0);
  gtk_editable_set_editable (GTK_EDITABLE (entry_config_move_path), FALSE);

  button_config_move_path = gtk_button_new ();
  gtk_widget_set_name (button_config_move_path, "button_config_move_path");
  gtk_widget_show (button_config_move_path);
  gtk_box_pack_start (GTK_BOX (hbox95), button_config_move_path, FALSE, FALSE, 0);

  alignment72 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment72, "alignment72");
  gtk_widget_show (alignment72);
  gtk_container_add (GTK_CONTAINER (button_config_move_path), alignment72);

  hbox206 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox206, "hbox206");
  gtk_widget_show (hbox206);
  gtk_container_add (GTK_CONTAINER (alignment72), hbox206);

  image118 = gtk_image_new_from_stock ("gtk-open", GTK_ICON_SIZE_BUTTON);
  gtk_widget_set_name (image118, "image118");
  gtk_widget_show (image118);
  gtk_box_pack_start (GTK_BOX (hbox206), image118, FALSE, FALSE, 0);

  label484 = gtk_label_new_with_mnemonic (_("_Browse"));
  gtk_widget_set_name (label484, "label484");
  gtk_widget_show (label484);
  gtk_box_pack_start (GTK_BOX (hbox206), label484, FALSE, FALSE, 0);

  label297 = gtk_label_new_with_mnemonic (_("Move completely downloaded files to"));
  gtk_widget_set_name (label297, "label297");
  gtk_widget_show (label297);
  gtk_frame_set_label_widget (GTK_FRAME (frame_move_downloaded_files), label297);

  frame60 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame60, "frame60");
  gtk_widget_show (frame60);
  gtk_box_pack_start (GTK_BOX (vbox38), frame60, FALSE, TRUE, 0);

  hbox201 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox201, "hbox201");
  gtk_widget_show (hbox201);
  gtk_container_add (GTK_CONTAINER (frame60), hbox201);
  gtk_container_set_border_width (GTK_CONTAINER (hbox201), 2);

  entry_config_bad_path = gtk_entry_new ();
  gtk_widget_set_name (entry_config_bad_path, "entry_config_bad_path");
  gtk_widget_show (entry_config_bad_path);
  gtk_box_pack_start (GTK_BOX (hbox201), entry_config_bad_path, TRUE, TRUE, 0);
  gtk_editable_set_editable (GTK_EDITABLE (entry_config_bad_path), FALSE);

  button_config_bad_path = gtk_button_new ();
  gtk_widget_set_name (button_config_bad_path, "button_config_bad_path");
  gtk_widget_show (button_config_bad_path);
  gtk_box_pack_start (GTK_BOX (hbox201), button_config_bad_path, FALSE, FALSE, 0);

  alignment71 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment71, "alignment71");
  gtk_widget_show (alignment71);
  gtk_container_add (GTK_CONTAINER (button_config_bad_path), alignment71);

  hbox205 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox205, "hbox205");
  gtk_widget_show (hbox205);
  gtk_container_add (GTK_CONTAINER (alignment71), hbox205);

  image117 = gtk_image_new_from_stock ("gtk-open", GTK_ICON_SIZE_BUTTON);
  gtk_widget_set_name (image117, "image117");
  gtk_widget_show (image117);
  gtk_box_pack_start (GTK_BOX (hbox205), image117, FALSE, FALSE, 0);

  label483 = gtk_label_new_with_mnemonic (_("_Browse"));
  gtk_widget_set_name (label483, "label483");
  gtk_widget_show (label483);
  gtk_box_pack_start (GTK_BOX (hbox205), label483, FALSE, FALSE, 0);

  label472 = gtk_label_new_with_mnemonic (_("Move corrupted downloaded files to"));
  gtk_widget_set_name (label472, "label472");
  gtk_widget_show (label472);
  gtk_frame_set_label_widget (GTK_FRAME (frame60), label472);

  frame123 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame123, "frame123");
  gtk_widget_show (frame123);
  gtk_box_pack_start (GTK_BOX (vbox38), frame123, FALSE, TRUE, 0);

  table97 = gtk_table_new (4, 1, FALSE);
  gtk_widget_set_name (table97, "table97");
  gtk_widget_show (table97);
  gtk_container_add (GTK_CONTAINER (frame123), table97);

  checkbutton_config_convert_spaces = gtk_check_button_new_with_mnemonic (_("Convert spaces to underscores in generated filenames"));
  gtk_widget_set_name (checkbutton_config_convert_spaces, "checkbutton_config_convert_spaces");
  gtk_widget_show (checkbutton_config_convert_spaces);
  gtk_table_attach (GTK_TABLE (table97), checkbutton_config_convert_spaces, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 4, 0);

  checkbutton_config_convert_evil_chars = gtk_check_button_new_with_mnemonic (_("Convert \"evil\" characters (like shell meta characters) to underscores in generated filenames"));
  gtk_widget_set_name (checkbutton_config_convert_evil_chars, "checkbutton_config_convert_evil_chars");
  gtk_widget_show (checkbutton_config_convert_evil_chars);
  gtk_table_attach (GTK_TABLE (table97), checkbutton_config_convert_evil_chars, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 4, 0);

  checkbutton_config_convert_old_filenames = gtk_check_button_new_with_mnemonic (_("Apply above conversions, upon startup, to existing files in the downloading directory"));
  gtk_widget_set_name (checkbutton_config_convert_old_filenames, "checkbutton_config_convert_old_filenames");
  gtk_widget_show (checkbutton_config_convert_old_filenames);
  gtk_table_attach (GTK_TABLE (table97), checkbutton_config_convert_old_filenames, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 4, 0);

  checkbutton_config_beautify_filenames = gtk_check_button_new_with_mnemonic (_("Beautify filenames by removing needless underscores"));
  gtk_widget_set_name (checkbutton_config_beautify_filenames, "checkbutton_config_beautify_filenames");
  gtk_widget_show (checkbutton_config_beautify_filenames);
  gtk_table_attach (GTK_TABLE (table97), checkbutton_config_beautify_filenames, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 4, 0);

  label880 = gtk_label_new (_("Miscellaneous"));
  gtk_widget_set_name (label880, "label880");
  gtk_widget_show (label880);
  gtk_frame_set_label_widget (GTK_FRAME (frame123), label880);

  hbox283 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox283, "hbox283");
  gtk_widget_show (hbox283);
  gtk_box_pack_start (GTK_BOX (vbox38), hbox283, FALSE, TRUE, 0);

  frame_expert_dl_source_quality = gtk_frame_new (NULL);
  gtk_widget_set_name (frame_expert_dl_source_quality, "frame_expert_dl_source_quality");
  gtk_widget_show (frame_expert_dl_source_quality);
  gtk_box_pack_start (GTK_BOX (hbox283), frame_expert_dl_source_quality, TRUE, TRUE, 0);

  hbox281 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox281, "hbox281");
  gtk_widget_show (hbox281);
  gtk_container_add (GTK_CONTAINER (frame_expert_dl_source_quality), hbox281);

  table39 = gtk_table_new (3, 1, FALSE);
  gtk_widget_set_name (table39, "table39");
  gtk_widget_show (table39);
  gtk_box_pack_start (GTK_BOX (hbox281), table39, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (table39), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table39), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table39), 4);

  checkbutton_config_download_optimistic_start = gtk_check_button_new_with_mnemonic (_("Optimistic first _chunk"));
  gtk_widget_set_name (checkbutton_config_download_optimistic_start, "checkbutton_config_download_optimistic_start");
  gtk_widget_show (checkbutton_config_download_optimistic_start);
  gtk_table_attach (GTK_TABLE (table39), checkbutton_config_download_optimistic_start, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 4, 0);

  checkbutton_config_req_urn = gtk_check_button_new_with_mnemonic (_("Require _URN"));
  gtk_widget_set_name (checkbutton_config_req_urn, "checkbutton_config_req_urn");
  gtk_widget_show (checkbutton_config_req_urn);
  gtk_table_attach (GTK_TABLE (table39), checkbutton_config_req_urn, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 4, 0);

  checkbutton_config_req_srv_name = gtk_check_button_new_with_mnemonic (_("Require _server name"));
  gtk_widget_set_name (checkbutton_config_req_srv_name, "checkbutton_config_req_srv_name");
  gtk_widget_show (checkbutton_config_req_srv_name);
  gtk_table_attach (GTK_TABLE (table39), checkbutton_config_req_srv_name, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 4, 0);

  hbox257 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox257, "hbox257");
  gtk_widget_show (hbox257);
  gtk_box_pack_start (GTK_BOX (hbox281), hbox257, TRUE, TRUE, 0);

  vbox126 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox126, "vbox126");
  gtk_widget_show (vbox126);
  gtk_box_pack_start (GTK_BOX (hbox257), vbox126, FALSE, TRUE, 4);

  checkbutton_config_use_alternate_sources = gtk_check_button_new_with_mnemonic (_("Watch hits for _alternate sources"));
  gtk_widget_set_name (checkbutton_config_use_alternate_sources, "checkbutton_config_use_alternate_sources");
  gtk_widget_show (checkbutton_config_use_alternate_sources);
  gtk_box_pack_start (GTK_BOX (vbox126), checkbutton_config_use_alternate_sources, FALSE, TRUE, 0);

  checkbutton_config_strict_sha1_matching = gtk_check_button_new_with_mnemonic (_("Strict SHA_1 matching"));
  gtk_widget_set_name (checkbutton_config_strict_sha1_matching, "checkbutton_config_strict_sha1_matching");
  gtk_widget_show (checkbutton_config_strict_sha1_matching);
  gtk_box_pack_start (GTK_BOX (vbox126), checkbutton_config_strict_sha1_matching, FALSE, TRUE, 0);

  checkbutton_auto_feed_dmesh = gtk_check_button_new_with_mnemonic (_("_Feed mesh from hits"));
  gtk_widget_set_name (checkbutton_auto_feed_dmesh, "checkbutton_auto_feed_dmesh");
  gtk_widget_show (checkbutton_auto_feed_dmesh);
  gtk_box_pack_start (GTK_BOX (vbox126), checkbutton_auto_feed_dmesh, FALSE, TRUE, 0);

  checkbutton_config_tth_auto_discovery = gtk_check_button_new_with_mnemonic (_("Allow TTH discovery"));
  gtk_widget_set_name (checkbutton_config_tth_auto_discovery, "checkbutton_config_tth_auto_discovery");
  gtk_widget_show (checkbutton_config_tth_auto_discovery);
  gtk_box_pack_start (GTK_BOX (vbox126), checkbutton_config_tth_auto_discovery, FALSE, FALSE, 0);

  label480 = gtk_label_new (_("Source quality"));
  gtk_widget_set_name (label480, "label480");
  gtk_widget_show (label480);
  gtk_frame_set_label_widget (GTK_FRAME (frame_expert_dl_source_quality), label480);

  frame16 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame16, "frame16");
  gtk_widget_show (frame16);
  gtk_box_pack_start (GTK_BOX (hbox283), frame16, TRUE, TRUE, 0);

  table38 = gtk_table_new (2, 3, FALSE);
  gtk_widget_set_name (table38, "table38");
  gtk_widget_show (table38);
  gtk_container_add (GTK_CONTAINER (frame16), table38);
  gtk_container_set_border_width (GTK_CONTAINER (table38), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table38), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table38), 4);

  label173 = gtk_label_new (_("bytes"));
  gtk_widget_set_name (label173, "label173");
  gtk_widget_show (label173);
  gtk_table_attach (GTK_TABLE (table38), label173, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label173), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label173), 0, 0.5);

  spinbutton_config_download_overlap_range_adj = gtk_adjustment_new (133, 128, 4096, 1, 10, 0);
  spinbutton_config_download_overlap_range = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_download_overlap_range_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_download_overlap_range, "spinbutton_config_download_overlap_range");
  gtk_widget_show (spinbutton_config_download_overlap_range);
  gtk_table_attach (GTK_TABLE (table38), spinbutton_config_download_overlap_range, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_tooltips_set_tip (tooltips, spinbutton_config_download_overlap_range, _("Amount of bytes to overlap when resuming download"), NULL);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_download_overlap_range), TRUE);

  label172 = gtk_label_new_with_mnemonic (_("Maximum number of _retries"));
  gtk_widget_set_name (label172, "label172");
  gtk_widget_show (label172);
  gtk_table_attach (GTK_TABLE (table38), label172, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label172), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label172), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label172), 4, 0);

  label171 = gtk_label_new_with_mnemonic (_("_Overlap when resuming"));
  gtk_widget_set_name (label171, "label171");
  gtk_widget_show (label171);
  gtk_table_attach (GTK_TABLE (table38), label171, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label171), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label171), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label171), 4, 0);

  spinbutton_config_download_max_retries_adj = gtk_adjustment_new (1, 0, 100000, 1, 10, 0);
  spinbutton_config_download_max_retries = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_download_max_retries_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_download_max_retries, "spinbutton_config_download_max_retries");
  gtk_widget_show (spinbutton_config_download_max_retries);
  gtk_table_attach (GTK_TABLE (table38), spinbutton_config_download_max_retries, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_tooltips_set_tip (tooltips, spinbutton_config_download_max_retries, _("Maximum attempts to make, not counting HTTP busy indications"), NULL);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_download_max_retries), TRUE);

  label985 = gtk_label_new (_("attempts"));
  gtk_widget_set_name (label985, "label985");
  gtk_widget_show (label985);
  gtk_table_attach (GTK_TABLE (table38), label985, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label985), 0, 0.5);

  label298 = gtk_label_new (_("Resume and retry"));
  gtk_widget_set_name (label298, "label298");
  gtk_widget_show (label298);
  gtk_frame_set_label_widget (GTK_FRAME (frame16), label298);

  frame_expert_dl_timeout = gtk_frame_new (NULL);
  gtk_widget_set_name (frame_expert_dl_timeout, "frame_expert_dl_timeout");
  gtk_widget_show (frame_expert_dl_timeout);
  gtk_box_pack_start (GTK_BOX (vbox38), frame_expert_dl_timeout, FALSE, TRUE, 0);

  table8 = gtk_table_new (3, 6, FALSE);
  gtk_widget_set_name (table8, "table8");
  gtk_widget_show (table8);
  gtk_container_add (GTK_CONTAINER (frame_expert_dl_timeout), table8);
  gtk_container_set_border_width (GTK_CONTAINER (table8), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table8), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table8), 4);

  spinbutton_config_download_retry_stopped_delay_adj = gtk_adjustment_new (15, 15, 100000, 1, 10, 0);
  spinbutton_config_download_retry_stopped_delay = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_download_retry_stopped_delay_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_download_retry_stopped_delay, "spinbutton_config_download_retry_stopped_delay");
  gtk_widget_show (spinbutton_config_download_retry_stopped_delay);
  gtk_table_attach (GTK_TABLE (table8), spinbutton_config_download_retry_stopped_delay, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_tooltips_set_tip (tooltips, spinbutton_config_download_retry_stopped_delay, _("Delay in seconds to wait when running download stops"), NULL);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_download_retry_stopped_delay), TRUE);

  spinbutton_config_download_retry_refused_delay_adj = gtk_adjustment_new (1, 15, 100000, 1, 10, 0);
  spinbutton_config_download_retry_refused_delay = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_download_retry_refused_delay_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_download_retry_refused_delay, "spinbutton_config_download_retry_refused_delay");
  gtk_widget_show (spinbutton_config_download_retry_refused_delay);
  gtk_table_attach (GTK_TABLE (table8), spinbutton_config_download_retry_refused_delay, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_tooltips_set_tip (tooltips, spinbutton_config_download_retry_refused_delay, _("Delay in seconds to wait if connection is refused"), NULL);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_download_retry_refused_delay), TRUE);

  spinbutton_config_download_retry_busy_delay_adj = gtk_adjustment_new (1, 15, 100000, 1, 10, 0);
  spinbutton_config_download_retry_busy_delay = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_download_retry_busy_delay_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_download_retry_busy_delay, "spinbutton_config_download_retry_busy_delay");
  gtk_widget_show (spinbutton_config_download_retry_busy_delay);
  gtk_table_attach (GTK_TABLE (table8), spinbutton_config_download_retry_busy_delay, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_tooltips_set_tip (tooltips, spinbutton_config_download_retry_busy_delay, _("Delay in seconds to wait after HTTP busy indication"), NULL);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_download_retry_busy_delay), TRUE);

  spinbutton_config_download_retry_timeout_delay_adj = gtk_adjustment_new (1, 15, 100000, 1, 10, 0);
  spinbutton_config_download_retry_timeout_delay = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_download_retry_timeout_delay_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_download_retry_timeout_delay, "spinbutton_config_download_retry_timeout_delay");
  gtk_widget_show (spinbutton_config_download_retry_timeout_delay);
  gtk_table_attach (GTK_TABLE (table8), spinbutton_config_download_retry_timeout_delay, 3, 4, 0, 1,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_tooltips_set_tip (tooltips, spinbutton_config_download_retry_timeout_delay, _("Delay in seconds to wait after connection failure"), NULL);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_download_retry_timeout_delay), TRUE);

  spinbutton_config_download_retry_timeout_max_adj = gtk_adjustment_new (15, 15, 100000, 1, 10, 0);
  spinbutton_config_download_retry_timeout_max = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_download_retry_timeout_max_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_download_retry_timeout_max, "spinbutton_config_download_retry_timeout_max");
  gtk_widget_show (spinbutton_config_download_retry_timeout_max);
  gtk_table_attach (GTK_TABLE (table8), spinbutton_config_download_retry_timeout_max, 3, 4, 1, 2,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_tooltips_set_tip (tooltips, spinbutton_config_download_retry_timeout_max, _("Maximum seconds to wait on auto-retry timeouts"), NULL);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_download_retry_timeout_max), TRUE);

  spinbutton_config_download_retry_timeout_min_adj = gtk_adjustment_new (1, 15, 100000, 1, 10, 0);
  spinbutton_config_download_retry_timeout_min = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_download_retry_timeout_min_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_download_retry_timeout_min, "spinbutton_config_download_retry_timeout_min");
  gtk_widget_show (spinbutton_config_download_retry_timeout_min);
  gtk_table_attach (GTK_TABLE (table8), spinbutton_config_download_retry_timeout_min, 3, 4, 2, 3,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_tooltips_set_tip (tooltips, spinbutton_config_download_retry_timeout_min, _("Minimum seconds to wait on auto-retry timeouts"), NULL);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_download_retry_timeout_min), TRUE);

  spinbutton_config_download_connecting_timeout_adj = gtk_adjustment_new (1, 1, 100000, 1, 10, 0);
  spinbutton_config_download_connecting_timeout = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_download_connecting_timeout_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_download_connecting_timeout, "spinbutton_config_download_connecting_timeout");
  gtk_widget_show (spinbutton_config_download_connecting_timeout);
  gtk_table_attach (GTK_TABLE (table8), spinbutton_config_download_connecting_timeout, 5, 6, 0, 1,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_tooltips_set_tip (tooltips, spinbutton_config_download_connecting_timeout, _("Number of seconds before timeout for a connecting download"), NULL);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_download_connecting_timeout), TRUE);

  spinbutton_config_download_push_sent_timeout_adj = gtk_adjustment_new (1, 1, 100000, 1, 10, 0);
  spinbutton_config_download_push_sent_timeout = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_download_push_sent_timeout_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_download_push_sent_timeout, "spinbutton_config_download_push_sent_timeout");
  gtk_widget_show (spinbutton_config_download_push_sent_timeout);
  gtk_table_attach (GTK_TABLE (table8), spinbutton_config_download_push_sent_timeout, 5, 6, 1, 2,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_tooltips_set_tip (tooltips, spinbutton_config_download_push_sent_timeout, _("Number of seconds before timeout for a 'push sent' download"), NULL);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_download_push_sent_timeout), TRUE);

  spinbutton_config_download_connected_timeout_adj = gtk_adjustment_new (1, 1, 100000, 1, 10, 0);
  spinbutton_config_download_connected_timeout = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_download_connected_timeout_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_download_connected_timeout, "spinbutton_config_download_connected_timeout");
  gtk_widget_show (spinbutton_config_download_connected_timeout);
  gtk_table_attach (GTK_TABLE (table8), spinbutton_config_download_connected_timeout, 5, 6, 2, 3,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_tooltips_set_tip (tooltips, spinbutton_config_download_connected_timeout, _("Number of seconds before timeout for a connected download"), NULL);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_download_connected_timeout), TRUE);

  label165 = gtk_label_new (_("Retry timeout delay"));
  gtk_widget_set_name (label165, "label165");
  gtk_widget_show (label165);
  gtk_table_attach (GTK_TABLE (table8), label165, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label165), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label165), 0, 0.5);

  label166 = gtk_label_new (_("Retry timeout max"));
  gtk_widget_set_name (label166, "label166");
  gtk_widget_show (label166);
  gtk_table_attach (GTK_TABLE (table8), label166, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label166), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label166), 0, 0.5);

  label167 = gtk_label_new (_("Retry timeout min"));
  gtk_widget_set_name (label167, "label167");
  gtk_widget_show (label167);
  gtk_table_attach (GTK_TABLE (table8), label167, 2, 3, 2, 3,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label167), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label167), 0, 0.5);

  label168 = gtk_label_new_with_mnemonic (_("Connectin_g timeout"));
  gtk_widget_set_name (label168, "label168");
  gtk_widget_show (label168);
  gtk_table_attach (GTK_TABLE (table8), label168, 4, 5, 0, 1,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label168), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label168), 0, 0.5);

  label169 = gtk_label_new_with_mnemonic (_("_Push sent timeout"));
  gtk_widget_set_name (label169, "label169");
  gtk_widget_show (label169);
  gtk_table_attach (GTK_TABLE (table8), label169, 4, 5, 1, 2,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label169), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label169), 0, 0.5);

  label170 = gtk_label_new_with_mnemonic (_("Connected time_out"));
  gtk_widget_set_name (label170, "label170");
  gtk_widget_show (label170);
  gtk_table_attach (GTK_TABLE (table8), label170, 4, 5, 2, 3,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label170), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label170), 0, 0.5);

  label162 = gtk_label_new (_("Retry stopped delay"));
  gtk_widget_set_name (label162, "label162");
  gtk_widget_show (label162);
  gtk_table_attach (GTK_TABLE (table8), label162, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 4, 0);
  gtk_label_set_justify (GTK_LABEL (label162), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label162), 0, 0.5);

  label163 = gtk_label_new (_("Retry refused delay"));
  gtk_widget_set_name (label163, "label163");
  gtk_widget_show (label163);
  gtk_table_attach (GTK_TABLE (table8), label163, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 4, 0);
  gtk_label_set_justify (GTK_LABEL (label163), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label163), 0, 0.5);

  label164 = gtk_label_new (_("Retry busy delay"));
  gtk_widget_set_name (label164, "label164");
  gtk_widget_show (label164);
  gtk_table_attach (GTK_TABLE (table8), label164, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 4, 0);
  gtk_label_set_justify (GTK_LABEL (label164), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label164), 0, 0.5);

  label299 = gtk_label_new (_("Delays and timeouts (all values in seconds)"));
  gtk_widget_set_name (label299, "label299");
  gtk_widget_show (label299);
  gtk_frame_set_label_widget (GTK_FRAME (frame_expert_dl_timeout), label299);

  frame51 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame51, "frame51");
  gtk_widget_show (frame51);
  gtk_box_pack_start (GTK_BOX (vbox38), frame51, FALSE, TRUE, 0);

  hbox282 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox282, "hbox282");
  gtk_widget_show (hbox282);
  gtk_container_add (GTK_CONTAINER (frame51), hbox282);

  table94 = gtk_table_new (5, 3, TRUE);
  gtk_widget_set_name (table94, "table94");
  gtk_widget_show (table94);
  gtk_box_pack_start (GTK_BOX (hbox282), table94, TRUE, TRUE, 0);
  gtk_table_set_row_spacings (GTK_TABLE (table94), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table94), 4);

  spinbutton_dl_minchunksize_adj = gtk_adjustment_new (1, 0, 67108900, 1, 10, 0);
  spinbutton_dl_minchunksize = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_dl_minchunksize_adj), 1, 0);
  gtk_widget_set_name (spinbutton_dl_minchunksize, "spinbutton_dl_minchunksize");
  gtk_widget_show (spinbutton_dl_minchunksize);
  gtk_table_attach (GTK_TABLE (table94), spinbutton_dl_minchunksize, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_dl_minchunksize), TRUE);

  spinbutton_dl_maxchunksize_adj = gtk_adjustment_new (1, 0, 67108900, 1, 10, 0);
  spinbutton_dl_maxchunksize = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_dl_maxchunksize_adj), 1, 0);
  gtk_widget_set_name (spinbutton_dl_maxchunksize, "spinbutton_dl_maxchunksize");
  gtk_widget_show (spinbutton_dl_maxchunksize);
  gtk_table_attach (GTK_TABLE (table94), spinbutton_dl_maxchunksize, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_dl_maxchunksize), TRUE);

  checkbutton_config_use_swarming = gtk_check_button_new_with_mnemonic (_("Enable s_warming"));
  gtk_widget_set_name (checkbutton_config_use_swarming, "checkbutton_config_use_swarming");
  gtk_widget_show (checkbutton_config_use_swarming);
  gtk_table_attach (GTK_TABLE (table94), checkbutton_config_use_swarming, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 4, 0);

  label368 = gtk_label_new_with_mnemonic (_("M_inimum chunk size"));
  gtk_widget_set_name (label368, "label368");
  gtk_widget_show (label368);
  gtk_table_attach (GTK_TABLE (table94), label368, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 4, 0);
  gtk_misc_set_alignment (GTK_MISC (label368), 0, 0.5);

  label369 = gtk_label_new_with_mnemonic (_("Ma_ximum chunk size"));
  gtk_widget_set_name (label369, "label369");
  gtk_widget_show (label369);
  gtk_table_attach (GTK_TABLE (table94), label369, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 4, 0);
  gtk_misc_set_alignment (GTK_MISC (label369), 0, 0.5);

  label918 = gtk_label_new (_("bytes"));
  gtk_widget_set_name (label918, "label918");
  gtk_widget_show (label918);
  gtk_table_attach (GTK_TABLE (table94), label918, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label918), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label918), 0, 0.5);

  label919 = gtk_label_new (_("bytes"));
  gtk_widget_set_name (label919, "label919");
  gtk_widget_show (label919);
  gtk_table_attach (GTK_TABLE (table94), label919, 2, 3, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label919), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label919), 0, 0.5);

  label936 = gtk_label_new (_("bytes"));
  gtk_widget_set_name (label936, "label936");
  gtk_widget_show (label936);
  gtk_table_attach (GTK_TABLE (table94), label936, 2, 3, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label936), 0, 0.5);

  label934 = gtk_label_new (_("Write buffer size"));
  gtk_widget_set_name (label934, "label934");
  gtk_widget_show (label934);
  gtk_table_attach (GTK_TABLE (table94), label934, 0, 1, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label934), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label934), 4, 0);

  spinbutton_download_buffer_size_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 0);
  spinbutton_download_buffer_size = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_download_buffer_size_adj), 1, 0);
  gtk_widget_set_name (spinbutton_download_buffer_size, "spinbutton_download_buffer_size");
  gtk_widget_show (spinbutton_download_buffer_size);
  gtk_table_attach (GTK_TABLE (table94), spinbutton_download_buffer_size, 1, 2, 4, 5,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label1055 = gtk_label_new (_("Pipelining maximum chunk size"));
  gtk_widget_set_name (label1055, "label1055");
  gtk_widget_show (label1055);
  gtk_table_attach (GTK_TABLE (table94), label1055, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label1055), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label1055), 4, 0);

  spinbutton_dl_pipeline_maxchunksize_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 0);
  spinbutton_dl_pipeline_maxchunksize = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_dl_pipeline_maxchunksize_adj), 1, 0);
  gtk_widget_set_name (spinbutton_dl_pipeline_maxchunksize, "spinbutton_dl_pipeline_maxchunksize");
  gtk_widget_show (spinbutton_dl_pipeline_maxchunksize);
  gtk_table_attach (GTK_TABLE (table94), spinbutton_dl_pipeline_maxchunksize, 1, 2, 3, 4,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label1056 = gtk_label_new (_("bytes"));
  gtk_widget_set_name (label1056, "label1056");
  gtk_widget_show (label1056);
  gtk_table_attach (GTK_TABLE (table94), label1056, 2, 3, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label1056), 0, 0.5);

  checkbutton_config_aggressive_swarming = gtk_check_button_new_with_mnemonic (_("A_ggressive mode"));
  gtk_widget_set_name (checkbutton_config_aggressive_swarming, "checkbutton_config_aggressive_swarming");
  gtk_widget_show (checkbutton_config_aggressive_swarming);
  gtk_table_attach (GTK_TABLE (table94), checkbutton_config_aggressive_swarming, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  checkbutton_config_enable_http_pipelining = gtk_check_button_new_with_mnemonic (_("Enable HTTP request pipelining"));
  gtk_widget_set_name (checkbutton_config_enable_http_pipelining, "checkbutton_config_enable_http_pipelining");
  gtk_widget_show (checkbutton_config_enable_http_pipelining);
  gtk_table_attach (GTK_TABLE (table94), checkbutton_config_enable_http_pipelining, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label366 = gtk_label_new (_("Downloading from multiple sources (swarming)"));
  gtk_widget_set_name (label366, "label366");
  gtk_widget_show (label366);
  gtk_frame_set_label_widget (GTK_FRAME (frame51), label366);

  g_signal_connect ((gpointer) button_config_save_path, "clicked",
                    G_CALLBACK (on_button_config_save_path_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_config_move_path, "clicked",
                    G_CALLBACK (on_button_config_move_path_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_config_bad_path, "clicked",
                    G_CALLBACK (on_button_config_bad_path_clicked),
                    NULL);

  gtk_label_set_mnemonic_widget (GTK_LABEL (label172), spinbutton_config_download_max_retries);
  gtk_label_set_mnemonic_widget (GTK_LABEL (label171), spinbutton_config_download_overlap_range);
  gtk_label_set_mnemonic_widget (GTK_LABEL (label168), spinbutton_config_download_connecting_timeout);
  gtk_label_set_mnemonic_widget (GTK_LABEL (label169), spinbutton_config_download_push_sent_timeout);
  gtk_label_set_mnemonic_widget (GTK_LABEL (label170), spinbutton_config_download_connected_timeout);
  gtk_label_set_mnemonic_widget (GTK_LABEL (label368), spinbutton_dl_minchunksize);
  gtk_label_set_mnemonic_widget (GTK_LABEL (label369), spinbutton_dl_maxchunksize);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (dlg_prefs_dl_tab, dlg_prefs_dl_tab, "dlg_prefs_dl_tab");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, scrolledwindow64, "scrolledwindow64");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, viewport32, "viewport32");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, vbox38, "vbox38");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, frame_save_new_files, "frame_save_new_files");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, hbox96, "hbox96");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, entry_config_save_path, "entry_config_save_path");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, button_config_save_path, "button_config_save_path");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, alignment73, "alignment73");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, hbox207, "hbox207");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, image119, "image119");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, label485, "label485");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, label296, "label296");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, frame_move_downloaded_files, "frame_move_downloaded_files");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, hbox95, "hbox95");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, entry_config_move_path, "entry_config_move_path");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, button_config_move_path, "button_config_move_path");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, alignment72, "alignment72");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, hbox206, "hbox206");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, image118, "image118");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, label484, "label484");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, label297, "label297");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, frame60, "frame60");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, hbox201, "hbox201");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, entry_config_bad_path, "entry_config_bad_path");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, button_config_bad_path, "button_config_bad_path");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, alignment71, "alignment71");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, hbox205, "hbox205");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, image117, "image117");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, label483, "label483");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, label472, "label472");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, frame123, "frame123");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, table97, "table97");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, checkbutton_config_convert_spaces, "checkbutton_config_convert_spaces");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, checkbutton_config_convert_evil_chars, "checkbutton_config_convert_evil_chars");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, checkbutton_config_convert_old_filenames, "checkbutton_config_convert_old_filenames");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, checkbutton_config_beautify_filenames, "checkbutton_config_beautify_filenames");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, label880, "label880");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, hbox283, "hbox283");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, frame_expert_dl_source_quality, "frame_expert_dl_source_quality");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, hbox281, "hbox281");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, table39, "table39");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, checkbutton_config_download_optimistic_start, "checkbutton_config_download_optimistic_start");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, checkbutton_config_req_urn, "checkbutton_config_req_urn");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, checkbutton_config_req_srv_name, "checkbutton_config_req_srv_name");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, hbox257, "hbox257");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, vbox126, "vbox126");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, checkbutton_config_use_alternate_sources, "checkbutton_config_use_alternate_sources");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, checkbutton_config_strict_sha1_matching, "checkbutton_config_strict_sha1_matching");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, checkbutton_auto_feed_dmesh, "checkbutton_auto_feed_dmesh");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, checkbutton_config_tth_auto_discovery, "checkbutton_config_tth_auto_discovery");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, label480, "label480");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, frame16, "frame16");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, table38, "table38");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, label173, "label173");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, spinbutton_config_download_overlap_range, "spinbutton_config_download_overlap_range");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, label172, "label172");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, label171, "label171");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, spinbutton_config_download_max_retries, "spinbutton_config_download_max_retries");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, label985, "label985");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, label298, "label298");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, frame_expert_dl_timeout, "frame_expert_dl_timeout");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, table8, "table8");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, spinbutton_config_download_retry_stopped_delay, "spinbutton_config_download_retry_stopped_delay");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, spinbutton_config_download_retry_refused_delay, "spinbutton_config_download_retry_refused_delay");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, spinbutton_config_download_retry_busy_delay, "spinbutton_config_download_retry_busy_delay");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, spinbutton_config_download_retry_timeout_delay, "spinbutton_config_download_retry_timeout_delay");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, spinbutton_config_download_retry_timeout_max, "spinbutton_config_download_retry_timeout_max");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, spinbutton_config_download_retry_timeout_min, "spinbutton_config_download_retry_timeout_min");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, spinbutton_config_download_connecting_timeout, "spinbutton_config_download_connecting_timeout");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, spinbutton_config_download_push_sent_timeout, "spinbutton_config_download_push_sent_timeout");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, spinbutton_config_download_connected_timeout, "spinbutton_config_download_connected_timeout");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, label165, "label165");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, label166, "label166");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, label167, "label167");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, label168, "label168");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, label169, "label169");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, label170, "label170");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, label162, "label162");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, label163, "label163");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, label164, "label164");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, label299, "label299");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, frame51, "frame51");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, hbox282, "hbox282");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, table94, "table94");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, spinbutton_dl_minchunksize, "spinbutton_dl_minchunksize");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, spinbutton_dl_maxchunksize, "spinbutton_dl_maxchunksize");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, checkbutton_config_use_swarming, "checkbutton_config_use_swarming");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, label368, "label368");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, label369, "label369");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, label918, "label918");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, label919, "label919");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, label936, "label936");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, label934, "label934");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, spinbutton_download_buffer_size, "spinbutton_download_buffer_size");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, label1055, "label1055");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, spinbutton_dl_pipeline_maxchunksize, "spinbutton_dl_pipeline_maxchunksize");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, label1056, "label1056");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, checkbutton_config_aggressive_swarming, "checkbutton_config_aggressive_swarming");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, checkbutton_config_enable_http_pipelining, "checkbutton_config_enable_http_pipelining");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dl_tab, label366, "label366");
  GLADE_HOOKUP_OBJECT_NO_REF (dlg_prefs_dl_tab, tooltips, "tooltips");

  return dlg_prefs_dl_tab;
}

GtkWidget*
create_dlg_prefs_ul_tab (void)
{
  GtkWidget *dlg_prefs_ul_tab;
  GtkWidget *scrolledwindow42;
  GtkWidget *viewport6;
  GtkWidget *vbox40;
  GtkWidget *frame_path_to_files;
  GtkWidget *vbox_path_to_files;
  GtkWidget *hbox9299;
  GtkWidget *scrolledwindow79;
  GtkWidget *treeview_shared_dirs;
  GtkWidget *hbox_path_buttons;
  GtkWidget *button_config_add_dir;
  GtkWidget *alignment70;
  GtkWidget *hbox204;
  GtkWidget *image116;
  GtkWidget *label482;
  GtkWidget *button_config_remove_dir;
  GtkWidget *alignment111;
  GtkWidget *hbox9298;
  GtkWidget *image566;
  GtkWidget *label933;
  GtkWidget *button_config_rescan_dir;
  GtkWidget *alignment69;
  GtkWidget *hbox203;
  GtkWidget *image115;
  GtkWidget *label481;
  GtkWidget *label_files_scanned;
  GtkWidget *hbox27;
  GtkWidget *label41;
  GtkWidget *entry_config_extensions;
  GtkWidget *hbox232;
  GtkWidget *checkbutton_scan_ignore_symlink_dirs;
  GtkWidget *checkbutton_scan_ignore_symlink_regfiles;
  GtkWidget *label300;
  GtkWidget *frame146;
  GtkWidget *table114;
  GtkWidget *checkbutton_enable_browse_host;
  GtkWidget *checkbutton_expose_relative_paths;
  GtkWidget *hbox284;
  GtkWidget *frame86;
  GtkWidget *table73;
  GtkWidget *checkbutton_pfsp_server;
  GtkWidget *label954;
  GtkObject *spinbutton_pfsp_minimum_filesize_adj;
  GtkWidget *spinbutton_pfsp_minimum_filesize;
  GtkWidget *label1030;
  GtkObject *spinbutton_pfsp_last_chunk_adj;
  GtkWidget *spinbutton_pfsp_last_chunk;
  GtkWidget *label726;
  GtkObject *spinbutton_pfsp_first_chunk_adj;
  GtkWidget *spinbutton_pfsp_first_chunk;
  GtkWidget *checkbutton_pfsp_rare_server;
  GtkWidget *label725;
  GtkWidget *frame_expert_ul_timeout;
  GtkWidget *table12;
  GtkWidget *label179;
  GtkWidget *label180;
  GtkObject *spinbutton_config_upload_connecting_timeout_adj;
  GtkWidget *spinbutton_config_upload_connecting_timeout;
  GtkObject *spinbutton_config_upload_connected_timeout_adj;
  GtkWidget *spinbutton_config_upload_connected_timeout;
  GtkWidget *label301;
  GtkWidget *vbox159;
  GtkWidget *checkbutton_config_query_answer_partials;
  GtkWidget *checkbutton_config_query_answer_whats_new;
  GtkWidget *hbox9297;
  GtkWidget *frame141;
  GtkWidget *table109;
  GtkWidget *label928;
  GtkObject *spinbutton_parq_min_size_adj;
  GtkWidget *spinbutton_parq_min_size;
  GtkWidget *label932;
  GtkWidget *checkbutton_parq_optimistic;
  GtkObject *spinbutton_parq_min_time_adj;
  GtkWidget *spinbutton_parq_min_time;
  GtkWidget *label929;
  GtkWidget *frame_expert_share_statistics;
  GtkWidget *vbox117;
  GtkWidget *hbox258;
  GtkWidget *viewport111;
  GtkWidget *frame101;
  GtkWidget *table87;
  GtkWidget *label786;
  GtkWidget *label788;
  GtkWidget *viewport83;
  GtkWidget *label_library_rescan_timestamp;
  GtkWidget *viewport84;
  GtkWidget *label_library_rescan_time;
  GtkWidget *label785;
  GtkWidget *viewport112;
  GtkWidget *frame_qrp_table_info;
  GtkWidget *table89;
  GtkWidget *vseparator5;
  GtkWidget *label820;
  GtkWidget *label821;
  GtkWidget *label814;
  GtkWidget *label815;
  GtkWidget *label816;
  GtkWidget *label808;
  GtkWidget *label809;
  GtkWidget *label810;
  GtkWidget *viewport94;
  GtkWidget *label_qrp_generation;
  GtkWidget *viewport96;
  GtkWidget *label_qrp_conflict_ratio;
  GtkWidget *viewport95;
  GtkWidget *label_qrp_fill_ratio;
  GtkWidget *viewport92;
  GtkWidget *label_qrp_slots;
  GtkWidget *viewport91;
  GtkWidget *label_qrp_hashed_keywords;
  GtkWidget *viewport93;
  GtkWidget *label_qrp_slots_filled;
  GtkWidget *label807;
  GtkWidget *hbox259;
  GtkWidget *viewport110;
  GtkWidget *frame_qrp_statistics;
  GtkWidget *table88;
  GtkWidget *label792;
  GtkWidget *label793;
  GtkWidget *label794;
  GtkWidget *label795;
  GtkWidget *label796;
  GtkWidget *label797;
  GtkWidget *viewport85;
  GtkWidget *label_qrp_indexing_timestamp;
  GtkWidget *viewport88;
  GtkWidget *label_qrp_indexing_time;
  GtkWidget *viewport86;
  GtkWidget *label_qrp_timestamp;
  GtkWidget *viewport87;
  GtkWidget *label_qrp_patch_timestamp;
  GtkWidget *viewport89;
  GtkWidget *label_qrp_computation_time;
  GtkWidget *viewport90;
  GtkWidget *label_qrp_patch_computation_time;
  GtkWidget *label791;
  GtkWidget *viewport113;
  GtkWidget *frame_qrp_patch_info;
  GtkWidget *table90;
  GtkWidget *label823;
  GtkWidget *label824;
  GtkWidget *label825;
  GtkWidget *label826;
  GtkWidget *viewport97;
  GtkWidget *label_qrp_patch_raw_length;
  GtkWidget *viewport98;
  GtkWidget *label_qrp_patch_length;
  GtkWidget *viewport99;
  GtkWidget *label_qrp_patch_comp_ratio;
  GtkWidget *label822;
  GtkWidget *label784;

  dlg_prefs_ul_tab = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_widget_set_name (dlg_prefs_ul_tab, "dlg_prefs_ul_tab");
  gtk_widget_set_size_request (dlg_prefs_ul_tab, 600, 400);
  gtk_window_set_title (GTK_WINDOW (dlg_prefs_ul_tab), _("Uploads"));

  scrolledwindow42 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow42, "scrolledwindow42");
  gtk_widget_show (scrolledwindow42);
  gtk_container_add (GTK_CONTAINER (dlg_prefs_ul_tab), scrolledwindow42);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow42), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);

  viewport6 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport6, "viewport6");
  gtk_widget_show (viewport6);
  gtk_container_add (GTK_CONTAINER (scrolledwindow42), viewport6);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport6), GTK_SHADOW_NONE);

  vbox40 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox40, "vbox40");
  gtk_widget_show (vbox40);
  gtk_container_add (GTK_CONTAINER (viewport6), vbox40);
  gtk_container_set_border_width (GTK_CONTAINER (vbox40), 4);

  frame_path_to_files = gtk_frame_new (NULL);
  gtk_widget_set_name (frame_path_to_files, "frame_path_to_files");
  gtk_widget_show (frame_path_to_files);
  gtk_box_pack_start (GTK_BOX (vbox40), frame_path_to_files, TRUE, TRUE, 0);

  vbox_path_to_files = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox_path_to_files, "vbox_path_to_files");
  gtk_widget_show (vbox_path_to_files);
  gtk_container_add (GTK_CONTAINER (frame_path_to_files), vbox_path_to_files);
  gtk_container_set_border_width (GTK_CONTAINER (vbox_path_to_files), 2);

  hbox9299 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox9299, "hbox9299");
  gtk_widget_show (hbox9299);
  gtk_box_pack_start (GTK_BOX (vbox_path_to_files), hbox9299, TRUE, TRUE, 0);

  scrolledwindow79 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow79, "scrolledwindow79");
  gtk_widget_show (scrolledwindow79);
  gtk_box_pack_start (GTK_BOX (hbox9299), scrolledwindow79, TRUE, TRUE, 0);
  gtk_widget_set_size_request (scrolledwindow79, -1, 100);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow79), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolledwindow79), GTK_SHADOW_ETCHED_IN);

  treeview_shared_dirs = gtk_tree_view_new ();
  gtk_widget_set_name (treeview_shared_dirs, "treeview_shared_dirs");
  gtk_widget_show (treeview_shared_dirs);
  gtk_container_add (GTK_CONTAINER (scrolledwindow79), treeview_shared_dirs);
  gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (treeview_shared_dirs), FALSE);
  gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (treeview_shared_dirs), TRUE);
  gtk_tree_view_set_reorderable (GTK_TREE_VIEW (treeview_shared_dirs), TRUE);

  hbox_path_buttons = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox_path_buttons, "hbox_path_buttons");
  gtk_widget_show (hbox_path_buttons);
  gtk_box_pack_start (GTK_BOX (vbox_path_to_files), hbox_path_buttons, FALSE, TRUE, 0);

  button_config_add_dir = gtk_button_new ();
  gtk_widget_set_name (button_config_add_dir, "button_config_add_dir");
  gtk_widget_show (button_config_add_dir);
  gtk_box_pack_start (GTK_BOX (hbox_path_buttons), button_config_add_dir, FALSE, FALSE, 0);

  alignment70 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment70, "alignment70");
  gtk_widget_show (alignment70);
  gtk_container_add (GTK_CONTAINER (button_config_add_dir), alignment70);

  hbox204 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox204, "hbox204");
  gtk_widget_show (hbox204);
  gtk_container_add (GTK_CONTAINER (alignment70), hbox204);

  image116 = gtk_image_new_from_stock ("gtk-add", GTK_ICON_SIZE_BUTTON);
  gtk_widget_set_name (image116, "image116");
  gtk_widget_show (image116);
  gtk_box_pack_start (GTK_BOX (hbox204), image116, FALSE, FALSE, 0);

  label482 = gtk_label_new_with_mnemonic (_("_Add directory"));
  gtk_widget_set_name (label482, "label482");
  gtk_widget_show (label482);
  gtk_box_pack_start (GTK_BOX (hbox204), label482, FALSE, FALSE, 0);

  button_config_remove_dir = gtk_button_new ();
  gtk_widget_set_name (button_config_remove_dir, "button_config_remove_dir");
  gtk_widget_show (button_config_remove_dir);
  gtk_box_pack_start (GTK_BOX (hbox_path_buttons), button_config_remove_dir, FALSE, FALSE, 0);

  alignment111 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment111, "alignment111");
  gtk_widget_show (alignment111);
  gtk_container_add (GTK_CONTAINER (button_config_remove_dir), alignment111);

  hbox9298 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox9298, "hbox9298");
  gtk_widget_show (hbox9298);
  gtk_container_add (GTK_CONTAINER (alignment111), hbox9298);

  image566 = gtk_image_new_from_stock ("gtk-remove", GTK_ICON_SIZE_BUTTON);
  gtk_widget_set_name (image566, "image566");
  gtk_widget_show (image566);
  gtk_box_pack_start (GTK_BOX (hbox9298), image566, FALSE, FALSE, 0);

  label933 = gtk_label_new_with_mnemonic (_("_Remove directory"));
  gtk_widget_set_name (label933, "label933");
  gtk_widget_show (label933);
  gtk_box_pack_start (GTK_BOX (hbox9298), label933, FALSE, FALSE, 0);

  button_config_rescan_dir = gtk_button_new ();
  gtk_widget_set_name (button_config_rescan_dir, "button_config_rescan_dir");
  gtk_widget_show (button_config_rescan_dir);
  gtk_box_pack_start (GTK_BOX (hbox_path_buttons), button_config_rescan_dir, FALSE, FALSE, 0);

  alignment69 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment69, "alignment69");
  gtk_widget_show (alignment69);
  gtk_container_add (GTK_CONTAINER (button_config_rescan_dir), alignment69);

  hbox203 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox203, "hbox203");
  gtk_widget_show (hbox203);
  gtk_container_add (GTK_CONTAINER (alignment69), hbox203);

  image115 = gtk_image_new_from_stock ("gtk-refresh", GTK_ICON_SIZE_BUTTON);
  gtk_widget_set_name (image115, "image115");
  gtk_widget_show (image115);
  gtk_box_pack_start (GTK_BOX (hbox203), image115, FALSE, FALSE, 0);

  label481 = gtk_label_new_with_mnemonic (_("_Rescan"));
  gtk_widget_set_name (label481, "label481");
  gtk_widget_show (label481);
  gtk_box_pack_start (GTK_BOX (hbox203), label481, FALSE, FALSE, 0);

  label_files_scanned = gtk_label_new (_("Files scanned"));
  gtk_widget_set_name (label_files_scanned, "label_files_scanned");
  gtk_widget_show (label_files_scanned);
  gtk_box_pack_start (GTK_BOX (hbox_path_buttons), label_files_scanned, TRUE, TRUE, 0);
  gtk_label_set_justify (GTK_LABEL (label_files_scanned), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label_files_scanned), 7.45058e-09, 0.5);

  hbox27 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox27, "hbox27");
  gtk_widget_show (hbox27);
  gtk_box_pack_start (GTK_BOX (vbox_path_to_files), hbox27, FALSE, TRUE, 0);

  label41 = gtk_label_new_with_mnemonic (_("Search _extensions"));
  gtk_widget_set_name (label41, "label41");
  gtk_widget_show (label41);
  gtk_box_pack_start (GTK_BOX (hbox27), label41, FALSE, FALSE, 4);
  gtk_label_set_justify (GTK_LABEL (label41), GTK_JUSTIFY_CENTER);

  entry_config_extensions = gtk_entry_new ();
  gtk_widget_set_name (entry_config_extensions, "entry_config_extensions");
  gtk_widget_show (entry_config_extensions);
  gtk_box_pack_start (GTK_BOX (hbox27), entry_config_extensions, TRUE, TRUE, 0);

  hbox232 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox232, "hbox232");
  gtk_widget_show (hbox232);
  gtk_box_pack_start (GTK_BOX (vbox_path_to_files), hbox232, FALSE, TRUE, 0);

  checkbutton_scan_ignore_symlink_dirs = gtk_check_button_new_with_mnemonic (_("Ignore symbolically linked _directories"));
  gtk_widget_set_name (checkbutton_scan_ignore_symlink_dirs, "checkbutton_scan_ignore_symlink_dirs");
  gtk_widget_show (checkbutton_scan_ignore_symlink_dirs);
  gtk_box_pack_start (GTK_BOX (hbox232), checkbutton_scan_ignore_symlink_dirs, FALSE, FALSE, 4);

  checkbutton_scan_ignore_symlink_regfiles = gtk_check_button_new_with_mnemonic (_("Ignore symbolically linked regular _files"));
  gtk_widget_set_name (checkbutton_scan_ignore_symlink_regfiles, "checkbutton_scan_ignore_symlink_regfiles");
  gtk_widget_show (checkbutton_scan_ignore_symlink_regfiles);
  gtk_box_pack_start (GTK_BOX (hbox232), checkbutton_scan_ignore_symlink_regfiles, FALSE, FALSE, 0);

  label300 = gtk_label_new_with_mnemonic (_("_Path(s) to files"));
  gtk_widget_set_name (label300, "label300");
  gtk_widget_show (label300);
  gtk_frame_set_label_widget (GTK_FRAME (frame_path_to_files), label300);

  frame146 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame146, "frame146");
  gtk_widget_show (frame146);
  gtk_box_pack_start (GTK_BOX (vbox40), frame146, FALSE, TRUE, 0);

  table114 = gtk_table_new (2, 1, FALSE);
  gtk_widget_set_name (table114, "table114");
  gtk_widget_show (table114);
  gtk_container_add (GTK_CONTAINER (frame146), table114);
  gtk_container_set_border_width (GTK_CONTAINER (table114), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table114), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table114), 4);

  checkbutton_enable_browse_host = gtk_check_button_new_with_mnemonic (_("Enable \"_Browse Host\" feature"));
  gtk_widget_set_name (checkbutton_enable_browse_host, "checkbutton_enable_browse_host");
  gtk_widget_show (checkbutton_enable_browse_host);
  gtk_table_attach (GTK_TABLE (table114), checkbutton_enable_browse_host, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 4, 0);

  checkbutton_expose_relative_paths = gtk_check_button_new_with_mnemonic (_("E_xpose relative paths"));
  gtk_widget_set_name (checkbutton_expose_relative_paths, "checkbutton_expose_relative_paths");
  gtk_widget_show (checkbutton_expose_relative_paths);
  gtk_table_attach (GTK_TABLE (table114), checkbutton_expose_relative_paths, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 4, 0);

  hbox284 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox284, "hbox284");
  gtk_widget_show (hbox284);
  gtk_box_pack_start (GTK_BOX (vbox40), hbox284, FALSE, TRUE, 0);

  frame86 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame86, "frame86");
  gtk_widget_show (frame86);
  gtk_box_pack_start (GTK_BOX (hbox284), frame86, FALSE, TRUE, 0);

  table73 = gtk_table_new (5, 2, FALSE);
  gtk_widget_set_name (table73, "table73");
  gtk_widget_show (table73);
  gtk_container_add (GTK_CONTAINER (frame86), table73);
  gtk_container_set_border_width (GTK_CONTAINER (table73), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table73), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table73), 4);

  checkbutton_pfsp_server = gtk_check_button_new_with_mnemonic (_("Enable upload of _partially downloaded files"));
  gtk_widget_set_name (checkbutton_pfsp_server, "checkbutton_pfsp_server");
  gtk_widget_show (checkbutton_pfsp_server);
  gtk_table_attach (GTK_TABLE (table73), checkbutton_pfsp_server, 0, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 4, 0);

  label954 = gtk_label_new (_("Minimum file size"));
  gtk_widget_set_name (label954, "label954");
  gtk_widget_show (label954);
  gtk_table_attach (GTK_TABLE (table73), label954, 0, 1, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 4, 0);
  gtk_misc_set_alignment (GTK_MISC (label954), 0, 0.5);

  spinbutton_pfsp_minimum_filesize_adj = gtk_adjustment_new (1, 0, 1000000, 1, 1024, 0);
  spinbutton_pfsp_minimum_filesize = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_pfsp_minimum_filesize_adj), 1, 0);
  gtk_widget_set_name (spinbutton_pfsp_minimum_filesize, "spinbutton_pfsp_minimum_filesize");
  gtk_widget_show (spinbutton_pfsp_minimum_filesize);
  gtk_table_attach (GTK_TABLE (table73), spinbutton_pfsp_minimum_filesize, 1, 2, 4, 5,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label1030 = gtk_label_new (_("Last chunk size"));
  gtk_widget_set_name (label1030, "label1030");
  gtk_widget_show (label1030);
  gtk_table_attach (GTK_TABLE (table73), label1030, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 4, 0);
  gtk_misc_set_alignment (GTK_MISC (label1030), 0, 0.5);

  spinbutton_pfsp_last_chunk_adj = gtk_adjustment_new (1, 0, 1000000, 1, 1024, 0);
  spinbutton_pfsp_last_chunk = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_pfsp_last_chunk_adj), 1, 0);
  gtk_widget_set_name (spinbutton_pfsp_last_chunk, "spinbutton_pfsp_last_chunk");
  gtk_widget_show (spinbutton_pfsp_last_chunk);
  gtk_table_attach (GTK_TABLE (table73), spinbutton_pfsp_last_chunk, 1, 2, 3, 4,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label726 = gtk_label_new_with_mnemonic (_("First chunk _size"));
  gtk_widget_set_name (label726, "label726");
  gtk_widget_show (label726);
  gtk_table_attach (GTK_TABLE (table73), label726, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 4, 0);
  gtk_misc_set_alignment (GTK_MISC (label726), 0, 0.5);

  spinbutton_pfsp_first_chunk_adj = gtk_adjustment_new (0, 0, 1000000, 1, 1024, 0);
  spinbutton_pfsp_first_chunk = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_pfsp_first_chunk_adj), 1, 0);
  gtk_widget_set_name (spinbutton_pfsp_first_chunk, "spinbutton_pfsp_first_chunk");
  gtk_widget_show (spinbutton_pfsp_first_chunk);
  gtk_table_attach (GTK_TABLE (table73), spinbutton_pfsp_first_chunk, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  checkbutton_pfsp_rare_server = gtk_check_button_new_with_mnemonic (_("Enable upload of partial files deemed rare"));
  gtk_widget_set_name (checkbutton_pfsp_rare_server, "checkbutton_pfsp_rare_server");
  gtk_widget_show (checkbutton_pfsp_rare_server);
  gtk_table_attach (GTK_TABLE (table73), checkbutton_pfsp_rare_server, 0, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 4, 0);

  label725 = gtk_label_new (_("Partial File Sharing"));
  gtk_widget_set_name (label725, "label725");
  gtk_widget_show (label725);
  gtk_frame_set_label_widget (GTK_FRAME (frame86), label725);

  frame_expert_ul_timeout = gtk_frame_new (NULL);
  gtk_widget_set_name (frame_expert_ul_timeout, "frame_expert_ul_timeout");
  gtk_widget_show (frame_expert_ul_timeout);
  gtk_box_pack_start (GTK_BOX (hbox284), frame_expert_ul_timeout, FALSE, TRUE, 0);

  table12 = gtk_table_new (2, 2, FALSE);
  gtk_widget_set_name (table12, "table12");
  gtk_widget_show (table12);
  gtk_container_add (GTK_CONTAINER (frame_expert_ul_timeout), table12);
  gtk_container_set_border_width (GTK_CONTAINER (table12), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table12), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table12), 4);

  label179 = gtk_label_new_with_mnemonic (_("Connectin_g timeout"));
  gtk_widget_set_name (label179, "label179");
  gtk_widget_show (label179);
  gtk_table_attach (GTK_TABLE (table12), label179, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label179), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label179), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label179), 4, 0);

  label180 = gtk_label_new_with_mnemonic (_("Connected time_out"));
  gtk_widget_set_name (label180, "label180");
  gtk_widget_show (label180);
  gtk_table_attach (GTK_TABLE (table12), label180, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label180), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label180), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label180), 4, 0);

  spinbutton_config_upload_connecting_timeout_adj = gtk_adjustment_new (1, 1, 100000, 1, 10, 0);
  spinbutton_config_upload_connecting_timeout = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_upload_connecting_timeout_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_upload_connecting_timeout, "spinbutton_config_upload_connecting_timeout");
  gtk_widget_show (spinbutton_config_upload_connecting_timeout);
  gtk_table_attach (GTK_TABLE (table12), spinbutton_config_upload_connecting_timeout, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_upload_connecting_timeout), TRUE);

  spinbutton_config_upload_connected_timeout_adj = gtk_adjustment_new (1, 1, 100000, 1, 10, 0);
  spinbutton_config_upload_connected_timeout = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_config_upload_connected_timeout_adj), 1, 0);
  gtk_widget_set_name (spinbutton_config_upload_connected_timeout, "spinbutton_config_upload_connected_timeout");
  gtk_widget_show (spinbutton_config_upload_connected_timeout);
  gtk_table_attach (GTK_TABLE (table12), spinbutton_config_upload_connected_timeout, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_config_upload_connected_timeout), TRUE);

  label301 = gtk_label_new (_("Timeouts (all values in seconds)"));
  gtk_widget_set_name (label301, "label301");
  gtk_widget_show (label301);
  gtk_frame_set_label_widget (GTK_FRAME (frame_expert_ul_timeout), label301);

  vbox159 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox159, "vbox159");
  gtk_widget_show (vbox159);
  gtk_box_pack_start (GTK_BOX (hbox284), vbox159, TRUE, TRUE, 0);

  checkbutton_config_query_answer_partials = gtk_check_button_new_with_mnemonic (_("Answer to queries for partial files"));
  gtk_widget_set_name (checkbutton_config_query_answer_partials, "checkbutton_config_query_answer_partials");
  gtk_widget_show (checkbutton_config_query_answer_partials);
  gtk_box_pack_start (GTK_BOX (vbox159), checkbutton_config_query_answer_partials, FALSE, FALSE, 0);

  checkbutton_config_query_answer_whats_new = gtk_check_button_new_with_mnemonic (_("Answer to what's-new? queries"));
  gtk_widget_set_name (checkbutton_config_query_answer_whats_new, "checkbutton_config_query_answer_whats_new");
  gtk_widget_show (checkbutton_config_query_answer_whats_new);
  gtk_box_pack_start (GTK_BOX (vbox159), checkbutton_config_query_answer_whats_new, FALSE, FALSE, 0);

  hbox9297 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox9297, "hbox9297");
  gtk_widget_show (hbox9297);
  gtk_box_pack_start (GTK_BOX (vbox40), hbox9297, FALSE, TRUE, 0);

  frame141 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame141, "frame141");
  gtk_widget_show (frame141);
  gtk_box_pack_start (GTK_BOX (hbox9297), frame141, FALSE, TRUE, 0);

  table109 = gtk_table_new (3, 2, FALSE);
  gtk_widget_set_name (table109, "table109");
  gtk_widget_show (table109);
  gtk_container_add (GTK_CONTAINER (frame141), table109);
  gtk_container_set_border_width (GTK_CONTAINER (table109), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table109), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table109), 4);

  label928 = gtk_label_new_with_mnemonic (_("Minimum chunk _size"));
  gtk_widget_set_name (label928, "label928");
  gtk_widget_show (label928);
  gtk_table_attach (GTK_TABLE (table109), label928, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 4, 0);
  gtk_misc_set_alignment (GTK_MISC (label928), 0, 0.5);

  spinbutton_parq_min_size_adj = gtk_adjustment_new (0, 0, 67108900, 1, 10, 0);
  spinbutton_parq_min_size = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_parq_min_size_adj), 1, 0);
  gtk_widget_set_name (spinbutton_parq_min_size, "spinbutton_parq_min_size");
  gtk_widget_show (spinbutton_parq_min_size);
  gtk_table_attach (GTK_TABLE (table109), spinbutton_parq_min_size, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  label932 = gtk_label_new_with_mnemonic (_("Minimum upload time"));
  gtk_widget_set_name (label932, "label932");
  gtk_widget_show (label932);
  gtk_table_attach (GTK_TABLE (table109), label932, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 4, 0);
  gtk_misc_set_alignment (GTK_MISC (label932), 0, 0.5);

  checkbutton_parq_optimistic = gtk_check_button_new_with_mnemonic (_("Use realistic PARQ estimates"));
  gtk_widget_set_name (checkbutton_parq_optimistic, "checkbutton_parq_optimistic");
  gtk_widget_show (checkbutton_parq_optimistic);
  gtk_table_attach (GTK_TABLE (table109), checkbutton_parq_optimistic, 0, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 4, 0);

  spinbutton_parq_min_time_adj = gtk_adjustment_new (0, 0, 67108900, 1, 10, 0);
  spinbutton_parq_min_time = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_parq_min_time_adj), 1, 0);
  gtk_widget_set_name (spinbutton_parq_min_time, "spinbutton_parq_min_time");
  gtk_widget_show (spinbutton_parq_min_time);
  gtk_table_attach (GTK_TABLE (table109), spinbutton_parq_min_time, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  label929 = gtk_label_new (_("Queuing details"));
  gtk_widget_set_name (label929, "label929");
  gtk_widget_show (label929);
  gtk_frame_set_label_widget (GTK_FRAME (frame141), label929);

  frame_expert_share_statistics = gtk_frame_new (NULL);
  gtk_widget_set_name (frame_expert_share_statistics, "frame_expert_share_statistics");
  gtk_widget_show (frame_expert_share_statistics);
  gtk_box_pack_start (GTK_BOX (vbox40), frame_expert_share_statistics, FALSE, TRUE, 0);

  vbox117 = gtk_vbox_new (FALSE, 4);
  gtk_widget_set_name (vbox117, "vbox117");
  gtk_widget_show (vbox117);
  gtk_container_add (GTK_CONTAINER (frame_expert_share_statistics), vbox117);
  gtk_container_set_border_width (GTK_CONTAINER (vbox117), 5);

  hbox258 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox258, "hbox258");
  gtk_widget_show (hbox258);
  gtk_box_pack_start (GTK_BOX (vbox117), hbox258, FALSE, TRUE, 0);

  viewport111 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport111, "viewport111");
  gtk_widget_show (viewport111);
  gtk_box_pack_start (GTK_BOX (hbox258), viewport111, FALSE, TRUE, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport111), GTK_SHADOW_OUT);

  frame101 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame101, "frame101");
  gtk_widget_show (frame101);
  gtk_container_add (GTK_CONTAINER (viewport111), frame101);

  table87 = gtk_table_new (2, 2, FALSE);
  gtk_widget_set_name (table87, "table87");
  gtk_widget_show (table87);
  gtk_container_add (GTK_CONTAINER (frame101), table87);
  gtk_container_set_border_width (GTK_CONTAINER (table87), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table87), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table87), 4);

  label786 = gtk_label_new (_("Last scan initiated on:"));
  gtk_widget_set_name (label786, "label786");
  gtk_widget_show (label786);
  gtk_table_attach (GTK_TABLE (table87), label786, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label786), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label786), 4, 0);

  label788 = gtk_label_new (_("File scanning time:"));
  gtk_widget_set_name (label788, "label788");
  gtk_widget_show (label788);
  gtk_table_attach (GTK_TABLE (table87), label788, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label788), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label788), 4, 0);

  viewport83 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport83, "viewport83");
  gtk_widget_show (viewport83);
  gtk_table_attach (GTK_TABLE (table87), viewport83, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport83), GTK_SHADOW_NONE);

  label_library_rescan_timestamp = gtk_label_new ("[place holder]");
  gtk_widget_set_name (label_library_rescan_timestamp, "label_library_rescan_timestamp");
  gtk_widget_show (label_library_rescan_timestamp);
  gtk_container_add (GTK_CONTAINER (viewport83), label_library_rescan_timestamp);
  gtk_label_set_justify (GTK_LABEL (label_library_rescan_timestamp), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label_library_rescan_timestamp), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_library_rescan_timestamp), 5, 0);

  viewport84 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport84, "viewport84");
  gtk_widget_show (viewport84);
  gtk_table_attach (GTK_TABLE (table87), viewport84, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport84), GTK_SHADOW_NONE);

  label_library_rescan_time = gtk_label_new ("[place holder]");
  gtk_widget_set_name (label_library_rescan_time, "label_library_rescan_time");
  gtk_widget_show (label_library_rescan_time);
  gtk_container_add (GTK_CONTAINER (viewport84), label_library_rescan_time);
  gtk_label_set_justify (GTK_LABEL (label_library_rescan_time), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label_library_rescan_time), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_library_rescan_time), 5, 0);

  label785 = gtk_label_new (_("Library scanning:"));
  gtk_widget_set_name (label785, "label785");
  gtk_widget_show (label785);
  gtk_frame_set_label_widget (GTK_FRAME (frame101), label785);

  viewport112 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport112, "viewport112");
  gtk_widget_show (viewport112);
  gtk_box_pack_start (GTK_BOX (hbox258), viewport112, TRUE, TRUE, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport112), GTK_SHADOW_OUT);

  frame_qrp_table_info = gtk_frame_new (NULL);
  gtk_widget_set_name (frame_qrp_table_info, "frame_qrp_table_info");
  gtk_widget_show (frame_qrp_table_info);
  gtk_container_add (GTK_CONTAINER (viewport112), frame_qrp_table_info);

  table89 = gtk_table_new (3, 6, FALSE);
  gtk_widget_set_name (table89, "table89");
  gtk_widget_show (table89);
  gtk_container_add (GTK_CONTAINER (frame_qrp_table_info), table89);
  gtk_container_set_border_width (GTK_CONTAINER (table89), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table89), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table89), 4);

  vseparator5 = gtk_vseparator_new ();
  gtk_widget_set_name (vseparator5, "vseparator5");
  gtk_widget_show (vseparator5);
  gtk_table_attach (GTK_TABLE (table89), vseparator5, 2, 3, 0, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  label820 = gtk_label_new ("%");
  gtk_widget_set_name (label820, "label820");
  gtk_widget_show (label820);
  gtk_table_attach (GTK_TABLE (table89), label820, 5, 6, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label820), 0, 0.5);

  label821 = gtk_label_new ("%");
  gtk_widget_set_name (label821, "label821");
  gtk_widget_show (label821);
  gtk_table_attach (GTK_TABLE (table89), label821, 5, 6, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label821), 0, 0.5);

  label814 = gtk_label_new (_("Generation:"));
  gtk_widget_set_name (label814, "label814");
  gtk_widget_show (label814);
  gtk_table_attach (GTK_TABLE (table89), label814, 3, 4, 0, 1,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label814), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label814), 4, 0);

  label815 = gtk_label_new (_("Filled ratio:"));
  gtk_widget_set_name (label815, "label815");
  gtk_widget_show (label815);
  gtk_table_attach (GTK_TABLE (table89), label815, 3, 4, 1, 2,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label815), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label815), 4, 0);

  label816 = gtk_label_new (_("Conflict ratio:"));
  gtk_widget_set_name (label816, "label816");
  gtk_widget_show (label816);
  gtk_table_attach (GTK_TABLE (table89), label816, 3, 4, 2, 3,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label816), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label816), 4, 0);

  label808 = gtk_label_new (_("Keywords:"));
  gtk_widget_set_name (label808, "label808");
  gtk_widget_show (label808);
  gtk_table_attach (GTK_TABLE (table89), label808, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label808), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label808), 4, 0);

  label809 = gtk_label_new (_("Slots:"));
  gtk_widget_set_name (label809, "label809");
  gtk_widget_show (label809);
  gtk_table_attach (GTK_TABLE (table89), label809, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label809), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label809), 4, 0);

  label810 = gtk_label_new (_("Filled slots:"));
  gtk_widget_set_name (label810, "label810");
  gtk_widget_show (label810);
  gtk_table_attach (GTK_TABLE (table89), label810, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label810), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label810), 4, 0);

  viewport94 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport94, "viewport94");
  gtk_widget_show (viewport94);
  gtk_table_attach (GTK_TABLE (table89), viewport94, 4, 5, 0, 1,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport94), GTK_SHADOW_NONE);

  label_qrp_generation = gtk_label_new ("[place holder]");
  gtk_widget_set_name (label_qrp_generation, "label_qrp_generation");
  gtk_widget_show (label_qrp_generation);
  gtk_container_add (GTK_CONTAINER (viewport94), label_qrp_generation);
  gtk_label_set_justify (GTK_LABEL (label_qrp_generation), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label_qrp_generation), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_qrp_generation), 5, 0);

  viewport96 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport96, "viewport96");
  gtk_widget_show (viewport96);
  gtk_table_attach (GTK_TABLE (table89), viewport96, 4, 5, 2, 3,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport96), GTK_SHADOW_NONE);

  label_qrp_conflict_ratio = gtk_label_new ("[place holder]");
  gtk_widget_set_name (label_qrp_conflict_ratio, "label_qrp_conflict_ratio");
  gtk_widget_show (label_qrp_conflict_ratio);
  gtk_container_add (GTK_CONTAINER (viewport96), label_qrp_conflict_ratio);
  gtk_label_set_justify (GTK_LABEL (label_qrp_conflict_ratio), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label_qrp_conflict_ratio), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_qrp_conflict_ratio), 5, 0);

  viewport95 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport95, "viewport95");
  gtk_widget_show (viewport95);
  gtk_table_attach (GTK_TABLE (table89), viewport95, 4, 5, 1, 2,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport95), GTK_SHADOW_NONE);

  label_qrp_fill_ratio = gtk_label_new ("[place holder]");
  gtk_widget_set_name (label_qrp_fill_ratio, "label_qrp_fill_ratio");
  gtk_widget_show (label_qrp_fill_ratio);
  gtk_container_add (GTK_CONTAINER (viewport95), label_qrp_fill_ratio);
  gtk_label_set_justify (GTK_LABEL (label_qrp_fill_ratio), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label_qrp_fill_ratio), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_qrp_fill_ratio), 5, 0);

  viewport92 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport92, "viewport92");
  gtk_widget_show (viewport92);
  gtk_table_attach (GTK_TABLE (table89), viewport92, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport92), GTK_SHADOW_NONE);

  label_qrp_slots = gtk_label_new ("[place holder]");
  gtk_widget_set_name (label_qrp_slots, "label_qrp_slots");
  gtk_widget_show (label_qrp_slots);
  gtk_container_add (GTK_CONTAINER (viewport92), label_qrp_slots);
  gtk_misc_set_alignment (GTK_MISC (label_qrp_slots), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_qrp_slots), 5, 0);

  viewport91 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport91, "viewport91");
  gtk_widget_show (viewport91);
  gtk_table_attach (GTK_TABLE (table89), viewport91, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport91), GTK_SHADOW_NONE);

  label_qrp_hashed_keywords = gtk_label_new ("[place holder]");
  gtk_widget_set_name (label_qrp_hashed_keywords, "label_qrp_hashed_keywords");
  gtk_widget_show (label_qrp_hashed_keywords);
  gtk_container_add (GTK_CONTAINER (viewport91), label_qrp_hashed_keywords);
  gtk_label_set_justify (GTK_LABEL (label_qrp_hashed_keywords), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label_qrp_hashed_keywords), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_qrp_hashed_keywords), 5, 0);

  viewport93 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport93, "viewport93");
  gtk_widget_show (viewport93);
  gtk_table_attach (GTK_TABLE (table89), viewport93, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport93), GTK_SHADOW_NONE);

  label_qrp_slots_filled = gtk_label_new ("[place holder]");
  gtk_widget_set_name (label_qrp_slots_filled, "label_qrp_slots_filled");
  gtk_widget_show (label_qrp_slots_filled);
  gtk_container_add (GTK_CONTAINER (viewport93), label_qrp_slots_filled);
  gtk_label_set_justify (GTK_LABEL (label_qrp_slots_filled), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label_qrp_slots_filled), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_qrp_slots_filled), 5, 0);

  label807 = gtk_label_new (_("Query routing table information:"));
  gtk_widget_set_name (label807, "label807");
  gtk_widget_show (label807);
  gtk_frame_set_label_widget (GTK_FRAME (frame_qrp_table_info), label807);

  hbox259 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox259, "hbox259");
  gtk_widget_show (hbox259);
  gtk_box_pack_start (GTK_BOX (vbox117), hbox259, FALSE, TRUE, 0);

  viewport110 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport110, "viewport110");
  gtk_widget_show (viewport110);
  gtk_box_pack_start (GTK_BOX (hbox259), viewport110, FALSE, TRUE, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport110), GTK_SHADOW_OUT);

  frame_qrp_statistics = gtk_frame_new (NULL);
  gtk_widget_set_name (frame_qrp_statistics, "frame_qrp_statistics");
  gtk_widget_show (frame_qrp_statistics);
  gtk_container_add (GTK_CONTAINER (viewport110), frame_qrp_statistics);

  table88 = gtk_table_new (3, 4, FALSE);
  gtk_widget_set_name (table88, "table88");
  gtk_widget_show (table88);
  gtk_container_add (GTK_CONTAINER (frame_qrp_statistics), table88);
  gtk_container_set_border_width (GTK_CONTAINER (table88), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table88), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table88), 4);

  label792 = gtk_label_new (_("Indexing started on:"));
  gtk_widget_set_name (label792, "label792");
  gtk_widget_show (label792);
  gtk_table_attach (GTK_TABLE (table88), label792, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label792), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label792), 0, 0.5);

  label793 = gtk_label_new (_("Table generation started on:"));
  gtk_widget_set_name (label793, "label793");
  gtk_widget_show (label793);
  gtk_table_attach (GTK_TABLE (table88), label793, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label793), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label793), 0, 0.5);

  label794 = gtk_label_new (_("Patch generation started on:"));
  gtk_widget_set_name (label794, "label794");
  gtk_widget_show (label794);
  gtk_table_attach (GTK_TABLE (table88), label794, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label794), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label794), 0, 0.5);

  label795 = gtk_label_new (_("and lasted"));
  gtk_widget_set_name (label795, "label795");
  gtk_widget_show (label795);
  gtk_table_attach (GTK_TABLE (table88), label795, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label795), 0, 0.5);

  label796 = gtk_label_new (_("and lasted"));
  gtk_widget_set_name (label796, "label796");
  gtk_widget_show (label796);
  gtk_table_attach (GTK_TABLE (table88), label796, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label796), 0, 0.5);

  label797 = gtk_label_new (_("and lasted"));
  gtk_widget_set_name (label797, "label797");
  gtk_widget_show (label797);
  gtk_table_attach (GTK_TABLE (table88), label797, 2, 3, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label797), 0, 0.5);

  viewport85 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport85, "viewport85");
  gtk_widget_show (viewport85);
  gtk_table_attach (GTK_TABLE (table88), viewport85, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport85), GTK_SHADOW_NONE);

  label_qrp_indexing_timestamp = gtk_label_new ("[place holder]");
  gtk_widget_set_name (label_qrp_indexing_timestamp, "label_qrp_indexing_timestamp");
  gtk_widget_show (label_qrp_indexing_timestamp);
  gtk_container_add (GTK_CONTAINER (viewport85), label_qrp_indexing_timestamp);
  gtk_label_set_justify (GTK_LABEL (label_qrp_indexing_timestamp), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label_qrp_indexing_timestamp), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_qrp_indexing_timestamp), 5, 0);

  viewport88 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport88, "viewport88");
  gtk_widget_show (viewport88);
  gtk_table_attach (GTK_TABLE (table88), viewport88, 3, 4, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport88), GTK_SHADOW_NONE);

  label_qrp_indexing_time = gtk_label_new ("[place holder]");
  gtk_widget_set_name (label_qrp_indexing_time, "label_qrp_indexing_time");
  gtk_widget_show (label_qrp_indexing_time);
  gtk_container_add (GTK_CONTAINER (viewport88), label_qrp_indexing_time);
  gtk_label_set_justify (GTK_LABEL (label_qrp_indexing_time), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label_qrp_indexing_time), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_qrp_indexing_time), 5, 0);

  viewport86 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport86, "viewport86");
  gtk_widget_show (viewport86);
  gtk_table_attach (GTK_TABLE (table88), viewport86, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport86), GTK_SHADOW_NONE);

  label_qrp_timestamp = gtk_label_new ("[place holder]");
  gtk_widget_set_name (label_qrp_timestamp, "label_qrp_timestamp");
  gtk_widget_show (label_qrp_timestamp);
  gtk_container_add (GTK_CONTAINER (viewport86), label_qrp_timestamp);
  gtk_label_set_justify (GTK_LABEL (label_qrp_timestamp), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label_qrp_timestamp), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_qrp_timestamp), 5, 0);

  viewport87 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport87, "viewport87");
  gtk_widget_show (viewport87);
  gtk_table_attach (GTK_TABLE (table88), viewport87, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport87), GTK_SHADOW_NONE);

  label_qrp_patch_timestamp = gtk_label_new ("[place holder]");
  gtk_widget_set_name (label_qrp_patch_timestamp, "label_qrp_patch_timestamp");
  gtk_widget_show (label_qrp_patch_timestamp);
  gtk_container_add (GTK_CONTAINER (viewport87), label_qrp_patch_timestamp);
  gtk_label_set_justify (GTK_LABEL (label_qrp_patch_timestamp), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label_qrp_patch_timestamp), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_qrp_patch_timestamp), 5, 0);

  viewport89 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport89, "viewport89");
  gtk_widget_show (viewport89);
  gtk_table_attach (GTK_TABLE (table88), viewport89, 3, 4, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport89), GTK_SHADOW_NONE);

  label_qrp_computation_time = gtk_label_new ("[place holder]");
  gtk_widget_set_name (label_qrp_computation_time, "label_qrp_computation_time");
  gtk_widget_show (label_qrp_computation_time);
  gtk_container_add (GTK_CONTAINER (viewport89), label_qrp_computation_time);
  gtk_label_set_justify (GTK_LABEL (label_qrp_computation_time), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label_qrp_computation_time), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_qrp_computation_time), 5, 0);

  viewport90 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport90, "viewport90");
  gtk_widget_show (viewport90);
  gtk_table_attach (GTK_TABLE (table88), viewport90, 3, 4, 2, 3,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport90), GTK_SHADOW_NONE);

  label_qrp_patch_computation_time = gtk_label_new ("[place holder]");
  gtk_widget_set_name (label_qrp_patch_computation_time, "label_qrp_patch_computation_time");
  gtk_widget_show (label_qrp_patch_computation_time);
  gtk_container_add (GTK_CONTAINER (viewport90), label_qrp_patch_computation_time);
  gtk_label_set_justify (GTK_LABEL (label_qrp_patch_computation_time), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label_qrp_patch_computation_time), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_qrp_patch_computation_time), 5, 0);

  label791 = gtk_label_new (_("Query Routing Protocol:"));
  gtk_widget_set_name (label791, "label791");
  gtk_widget_show (label791);
  gtk_frame_set_label_widget (GTK_FRAME (frame_qrp_statistics), label791);

  viewport113 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport113, "viewport113");
  gtk_widget_show (viewport113);
  gtk_box_pack_start (GTK_BOX (hbox259), viewport113, TRUE, TRUE, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport113), GTK_SHADOW_OUT);

  frame_qrp_patch_info = gtk_frame_new (NULL);
  gtk_widget_set_name (frame_qrp_patch_info, "frame_qrp_patch_info");
  gtk_widget_show (frame_qrp_patch_info);
  gtk_container_add (GTK_CONTAINER (viewport113), frame_qrp_patch_info);

  table90 = gtk_table_new (3, 3, FALSE);
  gtk_widget_set_name (table90, "table90");
  gtk_widget_show (table90);
  gtk_container_add (GTK_CONTAINER (frame_qrp_patch_info), table90);
  gtk_container_set_border_width (GTK_CONTAINER (table90), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table90), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table90), 4);

  label823 = gtk_label_new (_("Raw length:"));
  gtk_widget_set_name (label823, "label823");
  gtk_widget_show (label823);
  gtk_table_attach (GTK_TABLE (table90), label823, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label823), 0, 0.5);

  label824 = gtk_label_new (_("Compressed length:"));
  gtk_widget_set_name (label824, "label824");
  gtk_widget_show (label824);
  gtk_table_attach (GTK_TABLE (table90), label824, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label824), 0, 0.5);

  label825 = gtk_label_new (_("Compression ratio:"));
  gtk_widget_set_name (label825, "label825");
  gtk_widget_show (label825);
  gtk_table_attach (GTK_TABLE (table90), label825, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label825), 0, 0.5);

  label826 = gtk_label_new ("%");
  gtk_widget_set_name (label826, "label826");
  gtk_widget_show (label826);
  gtk_table_attach (GTK_TABLE (table90), label826, 2, 3, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label826), 0, 0.5);

  viewport97 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport97, "viewport97");
  gtk_widget_show (viewport97);
  gtk_table_attach (GTK_TABLE (table90), viewport97, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport97), GTK_SHADOW_NONE);

  label_qrp_patch_raw_length = gtk_label_new ("[place holder]");
  gtk_widget_set_name (label_qrp_patch_raw_length, "label_qrp_patch_raw_length");
  gtk_widget_show (label_qrp_patch_raw_length);
  gtk_container_add (GTK_CONTAINER (viewport97), label_qrp_patch_raw_length);
  gtk_label_set_justify (GTK_LABEL (label_qrp_patch_raw_length), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label_qrp_patch_raw_length), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_qrp_patch_raw_length), 5, 0);

  viewport98 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport98, "viewport98");
  gtk_widget_show (viewport98);
  gtk_table_attach (GTK_TABLE (table90), viewport98, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport98), GTK_SHADOW_NONE);

  label_qrp_patch_length = gtk_label_new ("[place holder]");
  gtk_widget_set_name (label_qrp_patch_length, "label_qrp_patch_length");
  gtk_widget_show (label_qrp_patch_length);
  gtk_container_add (GTK_CONTAINER (viewport98), label_qrp_patch_length);
  gtk_label_set_justify (GTK_LABEL (label_qrp_patch_length), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label_qrp_patch_length), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_qrp_patch_length), 5, 0);

  viewport99 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport99, "viewport99");
  gtk_widget_show (viewport99);
  gtk_table_attach (GTK_TABLE (table90), viewport99, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport99), GTK_SHADOW_NONE);

  label_qrp_patch_comp_ratio = gtk_label_new ("[place holder]");
  gtk_widget_set_name (label_qrp_patch_comp_ratio, "label_qrp_patch_comp_ratio");
  gtk_widget_show (label_qrp_patch_comp_ratio);
  gtk_container_add (GTK_CONTAINER (viewport99), label_qrp_patch_comp_ratio);
  gtk_label_set_justify (GTK_LABEL (label_qrp_patch_comp_ratio), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label_qrp_patch_comp_ratio), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_qrp_patch_comp_ratio), 5, 0);

  label822 = gtk_label_new (_("Query routing patch information:"));
  gtk_widget_set_name (label822, "label822");
  gtk_widget_show (label822);
  gtk_frame_set_label_widget (GTK_FRAME (frame_qrp_patch_info), label822);

  label784 = gtk_label_new (_("Statistics:"));
  gtk_widget_set_name (label784, "label784");
  gtk_widget_show (label784);
  gtk_frame_set_label_widget (GTK_FRAME (frame_expert_share_statistics), label784);

  g_signal_connect ((gpointer) button_config_add_dir, "clicked",
                    G_CALLBACK (on_button_config_add_dir_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_config_remove_dir, "clicked",
                    G_CALLBACK (on_button_config_remove_dir_clicked),
                    NULL);
  g_signal_connect ((gpointer) button_config_rescan_dir, "clicked",
                    G_CALLBACK (on_button_config_rescan_dir_clicked),
                    NULL);
  g_signal_connect ((gpointer) entry_config_extensions, "activate",
                    G_CALLBACK (on_entry_config_extensions_activate),
                    NULL);
  g_signal_connect ((gpointer) entry_config_extensions, "focus_out_event",
                    G_CALLBACK (on_entry_config_extensions_focus_out_event),
                    NULL);

  gtk_label_set_mnemonic_widget (GTK_LABEL (label41), entry_config_extensions);
  gtk_label_set_mnemonic_widget (GTK_LABEL (label726), spinbutton_pfsp_first_chunk);
  gtk_label_set_mnemonic_widget (GTK_LABEL (label179), spinbutton_config_upload_connecting_timeout);
  gtk_label_set_mnemonic_widget (GTK_LABEL (label180), spinbutton_config_upload_connected_timeout);
  gtk_label_set_mnemonic_widget (GTK_LABEL (label928), spinbutton_pfsp_first_chunk);
  gtk_label_set_mnemonic_widget (GTK_LABEL (label932), spinbutton_pfsp_first_chunk);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (dlg_prefs_ul_tab, dlg_prefs_ul_tab, "dlg_prefs_ul_tab");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, scrolledwindow42, "scrolledwindow42");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, viewport6, "viewport6");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, vbox40, "vbox40");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, frame_path_to_files, "frame_path_to_files");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, vbox_path_to_files, "vbox_path_to_files");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, hbox9299, "hbox9299");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, scrolledwindow79, "scrolledwindow79");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, treeview_shared_dirs, "treeview_shared_dirs");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, hbox_path_buttons, "hbox_path_buttons");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, button_config_add_dir, "button_config_add_dir");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, alignment70, "alignment70");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, hbox204, "hbox204");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, image116, "image116");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label482, "label482");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, button_config_remove_dir, "button_config_remove_dir");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, alignment111, "alignment111");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, hbox9298, "hbox9298");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, image566, "image566");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label933, "label933");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, button_config_rescan_dir, "button_config_rescan_dir");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, alignment69, "alignment69");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, hbox203, "hbox203");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, image115, "image115");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label481, "label481");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label_files_scanned, "label_files_scanned");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, hbox27, "hbox27");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label41, "label41");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, entry_config_extensions, "entry_config_extensions");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, hbox232, "hbox232");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, checkbutton_scan_ignore_symlink_dirs, "checkbutton_scan_ignore_symlink_dirs");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, checkbutton_scan_ignore_symlink_regfiles, "checkbutton_scan_ignore_symlink_regfiles");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label300, "label300");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, frame146, "frame146");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, table114, "table114");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, checkbutton_enable_browse_host, "checkbutton_enable_browse_host");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, checkbutton_expose_relative_paths, "checkbutton_expose_relative_paths");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, hbox284, "hbox284");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, frame86, "frame86");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, table73, "table73");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, checkbutton_pfsp_server, "checkbutton_pfsp_server");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label954, "label954");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, spinbutton_pfsp_minimum_filesize, "spinbutton_pfsp_minimum_filesize");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label1030, "label1030");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, spinbutton_pfsp_last_chunk, "spinbutton_pfsp_last_chunk");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label726, "label726");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, spinbutton_pfsp_first_chunk, "spinbutton_pfsp_first_chunk");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, checkbutton_pfsp_rare_server, "checkbutton_pfsp_rare_server");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label725, "label725");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, frame_expert_ul_timeout, "frame_expert_ul_timeout");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, table12, "table12");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label179, "label179");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label180, "label180");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, spinbutton_config_upload_connecting_timeout, "spinbutton_config_upload_connecting_timeout");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, spinbutton_config_upload_connected_timeout, "spinbutton_config_upload_connected_timeout");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label301, "label301");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, vbox159, "vbox159");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, checkbutton_config_query_answer_partials, "checkbutton_config_query_answer_partials");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, checkbutton_config_query_answer_whats_new, "checkbutton_config_query_answer_whats_new");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, hbox9297, "hbox9297");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, frame141, "frame141");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, table109, "table109");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label928, "label928");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, spinbutton_parq_min_size, "spinbutton_parq_min_size");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label932, "label932");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, checkbutton_parq_optimistic, "checkbutton_parq_optimistic");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, spinbutton_parq_min_time, "spinbutton_parq_min_time");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label929, "label929");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, frame_expert_share_statistics, "frame_expert_share_statistics");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, vbox117, "vbox117");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, hbox258, "hbox258");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, viewport111, "viewport111");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, frame101, "frame101");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, table87, "table87");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label786, "label786");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label788, "label788");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, viewport83, "viewport83");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label_library_rescan_timestamp, "label_library_rescan_timestamp");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, viewport84, "viewport84");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label_library_rescan_time, "label_library_rescan_time");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label785, "label785");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, viewport112, "viewport112");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, frame_qrp_table_info, "frame_qrp_table_info");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, table89, "table89");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, vseparator5, "vseparator5");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label820, "label820");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label821, "label821");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label814, "label814");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label815, "label815");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label816, "label816");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label808, "label808");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label809, "label809");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label810, "label810");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, viewport94, "viewport94");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label_qrp_generation, "label_qrp_generation");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, viewport96, "viewport96");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label_qrp_conflict_ratio, "label_qrp_conflict_ratio");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, viewport95, "viewport95");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label_qrp_fill_ratio, "label_qrp_fill_ratio");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, viewport92, "viewport92");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label_qrp_slots, "label_qrp_slots");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, viewport91, "viewport91");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label_qrp_hashed_keywords, "label_qrp_hashed_keywords");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, viewport93, "viewport93");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label_qrp_slots_filled, "label_qrp_slots_filled");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label807, "label807");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, hbox259, "hbox259");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, viewport110, "viewport110");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, frame_qrp_statistics, "frame_qrp_statistics");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, table88, "table88");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label792, "label792");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label793, "label793");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label794, "label794");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label795, "label795");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label796, "label796");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label797, "label797");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, viewport85, "viewport85");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label_qrp_indexing_timestamp, "label_qrp_indexing_timestamp");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, viewport88, "viewport88");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label_qrp_indexing_time, "label_qrp_indexing_time");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, viewport86, "viewport86");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label_qrp_timestamp, "label_qrp_timestamp");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, viewport87, "viewport87");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label_qrp_patch_timestamp, "label_qrp_patch_timestamp");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, viewport89, "viewport89");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label_qrp_computation_time, "label_qrp_computation_time");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, viewport90, "viewport90");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label_qrp_patch_computation_time, "label_qrp_patch_computation_time");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label791, "label791");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, viewport113, "viewport113");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, frame_qrp_patch_info, "frame_qrp_patch_info");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, table90, "table90");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label823, "label823");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label824, "label824");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label825, "label825");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label826, "label826");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, viewport97, "viewport97");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label_qrp_patch_raw_length, "label_qrp_patch_raw_length");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, viewport98, "viewport98");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label_qrp_patch_length, "label_qrp_patch_length");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, viewport99, "viewport99");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label_qrp_patch_comp_ratio, "label_qrp_patch_comp_ratio");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label822, "label822");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ul_tab, label784, "label784");

  return dlg_prefs_ul_tab;
}

GtkWidget*
create_dlg_prefs_ui_tab (void)
{
  GtkWidget *dlg_prefs_ui_tab;
  GtkWidget *scrolledwindow43;
  GtkWidget *viewport7;
  GtkWidget *vbox80;
  GtkWidget *frame52;
  GtkWidget *table35;
  GtkWidget *checkbutton_config_show_tooltips;
  GtkWidget *checkbutton_config_confirm_quit;
  GtkWidget *checkbutton_config_metric;
  GtkObject *spinbutton_search_accumulation_period_adj;
  GtkWidget *spinbutton_search_accumulation_period;
  GtkWidget *label834;
  GtkObject *spinbutton_entry_removal_timeout_adj;
  GtkWidget *spinbutton_entry_removal_timeout;
  GtkWidget *label750;
  GtkWidget *label749;
  GtkWidget *label833;
  GtkWidget *checkbutton_search_jump_to_created;
  GtkWidget *checkbutton_status_icon_enabled;
  GtkWidget *label373;
  GtkWidget *frame53;
  GtkWidget *table34;
  GtkWidget *checkbutton_expert_mode;
  GtkWidget *label374;
  GtkWidget *frame94;
  GtkWidget *table103;
  GtkWidget *checkbutton_node_show_detailed_info;
  GtkWidget *frame_gnet_detailed_traffic;
  GtkWidget *frame139;
  GtkWidget *table81;
  GtkWidget *checkbutton_gnet_info_txc;
  GtkWidget *checkbutton_gnet_info_tx_speed;
  GtkWidget *checkbutton_gnet_info_tx_queries;
  GtkWidget *checkbutton_gnet_info_tx_hits;
  GtkWidget *checkbutton_gnet_info_tx_dropped;
  GtkWidget *checkbutton_gnet_info_rxc;
  GtkWidget *checkbutton_gnet_info_rx_speed;
  GtkWidget *checkbutton_gnet_info_rx_queries;
  GtkWidget *checkbutton_gnet_info_rx_hits;
  GtkWidget *checkbutton_gnet_info_rx_dropped;
  GtkWidget *checkbutton_gnet_info_gen_queries;
  GtkWidget *checkbutton_gnet_info_sq_queries;
  GtkWidget *checkbutton_gnet_info_qrp_stats;
  GtkWidget *checkbutton_gnet_info_dbw;
  GtkWidget *checkbutton_gnet_info_rt;
  GtkWidget *checkbutton_gnet_info_shared_size;
  GtkWidget *checkbutton_gnet_info_shared_files;
  GtkWidget *checkbutton_gnet_info_tx_wire;
  GtkWidget *checkbutton_gnet_info_rx_wire;
  GtkWidget *label747;

  dlg_prefs_ui_tab = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_widget_set_name (dlg_prefs_ui_tab, "dlg_prefs_ui_tab");
  gtk_window_set_title (GTK_WINDOW (dlg_prefs_ui_tab), _("User Interface"));
  gtk_window_set_default_size (GTK_WINDOW (dlg_prefs_ui_tab), 600, 400);

  scrolledwindow43 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow43, "scrolledwindow43");
  gtk_widget_show (scrolledwindow43);
  gtk_container_add (GTK_CONTAINER (dlg_prefs_ui_tab), scrolledwindow43);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow43), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);

  viewport7 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport7, "viewport7");
  gtk_widget_show (viewport7);
  gtk_container_add (GTK_CONTAINER (scrolledwindow43), viewport7);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport7), GTK_SHADOW_NONE);

  vbox80 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox80, "vbox80");
  gtk_widget_show (vbox80);
  gtk_container_add (GTK_CONTAINER (viewport7), vbox80);
  gtk_container_set_border_width (GTK_CONTAINER (vbox80), 2);

  frame52 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame52, "frame52");
  gtk_widget_show (frame52);
  gtk_box_pack_start (GTK_BOX (vbox80), frame52, FALSE, TRUE, 0);

  table35 = gtk_table_new (7, 4, FALSE);
  gtk_widget_set_name (table35, "table35");
  gtk_widget_show (table35);
  gtk_container_add (GTK_CONTAINER (frame52), table35);
  gtk_container_set_border_width (GTK_CONTAINER (table35), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table35), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table35), 4);

  checkbutton_config_show_tooltips = gtk_check_button_new_with_mnemonic (_("Show _tooltips (does not affect all tooltips yet)"));
  gtk_widget_set_name (checkbutton_config_show_tooltips, "checkbutton_config_show_tooltips");
  gtk_widget_show (checkbutton_config_show_tooltips);
  gtk_table_attach (GTK_TABLE (table35), checkbutton_config_show_tooltips, 0, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 4, 0);

  checkbutton_config_confirm_quit = gtk_check_button_new_with_mnemonic (_("Show _confirmation dialog when leaving gtk-gnutella"));
  gtk_widget_set_name (checkbutton_config_confirm_quit, "checkbutton_config_confirm_quit");
  gtk_widget_show (checkbutton_config_confirm_quit);
  gtk_table_attach (GTK_TABLE (table35), checkbutton_config_confirm_quit, 0, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 4, 0);

  checkbutton_config_metric = gtk_check_button_new_with_mnemonic (_("Show _metric units"));
  gtk_widget_set_name (checkbutton_config_metric, "checkbutton_config_metric");
  gtk_widget_show (checkbutton_config_metric);
  gtk_table_attach (GTK_TABLE (table35), checkbutton_config_metric, 0, 3, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 4, 0);

  spinbutton_search_accumulation_period_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 0);
  spinbutton_search_accumulation_period = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_search_accumulation_period_adj), 1, 0);
  gtk_widget_set_name (spinbutton_search_accumulation_period, "spinbutton_search_accumulation_period");
  gtk_widget_show (spinbutton_search_accumulation_period);
  gtk_table_attach (GTK_TABLE (table35), spinbutton_search_accumulation_period, 2, 3, 6, 7,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label834 = gtk_label_new (_("seconds"));
  gtk_widget_set_name (label834, "label834");
  gtk_widget_show (label834);
  gtk_table_attach (GTK_TABLE (table35), label834, 3, 4, 6, 7,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label834), 0, 0.5);

  spinbutton_entry_removal_timeout_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 0);
  spinbutton_entry_removal_timeout = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_entry_removal_timeout_adj), 1, 0);
  gtk_widget_set_name (spinbutton_entry_removal_timeout, "spinbutton_entry_removal_timeout");
  gtk_widget_show (spinbutton_entry_removal_timeout);
  gtk_table_attach (GTK_TABLE (table35), spinbutton_entry_removal_timeout, 2, 3, 5, 6,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label750 = gtk_label_new (_("seconds"));
  gtk_widget_set_name (label750, "label750");
  gtk_widget_show (label750);
  gtk_table_attach (GTK_TABLE (table35), label750, 3, 4, 5, 6,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label750), 0, 0.5);

  label749 = gtk_label_new (_("Try to keep 'dead' entries around for"));
  gtk_widget_set_name (label749, "label749");
  gtk_widget_show (label749);
  gtk_table_attach (GTK_TABLE (table35), label749, 0, 1, 5, 6,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label749), 0, 0.5);

  label833 = gtk_label_new (_("Update search results pane every"));
  gtk_widget_set_name (label833, "label833");
  gtk_widget_show (label833);
  gtk_table_attach (GTK_TABLE (table35), label833, 0, 1, 6, 7,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label833), 0, 0.5);

  checkbutton_search_jump_to_created = gtk_check_button_new_with_mnemonic (_("Jump to newly created searches"));
  gtk_widget_set_name (checkbutton_search_jump_to_created, "checkbutton_search_jump_to_created");
  gtk_widget_show (checkbutton_search_jump_to_created);
  gtk_table_attach (GTK_TABLE (table35), checkbutton_search_jump_to_created, 0, 1, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 4, 0);

  checkbutton_status_icon_enabled = gtk_check_button_new_with_mnemonic (_("Show a status _icon"));
  gtk_widget_set_name (checkbutton_status_icon_enabled, "checkbutton_status_icon_enabled");
  gtk_widget_show (checkbutton_status_icon_enabled);
  gtk_table_attach (GTK_TABLE (table35), checkbutton_status_icon_enabled, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 4, 0);

  label373 = gtk_label_new (_("Miscellaneous"));
  gtk_widget_set_name (label373, "label373");
  gtk_widget_show (label373);
  gtk_frame_set_label_widget (GTK_FRAME (frame52), label373);

  frame53 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame53, "frame53");
  gtk_widget_show (frame53);
  gtk_box_pack_start (GTK_BOX (vbox80), frame53, FALSE, TRUE, 0);

  table34 = gtk_table_new (1, 1, FALSE);
  gtk_widget_set_name (table34, "table34");
  gtk_widget_show (table34);
  gtk_container_add (GTK_CONTAINER (frame53), table34);
  gtk_container_set_border_width (GTK_CONTAINER (table34), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table34), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table34), 4);

  checkbutton_expert_mode = gtk_check_button_new_with_mnemonic (_("Show additional information and settings for advanced and _expert users"));
  gtk_widget_set_name (checkbutton_expert_mode, "checkbutton_expert_mode");
  gtk_widget_show (checkbutton_expert_mode);
  gtk_table_attach (GTK_TABLE (table34), checkbutton_expert_mode, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 4, 0);

  label374 = gtk_label_new_with_mnemonic (_("Expert mode"));
  gtk_widget_set_name (label374, "label374");
  gtk_widget_show (label374);
  gtk_frame_set_label_widget (GTK_FRAME (frame53), label374);

  frame94 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame94, "frame94");
  gtk_widget_show (frame94);
  gtk_box_pack_start (GTK_BOX (vbox80), frame94, FALSE, FALSE, 0);

  table103 = gtk_table_new (2, 1, FALSE);
  gtk_widget_set_name (table103, "table103");
  gtk_widget_show (table103);
  gtk_container_add (GTK_CONTAINER (frame94), table103);

  checkbutton_node_show_detailed_info = gtk_check_button_new_with_mnemonic (_("Display detailed traffic information"));
  gtk_widget_set_name (checkbutton_node_show_detailed_info, "checkbutton_node_show_detailed_info");
  gtk_widget_show (checkbutton_node_show_detailed_info);
  gtk_table_attach (GTK_TABLE (table103), checkbutton_node_show_detailed_info, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 4, 0);

  frame_gnet_detailed_traffic = gtk_frame_new (NULL);
  gtk_widget_set_name (frame_gnet_detailed_traffic, "frame_gnet_detailed_traffic");
  gtk_widget_show (frame_gnet_detailed_traffic);
  gtk_table_attach (GTK_TABLE (table103), frame_gnet_detailed_traffic, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL), 0, 0);
  gtk_frame_set_shadow_type (GTK_FRAME (frame_gnet_detailed_traffic), GTK_SHADOW_OUT);

  frame139 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame139, "frame139");
  gtk_widget_show (frame139);
  gtk_container_add (GTK_CONTAINER (frame_gnet_detailed_traffic), frame139);
  gtk_container_set_border_width (GTK_CONTAINER (frame139), 2);

  table81 = gtk_table_new (7, 3, FALSE);
  gtk_widget_set_name (table81, "table81");
  gtk_widget_show (table81);
  gtk_container_add (GTK_CONTAINER (frame139), table81);
  gtk_container_set_border_width (GTK_CONTAINER (table81), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table81), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table81), 4);

  checkbutton_gnet_info_txc = gtk_check_button_new_with_mnemonic (_("TX compression"));
  gtk_widget_set_name (checkbutton_gnet_info_txc, "checkbutton_gnet_info_txc");
  gtk_widget_show (checkbutton_gnet_info_txc);
  gtk_table_attach (GTK_TABLE (table81), checkbutton_gnet_info_txc, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_gnet_info_tx_speed = gtk_check_button_new_with_mnemonic (_("TX speed"));
  gtk_widget_set_name (checkbutton_gnet_info_tx_speed, "checkbutton_gnet_info_tx_speed");
  gtk_widget_show (checkbutton_gnet_info_tx_speed);
  gtk_table_attach (GTK_TABLE (table81), checkbutton_gnet_info_tx_speed, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_gnet_info_tx_queries = gtk_check_button_new_with_mnemonic (_("TX queries"));
  gtk_widget_set_name (checkbutton_gnet_info_tx_queries, "checkbutton_gnet_info_tx_queries");
  gtk_widget_show (checkbutton_gnet_info_tx_queries);
  gtk_table_attach (GTK_TABLE (table81), checkbutton_gnet_info_tx_queries, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_gnet_info_tx_hits = gtk_check_button_new_with_mnemonic (_("TX query hits"));
  gtk_widget_set_name (checkbutton_gnet_info_tx_hits, "checkbutton_gnet_info_tx_hits");
  gtk_widget_show (checkbutton_gnet_info_tx_hits);
  gtk_table_attach (GTK_TABLE (table81), checkbutton_gnet_info_tx_hits, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_gnet_info_tx_dropped = gtk_check_button_new_with_mnemonic (_("TX dropped"));
  gtk_widget_set_name (checkbutton_gnet_info_tx_dropped, "checkbutton_gnet_info_tx_dropped");
  gtk_widget_show (checkbutton_gnet_info_tx_dropped);
  gtk_table_attach (GTK_TABLE (table81), checkbutton_gnet_info_tx_dropped, 0, 1, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_gnet_info_rxc = gtk_check_button_new_with_mnemonic (_("RX compression"));
  gtk_widget_set_name (checkbutton_gnet_info_rxc, "checkbutton_gnet_info_rxc");
  gtk_widget_show (checkbutton_gnet_info_rxc);
  gtk_table_attach (GTK_TABLE (table81), checkbutton_gnet_info_rxc, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_gnet_info_rx_speed = gtk_check_button_new_with_mnemonic (_("RX speed"));
  gtk_widget_set_name (checkbutton_gnet_info_rx_speed, "checkbutton_gnet_info_rx_speed");
  gtk_widget_show (checkbutton_gnet_info_rx_speed);
  gtk_table_attach (GTK_TABLE (table81), checkbutton_gnet_info_rx_speed, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_gnet_info_rx_queries = gtk_check_button_new_with_mnemonic (_("RX queries"));
  gtk_widget_set_name (checkbutton_gnet_info_rx_queries, "checkbutton_gnet_info_rx_queries");
  gtk_widget_show (checkbutton_gnet_info_rx_queries);
  gtk_table_attach (GTK_TABLE (table81), checkbutton_gnet_info_rx_queries, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_gnet_info_rx_hits = gtk_check_button_new_with_mnemonic (_("RX query hits"));
  gtk_widget_set_name (checkbutton_gnet_info_rx_hits, "checkbutton_gnet_info_rx_hits");
  gtk_widget_show (checkbutton_gnet_info_rx_hits);
  gtk_table_attach (GTK_TABLE (table81), checkbutton_gnet_info_rx_hits, 1, 2, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_gnet_info_rx_dropped = gtk_check_button_new_with_mnemonic (_("RX dropped"));
  gtk_widget_set_name (checkbutton_gnet_info_rx_dropped, "checkbutton_gnet_info_rx_dropped");
  gtk_widget_show (checkbutton_gnet_info_rx_dropped);
  gtk_table_attach (GTK_TABLE (table81), checkbutton_gnet_info_rx_dropped, 1, 2, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_gnet_info_gen_queries = gtk_check_button_new_with_mnemonic (_("Generated queries"));
  gtk_widget_set_name (checkbutton_gnet_info_gen_queries, "checkbutton_gnet_info_gen_queries");
  gtk_widget_show (checkbutton_gnet_info_gen_queries);
  gtk_table_attach (GTK_TABLE (table81), checkbutton_gnet_info_gen_queries, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_gnet_info_sq_queries = gtk_check_button_new_with_mnemonic (_("Pending local queries"));
  gtk_widget_set_name (checkbutton_gnet_info_sq_queries, "checkbutton_gnet_info_sq_queries");
  gtk_widget_show (checkbutton_gnet_info_sq_queries);
  gtk_table_attach (GTK_TABLE (table81), checkbutton_gnet_info_sq_queries, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_gnet_info_qrp_stats = gtk_check_button_new_with_mnemonic (_("QRP stats"));
  gtk_widget_set_name (checkbutton_gnet_info_qrp_stats, "checkbutton_gnet_info_qrp_stats");
  gtk_widget_show (checkbutton_gnet_info_qrp_stats);
  gtk_table_attach (GTK_TABLE (table81), checkbutton_gnet_info_qrp_stats, 2, 3, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_gnet_info_dbw = gtk_check_button_new_with_mnemonic (_("Dup / Bad / Weird"));
  gtk_widget_set_name (checkbutton_gnet_info_dbw, "checkbutton_gnet_info_dbw");
  gtk_widget_show (checkbutton_gnet_info_dbw);
  gtk_table_attach (GTK_TABLE (table81), checkbutton_gnet_info_dbw, 2, 3, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_gnet_info_rt = gtk_check_button_new_with_mnemonic (_("Ping / Pong round trip"));
  gtk_widget_set_name (checkbutton_gnet_info_rt, "checkbutton_gnet_info_rt");
  gtk_widget_show (checkbutton_gnet_info_rt);
  gtk_table_attach (GTK_TABLE (table81), checkbutton_gnet_info_rt, 2, 3, 4, 5,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_gnet_info_shared_size = gtk_check_button_new_with_mnemonic (_("Library size"));
  gtk_widget_set_name (checkbutton_gnet_info_shared_size, "checkbutton_gnet_info_shared_size");
  gtk_widget_show (checkbutton_gnet_info_shared_size);
  gtk_table_attach (GTK_TABLE (table81), checkbutton_gnet_info_shared_size, 0, 1, 6, 7,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_gnet_info_shared_files = gtk_check_button_new_with_mnemonic (_("Library # of files"));
  gtk_widget_set_name (checkbutton_gnet_info_shared_files, "checkbutton_gnet_info_shared_files");
  gtk_widget_show (checkbutton_gnet_info_shared_files);
  gtk_table_attach (GTK_TABLE (table81), checkbutton_gnet_info_shared_files, 1, 2, 6, 7,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_gnet_info_tx_wire = gtk_check_button_new_with_mnemonic (_("TX wire bytes"));
  gtk_widget_set_name (checkbutton_gnet_info_tx_wire, "checkbutton_gnet_info_tx_wire");
  gtk_widget_show (checkbutton_gnet_info_tx_wire);
  gtk_table_attach (GTK_TABLE (table81), checkbutton_gnet_info_tx_wire, 0, 1, 5, 6,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_gnet_info_rx_wire = gtk_check_button_new_with_mnemonic (_("RX wire bytes"));
  gtk_widget_set_name (checkbutton_gnet_info_rx_wire, "checkbutton_gnet_info_rx_wire");
  gtk_widget_show (checkbutton_gnet_info_rx_wire);
  gtk_table_attach (GTK_TABLE (table81), checkbutton_gnet_info_rx_wire, 1, 2, 5, 6,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label747 = gtk_label_new (_("Gnutella display"));
  gtk_widget_set_name (label747, "label747");
  gtk_widget_show (label747);
  gtk_frame_set_label_widget (GTK_FRAME (frame94), label747);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (dlg_prefs_ui_tab, dlg_prefs_ui_tab, "dlg_prefs_ui_tab");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ui_tab, scrolledwindow43, "scrolledwindow43");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ui_tab, viewport7, "viewport7");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ui_tab, vbox80, "vbox80");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ui_tab, frame52, "frame52");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ui_tab, table35, "table35");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ui_tab, checkbutton_config_show_tooltips, "checkbutton_config_show_tooltips");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ui_tab, checkbutton_config_confirm_quit, "checkbutton_config_confirm_quit");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ui_tab, checkbutton_config_metric, "checkbutton_config_metric");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ui_tab, spinbutton_search_accumulation_period, "spinbutton_search_accumulation_period");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ui_tab, label834, "label834");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ui_tab, spinbutton_entry_removal_timeout, "spinbutton_entry_removal_timeout");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ui_tab, label750, "label750");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ui_tab, label749, "label749");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ui_tab, label833, "label833");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ui_tab, checkbutton_search_jump_to_created, "checkbutton_search_jump_to_created");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ui_tab, checkbutton_status_icon_enabled, "checkbutton_status_icon_enabled");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ui_tab, label373, "label373");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ui_tab, frame53, "frame53");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ui_tab, table34, "table34");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ui_tab, checkbutton_expert_mode, "checkbutton_expert_mode");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ui_tab, label374, "label374");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ui_tab, frame94, "frame94");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ui_tab, table103, "table103");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ui_tab, checkbutton_node_show_detailed_info, "checkbutton_node_show_detailed_info");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ui_tab, frame_gnet_detailed_traffic, "frame_gnet_detailed_traffic");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ui_tab, frame139, "frame139");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ui_tab, table81, "table81");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ui_tab, checkbutton_gnet_info_txc, "checkbutton_gnet_info_txc");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ui_tab, checkbutton_gnet_info_tx_speed, "checkbutton_gnet_info_tx_speed");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ui_tab, checkbutton_gnet_info_tx_queries, "checkbutton_gnet_info_tx_queries");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ui_tab, checkbutton_gnet_info_tx_hits, "checkbutton_gnet_info_tx_hits");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ui_tab, checkbutton_gnet_info_tx_dropped, "checkbutton_gnet_info_tx_dropped");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ui_tab, checkbutton_gnet_info_rxc, "checkbutton_gnet_info_rxc");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ui_tab, checkbutton_gnet_info_rx_speed, "checkbutton_gnet_info_rx_speed");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ui_tab, checkbutton_gnet_info_rx_queries, "checkbutton_gnet_info_rx_queries");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ui_tab, checkbutton_gnet_info_rx_hits, "checkbutton_gnet_info_rx_hits");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ui_tab, checkbutton_gnet_info_rx_dropped, "checkbutton_gnet_info_rx_dropped");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ui_tab, checkbutton_gnet_info_gen_queries, "checkbutton_gnet_info_gen_queries");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ui_tab, checkbutton_gnet_info_sq_queries, "checkbutton_gnet_info_sq_queries");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ui_tab, checkbutton_gnet_info_qrp_stats, "checkbutton_gnet_info_qrp_stats");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ui_tab, checkbutton_gnet_info_dbw, "checkbutton_gnet_info_dbw");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ui_tab, checkbutton_gnet_info_rt, "checkbutton_gnet_info_rt");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ui_tab, checkbutton_gnet_info_shared_size, "checkbutton_gnet_info_shared_size");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ui_tab, checkbutton_gnet_info_shared_files, "checkbutton_gnet_info_shared_files");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ui_tab, checkbutton_gnet_info_tx_wire, "checkbutton_gnet_info_tx_wire");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ui_tab, checkbutton_gnet_info_rx_wire, "checkbutton_gnet_info_rx_wire");
  GLADE_HOOKUP_OBJECT (dlg_prefs_ui_tab, label747, "label747");

  return dlg_prefs_ui_tab;
}

GtkWidget*
create_dlg_prefs_dbg_tab (void)
{
  GtkWidget *dlg_prefs_dbg_tab;
  GtkWidget *scrolledwindow44;
  GtkWidget *viewport8;
  GtkWidget *vbox81;
  GtkWidget *frame140;
  GtkWidget *vbox145;
  GtkWidget *hbox9295;
  GtkWidget *label922;
  GtkWidget *entry_dbg_property_pattern;
  GtkWidget *button_dbg_property_refresh;
  GtkWidget *scrolledwindow78;
  GtkWidget *treeview_dbg_property;
  GtkWidget *hbox9301;
  GtkWidget *label956;
  GtkWidget *label_dbg_property_default;
  GtkWidget *hbox9300;
  GtkWidget *label955;
  GtkWidget *label_dbg_property_limits;
  GtkWidget *label921;
  GtkWidget *frame_expert_unmapped;
  GtkWidget *table60;
  GtkWidget *label870;
  GtkWidget *label571;
  GtkWidget *entry_sys_physmem;
  GtkWidget *label1048;
  GtkWidget *entry_average_servent_downtime;
  GtkWidget *label564;
  GtkWidget *label566;
  GtkWidget *entry_average_ip_uptime;
  GtkWidget *entry_average_servent_uptime;
  GtkWidget *label558;

  dlg_prefs_dbg_tab = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_widget_set_name (dlg_prefs_dbg_tab, "dlg_prefs_dbg_tab");
  gtk_window_set_title (GTK_WINDOW (dlg_prefs_dbg_tab), _("Debugging"));
  gtk_window_set_default_size (GTK_WINDOW (dlg_prefs_dbg_tab), 640, 480);

  scrolledwindow44 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow44, "scrolledwindow44");
  gtk_widget_show (scrolledwindow44);
  gtk_container_add (GTK_CONTAINER (dlg_prefs_dbg_tab), scrolledwindow44);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow44), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);

  viewport8 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport8, "viewport8");
  gtk_widget_show (viewport8);
  gtk_container_add (GTK_CONTAINER (scrolledwindow44), viewport8);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport8), GTK_SHADOW_NONE);

  vbox81 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox81, "vbox81");
  gtk_widget_show (vbox81);
  gtk_container_add (GTK_CONTAINER (viewport8), vbox81);
  gtk_container_set_border_width (GTK_CONTAINER (vbox81), 2);

  frame140 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame140, "frame140");
  gtk_widget_show (frame140);
  gtk_box_pack_start (GTK_BOX (vbox81), frame140, TRUE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (frame140), 2);

  vbox145 = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox145, "vbox145");
  gtk_widget_show (vbox145);
  gtk_container_add (GTK_CONTAINER (frame140), vbox145);

  hbox9295 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox9295, "hbox9295");
  gtk_widget_show (hbox9295);
  gtk_box_pack_start (GTK_BOX (vbox145), hbox9295, FALSE, FALSE, 0);

  label922 = gtk_label_new (_("Property pattern:"));
  gtk_widget_set_name (label922, "label922");
  gtk_widget_show (label922);
  gtk_box_pack_start (GTK_BOX (hbox9295), label922, FALSE, TRUE, 0);
  gtk_misc_set_alignment (GTK_MISC (label922), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label922), 4, 0);

  entry_dbg_property_pattern = gtk_entry_new ();
  gtk_widget_set_name (entry_dbg_property_pattern, "entry_dbg_property_pattern");
  gtk_widget_show (entry_dbg_property_pattern);
  gtk_box_pack_start (GTK_BOX (hbox9295), entry_dbg_property_pattern, TRUE, TRUE, 0);

  button_dbg_property_refresh = gtk_button_new_from_stock ("gtk-refresh");
  gtk_widget_set_name (button_dbg_property_refresh, "button_dbg_property_refresh");
  gtk_widget_show (button_dbg_property_refresh);
  gtk_box_pack_start (GTK_BOX (hbox9295), button_dbg_property_refresh, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (button_dbg_property_refresh), 2);

  scrolledwindow78 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow78, "scrolledwindow78");
  gtk_widget_show (scrolledwindow78);
  gtk_box_pack_start (GTK_BOX (vbox145), scrolledwindow78, TRUE, TRUE, 0);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow78), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolledwindow78), GTK_SHADOW_IN);

  treeview_dbg_property = gtk_tree_view_new ();
  gtk_widget_set_name (treeview_dbg_property, "treeview_dbg_property");
  gtk_widget_show (treeview_dbg_property);
  gtk_container_add (GTK_CONTAINER (scrolledwindow78), treeview_dbg_property);
  gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (treeview_dbg_property), TRUE);

  hbox9301 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox9301, "hbox9301");
  gtk_widget_show (hbox9301);
  gtk_box_pack_start (GTK_BOX (vbox145), hbox9301, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (hbox9301), 2);

  label956 = gtk_label_new (_("Default value:"));
  gtk_widget_set_name (label956, "label956");
  gtk_widget_show (label956);
  gtk_box_pack_start (GTK_BOX (hbox9301), label956, FALSE, TRUE, 0);
  gtk_misc_set_alignment (GTK_MISC (label956), 0, 0.5);

  label_dbg_property_default = gtk_label_new (_("<no property selected>"));
  gtk_widget_set_name (label_dbg_property_default, "label_dbg_property_default");
  gtk_widget_show (label_dbg_property_default);
  gtk_box_pack_start (GTK_BOX (hbox9301), label_dbg_property_default, FALSE, FALSE, 0);
  gtk_misc_set_alignment (GTK_MISC (label_dbg_property_default), 0, 0.5);

  hbox9300 = gtk_hbox_new (FALSE, 4);
  gtk_widget_set_name (hbox9300, "hbox9300");
  gtk_widget_show (hbox9300);
  gtk_box_pack_start (GTK_BOX (vbox145), hbox9300, FALSE, TRUE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (hbox9300), 2);

  label955 = gtk_label_new (_("Min/Max:"));
  gtk_widget_set_name (label955, "label955");
  gtk_widget_show (label955);
  gtk_box_pack_start (GTK_BOX (hbox9300), label955, FALSE, TRUE, 0);
  gtk_misc_set_alignment (GTK_MISC (label955), 0, 0.5);

  label_dbg_property_limits = gtk_label_new (_("<no property selected>"));
  gtk_widget_set_name (label_dbg_property_limits, "label_dbg_property_limits");
  gtk_widget_show (label_dbg_property_limits);
  gtk_box_pack_start (GTK_BOX (hbox9300), label_dbg_property_limits, FALSE, FALSE, 0);
  gtk_misc_set_alignment (GTK_MISC (label_dbg_property_limits), 0, 0.5);

  label921 = gtk_label_new (_("Property browser"));
  gtk_widget_set_name (label921, "label921");
  gtk_widget_show (label921);
  gtk_frame_set_label_widget (GTK_FRAME (frame140), label921);

  frame_expert_unmapped = gtk_frame_new (NULL);
  gtk_widget_set_name (frame_expert_unmapped, "frame_expert_unmapped");
  gtk_widget_show (frame_expert_unmapped);
  gtk_box_pack_start (GTK_BOX (vbox81), frame_expert_unmapped, FALSE, TRUE, 0);

  table60 = gtk_table_new (4, 3, FALSE);
  gtk_widget_set_name (table60, "table60");
  gtk_widget_show (table60);
  gtk_container_add (GTK_CONTAINER (frame_expert_unmapped), table60);
  gtk_container_set_border_width (GTK_CONTAINER (table60), 2);
  gtk_table_set_row_spacings (GTK_TABLE (table60), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table60), 4);

  label870 = gtk_label_new (_(" "));
  gtk_widget_set_name (label870, "label870");
  gtk_widget_show (label870);
  gtk_table_attach (GTK_TABLE (table60), label870, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label870), 0, 0.5);

  label571 = gtk_label_new (_("Available physical memory:"));
  gtk_widget_set_name (label571, "label571");
  gtk_widget_show (label571);
  gtk_table_attach (GTK_TABLE (table60), label571, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label571), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label571), 4, 0);

  entry_sys_physmem = gtk_entry_new ();
  gtk_widget_set_name (entry_sys_physmem, "entry_sys_physmem");
  gtk_widget_show (entry_sys_physmem);
  gtk_table_attach (GTK_TABLE (table60), entry_sys_physmem, 1, 2, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_editable_set_editable (GTK_EDITABLE (entry_sys_physmem), FALSE);

  label1048 = gtk_label_new (_("Avg. downtime of this servent"));
  gtk_widget_set_name (label1048, "label1048");
  gtk_widget_show (label1048);
  gtk_table_attach (GTK_TABLE (table60), label1048, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label1048), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label1048), 4, 0);

  entry_average_servent_downtime = gtk_entry_new ();
  gtk_widget_set_name (entry_average_servent_downtime, "entry_average_servent_downtime");
  gtk_widget_show (entry_average_servent_downtime);
  gtk_table_attach (GTK_TABLE (table60), entry_average_servent_downtime, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_editable_set_editable (GTK_EDITABLE (entry_average_servent_downtime), FALSE);

  label564 = gtk_label_new (_("Avg. time between IP address changes:"));
  gtk_widget_set_name (label564, "label564");
  gtk_widget_show (label564);
  gtk_table_attach (GTK_TABLE (table60), label564, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label564), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label564), 4, 0);

  label566 = gtk_label_new (_("Avg. uptime of this servent:"));
  gtk_widget_set_name (label566, "label566");
  gtk_widget_show (label566);
  gtk_table_attach (GTK_TABLE (table60), label566, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label566), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label566), 4, 0);

  entry_average_ip_uptime = gtk_entry_new ();
  gtk_widget_set_name (entry_average_ip_uptime, "entry_average_ip_uptime");
  gtk_widget_show (entry_average_ip_uptime);
  gtk_table_attach (GTK_TABLE (table60), entry_average_ip_uptime, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_editable_set_editable (GTK_EDITABLE (entry_average_ip_uptime), FALSE);

  entry_average_servent_uptime = gtk_entry_new ();
  gtk_widget_set_name (entry_average_servent_uptime, "entry_average_servent_uptime");
  gtk_widget_show (entry_average_servent_uptime);
  gtk_table_attach (GTK_TABLE (table60), entry_average_servent_uptime, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_editable_set_editable (GTK_EDITABLE (entry_average_servent_uptime), FALSE);

  label558 = gtk_label_new (_("Diverse properties"));
  gtk_widget_set_name (label558, "label558");
  gtk_widget_show (label558);
  gtk_frame_set_label_widget (GTK_FRAME (frame_expert_unmapped), label558);

  g_signal_connect ((gpointer) entry_dbg_property_pattern, "activate",
                    G_CALLBACK (on_entry_dbg_property_pattern_activate),
                    NULL);
  g_signal_connect ((gpointer) button_dbg_property_refresh, "clicked",
                    G_CALLBACK (on_button_dbg_property_refresh_clicked),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (dlg_prefs_dbg_tab, dlg_prefs_dbg_tab, "dlg_prefs_dbg_tab");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dbg_tab, scrolledwindow44, "scrolledwindow44");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dbg_tab, viewport8, "viewport8");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dbg_tab, vbox81, "vbox81");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dbg_tab, frame140, "frame140");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dbg_tab, vbox145, "vbox145");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dbg_tab, hbox9295, "hbox9295");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dbg_tab, label922, "label922");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dbg_tab, entry_dbg_property_pattern, "entry_dbg_property_pattern");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dbg_tab, button_dbg_property_refresh, "button_dbg_property_refresh");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dbg_tab, scrolledwindow78, "scrolledwindow78");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dbg_tab, treeview_dbg_property, "treeview_dbg_property");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dbg_tab, hbox9301, "hbox9301");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dbg_tab, label956, "label956");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dbg_tab, label_dbg_property_default, "label_dbg_property_default");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dbg_tab, hbox9300, "hbox9300");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dbg_tab, label955, "label955");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dbg_tab, label_dbg_property_limits, "label_dbg_property_limits");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dbg_tab, label921, "label921");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dbg_tab, frame_expert_unmapped, "frame_expert_unmapped");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dbg_tab, table60, "table60");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dbg_tab, label870, "label870");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dbg_tab, label571, "label571");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dbg_tab, entry_sys_physmem, "entry_sys_physmem");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dbg_tab, label1048, "label1048");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dbg_tab, entry_average_servent_downtime, "entry_average_servent_downtime");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dbg_tab, label564, "label564");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dbg_tab, label566, "label566");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dbg_tab, entry_average_ip_uptime, "entry_average_ip_uptime");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dbg_tab, entry_average_servent_uptime, "entry_average_servent_uptime");
  GLADE_HOOKUP_OBJECT (dlg_prefs_dbg_tab, label558, "label558");

  return dlg_prefs_dbg_tab;
}

GtkWidget*
create_popup_search_list (void)
{
  GtkWidget *popup_search_list;
  GtkWidget *popup_search_list_edit_filters;
  GtkWidget *image2206;
  GtkWidget *separator21;
  GtkWidget *popup_search_list_stop;
  GtkWidget *image2207;
  GtkWidget *popup_search_list_resume;
  GtkWidget *image2208;
  GtkWidget *popup_search_list_restart;
  GtkWidget *image2209;
  GtkWidget *popup_search_list_duplicate;
  GtkWidget *image2210;
  GtkWidget *popup_search_list_close;
  GtkWidget *image2211;

  popup_search_list = gtk_menu_new ();
  gtk_widget_set_name (popup_search_list, "popup_search_list");

  popup_search_list_edit_filters = gtk_image_menu_item_new_with_mnemonic (_("_Edit filters"));
  gtk_widget_set_name (popup_search_list_edit_filters, "popup_search_list_edit_filters");
  gtk_widget_show (popup_search_list_edit_filters);
  gtk_container_add (GTK_CONTAINER (popup_search_list), popup_search_list_edit_filters);

  image2206 = gtk_image_new_from_stock ("gtk-properties", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image2206, "image2206");
  gtk_widget_show (image2206);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (popup_search_list_edit_filters), image2206);

  separator21 = gtk_separator_menu_item_new ();
  gtk_widget_set_name (separator21, "separator21");
  gtk_widget_show (separator21);
  gtk_container_add (GTK_CONTAINER (popup_search_list), separator21);
  gtk_widget_set_sensitive (separator21, FALSE);

  popup_search_list_stop = gtk_image_menu_item_new_with_mnemonic (_("_Stop"));
  gtk_widget_set_name (popup_search_list_stop, "popup_search_list_stop");
  gtk_widget_show (popup_search_list_stop);
  gtk_container_add (GTK_CONTAINER (popup_search_list), popup_search_list_stop);

  image2207 = gtk_image_new_from_stock ("gtk-stop", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image2207, "image2207");
  gtk_widget_show (image2207);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (popup_search_list_stop), image2207);

  popup_search_list_resume = gtk_image_menu_item_new_with_mnemonic (_("Resu_me"));
  gtk_widget_set_name (popup_search_list_resume, "popup_search_list_resume");
  gtk_widget_show (popup_search_list_resume);
  gtk_container_add (GTK_CONTAINER (popup_search_list), popup_search_list_resume);

  image2208 = gtk_image_new_from_stock ("gtk-go-forward", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image2208, "image2208");
  gtk_widget_show (image2208);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (popup_search_list_resume), image2208);

  popup_search_list_restart = gtk_image_menu_item_new_with_mnemonic (_("_Restart"));
  gtk_widget_set_name (popup_search_list_restart, "popup_search_list_restart");
  gtk_widget_show (popup_search_list_restart);
  gtk_container_add (GTK_CONTAINER (popup_search_list), popup_search_list_restart);

  image2209 = gtk_image_new_from_stock ("gtk-redo", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image2209, "image2209");
  gtk_widget_show (image2209);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (popup_search_list_restart), image2209);

  popup_search_list_duplicate = gtk_image_menu_item_new_with_mnemonic (_("_Duplicate"));
  gtk_widget_set_name (popup_search_list_duplicate, "popup_search_list_duplicate");
  gtk_widget_show (popup_search_list_duplicate);
  gtk_container_add (GTK_CONTAINER (popup_search_list), popup_search_list_duplicate);

  image2210 = gtk_image_new_from_stock ("gtk-copy", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image2210, "image2210");
  gtk_widget_show (image2210);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (popup_search_list_duplicate), image2210);

  popup_search_list_close = gtk_image_menu_item_new_with_mnemonic (_("Close"));
  gtk_widget_set_name (popup_search_list_close, "popup_search_list_close");
  gtk_widget_show (popup_search_list_close);
  gtk_container_add (GTK_CONTAINER (popup_search_list), popup_search_list_close);

  image2211 = gtk_image_new_from_stock ("gtk-close", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image2211, "image2211");
  gtk_widget_show (image2211);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (popup_search_list_close), image2211);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (popup_search_list, popup_search_list, "popup_search_list");
  GLADE_HOOKUP_OBJECT (popup_search_list, popup_search_list_edit_filters, "popup_search_list_edit_filters");
  GLADE_HOOKUP_OBJECT (popup_search_list, image2206, "image2206");
  GLADE_HOOKUP_OBJECT (popup_search_list, separator21, "separator21");
  GLADE_HOOKUP_OBJECT (popup_search_list, popup_search_list_stop, "popup_search_list_stop");
  GLADE_HOOKUP_OBJECT (popup_search_list, image2207, "image2207");
  GLADE_HOOKUP_OBJECT (popup_search_list, popup_search_list_resume, "popup_search_list_resume");
  GLADE_HOOKUP_OBJECT (popup_search_list, image2208, "image2208");
  GLADE_HOOKUP_OBJECT (popup_search_list, popup_search_list_restart, "popup_search_list_restart");
  GLADE_HOOKUP_OBJECT (popup_search_list, image2209, "image2209");
  GLADE_HOOKUP_OBJECT (popup_search_list, popup_search_list_duplicate, "popup_search_list_duplicate");
  GLADE_HOOKUP_OBJECT (popup_search_list, image2210, "image2210");
  GLADE_HOOKUP_OBJECT (popup_search_list, popup_search_list_close, "popup_search_list_close");
  GLADE_HOOKUP_OBJECT (popup_search_list, image2211, "image2211");

  return popup_search_list;
}

GtkWidget*
create_main_window_downloads_tab (void)
{
  GtkWidget *main_window_downloads_tab;
  GtkWidget *vbox142;
  GtkWidget *vpaned_fileinfo;
  GtkWidget *viewport478;
  GtkWidget *notebook_downloads;
  GtkWidget *empty_notebook_page;
  GtkWidget *label1023;
  GtkWidget *label1024;
  GtkWidget *scrolledwindow899;
  GtkWidget *viewport479;
  GtkWidget *vbox151;
  GtkWidget *table67;
  GtkWidget *label837;
  GtkWidget *frame105;
  GtkWidget *drawingarea_fi_progress;
  GtkWidget *notebook_downloads_info;
  GtkWidget *vbox106;
  GtkWidget *scrolledwindow88;
  GtkWidget *treeview_download_details;
  GtkWidget *label1012;
  GtkWidget *scrolledwindow72;
  GtkWidget *treeview_download_aliases;
  GtkWidget *label1013;
  GtkWidget *scrolledwindow89;
  GtkWidget *treeview_download_sources;
  GtkWidget *label1022;
  GtkWidget *frame147;
  GtkWidget *vbox154;
  GtkWidget *table115;
  GtkWidget *label334;
  GtkWidget *label1027;
  GtkWidget *entry_downloads_filter_regex;
  GtkWidget *entry_downloads_select_regex;
  GtkWidget *checkbutton_downloads_select_regex_case;
  GtkWidget *checkbutton_downloads_select_regex_invert;
  GtkWidget *checkbutton_downloads_filter_regex_invert;
  GtkWidget *checkbutton_downloads_filter_regex_case;
  GtkWidget *hbox9343;
  GtkWidget *label1028;
  GtkWidget *hbox261;
  GtkWidget *table95;
  GtkWidget *label64;
  GtkObject *spinbutton_max_downloads_adj;
  GtkWidget *spinbutton_max_downloads;
  GtkWidget *label831;
  GtkObject *spinbutton_mismatch_backout_adj;
  GtkWidget *spinbutton_mismatch_backout;
  GtkWidget *checkbutton_dl_remove_file_on_mismatch;
  GtkWidget *checkbutton_download_delete_aborted;
  GtkWidget *checkbutton_downloads_never_push;
  GtkWidget *label80;
  GtkWidget *label1009;
  GtkObject *spinbutton_max_host_downloads_adj;
  GtkWidget *spinbutton_max_host_downloads;
  GtkObject *spinbutton_max_file_downloads_adj;
  GtkWidget *spinbutton_max_file_downloads;
  GtkWidget *vbox129;
  GtkWidget *checkbutton_dl_clear_finished;
  GtkWidget *frame85;
  GtkWidget *vbox130;
  GtkWidget *checkbutton_dl_clear_complete;
  GtkWidget *checkbutton_dl_clear_failed;
  GtkWidget *checkbutton_dl_clear_unavailable;
  GtkWidget *label724;
  GtkWidget *label1014;
  GtkWidget *table53;
  GtkWidget *viewport475;
  GtkWidget *hbox235;
  GtkWidget *label1025;
  GtkWidget *label_fi_all_count;
  GtkWidget *label717;
  GtkWidget *label_fi_with_source_count;
  GtkWidget *label719;
  GtkWidget *label913;
  GtkWidget *viewport29;
  GtkWidget *hbox234;
  GtkWidget *label_dl_running_count;
  GtkWidget *label910;
  GtkWidget *label708;
  GtkWidget *label_dl_active_count;
  GtkWidget *label710;
  GtkWidget *label_dl_aqueued_count;
  GtkWidget *label712;
  GtkWidget *label909;
  GtkWidget *viewport28;
  GtkWidget *hbox212;
  GtkWidget *label_dl_queue_count;
  GtkWidget *label586;
  GtkWidget *label_dl_qalive_count;
  GtkWidget *label588;
  GtkWidget *label_dl_pqueued_count;
  GtkWidget *label714;
  GtkWidget *label1026;
  GtkWidget *togglebutton_queue_freeze;
  GtkWidget *alignment137;
  GtkWidget *table110;
  GtkWidget *vbox_queue_thaw;
  GtkWidget *hbox9334;
  GtkWidget *image1798;
  GtkWidget *label996;
  GtkWidget *vbox_queue_freeze;
  GtkWidget *hbox9335;
  GtkWidget *image1797;
  GtkWidget *label995;
  GtkWidget *button_downloads_clear_completed;
  GtkWidget *alignment150;
  GtkWidget *hbox9355;
  GtkWidget *image2295;
  GtkWidget *label1084;
  GtkTooltips *tooltips;

  tooltips = gtk_tooltips_new ();

  main_window_downloads_tab = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_widget_set_name (main_window_downloads_tab, "main_window_downloads_tab");
  gtk_widget_set_size_request (main_window_downloads_tab, 600, 400);

  vbox142 = gtk_vbox_new (FALSE, 3);
  gtk_widget_set_name (vbox142, "vbox142");
  gtk_widget_show (vbox142);
  gtk_container_add (GTK_CONTAINER (main_window_downloads_tab), vbox142);

  vpaned_fileinfo = gtk_vpaned_new ();
  gtk_widget_set_name (vpaned_fileinfo, "vpaned_fileinfo");
  gtk_widget_show (vpaned_fileinfo);
  gtk_box_pack_start (GTK_BOX (vbox142), vpaned_fileinfo, TRUE, TRUE, 0);
  gtk_paned_set_position (GTK_PANED (vpaned_fileinfo), 305);

  viewport478 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport478, "viewport478");
  gtk_widget_show (viewport478);
  gtk_paned_pack1 (GTK_PANED (vpaned_fileinfo), viewport478, FALSE, TRUE);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport478), GTK_SHADOW_NONE);

  notebook_downloads = gtk_notebook_new ();
  gtk_widget_set_name (notebook_downloads, "notebook_downloads");
  gtk_widget_show (notebook_downloads);
  gtk_container_add (GTK_CONTAINER (viewport478), notebook_downloads);
  gtk_notebook_set_tab_pos (GTK_NOTEBOOK (notebook_downloads), GTK_POS_BOTTOM);

  empty_notebook_page = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (empty_notebook_page);
  gtk_container_add (GTK_CONTAINER (notebook_downloads), empty_notebook_page);

  label1023 = gtk_label_new ("");
  gtk_widget_set_name (label1023, "label1023");
  gtk_widget_show (label1023);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_downloads), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_downloads), 0), label1023);

  empty_notebook_page = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (empty_notebook_page);
  gtk_container_add (GTK_CONTAINER (notebook_downloads), empty_notebook_page);

  label1024 = gtk_label_new ("");
  gtk_widget_set_name (label1024, "label1024");
  gtk_widget_show (label1024);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_downloads), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_downloads), 1), label1024);

  scrolledwindow899 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow899, "scrolledwindow899");
  gtk_widget_show (scrolledwindow899);
  gtk_paned_pack2 (GTK_PANED (vpaned_fileinfo), scrolledwindow899, TRUE, TRUE);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow899), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);

  viewport479 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport479, "viewport479");
  gtk_widget_show (viewport479);
  gtk_container_add (GTK_CONTAINER (scrolledwindow899), viewport479);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport479), GTK_SHADOW_NONE);

  vbox151 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox151, "vbox151");
  gtk_widget_show (vbox151);
  gtk_container_add (GTK_CONTAINER (viewport479), vbox151);

  table67 = gtk_table_new (1, 2, FALSE);
  gtk_widget_set_name (table67, "table67");
  gtk_widget_show (table67);
  gtk_box_pack_start (GTK_BOX (vbox151), table67, FALSE, TRUE, 0);
  gtk_table_set_row_spacings (GTK_TABLE (table67), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table67), 4);

  label837 = gtk_label_new (_("Progress:"));
  gtk_widget_set_name (label837, "label837");
  gtk_widget_show (label837);
  gtk_table_attach (GTK_TABLE (table67), label837, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label837), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label837), 4, 0);

  frame105 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame105, "frame105");
  gtk_widget_show (frame105);
  gtk_table_attach (GTK_TABLE (table67), frame105, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);
  gtk_frame_set_label_align (GTK_FRAME (frame105), 0, 0);

  drawingarea_fi_progress = gtk_drawing_area_new ();
  gtk_widget_set_name (drawingarea_fi_progress, "drawingarea_fi_progress");
  gtk_widget_show (drawingarea_fi_progress);
  gtk_container_add (GTK_CONTAINER (frame105), drawingarea_fi_progress);
  gtk_widget_set_size_request (drawingarea_fi_progress, -1, 14);
  gtk_tooltips_set_tip (tooltips, drawingarea_fi_progress, _("Shows visual information on the download progress. Green chunks have been downloaded, with the brighter green chunks touched during this session. Yellow chunks are active right now; these active chunks are also marked with a triangle. Red chunks have not been downloaded yet. The blue line indicates which parts of the file have been seen on the network in this session."), NULL);
  gtk_widget_set_events (drawingarea_fi_progress, GDK_ENTER_NOTIFY_MASK | GDK_LEAVE_NOTIFY_MASK);

  notebook_downloads_info = gtk_notebook_new ();
  gtk_widget_set_name (notebook_downloads_info, "notebook_downloads_info");
  gtk_widget_show (notebook_downloads_info);
  gtk_box_pack_start (GTK_BOX (vbox151), notebook_downloads_info, TRUE, TRUE, 0);
  gtk_notebook_set_tab_pos (GTK_NOTEBOOK (notebook_downloads_info), GTK_POS_BOTTOM);
  gtk_notebook_set_scrollable (GTK_NOTEBOOK (notebook_downloads_info), TRUE);

  vbox106 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox106, "vbox106");
  gtk_widget_show (vbox106);
  gtk_container_add (GTK_CONTAINER (notebook_downloads_info), vbox106);

  scrolledwindow88 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow88, "scrolledwindow88");
  gtk_widget_show (scrolledwindow88);
  gtk_box_pack_start (GTK_BOX (vbox106), scrolledwindow88, TRUE, TRUE, 0);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow88), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolledwindow88), GTK_SHADOW_ETCHED_IN);

  treeview_download_details = gtk_tree_view_new ();
  gtk_widget_set_name (treeview_download_details, "treeview_download_details");
  gtk_widget_show (treeview_download_details);
  gtk_container_add (GTK_CONTAINER (scrolledwindow88), treeview_download_details);
  gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (treeview_download_details), FALSE);
  gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (treeview_download_details), TRUE);
  gtk_tree_view_set_enable_search (GTK_TREE_VIEW (treeview_download_details), FALSE);

  label1012 = gtk_label_new (_("Details"));
  gtk_widget_set_name (label1012, "label1012");
  gtk_widget_show (label1012);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_downloads_info), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_downloads_info), 0), label1012);

  scrolledwindow72 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow72, "scrolledwindow72");
  gtk_widget_show (scrolledwindow72);
  gtk_container_add (GTK_CONTAINER (notebook_downloads_info), scrolledwindow72);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow72), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolledwindow72), GTK_SHADOW_ETCHED_IN);

  treeview_download_aliases = gtk_tree_view_new ();
  gtk_widget_set_name (treeview_download_aliases, "treeview_download_aliases");
  gtk_widget_show (treeview_download_aliases);
  gtk_container_add (GTK_CONTAINER (scrolledwindow72), treeview_download_aliases);
  gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (treeview_download_aliases), FALSE);
  gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (treeview_download_aliases), TRUE);

  label1013 = gtk_label_new (_("Aliases"));
  gtk_widget_set_name (label1013, "label1013");
  gtk_widget_show (label1013);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_downloads_info), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_downloads_info), 1), label1013);

  scrolledwindow89 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow89, "scrolledwindow89");
  gtk_widget_show (scrolledwindow89);
  gtk_container_add (GTK_CONTAINER (notebook_downloads_info), scrolledwindow89);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow89), GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS);
  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolledwindow89), GTK_SHADOW_IN);

  treeview_download_sources = gtk_tree_view_new ();
  gtk_widget_set_name (treeview_download_sources, "treeview_download_sources");
  gtk_widget_show (treeview_download_sources);
  gtk_container_add (GTK_CONTAINER (scrolledwindow89), treeview_download_sources);
  gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (treeview_download_sources), TRUE);
  gtk_tree_view_set_enable_search (GTK_TREE_VIEW (treeview_download_sources), FALSE);

  label1022 = gtk_label_new (_("Sources"));
  gtk_widget_set_name (label1022, "label1022");
  gtk_widget_show (label1022);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_downloads_info), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_downloads_info), 2), label1022);

  frame147 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame147, "frame147");
  gtk_widget_show (frame147);
  gtk_container_add (GTK_CONTAINER (notebook_downloads_info), frame147);

  vbox154 = gtk_vbox_new (FALSE, 4);
  gtk_widget_set_name (vbox154, "vbox154");
  gtk_widget_show (vbox154);
  gtk_container_add (GTK_CONTAINER (frame147), vbox154);

  table115 = gtk_table_new (2, 4, FALSE);
  gtk_widget_set_name (table115, "table115");
  gtk_widget_show (table115);
  gtk_box_pack_start (GTK_BOX (vbox154), table115, FALSE, TRUE, 0);
  gtk_table_set_col_spacings (GTK_TABLE (table115), 4);

  label334 = gtk_label_new (_("Select files by regex"));
  gtk_widget_set_name (label334, "label334");
  gtk_widget_show (label334);
  gtk_table_attach (GTK_TABLE (table115), label334, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label334), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label334), 4, 0);

  label1027 = gtk_label_new (_("Filter files by regex"));
  gtk_widget_set_name (label1027, "label1027");
  gtk_widget_show (label1027);
  gtk_table_attach (GTK_TABLE (table115), label1027, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label1027), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label1027), 4, 0);

  entry_downloads_filter_regex = gtk_entry_new ();
  gtk_widget_set_name (entry_downloads_filter_regex, "entry_downloads_filter_regex");
  gtk_widget_show (entry_downloads_filter_regex);
  gtk_table_attach (GTK_TABLE (table115), entry_downloads_filter_regex, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  entry_downloads_select_regex = gtk_entry_new ();
  gtk_widget_set_name (entry_downloads_select_regex, "entry_downloads_select_regex");
  gtk_widget_show (entry_downloads_select_regex);
  gtk_table_attach (GTK_TABLE (table115), entry_downloads_select_regex, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_downloads_select_regex_case = gtk_check_button_new_with_mnemonic (_("case-sensitive"));
  gtk_widget_set_name (checkbutton_downloads_select_regex_case, "checkbutton_downloads_select_regex_case");
  gtk_widget_show (checkbutton_downloads_select_regex_case);
  gtk_table_attach (GTK_TABLE (table115), checkbutton_downloads_select_regex_case, 2, 3, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_downloads_select_regex_invert = gtk_check_button_new_with_mnemonic (_("invert"));
  gtk_widget_set_name (checkbutton_downloads_select_regex_invert, "checkbutton_downloads_select_regex_invert");
  gtk_widget_show (checkbutton_downloads_select_regex_invert);
  gtk_table_attach (GTK_TABLE (table115), checkbutton_downloads_select_regex_invert, 3, 4, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_downloads_filter_regex_invert = gtk_check_button_new_with_mnemonic (_("invert"));
  gtk_widget_set_name (checkbutton_downloads_filter_regex_invert, "checkbutton_downloads_filter_regex_invert");
  gtk_widget_show (checkbutton_downloads_filter_regex_invert);
  gtk_table_attach (GTK_TABLE (table115), checkbutton_downloads_filter_regex_invert, 3, 4, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_downloads_filter_regex_case = gtk_check_button_new_with_mnemonic (_("case-sensitive"));
  gtk_widget_set_name (checkbutton_downloads_filter_regex_case, "checkbutton_downloads_filter_regex_case");
  gtk_widget_show (checkbutton_downloads_filter_regex_case);
  gtk_table_attach (GTK_TABLE (table115), checkbutton_downloads_filter_regex_case, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  hbox9343 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox9343, "hbox9343");
  gtk_widget_show (hbox9343);
  gtk_box_pack_start (GTK_BOX (vbox154), hbox9343, FALSE, TRUE, 0);

  label1028 = gtk_label_new (_("Tools"));
  gtk_widget_set_name (label1028, "label1028");
  gtk_widget_show (label1028);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_downloads_info), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_downloads_info), 3), label1028);

  hbox261 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox261, "hbox261");
  gtk_widget_show (hbox261);
  gtk_container_add (GTK_CONTAINER (notebook_downloads_info), hbox261);
  gtk_container_set_border_width (GTK_CONTAINER (hbox261), 2);

  table95 = gtk_table_new (4, 4, FALSE);
  gtk_widget_set_name (table95, "table95");
  gtk_widget_show (table95);
  gtk_box_pack_start (GTK_BOX (hbox261), table95, FALSE, TRUE, 0);
  gtk_table_set_row_spacings (GTK_TABLE (table95), 2);
  gtk_table_set_col_spacings (GTK_TABLE (table95), 4);

  label64 = gtk_label_new (_("Max. simultaneous downloads"));
  gtk_widget_set_name (label64, "label64");
  gtk_widget_show (label64);
  gtk_table_attach (GTK_TABLE (table95), label64, 0, 1, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label64), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label64), 0, 0.5);

  spinbutton_max_downloads_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 0);
  spinbutton_max_downloads = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_max_downloads_adj), 1, 0);
  gtk_widget_set_name (spinbutton_max_downloads, "spinbutton_max_downloads");
  gtk_widget_show (spinbutton_max_downloads);
  gtk_table_attach (GTK_TABLE (table95), spinbutton_max_downloads, 1, 2, 1, 2,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_max_downloads), TRUE);

  label831 = gtk_label_new (_("Bytes to back off on mismatch"));
  gtk_widget_set_name (label831, "label831");
  gtk_widget_show (label831);
  gtk_table_attach (GTK_TABLE (table95), label831, 0, 1, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label831), 0, 0.5);

  spinbutton_mismatch_backout_adj = gtk_adjustment_new (50000, 0, 250000, 1000, 10000, 0);
  spinbutton_mismatch_backout = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_mismatch_backout_adj), 100, 0);
  gtk_widget_set_name (spinbutton_mismatch_backout, "spinbutton_mismatch_backout");
  gtk_widget_show (spinbutton_mismatch_backout);
  gtk_table_attach (GTK_TABLE (table95), spinbutton_mismatch_backout, 1, 2, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_mismatch_backout), TRUE);

  checkbutton_dl_remove_file_on_mismatch = gtk_check_button_new_with_mnemonic (_("Delete file on mismatch"));
  gtk_widget_set_name (checkbutton_dl_remove_file_on_mismatch, "checkbutton_dl_remove_file_on_mismatch");
  gtk_widget_show (checkbutton_dl_remove_file_on_mismatch);
  gtk_table_attach (GTK_TABLE (table95), checkbutton_dl_remove_file_on_mismatch, 2, 3, 3, 4,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_download_delete_aborted = gtk_check_button_new_with_mnemonic (_("Delete file on abort"));
  gtk_widget_set_name (checkbutton_download_delete_aborted, "checkbutton_download_delete_aborted");
  gtk_widget_show (checkbutton_download_delete_aborted);
  gtk_table_attach (GTK_TABLE (table95), checkbutton_download_delete_aborted, 2, 3, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  checkbutton_downloads_never_push = gtk_check_button_new_with_mnemonic (_("Never send a push request"));
  gtk_widget_set_name (checkbutton_downloads_never_push, "checkbutton_downloads_never_push");
  gtk_widget_show (checkbutton_downloads_never_push);
  gtk_table_attach (GTK_TABLE (table95), checkbutton_downloads_never_push, 2, 3, 1, 2,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  label80 = gtk_label_new (_("Max. downloads from single host"));
  gtk_widget_set_name (label80, "label80");
  gtk_widget_show (label80);
  gtk_table_attach (GTK_TABLE (table95), label80, 0, 1, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label80), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label80), 0, 0.5);

  label1009 = gtk_label_new (_("Max. simultaneous downloads per file"));
  gtk_widget_set_name (label1009, "label1009");
  gtk_widget_show (label1009);
  gtk_table_attach (GTK_TABLE (table95), label1009, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_label_set_justify (GTK_LABEL (label1009), GTK_JUSTIFY_CENTER);
  gtk_misc_set_alignment (GTK_MISC (label1009), 0, 0.5);

  spinbutton_max_host_downloads_adj = gtk_adjustment_new (1, 1, 100, 1, 10, 0);
  spinbutton_max_host_downloads = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_max_host_downloads_adj), 1, 0);
  gtk_widget_set_name (spinbutton_max_host_downloads, "spinbutton_max_host_downloads");
  gtk_widget_show (spinbutton_max_host_downloads);
  gtk_table_attach (GTK_TABLE (table95), spinbutton_max_host_downloads, 1, 2, 2, 3,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_max_host_downloads), TRUE);

  spinbutton_max_file_downloads_adj = gtk_adjustment_new (1, 0, 100, 1, 10, 0);
  spinbutton_max_file_downloads = gtk_spin_button_new (GTK_ADJUSTMENT (spinbutton_max_file_downloads_adj), 1, 0);
  gtk_widget_set_name (spinbutton_max_file_downloads, "spinbutton_max_file_downloads");
  gtk_widget_show (spinbutton_max_file_downloads);
  gtk_table_attach (GTK_TABLE (table95), spinbutton_max_file_downloads, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbutton_max_file_downloads), TRUE);

  vbox129 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox129, "vbox129");
  gtk_widget_show (vbox129);
  gtk_box_pack_start (GTK_BOX (hbox261), vbox129, FALSE, TRUE, 0);

  checkbutton_dl_clear_finished = gtk_check_button_new_with_mnemonic (_("Automatically clear finished files"));
  gtk_widget_set_name (checkbutton_dl_clear_finished, "checkbutton_dl_clear_finished");
  gtk_widget_show (checkbutton_dl_clear_finished);
  gtk_box_pack_start (GTK_BOX (vbox129), checkbutton_dl_clear_finished, FALSE, FALSE, 0);

  frame85 = gtk_frame_new (NULL);
  gtk_widget_set_name (frame85, "frame85");
  gtk_widget_show (frame85);
  gtk_box_pack_start (GTK_BOX (vbox129), frame85, FALSE, TRUE, 0);

  vbox130 = gtk_vbox_new (FALSE, 2);
  gtk_widget_set_name (vbox130, "vbox130");
  gtk_widget_show (vbox130);
  gtk_container_add (GTK_CONTAINER (frame85), vbox130);
  gtk_container_set_border_width (GTK_CONTAINER (vbox130), 2);

  checkbutton_dl_clear_complete = gtk_check_button_new_with_mnemonic (_("completed"));
  gtk_widget_set_name (checkbutton_dl_clear_complete, "checkbutton_dl_clear_complete");
  gtk_widget_show (checkbutton_dl_clear_complete);
  gtk_box_pack_start (GTK_BOX (vbox130), checkbutton_dl_clear_complete, FALSE, FALSE, 0);

  checkbutton_dl_clear_failed = gtk_check_button_new_with_mnemonic (_("failed"));
  gtk_widget_set_name (checkbutton_dl_clear_failed, "checkbutton_dl_clear_failed");
  gtk_widget_show (checkbutton_dl_clear_failed);
  gtk_box_pack_start (GTK_BOX (vbox130), checkbutton_dl_clear_failed, FALSE, FALSE, 0);

  checkbutton_dl_clear_unavailable = gtk_check_button_new_with_mnemonic (_("unavailable"));
  gtk_widget_set_name (checkbutton_dl_clear_unavailable, "checkbutton_dl_clear_unavailable");
  gtk_widget_show (checkbutton_dl_clear_unavailable);
  gtk_box_pack_start (GTK_BOX (vbox130), checkbutton_dl_clear_unavailable, FALSE, FALSE, 0);

  label724 = gtk_label_new (_("Automatically clear sources when..."));
  gtk_widget_set_name (label724, "label724");
  gtk_widget_show (label724);
  gtk_frame_set_label_widget (GTK_FRAME (frame85), label724);

  label1014 = gtk_label_new (_("Settings"));
  gtk_widget_set_name (label1014, "label1014");
  gtk_widget_show (label1014);
  gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook_downloads_info), gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook_downloads_info), 4), label1014);

  table53 = gtk_table_new (1, 8, FALSE);
  gtk_widget_set_name (table53, "table53");
  gtk_widget_show (table53);
  gtk_box_pack_start (GTK_BOX (vbox142), table53, FALSE, TRUE, 0);
  gtk_table_set_row_spacings (GTK_TABLE (table53), 2);

  viewport475 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport475, "viewport475");
  gtk_widget_show (viewport475);
  gtk_table_attach (GTK_TABLE (table53), viewport475, 2, 4, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL), 0, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport475), GTK_SHADOW_ETCHED_IN);

  hbox235 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox235, "hbox235");
  gtk_widget_show (hbox235);
  gtk_container_add (GTK_CONTAINER (viewport475), hbox235);

  label1025 = gtk_label_new ("");
  gtk_widget_set_name (label1025, "label1025");
  gtk_widget_show (label1025);
  gtk_box_pack_start (GTK_BOX (hbox235), label1025, FALSE, FALSE, 0);
  gtk_misc_set_padding (GTK_MISC (label1025), 4, 0);

  label_fi_all_count = gtk_label_new ("[all count]");
  gtk_widget_set_name (label_fi_all_count, "label_fi_all_count");
  gtk_widget_show (label_fi_all_count);
  gtk_box_pack_start (GTK_BOX (hbox235), label_fi_all_count, FALSE, TRUE, 0);

  label717 = gtk_label_new (_(" registered, "));
  gtk_widget_set_name (label717, "label717");
  gtk_widget_show (label717);
  gtk_box_pack_start (GTK_BOX (hbox235), label717, FALSE, TRUE, 0);

  label_fi_with_source_count = gtk_label_new ("[with source count]");
  gtk_widget_set_name (label_fi_with_source_count, "label_fi_with_source_count");
  gtk_widget_show (label_fi_with_source_count);
  gtk_box_pack_start (GTK_BOX (hbox235), label_fi_with_source_count, FALSE, TRUE, 0);

  label719 = gtk_label_new (_(" with sources"));
  gtk_widget_set_name (label719, "label719");
  gtk_widget_show (label719);
  gtk_box_pack_start (GTK_BOX (hbox235), label719, FALSE, TRUE, 0);

  label913 = gtk_label_new ("");
  gtk_widget_set_name (label913, "label913");
  gtk_widget_show (label913);
  gtk_box_pack_start (GTK_BOX (hbox235), label913, FALSE, TRUE, 4);

  viewport29 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport29, "viewport29");
  gtk_widget_show (viewport29);
  gtk_table_attach (GTK_TABLE (table53), viewport29, 4, 6, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL), 0, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport29), GTK_SHADOW_ETCHED_IN);

  hbox234 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox234, "hbox234");
  gtk_widget_show (hbox234);
  gtk_container_add (GTK_CONTAINER (viewport29), hbox234);

  label_dl_running_count = gtk_label_new ("[running]");
  gtk_widget_set_name (label_dl_running_count, "label_dl_running_count");
  gtk_widget_show (label_dl_running_count);
  gtk_box_pack_start (GTK_BOX (hbox234), label_dl_running_count, TRUE, TRUE, 0);
  gtk_label_set_justify (GTK_LABEL (label_dl_running_count), GTK_JUSTIFY_RIGHT);
  gtk_misc_set_alignment (GTK_MISC (label_dl_running_count), 1, 0.5);
  gtk_misc_set_padding (GTK_MISC (label_dl_running_count), 5, 0);

  label910 = gtk_label_new ("");
  gtk_widget_set_name (label910, "label910");
  gtk_widget_show (label910);
  gtk_box_pack_start (GTK_BOX (hbox234), label910, FALSE, FALSE, 4);

  label708 = gtk_label_new ("(");
  gtk_widget_set_name (label708, "label708");
  gtk_widget_show (label708);
  gtk_box_pack_start (GTK_BOX (hbox234), label708, FALSE, FALSE, 0);
  gtk_label_set_justify (GTK_LABEL (label708), GTK_JUSTIFY_RIGHT);
  gtk_misc_set_alignment (GTK_MISC (label708), 1, 0.5);

  label_dl_active_count = gtk_label_new ("[active]");
  gtk_widget_set_name (label_dl_active_count, "label_dl_active_count");
  gtk_widget_show (label_dl_active_count);
  gtk_box_pack_start (GTK_BOX (hbox234), label_dl_active_count, FALSE, FALSE, 0);
  gtk_label_set_justify (GTK_LABEL (label_dl_active_count), GTK_JUSTIFY_RIGHT);
  gtk_misc_set_alignment (GTK_MISC (label_dl_active_count), 1, 0.5);

  label710 = gtk_label_new (_(", "));
  gtk_widget_set_name (label710, "label710");
  gtk_widget_show (label710);
  gtk_box_pack_start (GTK_BOX (hbox234), label710, FALSE, FALSE, 0);
  gtk_label_set_justify (GTK_LABEL (label710), GTK_JUSTIFY_RIGHT);

  label_dl_aqueued_count = gtk_label_new ("[aqueued]");
  gtk_widget_set_name (label_dl_aqueued_count, "label_dl_aqueued_count");
  gtk_widget_show (label_dl_aqueued_count);
  gtk_box_pack_start (GTK_BOX (hbox234), label_dl_aqueued_count, FALSE, FALSE, 0);
  gtk_label_set_justify (GTK_LABEL (label_dl_aqueued_count), GTK_JUSTIFY_RIGHT);

  label712 = gtk_label_new (")");
  gtk_widget_set_name (label712, "label712");
  gtk_widget_show (label712);
  gtk_box_pack_start (GTK_BOX (hbox234), label712, FALSE, FALSE, 0);
  gtk_label_set_justify (GTK_LABEL (label712), GTK_JUSTIFY_RIGHT);
  gtk_misc_set_alignment (GTK_MISC (label712), 0, 0.5);

  label909 = gtk_label_new ("");
  gtk_widget_set_name (label909, "label909");
  gtk_widget_show (label909);
  gtk_box_pack_start (GTK_BOX (hbox234), label909, FALSE, FALSE, 0);
  gtk_misc_set_padding (GTK_MISC (label909), 4, 0);

  viewport28 = gtk_viewport_new (NULL, NULL);
  gtk_widget_set_name (viewport28, "viewport28");
  gtk_widget_show (viewport28);
  gtk_table_attach (GTK_TABLE (table53), viewport28, 6, 7, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_SHRINK | GTK_FILL),
                    (GtkAttachOptions) (GTK_SHRINK | GTK_FILL), 0, 0);
  gtk_viewport_set_shadow_type (GTK_VIEWPORT (viewport28), GTK_SHADOW_ETCHED_IN);

  hbox212 = gtk_hbox_new (FALSE, 0);
  gtk_widget_set_name (hbox212, "hbox212");
  gtk_widget_show (hbox212);
  gtk_container_add (GTK_CONTAINER (viewport28), hbox212);
  gtk_container_set_border_width (GTK_CONTAINER (hbox212), 2);

  label_dl_queue_count = gtk_label_new ("[queued downloads]");
  gtk_widget_set_name (label_dl_queue_count, "label_dl_queue_count");
  gtk_widget_show (label_dl_queue_count);
  gtk_box_pack_start (GTK_BOX (hbox212), label_dl_queue_count, TRUE, TRUE, 0);
  gtk_misc_set_alignment (GTK_MISC (label_dl_queue_count), 1, 0.5);

  label586 = gtk_label_new (_(" queued ("));
  gtk_widget_set_name (label586, "label586");
  gtk_widget_show (label586);
  gtk_box_pack_start (GTK_BOX (hbox212), label586, FALSE, FALSE, 0);

  label_dl_qalive_count = gtk_label_new ("[hosts alive]");
  gtk_widget_set_name (label_dl_qalive_count, "label_dl_qalive_count");
  gtk_widget_show (label_dl_qalive_count);
  gtk_box_pack_start (GTK_BOX (hbox212), label_dl_qalive_count, FALSE, FALSE, 0);

  label588 = gtk_label_new (_(" alive with "));
  gtk_widget_set_name (label588, "label588");
  gtk_widget_show (label588);
  gtk_box_pack_start (GTK_BOX (hbox212), label588, FALSE, FALSE, 0);

  label_dl_pqueued_count = gtk_label_new ("[pqueued]");
  gtk_widget_set_name (label_dl_pqueued_count, "label_dl_pqueued_count");
  gtk_widget_show (label_dl_pqueued_count);
  gtk_box_pack_start (GTK_BOX (hbox212), label_dl_pqueued_count, FALSE, FALSE, 0);

  label714 = gtk_label_new (_(" passive)"));
  gtk_widget_set_name (label714, "label714");
  gtk_widget_show (label714);
  gtk_box_pack_start (GTK_BOX (hbox212), label714, FALSE, FALSE, 0);

  label1026 = gtk_label_new ("");
  gtk_widget_set_name (label1026, "label1026");
  gtk_widget_show (label1026);
  gtk_table_attach (GTK_TABLE (table53), label1026, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_misc_set_alignment (GTK_MISC (label1026), 0, 0.5);
  gtk_misc_set_padding (GTK_MISC (label1026), 2, 0);

  togglebutton_queue_freeze = gtk_toggle_button_new ();
  gtk_widget_set_name (togglebutton_queue_freeze, "togglebutton_queue_freeze");
  gtk_widget_show (togglebutton_queue_freeze);
  gtk_table_attach (GTK_TABLE (table53), togglebutton_queue_freeze, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);

  alignment137 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment137, "alignment137");
  gtk_widget_show (alignment137);
  gtk_container_add (GTK_CONTAINER (togglebutton_queue_freeze), alignment137);

  table110 = gtk_table_new (1, 2, FALSE);
  gtk_widget_set_name (table110, "table110");
  gtk_widget_show (table110);
  gtk_container_add (GTK_CONTAINER (alignment137), table110);

  vbox_queue_thaw = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox_queue_thaw, "vbox_queue_thaw");
  gtk_table_attach (GTK_TABLE (table110), vbox_queue_thaw, 1, 2, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  hbox9334 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox9334, "hbox9334");
  gtk_widget_show (hbox9334);
  gtk_box_pack_start (GTK_BOX (vbox_queue_thaw), hbox9334, FALSE, TRUE, 0);

  image1798 = gtk_image_new_from_stock ("gtk-refresh", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image1798, "image1798");
  gtk_widget_show (image1798);
  gtk_box_pack_start (GTK_BOX (hbox9334), image1798, FALSE, TRUE, 0);

  label996 = gtk_label_new_with_mnemonic (_("Thaw queue"));
  gtk_widget_set_name (label996, "label996");
  gtk_widget_show (label996);
  gtk_box_pack_start (GTK_BOX (hbox9334), label996, FALSE, TRUE, 0);

  vbox_queue_freeze = gtk_vbox_new (FALSE, 0);
  gtk_widget_set_name (vbox_queue_freeze, "vbox_queue_freeze");
  gtk_widget_show (vbox_queue_freeze);
  gtk_table_attach (GTK_TABLE (table110), vbox_queue_freeze, 0, 1, 0, 1,
                    (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
                    (GtkAttachOptions) (GTK_FILL), 0, 0);

  hbox9335 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox9335, "hbox9335");
  gtk_widget_show (hbox9335);
  gtk_box_pack_start (GTK_BOX (vbox_queue_freeze), hbox9335, FALSE, TRUE, 0);

  image1797 = gtk_image_new_from_stock ("gtk-dialog-error", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image1797, "image1797");
  gtk_widget_show (image1797);
  gtk_box_pack_start (GTK_BOX (hbox9335), image1797, FALSE, TRUE, 0);

  label995 = gtk_label_new_with_mnemonic (_("Freeze queue"));
  gtk_widget_set_name (label995, "label995");
  gtk_widget_show (label995);
  gtk_box_pack_start (GTK_BOX (hbox9335), label995, FALSE, TRUE, 0);

  button_downloads_clear_completed = gtk_button_new ();
  gtk_widget_set_name (button_downloads_clear_completed, "button_downloads_clear_completed");
  gtk_widget_show (button_downloads_clear_completed);
  gtk_table_attach (GTK_TABLE (table53), button_downloads_clear_completed, 7, 8, 0, 1,
                    (GtkAttachOptions) (GTK_FILL),
                    (GtkAttachOptions) (0), 0, 0);
  gtk_container_set_border_width (GTK_CONTAINER (button_downloads_clear_completed), 2);
  gtk_widget_set_sensitive (button_downloads_clear_completed, FALSE);
  gtk_tooltips_set_tip (tooltips, button_downloads_clear_completed, _("Remove completed downloads from list"), NULL);

  alignment150 = gtk_alignment_new (0.5, 0.5, 0, 0);
  gtk_widget_set_name (alignment150, "alignment150");
  gtk_widget_show (alignment150);
  gtk_container_add (GTK_CONTAINER (button_downloads_clear_completed), alignment150);

  hbox9355 = gtk_hbox_new (FALSE, 2);
  gtk_widget_set_name (hbox9355, "hbox9355");
  gtk_widget_show (hbox9355);
  gtk_container_add (GTK_CONTAINER (alignment150), hbox9355);

  image2295 = gtk_image_new_from_stock ("gtk-clear", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image2295, "image2295");
  gtk_widget_show (image2295);
  gtk_box_pack_start (GTK_BOX (hbox9355), image2295, FALSE, FALSE, 0);

  label1084 = gtk_label_new_with_mnemonic (_("_Clear completed"));
  gtk_widget_set_name (label1084, "label1084");
  gtk_widget_show (label1084);
  gtk_box_pack_start (GTK_BOX (hbox9355), label1084, FALSE, FALSE, 0);

  g_signal_connect ((gpointer) drawingarea_fi_progress, "realize",
                    G_CALLBACK (on_drawingarea_fi_progress_realize),
                    NULL);
  g_signal_connect ((gpointer) drawingarea_fi_progress, "expose_event",
                    G_CALLBACK (on_drawingarea_fi_progress_expose_event),
                    NULL);
  g_signal_connect ((gpointer) entry_downloads_filter_regex, "activate",
                    G_CALLBACK (on_entry_downloads_filter_regex_activate),
                    NULL);
  g_signal_connect ((gpointer) entry_downloads_select_regex, "activate",
                    G_CALLBACK (on_entry_downloads_select_regex_activate),
                    NULL);
  g_signal_connect ((gpointer) checkbutton_downloads_select_regex_case, "toggled",
                    G_CALLBACK (on_checkbutton_downloads_select_regex_case_toggled),
                    NULL);
  g_signal_connect ((gpointer) checkbutton_downloads_select_regex_invert, "toggled",
                    G_CALLBACK (on_checkbutton_downloads_select_regex_invert_toggled),
                    NULL);
  g_signal_connect ((gpointer) checkbutton_downloads_filter_regex_invert, "toggled",
                    G_CALLBACK (on_checkbutton_downloads_filter_regex_invert_toggled),
                    NULL);
  g_signal_connect ((gpointer) checkbutton_downloads_filter_regex_case, "toggled",
                    G_CALLBACK (on_checkbutton_downloads_filter_regex_case_toggled),
                    NULL);
  g_signal_connect ((gpointer) togglebutton_queue_freeze, "toggled",
                    G_CALLBACK (on_togglebutton_queue_freeze_toggled),
                    NULL);
  g_signal_connect ((gpointer) button_downloads_clear_completed, "clicked",
                    G_CALLBACK (on_button_downloads_clear_completed_clicked),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (main_window_downloads_tab, main_window_downloads_tab, "main_window_downloads_tab");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, vbox142, "vbox142");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, vpaned_fileinfo, "vpaned_fileinfo");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, viewport478, "viewport478");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, notebook_downloads, "notebook_downloads");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, label1023, "label1023");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, label1024, "label1024");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, scrolledwindow899, "scrolledwindow899");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, viewport479, "viewport479");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, vbox151, "vbox151");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, table67, "table67");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, label837, "label837");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, frame105, "frame105");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, drawingarea_fi_progress, "drawingarea_fi_progress");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, notebook_downloads_info, "notebook_downloads_info");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, vbox106, "vbox106");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, scrolledwindow88, "scrolledwindow88");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, treeview_download_details, "treeview_download_details");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, label1012, "label1012");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, scrolledwindow72, "scrolledwindow72");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, treeview_download_aliases, "treeview_download_aliases");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, label1013, "label1013");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, scrolledwindow89, "scrolledwindow89");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, treeview_download_sources, "treeview_download_sources");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, label1022, "label1022");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, frame147, "frame147");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, vbox154, "vbox154");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, table115, "table115");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, label334, "label334");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, label1027, "label1027");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, entry_downloads_filter_regex, "entry_downloads_filter_regex");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, entry_downloads_select_regex, "entry_downloads_select_regex");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, checkbutton_downloads_select_regex_case, "checkbutton_downloads_select_regex_case");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, checkbutton_downloads_select_regex_invert, "checkbutton_downloads_select_regex_invert");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, checkbutton_downloads_filter_regex_invert, "checkbutton_downloads_filter_regex_invert");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, checkbutton_downloads_filter_regex_case, "checkbutton_downloads_filter_regex_case");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, hbox9343, "hbox9343");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, label1028, "label1028");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, hbox261, "hbox261");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, table95, "table95");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, label64, "label64");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, spinbutton_max_downloads, "spinbutton_max_downloads");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, label831, "label831");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, spinbutton_mismatch_backout, "spinbutton_mismatch_backout");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, checkbutton_dl_remove_file_on_mismatch, "checkbutton_dl_remove_file_on_mismatch");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, checkbutton_download_delete_aborted, "checkbutton_download_delete_aborted");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, checkbutton_downloads_never_push, "checkbutton_downloads_never_push");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, label80, "label80");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, label1009, "label1009");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, spinbutton_max_host_downloads, "spinbutton_max_host_downloads");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, spinbutton_max_file_downloads, "spinbutton_max_file_downloads");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, vbox129, "vbox129");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, checkbutton_dl_clear_finished, "checkbutton_dl_clear_finished");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, frame85, "frame85");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, vbox130, "vbox130");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, checkbutton_dl_clear_complete, "checkbutton_dl_clear_complete");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, checkbutton_dl_clear_failed, "checkbutton_dl_clear_failed");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, checkbutton_dl_clear_unavailable, "checkbutton_dl_clear_unavailable");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, label724, "label724");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, label1014, "label1014");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, table53, "table53");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, viewport475, "viewport475");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, hbox235, "hbox235");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, label1025, "label1025");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, label_fi_all_count, "label_fi_all_count");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, label717, "label717");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, label_fi_with_source_count, "label_fi_with_source_count");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, label719, "label719");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, label913, "label913");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, viewport29, "viewport29");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, hbox234, "hbox234");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, label_dl_running_count, "label_dl_running_count");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, label910, "label910");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, label708, "label708");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, label_dl_active_count, "label_dl_active_count");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, label710, "label710");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, label_dl_aqueued_count, "label_dl_aqueued_count");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, label712, "label712");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, label909, "label909");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, viewport28, "viewport28");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, hbox212, "hbox212");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, label_dl_queue_count, "label_dl_queue_count");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, label586, "label586");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, label_dl_qalive_count, "label_dl_qalive_count");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, label588, "label588");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, label_dl_pqueued_count, "label_dl_pqueued_count");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, label714, "label714");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, label1026, "label1026");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, togglebutton_queue_freeze, "togglebutton_queue_freeze");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, alignment137, "alignment137");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, table110, "table110");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, vbox_queue_thaw, "vbox_queue_thaw");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, hbox9334, "hbox9334");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, image1798, "image1798");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, label996, "label996");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, vbox_queue_freeze, "vbox_queue_freeze");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, hbox9335, "hbox9335");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, image1797, "image1797");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, label995, "label995");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, button_downloads_clear_completed, "button_downloads_clear_completed");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, alignment150, "alignment150");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, hbox9355, "hbox9355");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, image2295, "image2295");
  GLADE_HOOKUP_OBJECT (main_window_downloads_tab, label1084, "label1084");
  GLADE_HOOKUP_OBJECT_NO_REF (main_window_downloads_tab, tooltips, "tooltips");

  return main_window_downloads_tab;
}

GtkWidget*
create_dlg_faq (void)
{
  GtkWidget *dlg_faq;
  GdkPixbuf *dlg_faq_icon_pixbuf;
  GtkWidget *scrolledwindow80;
  GtkWidget *textview_faq;

  dlg_faq = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_widget_set_name (dlg_faq, "dlg_faq");
  gtk_window_set_position (GTK_WINDOW (dlg_faq), GTK_WIN_POS_MOUSE);
  gtk_window_set_default_size (GTK_WINDOW (dlg_faq), 600, 400);
  dlg_faq_icon_pixbuf = create_pixbuf ("icon.48x48.xpm");
  if (dlg_faq_icon_pixbuf)
    {
      gtk_window_set_icon (GTK_WINDOW (dlg_faq), dlg_faq_icon_pixbuf);
      g_object_unref (dlg_faq_icon_pixbuf);
    }

  scrolledwindow80 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow80, "scrolledwindow80");
  gtk_widget_show (scrolledwindow80);
  gtk_container_add (GTK_CONTAINER (dlg_faq), scrolledwindow80);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow80), GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS);

  textview_faq = gtk_text_view_new ();
  gtk_widget_set_name (textview_faq, "textview_faq");
  gtk_widget_show (textview_faq);
  gtk_container_add (GTK_CONTAINER (scrolledwindow80), textview_faq);
  gtk_text_view_set_editable (GTK_TEXT_VIEW (textview_faq), FALSE);
  gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (textview_faq), GTK_WRAP_WORD);
  gtk_text_view_set_left_margin (GTK_TEXT_VIEW (textview_faq), 4);
  gtk_text_view_set_right_margin (GTK_TEXT_VIEW (textview_faq), 4);

  g_signal_connect ((gpointer) dlg_faq, "delete_event",
                    G_CALLBACK (on_dlg_faq_delete_event),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (dlg_faq, dlg_faq, "dlg_faq");
  GLADE_HOOKUP_OBJECT (dlg_faq, scrolledwindow80, "scrolledwindow80");
  GLADE_HOOKUP_OBJECT (dlg_faq, textview_faq, "textview_faq");

  gtk_widget_grab_focus (textview_faq);
  return dlg_faq;
}

GtkWidget*
create_dlg_ancient (void)
{
  GtkWidget *dlg_ancient;
  GdkPixbuf *dlg_ancient_icon_pixbuf;
  GtkWidget *scrolledwindow81;
  GtkWidget *textview_ancient;

  dlg_ancient = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_widget_set_name (dlg_ancient, "dlg_ancient");
  gtk_window_set_position (GTK_WINDOW (dlg_ancient), GTK_WIN_POS_MOUSE);
  gtk_window_set_default_size (GTK_WINDOW (dlg_ancient), 320, 240);
  dlg_ancient_icon_pixbuf = create_pixbuf ("icon.48x48.xpm");
  if (dlg_ancient_icon_pixbuf)
    {
      gtk_window_set_icon (GTK_WINDOW (dlg_ancient), dlg_ancient_icon_pixbuf);
      g_object_unref (dlg_ancient_icon_pixbuf);
    }

  scrolledwindow81 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow81, "scrolledwindow81");
  gtk_widget_show (scrolledwindow81);
  gtk_container_add (GTK_CONTAINER (dlg_ancient), scrolledwindow81);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow81), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);

  textview_ancient = gtk_text_view_new ();
  gtk_widget_set_name (textview_ancient, "textview_ancient");
  gtk_widget_show (textview_ancient);
  gtk_container_add (GTK_CONTAINER (scrolledwindow81), textview_ancient);
  gtk_text_view_set_editable (GTK_TEXT_VIEW (textview_ancient), FALSE);
  gtk_text_view_set_accepts_tab (GTK_TEXT_VIEW (textview_ancient), FALSE);
  gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (textview_ancient), GTK_WRAP_WORD);
  gtk_text_view_set_cursor_visible (GTK_TEXT_VIEW (textview_ancient), FALSE);
  gtk_text_view_set_left_margin (GTK_TEXT_VIEW (textview_ancient), 4);
  gtk_text_view_set_right_margin (GTK_TEXT_VIEW (textview_ancient), 4);

  g_signal_connect ((gpointer) dlg_ancient, "delete_event",
                    G_CALLBACK (on_dlg_ancient_delete_event),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (dlg_ancient, dlg_ancient, "dlg_ancient");
  GLADE_HOOKUP_OBJECT (dlg_ancient, scrolledwindow81, "scrolledwindow81");
  GLADE_HOOKUP_OBJECT (dlg_ancient, textview_ancient, "textview_ancient");

  gtk_widget_grab_focus (textview_ancient);
  return dlg_ancient;
}

GtkWidget*
create_popup_sources (void)
{
  GtkWidget *popup_sources;
  GtkWidget *popup_sources_start_now;
  GtkWidget *image2278;
  GtkWidget *popup_sources_pause;
  GtkWidget *image2279;
  GtkWidget *popup_sources_resume;
  GtkWidget *image2280;
  GtkWidget *popup_sources_queue;
  GtkWidget *image2281;
  GtkWidget *popup_sources_forget;
  GtkWidget *image2282;
  GtkWidget *separator34;
  GtkWidget *popup_sources_copy_url;
  GtkWidget *image2283;
  GtkWidget *popup_sources_browse_host;
  GtkWidget *image2284;
  GtkWidget *popup_sources_connect;
  GtkWidget *image2285;
  GtkWidget *popup_sources_push;
  GtkWidget *image2286;
  GtkWidget *separator31;
  GtkWidget *popup_sources_config_cols;
  GtkWidget *image2287;

  popup_sources = gtk_menu_new ();
  gtk_widget_set_name (popup_sources, "popup_sources");

  popup_sources_start_now = gtk_image_menu_item_new_with_mnemonic (_("Start now"));
  gtk_widget_set_name (popup_sources_start_now, "popup_sources_start_now");
  gtk_widget_show (popup_sources_start_now);
  gtk_container_add (GTK_CONTAINER (popup_sources), popup_sources_start_now);

  image2278 = gtk_image_new_from_stock ("gtk-connect", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image2278, "image2278");
  gtk_widget_show (image2278);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (popup_sources_start_now), image2278);

  popup_sources_pause = gtk_image_menu_item_new_with_mnemonic (_("Pause"));
  gtk_widget_set_name (popup_sources_pause, "popup_sources_pause");
  gtk_widget_show (popup_sources_pause);
  gtk_container_add (GTK_CONTAINER (popup_sources), popup_sources_pause);

  image2279 = gtk_image_new_from_stock ("gtk-media-pause", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image2279, "image2279");
  gtk_widget_show (image2279);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (popup_sources_pause), image2279);

  popup_sources_resume = gtk_image_menu_item_new_with_mnemonic (_("Resume"));
  gtk_widget_set_name (popup_sources_resume, "popup_sources_resume");
  gtk_widget_show (popup_sources_resume);
  gtk_container_add (GTK_CONTAINER (popup_sources), popup_sources_resume);

  image2280 = gtk_image_new_from_stock ("gtk-redo", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image2280, "image2280");
  gtk_widget_show (image2280);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (popup_sources_resume), image2280);

  popup_sources_queue = gtk_image_menu_item_new_with_mnemonic (_("Move back to queue"));
  gtk_widget_set_name (popup_sources_queue, "popup_sources_queue");
  gtk_widget_show (popup_sources_queue);
  gtk_container_add (GTK_CONTAINER (popup_sources), popup_sources_queue);

  image2281 = gtk_image_new_from_stock ("gtk-disconnect", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image2281, "image2281");
  gtk_widget_show (image2281);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (popup_sources_queue), image2281);

  popup_sources_forget = gtk_image_menu_item_new_with_mnemonic (_("Forget"));
  gtk_widget_set_name (popup_sources_forget, "popup_sources_forget");
  gtk_widget_show (popup_sources_forget);
  gtk_container_add (GTK_CONTAINER (popup_sources), popup_sources_forget);

  image2282 = gtk_image_new_from_stock ("gtk-stop", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image2282, "image2282");
  gtk_widget_show (image2282);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (popup_sources_forget), image2282);

  separator34 = gtk_separator_menu_item_new ();
  gtk_widget_set_name (separator34, "separator34");
  gtk_widget_show (separator34);
  gtk_container_add (GTK_CONTAINER (popup_sources), separator34);
  gtk_widget_set_sensitive (separator34, FALSE);

  popup_sources_copy_url = gtk_image_menu_item_new_with_mnemonic (_("Copy URL to clipboard"));
  gtk_widget_set_name (popup_sources_copy_url, "popup_sources_copy_url");
  gtk_widget_show (popup_sources_copy_url);
  gtk_container_add (GTK_CONTAINER (popup_sources), popup_sources_copy_url);

  image2283 = gtk_image_new_from_stock ("gtk-copy", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image2283, "image2283");
  gtk_widget_show (image2283);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (popup_sources_copy_url), image2283);

  popup_sources_browse_host = gtk_image_menu_item_new_with_mnemonic (_("Browse host"));
  gtk_widget_set_name (popup_sources_browse_host, "popup_sources_browse_host");
  gtk_widget_show (popup_sources_browse_host);
  gtk_container_add (GTK_CONTAINER (popup_sources), popup_sources_browse_host);

  image2284 = gtk_image_new_from_stock ("gtk-index", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image2284, "image2284");
  gtk_widget_show (image2284);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (popup_sources_browse_host), image2284);

  popup_sources_connect = gtk_image_menu_item_new_with_mnemonic (_("Connect to host"));
  gtk_widget_set_name (popup_sources_connect, "popup_sources_connect");
  gtk_widget_show (popup_sources_connect);
  gtk_container_add (GTK_CONTAINER (popup_sources), popup_sources_connect);

  image2285 = gtk_image_new_from_stock ("gtk-network", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image2285, "image2285");
  gtk_widget_show (image2285);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (popup_sources_connect), image2285);

  popup_sources_push = gtk_image_menu_item_new_with_mnemonic (_("Force push mode"));
  gtk_widget_set_name (popup_sources_push, "popup_sources_push");
  gtk_widget_show (popup_sources_push);
  gtk_container_add (GTK_CONTAINER (popup_sources), popup_sources_push);

  image2286 = create_pixmap (popup_sources, "go_back.xpm");
  gtk_widget_set_name (image2286, "image2286");
  gtk_widget_show (image2286);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (popup_sources_push), image2286);

  separator31 = gtk_separator_menu_item_new ();
  gtk_widget_set_name (separator31, "separator31");
  gtk_widget_show (separator31);
  gtk_container_add (GTK_CONTAINER (popup_sources), separator31);
  gtk_widget_set_sensitive (separator31, FALSE);

  popup_sources_config_cols = gtk_image_menu_item_new_with_mnemonic (_("Configure columns"));
  gtk_widget_set_name (popup_sources_config_cols, "popup_sources_config_cols");
  gtk_widget_show (popup_sources_config_cols);
  gtk_container_add (GTK_CONTAINER (popup_sources), popup_sources_config_cols);

  image2287 = gtk_image_new_from_stock ("gtk-preferences", GTK_ICON_SIZE_MENU);
  gtk_widget_set_name (image2287, "image2287");
  gtk_widget_show (image2287);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (popup_sources_config_cols), image2287);

  g_signal_connect ((gpointer) popup_sources_start_now, "activate",
                    G_CALLBACK (on_popup_sources_start_now_activate),
                    NULL);
  g_signal_connect ((gpointer) popup_sources_pause, "activate",
                    G_CALLBACK (on_popup_sources_pause_activate),
                    NULL);
  g_signal_connect ((gpointer) popup_sources_resume, "activate",
                    G_CALLBACK (on_popup_sources_resume_activate),
                    NULL);
  g_signal_connect ((gpointer) popup_sources_queue, "activate",
                    G_CALLBACK (on_popup_sources_queue_activate),
                    NULL);
  g_signal_connect ((gpointer) popup_sources_forget, "activate",
                    G_CALLBACK (on_popup_sources_forget_activate),
                    NULL);
  g_signal_connect ((gpointer) popup_sources_copy_url, "activate",
                    G_CALLBACK (on_popup_sources_copy_url_activate),
                    NULL);
  g_signal_connect ((gpointer) popup_sources_browse_host, "activate",
                    G_CALLBACK (on_popup_sources_browse_host_activate),
                    NULL);
  g_signal_connect ((gpointer) popup_sources_connect, "activate",
                    G_CALLBACK (on_popup_sources_connect_activate),
                    NULL);
  g_signal_connect ((gpointer) popup_sources_push, "activate",
                    G_CALLBACK (on_popup_sources_push_activate),
                    NULL);
  g_signal_connect ((gpointer) popup_sources_config_cols, "activate",
                    G_CALLBACK (on_popup_sources_config_cols_activate),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (popup_sources, popup_sources, "popup_sources");
  GLADE_HOOKUP_OBJECT (popup_sources, popup_sources_start_now, "popup_sources_start_now");
  GLADE_HOOKUP_OBJECT (popup_sources, image2278, "image2278");
  GLADE_HOOKUP_OBJECT (popup_sources, popup_sources_pause, "popup_sources_pause");
  GLADE_HOOKUP_OBJECT (popup_sources, image2279, "image2279");
  GLADE_HOOKUP_OBJECT (popup_sources, popup_sources_resume, "popup_sources_resume");
  GLADE_HOOKUP_OBJECT (popup_sources, image2280, "image2280");
  GLADE_HOOKUP_OBJECT (popup_sources, popup_sources_queue, "popup_sources_queue");
  GLADE_HOOKUP_OBJECT (popup_sources, image2281, "image2281");
  GLADE_HOOKUP_OBJECT (popup_sources, popup_sources_forget, "popup_sources_forget");
  GLADE_HOOKUP_OBJECT (popup_sources, image2282, "image2282");
  GLADE_HOOKUP_OBJECT (popup_sources, separator34, "separator34");
  GLADE_HOOKUP_OBJECT (popup_sources, popup_sources_copy_url, "popup_sources_copy_url");
  GLADE_HOOKUP_OBJECT (popup_sources, image2283, "image2283");
  GLADE_HOOKUP_OBJECT (popup_sources, popup_sources_browse_host, "popup_sources_browse_host");
  GLADE_HOOKUP_OBJECT (popup_sources, image2284, "image2284");
  GLADE_HOOKUP_OBJECT (popup_sources, popup_sources_connect, "popup_sources_connect");
  GLADE_HOOKUP_OBJECT (popup_sources, image2285, "image2285");
  GLADE_HOOKUP_OBJECT (popup_sources, popup_sources_push, "popup_sources_push");
  GLADE_HOOKUP_OBJECT (popup_sources, image2286, "image2286");
  GLADE_HOOKUP_OBJECT (popup_sources, separator31, "separator31");
  GLADE_HOOKUP_OBJECT (popup_sources, popup_sources_config_cols, "popup_sources_config_cols");
  GLADE_HOOKUP_OBJECT (popup_sources, image2287, "image2287");

  return popup_sources;
}

GtkWidget*
create_popup_tray (void)
{
  GtkWidget *popup_tray;
  GtkWidget *popup_tray_preferences;
  GtkWidget *popup_tray_quit;
  GtkAccelGroup *accel_group;

  accel_group = gtk_accel_group_new ();

  popup_tray = gtk_menu_new ();
  gtk_widget_set_name (popup_tray, "popup_tray");

  popup_tray_preferences = gtk_image_menu_item_new_from_stock ("gtk-preferences", accel_group);
  gtk_widget_set_name (popup_tray_preferences, "popup_tray_preferences");
  gtk_widget_show (popup_tray_preferences);
  gtk_container_add (GTK_CONTAINER (popup_tray), popup_tray_preferences);

  popup_tray_quit = gtk_image_menu_item_new_from_stock ("gtk-quit", accel_group);
  gtk_widget_set_name (popup_tray_quit, "popup_tray_quit");
  gtk_widget_show (popup_tray_quit);
  gtk_container_add (GTK_CONTAINER (popup_tray), popup_tray_quit);

  g_signal_connect ((gpointer) popup_tray_preferences, "activate",
                    G_CALLBACK (on_popup_tray_preferences_activate),
                    NULL);
  g_signal_connect ((gpointer) popup_tray_quit, "activate",
                    G_CALLBACK (on_popup_tray_quit_activate),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (popup_tray, popup_tray, "popup_tray");
  GLADE_HOOKUP_OBJECT (popup_tray, popup_tray_preferences, "popup_tray_preferences");
  GLADE_HOOKUP_OBJECT (popup_tray, popup_tray_quit, "popup_tray_quit");

  gtk_menu_set_accel_group (GTK_MENU (popup_tray), accel_group);

  return popup_tray;
}

GtkWidget*
create_dlg_glossary (void)
{
  GtkWidget *dlg_glossary;
  GdkPixbuf *dlg_glossary_icon_pixbuf;
  GtkWidget *scrolledwindow902;
  GtkWidget *textview_glossary;

  dlg_glossary = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_widget_set_name (dlg_glossary, "dlg_glossary");
  gtk_window_set_position (GTK_WINDOW (dlg_glossary), GTK_WIN_POS_MOUSE);
  gtk_window_set_default_size (GTK_WINDOW (dlg_glossary), 600, 400);
  dlg_glossary_icon_pixbuf = create_pixbuf ("icon.48x48.xpm");
  if (dlg_glossary_icon_pixbuf)
    {
      gtk_window_set_icon (GTK_WINDOW (dlg_glossary), dlg_glossary_icon_pixbuf);
      g_object_unref (dlg_glossary_icon_pixbuf);
    }

  scrolledwindow902 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_set_name (scrolledwindow902, "scrolledwindow902");
  gtk_widget_show (scrolledwindow902);
  gtk_container_add (GTK_CONTAINER (dlg_glossary), scrolledwindow902);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow902), GTK_POLICY_AUTOMATIC, GTK_POLICY_ALWAYS);

  textview_glossary = gtk_text_view_new ();
  gtk_widget_set_name (textview_glossary, "textview_glossary");
  gtk_widget_show (textview_glossary);
  gtk_container_add (GTK_CONTAINER (scrolledwindow902), textview_glossary);
  gtk_text_view_set_editable (GTK_TEXT_VIEW (textview_glossary), FALSE);
  gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (textview_glossary), GTK_WRAP_WORD);
  gtk_text_view_set_left_margin (GTK_TEXT_VIEW (textview_glossary), 4);
  gtk_text_view_set_right_margin (GTK_TEXT_VIEW (textview_glossary), 4);

  g_signal_connect ((gpointer) dlg_glossary, "delete_event",
                    G_CALLBACK (on_dlg_glossary_delete_event),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (dlg_glossary, dlg_glossary, "dlg_glossary");
  GLADE_HOOKUP_OBJECT (dlg_glossary, scrolledwindow902, "scrolledwindow902");
  GLADE_HOOKUP_OBJECT (dlg_glossary, textview_glossary, "textview_glossary");

  gtk_widget_grab_focus (textview_glossary);
  return dlg_glossary;
}

